const path = require('path')

const aliases = require('./tools/createAliases')

module.exports = {
  extends: [
    'airbnb-typescript',
    'prettier',
    'prettier/react',
    'plugin:wdio/recommended',
  ],
  parser: '@typescript-eslint/parser',
  parserOptions: {
    project: './tsconfig.json',
    extraFileExtensions: ['.html'],
  },
  plugins: [
    'jest',
    'wdio',
    'react-hooks',
    '@typescript-eslint',
    'eslint-plugin-html',
  ],
  globals: {
    AssertionError: true,
    safari: true,
    __DEV__: true,
    __PROD__: true,
    __DISABLE_ADS__: true,
  },
  env: {
    'jest/globals': true,
    browser: true,
  },
  settings: {
    'import/extensions': ['.js', '.jsx', '.ts', '.tsx', 'html'],
    'import/resolver': {
      alias: {
        map: Object.keys(aliases).map((key) => [
          key,
          path.resolve(__dirname, aliases[key]),
        ]),
        extensions: ['.js', '.jsx', '.ts', '.tsx', 'html'],
      },
    },
  },
  // RULES
  rules: {
    // CONSOLE
    'no-console': [
      'warn',
      {
        allow: ['warn', 'error'],
      },
    ],
    // REACT
    'react-hooks/rules-of-hooks': 'error',
    'react/jsx-filename-extension': [
      1,
      {
        extensions: ['.js', '.jsx', '.tsx', '.html'],
      },
    ],
    'react/jsx-props-no-spreading': 'off',
    'react/jsx-one-expression-per-line': 'off',
    'react/no-array-index-key': 1,
    'react/require-default-props': [
      2,
      {
        ignoreFunctionalComponents: true,
      },
    ],
    'react/forbid-prop-types': 'off',
    'react/no-did-update-set-state': 'off',
    // ACCESSIBILITY
    'jsx-a11y/no-autofocus': 1,
    'jsx-a11y/control-has-associated-label': 1,
    'jsx-a11y/media-has-caption': 1,
    'jsx-a11y/interactive-supports-focus': 1,
    'jsx-a11y/click-events-have-key-events': 1,
    'jsx-a11y/role-has-required-aria-props': 1,
    // IMPORTS
    'global-require': 1,
    'import/no-cycle': 1,
    'import/no-dynamic-require': 1,
    'import/no-named-as-default': 0,
    'import/no-named-as-default-member': 0,
    'import/order': [
      'error',
      {
        'newlines-between': 'always',
        groups: [
          'builtin',
          'external',
          'internal',
          'index',
          'parent',
          'sibling',
        ],
      },
    ],
    'import/no-extraneous-dependencies': [
      'error',
      {
        devDependencies: [
          '**/*.test.ts',
          '**/*.test.tsx',
          '**/*.test.js',
          '**/*.test.jsx',
          '**/tools/**',
          '**/__tests__/**',
          '**/*.stories.tsx',
          '**/*.stories.js',
          'webpack.config.js',
          'playwright.config.ts',
        ],
        optionalDependencies: false,
        peerDependencies: false,
      },
    ],
    'import/prefer-default-export': 0,
    // BRANCHES (IF / ELSE / SWITCH)
    curly: 'error',
    'brace-style': ['error', '1tbs'],
    // "default-param-last": 2,
    // OPERATORS (+ / - / ^ / | etc.)
    'no-bitwise': 'off',
    // VARIABLES
    'vars-on-top': 'error',
    'no-shadow': 'off',
    'no-underscore-dangle': [
      'error',
      {
        allow: [
          '__REDUX_DEVTOOLS_EXTENSION__',
          '__DEV__',
          '__observeInView__',
          'puzzle_data',
        ],
        allowAfterThis: true,
      },
    ],
    // FUNCTIONS
    'func-names': ['error', 'as-needed'],
    'no-param-reassign': [
      'error',
      {
        props: false,
      },
    ],
    'padding-line-between-statements': [
      'error',
      {
        blankLine: 'always',
        prev: [
          'multiline-const',
          'multiline-let',
          'multiline-var',
          'block-like',
          'if',
          'for',
          'try',
          'do',
          'while',
          'return',
        ],
        next: [
          'multiline-const',
          'multiline-let',
          'multiline-var',
          'block-like',
          'if',
          'for',
          'try',
          'do',
          'while',
          'return',
        ],
      },
    ],
    'consistent-return': 'off',
    'no-loop-func': 1,
    'require-await': 2,
    radix: 'off',
    // OBJECTS / CLASSES
    'grouped-accessor-pairs': 2,
    'no-prototype-builtins': 'off',
    // STRINGS
    'no-multi-str': 'error',
    // TYPESCRIPT OVERRIDES
    '@typescript-eslint/semi': 'off',
    '@typescript-eslint/quotes': 'off',
    '@typescript-eslint/indent': 'off',
    '@typescript-eslint/naming-convention': 'off',
    '@typescript-eslint/no-shadow': 'off',
    '@typescript-eslint/no-unused-vars': 'off',
    '@typescript-eslint/no-unused-expressions': 'off',
    '@typescript-eslint/no-extra-semi': 'off',
    '@typescript-eslint/space-before-function-paren': 'off',
    '@typescript-eslint/return-await': 'off',
    '@typescript-eslint/no-loop-func': 'off',
    '@typescript-eslint/no-implied-eval': 'off',
  },
  // OVERRIDES
  overrides: [
    {
      files: ['*.test.js', '*.spec.js'],
      rules: {
        'react/button-has-type': 0,
      },
    },
    {
      files: ['*.stories.js'],
      rules: {
        'react/prop-types': 0,
      },
    },
    {
      files: ['*.tsx'],
      rules: {
        'react/require-default-props': 'off',
      },
    },
  ],
}
