import React, { createContext, useContext } from 'react'

export const UserContext = createContext({
  userType: {},
  setUserType: () => {},
  hasLoaded: true,
})

export const UserProvider = ({ children, userType }) => (
  <UserContext.Provider value={{ userType, setUserType: () => {}, hasLoaded: true }}>
    {children}
  </UserContext.Provider>
)

export const useUser = () => useContext(UserContext)

export const withUser = (Component) => {
  const WithUser = (props) => {
    const user = useUser()

    return <Component user={user} {...props} />
  }

  return WithUser
}
