const path = require('path')
const autoprefixer = require('autoprefixer')
const correctURLs = require('../tools/pluginPostcssAssetUrls')
const aliases = require('../tools/createAliases')

module.exports = {
  core: {
    builder: 'webpack5',
  },
  stories: [
    './**/*.stories.@(js|mdx|tsx)',
    '../src/**/*.stories.@(js|mdx|tsx)',
  ],
  addons: [
    '@storybook/addon-essentials',
    '@storybook/addon-a11y',
    'storybook-addon-pseudo-states',
  ],
  staticDirs: ['../src/public'],
  webpackFinal: async (config, { configType }) => {
    config.resolve.alias = Object.keys(aliases).reduce((acc, key) => {
      acc[key] = path.resolve(__dirname, `../${aliases[key]}`)
      return acc
    }, {})
    config.resolve.alias['foundation'] = path.resolve(
      __dirname,
      './__mocks__/foundation.js',
    )
    config.resolve.alias['user'] = path.resolve(
      __dirname,
      './__mocks__/user.js',
    )
    config.resolve.alias['child_process'] = path.resolve(
      __dirname,
      './__mocks__/child_process.js',
    )
    config.resolve.fallback = {
      http: false,
      https: false,
      path: false,
      os: false,
      querystring: false,
    }
    config.module.rules.push({
      test: /\.s[ac]ss$/i,
      use: [
        'style-loader',
        {
          loader: 'string-replace-loader',
          options: {
            search: '/puzzles/public',
            replace: '',
            flags: 'g',
          },
        },
        {
          loader: 'css-loader',
          options: {
            url: false,
            modules: {
              // only load as a CSS module if file name contains .module
              auto: true,
              // determines the classname used for CSS module classes
              localIdentName: '[name]_[local]__[hash:base64:5]',
            },
          },
        },
        {
          loader: 'postcss-loader',
          options: {
            postcssOptions: {
              plugins: [autoprefixer, correctURLs],
            },
          },
        },
        // Compiles Sass to CSS
        'sass-loader',
      ],
    })

    config.module.rules.push({
      test: /\.(css|svg)$/,
      use: [
        {
          loader: 'string-replace-loader',
          options: {
            search: '/puzzles/public',
            replace: '',
            flags: 'g',
          },
        },
      ],
    })

    return config
  },
}
