import { test, expect } from '@playwright/test'
import type { Response } from '@playwright/test'

test.describe('Fastly caching', () => {
  // Don't run caching tests against local environments
  test.skip(() => !process.env.CI)

  async function assertHeaderWithPromise(
    requestPromise: Promise<Response>,
    values: string[],
  ) {
    const response = await requestPromise
    const headers = await response.allHeaders()
    await expect(['HIT', 'MISS'].includes(headers['x-cache'])).toBe(
      true,
    )
  }

  test('Connections', async ({ page }) => {
    const url = '/games/connections'

    // First request can HIT or MISS
    const firstRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(firstRequest, ['HIT', 'MISS'])

    // Second request must HIT
    const secondRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(secondRequest, ['HIT'])
  })

  test('Wordle', async ({ page }) => {
    const url = '/games/wordle/index.html'

    // First request can HIT or MISS
    const firstRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(firstRequest, ['HIT', 'MISS'])

    // Second request must HIT
    const secondRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(secondRequest, ['HIT'])
  })

  test('Tiles (Canonical)', async ({ page }) => {
    const url = '/puzzles/tiles'

    // First request can HIT or MISS
    const firstRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(firstRequest, ['HIT', 'MISS'])

    // Second request must HIT
    const secondRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(secondRequest, ['HIT'])
  })

  test('Tiles (Pallette)', async ({ page }) => {
    const url = '/puzzles/tiles/palette/paris'

    // First request can HIT or MISS
    const firstRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(firstRequest, ['HIT', 'MISS'])

    // Second request must HIT
    const secondRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(secondRequest, ['HIT'])
  })

  test('Letter Boxed', async ({ page }) => {
    const url = '/puzzles/letter-boxed'

    // First request can HIT or MISS
    const firstRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(firstRequest, ['HIT', 'MISS'])

    // Second request must HIT
    const secondRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(secondRequest, ['HIT'])
  })

  test('Sudoku (Canonical)', async ({ page }) => {
    const url = '/puzzles/sudoku'

    // First request can HIT or MISS
    const firstRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(firstRequest, ['HIT', 'MISS'])

    // Second request must HIT
    const secondRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(secondRequest, ['HIT'])
  })

  test('Sudoku (Easy)', async ({ page }) => {
    const url = '/puzzles/sudoku/easy'

    // First request can HIT or MISS
    const firstRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(firstRequest, ['HIT', 'MISS'])

    // Second request must HIT
    const secondRequest = page.waitForResponse(url)
    await page.goto(url)
    await assertHeaderWithPromise(secondRequest, ['HIT'])
  })
})
