import { test, expect } from '@playwright/test'
import type { Page } from '@playwright/test'

test.describe.configure({ mode: 'serial' })

let page: Page

test.beforeAll(async ({ browser }) => {
  page = await browser.newPage()
})

test.afterAll(async () => {
  await page.close()
})

test.describe('Connections: Smoke Test', () => {
  // Connections has CORS issues in preview envs, so only run in staging.
  test.skip(() => !process.env.IS_STAGING && !!process.env.CI)

  test('the page loads without error', async () => {
    await page.goto('/games/connections')
    await expect(page).toHaveTitle(/Connections/)
  })

  test('the welcome moment has loaded', async () => {
    await page.getByRole('button', { name: 'Play' }).click()
  })

  test('the how to play modal appears', async () => {
    await expect(
      page.getByRole('heading', { name: /how to play connections/i }),
    ).toBeVisible()
    await page.locator('#close-help').click()
  })
})
