import { test, expect } from '@playwright/test'
import type { Page } from '@playwright/test'

test.describe.configure({ mode: 'serial' })

let page: Page

test.beforeAll(async ({ browser }) => {
  page = await browser.newPage()
})

test.afterAll(async () => {
  await page.close()
})

test.describe('Hub: Smoke Test', () => {
  test('the page loads without error', async () => {
    await page.goto('/crosswords')
    await expect(page).toHaveTitle(/Crossword/)
  })

  test('the mini and promo cards have loaded', async () => {
    await expect(
      page.locator('[data-track-hub="The Mini"]'),
    ).toBeVisible()
    await expect(
      page.locator('[data-track-hub="The Crossword"]'),
    ).toBeVisible()
  })

  test('desktop: the promo card loads', async () => {
    await expect(
      page.locator('.hub-promo-card').first(),
    ).toBeVisible()
  })

  test('the game cards all load', async () => {
    await expect(
      page.locator('[data-track-hub="Spelling Bee"]'),
    ).toBeVisible()
    await expect(
      page.locator('[data-track-hub="Wordle"]'),
    ).toBeVisible()
    await expect(
      page.locator('[data-track-hub="Connections"]'),
    ).toBeVisible()
    await expect(
      page.locator('[data-track-hub="Letter Boxed"]'),
    ).toBeVisible()
    await expect(
      page.locator('[data-track-hub="Tiles"]'),
    ).toBeVisible()
    await expect(
      page.locator('[data-track-hub="Vertex"]'),
    ).toBeVisible()
    await expect(
      page.locator('[data-track-hub="Sudoku"]'),
    ).toBeVisible()
  })

  test('the featured article loads', async () => {
    await expect(
      page.getByRole('heading', { name: 'Featured Article' }),
    ).toBeVisible()
    await expect(
      page.locator('[data-track-hub="Featured Article"]'),
    ).toBeVisible()
  })

  test('the free puzzle cards load', async () => {
    await expect(
      page.getByRole('heading', { name: 'Free From Our Archive' }),
    ).toBeVisible()
    await expect(
      page.locator('[data-track-hub="monthly-bonus"]'),
    ).toHaveCount(4)
  })
})
