import { test, expect } from '@playwright/test'
import type { Page } from '@playwright/test'

test.describe.configure({ mode: 'serial' })

let page: Page

test.beforeAll(async ({ browser }) => {
  page = await browser.newPage()
})

test.afterAll(async () => {
  await page.close()
})

test.describe('Letter Boxed: Smoke Test', () => {
  test('the page loads without error', async () => {
    await page.goto('/puzzles/letter-boxed')
    await expect(page).toHaveTitle(/Letter Boxed/)
  })

  test('the welcome moment has loaded', async () => {
    await page
      .getByRole('button', { name: 'Play', exact: true })
      .click()
  })

  test('the game board is playable', async () => {
    await expect(page.locator('.lb-square-container')).toBeVisible()

    const answer = await page.evaluate(
      () => window.gameData.ourSolution[0],
    )
    await page.keyboard.type(answer)
    await page.keyboard.press('Enter')

    await expect(page.getByText(answer)).toBeTruthy()
  })
})
