import { test, expect } from '@playwright/test'
import type { Page } from '@playwright/test'

test.describe.configure({ mode: 'serial' })

let page: Page

test.beforeAll(async ({ browser }) => {
  page = await browser.newPage()
})

test.afterAll(async () => {
  await page.close()
})

test.describe('Spelling Bee: Smoke Test', () => {
  test('the page loads without error', async () => {
    await page.goto('/puzzles/spelling-bee')
    await expect(page).toHaveTitle(/Spelling Bee/)
  })

  test('the welcome moment has loaded', async () => {
    await page.getByRole('button', { name: 'Play' }).click()
  })

  test('the game board is playable', async () => {
    await expect(page.getByTestId('hive')).toBeVisible()

    const answer = await page.evaluate(
      () => window.gameData.today.answers[0],
    )
    await page.keyboard.type(answer)
    await page.keyboard.press('Enter')

    await expect(page.getByText(answer)).toBeTruthy()
  })
})
