import { test, expect } from '@playwright/test'
import type { Page } from '@playwright/test'

test.describe.configure({ mode: 'serial' })

let page: Page

test.beforeAll(async ({ browser }) => {
  page = await browser.newPage()
})

test.afterAll(async () => {
  await page.close()
})

test.describe('Wordle: Smoke Test', () => {
  test('the page loads without error', async () => {
    await page.goto('/games/wordle/index.html')
    await expect(page).toHaveTitle(/Wordle/)
  })

  test('the welcome moment has loaded', async () => {
    await page.getByTestId('Play').click()
  })

  test('mobile: ad interstitial shows', async () => {
    const isInterstitialShowing = await page
      .getByRole('dialog')
      .isVisible()

    if (isInterstitialShowing) {
      await page.getByRole('button', { name: /continue/i }).click()
    }
  })

  test('the how to play modal appears', async () => {
    await expect(
      page.getByRole('heading', { name: /how to play/i }),
    ).toBeVisible()
    await page.getByRole('button', { name: /close/i }).click()
  })

  test('the game board is playable', async () => {
    await page.keyboard.type('aarti')
    await page.keyboard.press('Enter')

    await expect(page.getByRole('img', { name: 'a' })).toBeTruthy()
  })
})
