const agent = require('@google-cloud/trace-agent')

const {
  CLOUD_TRACE_ENABLED,
  CLOUD_SERVICE_CONTEXT: serviceContext,
} = require('./constants')

const cloudTraceConfig = {
  // On/Off switch.
  enabled: CLOUD_TRACE_ENABLED,
  serviceContext,

  // Log levels: 0-disabled,1-error,2-warn,3-info,4-debug
  logLevel: 1,

  // A list of trace plugins to load. Each field's key in this object is the
  // name of the module to trace, and its value is the require-friendly path
  // to the plugin.
  // By default, all of the following plugins are loaded.
  // Specifying a different object for this field in the configuration passed
  // to the method that starts the trace agent will cause that object to be
  // merged with this one.
  // To disable a plugin in this list, you may override its path with a falsey
  // value. Disabling any of the default plugins may cause unwanted behavior,
  // so use caution.
  plugins: {},

  samplingRate: 0.5, // max 1 sample every 2 seconds

  // If paths are present in this array, then these paths will be ignored before
  // `samplingRate` based decisions are made. Paths must include a leading
  // forward slash and be of the form:
  //   /componentOne/componentTwo/...
  // Paths can additionally be classified by regex in which case any path matching
  // any provided regex will be ignored.
  // We ignore the health checker probes (/_ah/health) by default.
  ignoreUrls: ['/healthz', '/games-assets/*'],
}

// this needs to be called before any http request is handled
agent.start(cloudTraceConfig)
