import {
  AbraExposeFn,
  AbraGetVariantFn,
  UserEntitlement,
} from 'foundation'

import isPhone from './isPhone'

const AA_TEST_NAME = 'DFP_ConnectionsMobile_AA'
const AB_TEST_NAME = 'DFP_ConnectionsMobile'

const VARIANT_1 = '1_Variant'

const CONTROL = '0_Control'

interface AbraVariantChecks {
  getVariant: AbraGetVariantFn
  reportExposure: AbraExposeFn
}

export const isInVariant = ({
  getVariant,
  reportExposure,
}: AbraVariantChecks): boolean => {
  const aaVariant = getVariant(AA_TEST_NAME)
  if (aaVariant) {
    reportExposure(AA_TEST_NAME)
  }
  const abVariant = getVariant(AB_TEST_NAME)
  if (!abVariant) return false
  reportExposure(AB_TEST_NAME)
  return abVariant === VARIANT_1
}

export const isMobileWeb = () => {
  if (typeof window === 'undefined') return false

  return (
    isPhone() &&
    !!window.isMobileDevice &&
    !window.gamesAppPlatform &&
    !window.newsreaderAppPlatform
  )
}

interface InterstlCheckInputs {
  entitlement: UserEntitlement
  isGameFinished: boolean
  abraVariantChecks: AbraVariantChecks
}
export const canCheckForAdTest = ({
  entitlement,
  isGameFinished,
  abraVariantChecks,
}: InterstlCheckInputs): boolean => {
  const isNotCrosswordSub = !entitlement.includes('cr')
  return (
    isNotCrosswordSub &&
    isMobileWeb() &&
    !isGameFinished &&
    isInVariant(abraVariantChecks)
  )
}
