import React from 'react'
import { configureStore } from '@reduxjs/toolkit'
import { Story } from '@storybook/react'

import {
  withProvider,
  withUserProvider,
} from 'shared/storybook/helpers'

import useAnimation from '../../../shared/moments/components/stories/useAnimation'
import Welcome from '../Welcome'

const store = configureStore({ reducer: () => {} })

interface Props {
  today: Date
  editor: string
}

interface UserProps {
  hasXwd: boolean
  isLoggedIn: boolean
  entitlement: string
}

const defaultArgs = {
  hasXwd: false,
  isLoggedIn: false,
  today: new Date(),
  editor: 'Wyna Liu',
  entitlement: 'anon',
}

const StoryTemplate: Story<Props & UserProps> = ({
  today,
  editor,
}: Props) => (
  <Welcome
    today={today}
    editor={editor}
    isGameFinished={false}
    transitionFromWelcomeToGame={() => {}}
    transitionFromWelcomeToAd={() => {}}
  />
)

export const Anon = StoryTemplate.bind({})
Anon.args = { ...defaultArgs, hasXwd: false, isLoggedIn: false }

export const AnonSub = StoryTemplate.bind({})
AnonSub.args = {
  ...defaultArgs,
  hasXwd: true,
  isLoggedIn: false,
  entitlement: 'anon',
}

export const Regi = StoryTemplate.bind({})
Regi.args = {
  ...defaultArgs,
  hasXwd: false,
  isLoggedIn: true,
  entitlement: 'reg',
}

export const Sub = StoryTemplate.bind({})
Sub.args = {
  ...defaultArgs,
  hasXwd: true,
  isLoggedIn: true,
  entitlement: 'cr',
}

const hideControl = { table: { disable: true } }

export default {
  title: 'Connections/Moments/Welcome',

  argTypes: {
    hasXwd: hideControl,
    isLoggedIn: hideControl,
    entitlement: hideControl,
  },
  decorators: [
    (
      StoryComponent: Story,
      {
        args: { hasXwd, isLoggedIn, entitlement },
      }: {
        args: {
          hasXwd: boolean
          isLoggedIn: boolean
          entitlement: string
        }
      },
    ) => {
      useAnimation('storybook-welcome')

      return withUserProvider(
        withProvider(
          <div id="storybook-welcome">
            <StoryComponent />
          </div>,
          store,
        ),
        { hasXwd, isLoggedIn, entitlement },
      )
    },
  ],
}
