import { loadSolution } from './api'

const SOLUTION_REJECTS_DATE = new Date('2022-10-02')
const SUCCESS_DATE = new Date('2022-01-02')

jest.mock('foundation', () => {
  return {
    xhr: {
      get: (url: string) => {
        if (
          url ===
          `domain.com/svc/connections/v2/${new Date(
            '2022-01-02',
          ).toLocaleDateString('en-CA')}.json`
        ) {
          return Promise.resolve({
            status: 200,
            id: 209,
            print_date: '2024-01-05',
            editor: 'Wyna Liu',
            categories: [],
          })
        }

        return Promise.reject(new Error('any error'))
      },
    },
    env: {
      name: 'foobar',
      edge: 'domain.com',
    },
  }
})

describe('loadSolution', () => {
  it('if backend solution fetching succeeds, returns expected response', async () => {
    const data = await loadSolution({
      today: SUCCESS_DATE,
    })

    expect(data).toEqual({
      status: 200,
      id: 209,
      print_date: '2024-01-05',
      editor: 'Wyna Liu',
      categories: [],
    })
  })

  it('if backend solution fetching fails, returns expected response', () => {
    const rejectCall = loadSolution({ today: SOLUTION_REJECTS_DATE })
    // test that 'any error' from mock as well as additional message string from api call
    expect(rejectCall).rejects.toThrowError(
      `message: any error, today: ${SOLUTION_REJECTS_DATE}`,
    )
  })
})
