import { format } from 'date-fns'

import { env, xhr } from 'foundation'

import { PuzzleResponseError, PuzzleResponseSuccess } from './types'

const SOLUTION_ENDPOINT = (d: Date) =>
  `${env.edge}/svc/connections/v2/${format(d, 'yyyy-MM-dd')}.json`

export const loadSolution = ({ today }: { today: Date }) => {
  return xhr
    .get<PuzzleResponseSuccess | PuzzleResponseError>(
      SOLUTION_ENDPOINT(today),
      {
        withStatus: true,
      },
    )
    .catch((e) => {
      const additionalInfo = [
        `message: ${e.message}`,
        `today: ${today}`,
        `new Date(): ${new Date()}`,
        `new Date().getTimezoneOffset(): ${new Date().getTimezoneOffset()}`,
        `Intl.DateTimeFormat().resolvedOptions().timeZone: ${
          Intl.DateTimeFormat().resolvedOptions().timeZone
        }`,
      ]
      e.message = additionalInfo.join(', ')
      throw e
    })
}
