import React from 'react'

import { useTheme } from '../Theme'

import styles from './ActionButton.module.scss'
import { ButtonSize } from './types'

export interface ButtonPropsInitial
  extends React.DetailedHTMLProps<
      React.ButtonHTMLAttributes<HTMLButtonElement>,
      HTMLButtonElement
    >,
    React.AriaAttributes {
  size?: ButtonSize
  isFilled?: boolean
  isSubmit?: boolean
}

type ButtonProps = Omit<ButtonPropsInitial, 'type'>

function styleForSize(size: ButtonSize): string {
  switch (size) {
    case ButtonSize.X_SMALL:
      return styles.xSmall
    case ButtonSize.SMALL:
      return styles.small
    case ButtonSize.MEDIUM:
      return styles.medium
    case ButtonSize.LARGE:
      return styles.large
    default:
      return ''
  }
}

const ActionButton: React.FC<ButtonProps> = (btnProps) => {
  const { children, size, isSubmit, disabled, isFilled, ...props } =
    btnProps
  const theme = useTheme()

  let colors = {
    backgroundColor: theme.BUTTONS.ACTIONS.BACKGROUND,
    color: theme.BUTTONS.ACTIONS.COLOR,
    borderColor: theme.BUTTONS.ACTIONS.BORDER,
  }

  if (disabled) {
    colors = {
      backgroundColor: theme.BUTTONS.DISABLED.BACKGROUND,
      color: theme.BUTTONS.DISABLED.COLOR,
      borderColor: theme.BUTTONS.DISABLED.COLOR,
    }
  }

  if (isFilled && !disabled) {
    colors = {
      backgroundColor: theme.BUTTONS.CTA.BACKGROUND,
      color: theme.BUTTONS.CTA.COLOR,
      borderColor: theme.BUTTONS.ACTIONS.BACKGROUND,
    }
  }

  return (
    <button
      disabled={disabled}
      type={isSubmit ? 'submit' : 'button'}
      style={colors}
      {...props}
      className={`${styles.button} ${
        (size && styleForSize(size)) || ''
      }`}
    >
      {children}
    </button>
  )
}

export default ActionButton
