import React from 'react'
import { Story } from '@storybook/react'

import { ThemeProvider } from '../../Theme'
import ActionButtonComponent from '../ActionButton'
import { ButtonSize } from '../types'

interface Props {
  disabled: boolean
  content: string
  size?: ButtonSize | 'unset'
  fill: boolean
}

const ActionButtonTemplate: Story<Props> = ({
  disabled = false,
  content = 'Hello',
  size,
  fill = false,
}: Props) => {
  return (
    <ThemeProvider>
      <ActionButtonComponent
        disabled={disabled}
        size={size === 'unset' ? undefined : size}
        isFilled={fill ? true : undefined}
      >
        {content}
      </ActionButtonComponent>
    </ThemeProvider>
  )
}

export const ActionButton = ActionButtonTemplate.bind({})
ActionButton.args = {
  content: 'Hello',
  disabled: false,
  size: undefined,
  fill: false,
}

export default {
  component: ActionButton,
  title: 'Connections/Components/Action Button',
  argTypes: {
    size: {
      options: ['unset', ButtonSize.MEDIUM, ButtonSize.LARGE],
      control: {
        type: 'select',
      },
    },
  },
}
