import React, { SetStateAction } from 'react'

import { trackClick } from 'foundation'

import { MAX_MISTAKES } from '../../constants'
import {
  saveCardOrder,
  saveDeselectedCards,
} from '../../localstorage/localstorage'
import { AnimationEnum, Board, CardsAnimation } from '../../types'
import ActionButton from '../ActionButton/ActionButton'
import { ButtonSize } from '../ActionButton/types'
import { deselectAllCards } from '../Board/helpers'
import { getNthDayOfGame } from '../sharedHelpers'

import { shuffleCards } from './helpers'

interface Props {
  board: Board
  onSubmit: () => void
  updateBoard: (b: Board) => void
  isRecentIncorrect: boolean
  isDisabled: boolean
  cardsPerCategory: number
  setAnimation: (value: SetStateAction<CardsAnimation>) => void
  today: Date
}

export default ({
  board,
  updateBoard,
  onSubmit,
  isRecentIncorrect,
  isDisabled,
  cardsPerCategory,
  setAnimation,
  today,
}: Props) => {
  const solvedCategories = board.categories.filter((c) => c.solved)
  const correctNumberOfCardsSelected =
    board.cards.filter((c) => c.selected).length === cardsPerCategory

  const playerHasMistakesLeft =
    board.guesses.filter((g) => !g.correct).length < MAX_MISTAKES

  const enableSubmit =
    !isDisabled &&
    !isRecentIncorrect &&
    correctNumberOfCardsSelected &&
    playerHasMistakesLeft

  const disableDeselected =
    isDisabled || board.cards.filter((c) => c.selected).length <= 0

  return (
    <>
      <ActionButton
        form="default-choices"
        disabled={
          isDisabled ||
          solvedCategories.length === board.categories.length
        }
        onClick={() => {
          trackClick({
            name: 'connections',
            label: 'shuffle',
            context: getNthDayOfGame(today),
            moduleName: ['b: 4-8-4'],
          })
          setAnimation(AnimationEnum.SHUFFLE)

          const startIndex = 16 - board.cards.length
          const shuffledCards = shuffleCards(board.cards)

          saveCardOrder({ cards: shuffledCards, startIndex })
          updateBoard({
            categories: board.categories,
            guesses: board.guesses,
            cards: shuffledCards,
          })
        }}
      >
        Shuffle
      </ActionButton>
      <ActionButton
        form="default-choices"
        size={ButtonSize.MEDIUM}
        disabled={disableDeselected}
        onClick={() => {
          trackClick({
            name: 'connections',
            label: 'deselect',
            context: getNthDayOfGame(today),
            moduleName: ['b: 4-8-4'],
          })
          saveDeselectedCards()
          updateBoard({
            categories: board.categories,
            guesses: board.guesses,
            cards: deselectAllCards(board.cards),
          })
        }}
      >
        Deselect all
      </ActionButton>
      <ActionButton
        isSubmit
        form="default-choices"
        size={ButtonSize.X_SMALL}
        disabled={!enableSubmit}
        isFilled
        onClick={(e) => {
          e.preventDefault()
          onSubmit()
        }}
      >
        Submit
      </ActionButton>
    </>
  )
}
