import { Level } from '../../levelTypes'
import { Card, Category } from '../../types'

import { convertToSquares } from './helpers'

function createCategory(
  level: Level,
  startingPosition: number,
  orderSolved: number,
): Category {
  const cards = Array(4)
    .fill(0)
    .map((content, i): Card => {
      const originalPosition = startingPosition + i
      return {
        level,
        originalPosition,
        selected: false,
        content: `Level ${level}: ${content}`,
        currentPosition: originalPosition,
      }
    })

  return {
    title: `title for ${level}`,
    solved: { order: orderSolved },
    level,
    cards,
  }
}
describe('Connections/Components/Board/Helpers', () => {
  describe('convertToSquares()', () => {
    const categories = [
      createCategory(Level.Level1, 8, 2),
      createCategory(Level.Level2, 4, 1),
      createCategory(Level.Level3, 0, 0),
      createCategory(Level.Level4, 12, 3),
    ]
    it('returns correct values when player makes no mistakes', () => {
      const correctGuesses = [
        { cards: '0,1,2,3', correct: true },
        { cards: '4,5,6,7', correct: true },
        { cards: '8,9,10,11', correct: true },
        { cards: '12,13,14,15', correct: true },
      ]
      expect(convertToSquares(correctGuesses, categories)).toEqual([
        [Level.Level3, Level.Level3, Level.Level3, Level.Level3],
        [Level.Level2, Level.Level2, Level.Level2, Level.Level2],
        [Level.Level1, Level.Level1, Level.Level1, Level.Level1],
        [Level.Level4, Level.Level4, Level.Level4, Level.Level4],
      ])
    })

    it('returns correct values when player makes mistakes', () => {
      const incorrectGuesses = [
        { cards: '0,1,2,7', correct: false },
        { cards: '4,5,10,7', correct: false },
        { cards: '8,1,10,11', correct: false },
        { cards: '12,5,14,15', correct: false },
      ]
      const result = convertToSquares(incorrectGuesses, categories)
      expect(result).toEqual([
        [Level.Level3, Level.Level3, Level.Level3, Level.Level2],
        [Level.Level2, Level.Level2, Level.Level1, Level.Level2],
        [Level.Level1, Level.Level3, Level.Level1, Level.Level1],
        [Level.Level4, Level.Level2, Level.Level4, Level.Level4],
      ])
    })
  })
})
