import {
  AnimationEnum,
  CardAnimation,
  ThemeContextType,
} from '../../types'

import { calculateFontSize, animationClass } from './helpers'

describe('Connections/Components/Card/Helpers', () => {
  it('returns correct font size classes based on word length', () => {
    const shortWord = 'ok'
    const mediumWord = 'alrightys'
    const longWord = 'basketball'

    const smallFontSizeStyle = calculateFontSize(shortWord)
    const mediumFontSizeStyle = calculateFontSize(mediumWord)
    const largeFontSizeStyle = calculateFontSize(longWord)

    expect(smallFontSizeStyle).toEqual('labelXLg')
    expect(mediumFontSizeStyle).toEqual('labelMd')
    expect(largeFontSizeStyle).toEqual('labelSm')
  })

  it('returns correct animation classes based on effects', () => {
    const shakeEffectClass = animationClass({
      effect: AnimationEnum.SHAKE,
    })

    const bounceDefaultEffectClass = animationClass({
      effect: AnimationEnum.BOUNCE,
      timeout: 1,
    })

    const bounceDefaultEffectClassDefault = animationClass({
      effect: AnimationEnum.BOUNCE,
      timeout: 4,
    })

    const bounceEffectClassBounce = animationClass({
      effect: AnimationEnum.SHUFFLE,
      selected: true,
    })

    expect(shakeEffectClass).toEqual(' mistakeShake')
    expect(bounceDefaultEffectClass).toEqual(' bounce1')
    expect(bounceDefaultEffectClassDefault).toEqual(' bounce4')
    expect(bounceEffectClassBounce).toEqual(' shuffleSelected')
    expect(shakeEffectClass).toEqual(' mistakeShake')
  })
})
