import {
  AnimationEnum,
  CardAnimation,
  ThemeContextType,
} from '../../types'

import styles from './Card.module.scss'

export function calculateFontSize(cardContent: string): string {
  const wordsLongToShort = cardContent
    .split(' ')
    .sort((a, b) => b.length - a.length)
  const longestWord = wordsLongToShort[0]

  switch (longestWord.length) {
    case 1:
    case 2:
    case 3:
    case 4:
    case 5:
    case 6:
    case 7:
      return styles.labelXLg
    case 8:
      return styles.labelLg
    case 9:
      return styles.labelMd
    case 10:
    case 11:
      return styles.labelSm
    default:
      return styles.labelXSm
  }
}

function bounceClass(timeout: number): string {
  switch (timeout) {
    case 1:
      return styles.bounce1
    case 2:
      return styles.bounce2
    case 3:
      return styles.bounce3
    default:
      return styles.bounce4
  }
}

export const animationClass = (
  animation:
    | { effect: AnimationEnum.SHAKE }
    | { effect: AnimationEnum.BOUNCE; timeout: number }
    | { effect: AnimationEnum.SHUFFLE; selected: boolean }
    | undefined,
): string => {
  if (animation?.effect === AnimationEnum.SHAKE) {
    return ` ${styles.mistakeShake}`
  }

  if (animation?.effect === AnimationEnum.BOUNCE) {
    return ` ${bounceClass(animation.timeout)}`
  }

  if (animation?.effect === AnimationEnum.SHUFFLE) {
    return animation.selected
      ? ` ${styles.shuffleSelected}`
      : ` ${styles.shuffle}`
  }

  return ''
}

export const animationShakeStyle = (
  animation: CardAnimation | undefined,
  theme: ThemeContextType,
  colors: ThemeContextType['GAME']['INITIAL'],
): { backgroundColor: string; color: string } => {
  return {
    backgroundColor:
      animation?.effect === AnimationEnum.SHAKE
        ? theme.GAME.INCORRECT.BACKGROUND
        : colors.BACKGROUND,
    color:
      animation?.effect === AnimationEnum.SHAKE
        ? theme.GAME.INCORRECT.COLOR
        : colors.COLOR,
  }
}
