import React from 'react'
import { Story } from '@storybook/react'

import CardComponent from '../Card'
import { ThemeProvider } from '../../Theme'
import { Card as CardType } from '../../../types'
import { Level } from '../../../levelTypes'

interface Props extends CardType {
  disabled: boolean
  size: 'desktop' | 'mobile'
  showColor: boolean
}

const sizeRecord = {
  desktop: ['80px', '150px'],
  mobile: ['22.5vw', '22.5vw'],
}

const CardTemplate: Story<Props> = ({
  content = 'Hello',
  size = 'desktop',
  disabled = false,
  level = Level.Level1,
  selected = false,
  showColor = false,
}: Props) => {
  const [h, w] = sizeRecord[size]

  return (
    <ThemeProvider>
      <div
        style={{
          width: `${w}`,
          height: `${h}`,
          margin: '20px auto',
        }}
      >
        <CardComponent
          content={content}
          disabled={disabled}
          originalPosition={14}
          currentPosition={14}
          level={level}
          selected={selected}
          showColor={showColor}
          updateSelected={() => {}}
        />
      </div>
    </ThemeProvider>
  )
}

export const Card = CardTemplate.bind({})
Card.args = {
  content: 'Hello',
  level: Level.Level2,
  selected: false,
  size: 'desktop',
  showColor: false,
}

export default {
  component: Card,
  title: 'Connections/Components/Card',
  decorators: [
    (Story: Story) => {
      document.body.classList.add('pz-desktop')
      document.body.classList.add('pz-page')
      return (
        <div
          id="modal-system-portal"
          className="modal-system-container"
        >
          <Story />
        </div>
      )
    },
  ],
  argTypes: {
    size: {
      options: ['desktop', 'mobile'],
      control: {
        type: 'select',
      },
    },
    level: {
      options: Object.values(Level),
      control: {
        type: 'select',
      },
    },
  },
}
