import React from 'react'
import { Flipped } from 'react-flip-toolkit'

import { saveSelectedCard } from '../../localstorage/localstorage'
import { AnimationEnum, Board } from '../../types'
import CardComponent from '../Card/Card'
import { cardSort } from '../sharedHelpers'

import * as helpers from './helpers'

interface Props {
  board: Board
  updateBoard: (b: Board) => void
  animation: false | AnimationEnum
  disabled: boolean
  cardsPerCategory: number
}

export default ({
  board,
  updateBoard,
  animation,
  disabled,
  cardsPerCategory,
}: Props) => {
  const maxCardsSelected =
    board.cards.filter((c) => c.selected).length >= cardsPerCategory
  let selectedIndex = 0

  return (
    <>
      {board.cards.sort(cardSort).map((card, i) => {
        if (card.selected) selectedIndex += 1

        return (
          <Flipped
            key={`${card.content}-flip`}
            flipId={card.content}
            shouldFlip={(prev, curr) => {
              // Skip flip animation for shuffle state change
              // which has a fade effect instead
              if (
                prev.animation === 'shuffle' ||
                curr.animation === 'shuffle'
              ) {
                return false
              }

              return true
            }}
          >
            <CardComponent
              {...card}
              disabled={
                disabled || (maxCardsSelected && !card.selected)
              }
              key={`card-position-${card.originalPosition}`}
              animation={helpers.cardAnimation(
                animation,
                card.selected,
                selectedIndex,
              )}
              updateSelected={(s) => {
                saveSelectedCard({
                  cardContent: board.cards.find((_, j) => i === j)
                    ?.content,
                  selected: s,
                })
                updateBoard({
                  categories: board.categories,
                  guesses: board.guesses,
                  cards: board.cards.map((c, j) =>
                    i === j ? { ...c, selected: s } : { ...c },
                  ),
                })
              }}
            />
          </Flipped>
        )
      })}
    </>
  )
}
