import React from 'react'
import { Story } from '@storybook/react'

import ErrorComponent from '../Error'
import { ThemeProvider } from '../../Theme'
import { ErrorName } from '../../../api/types'

const ErrorTemplate: Story<{
  errorType: ErrorName
  showBackButton: boolean
}> = ({
  errorType = 'default',
  showBackButton = true,
}: {
  errorType: ErrorName
  showBackButton: boolean
}) => (
  <ThemeProvider>
    <ErrorComponent
      errorType={errorType}
      showBackButton={showBackButton}
    />
  </ThemeProvider>
)

export const Error = ErrorTemplate.bind({})
Error.args = {
  errorType: 'default',
  showBackButton: true,
}

export default {
  title: 'Connections/Error',
  component: Error,
  argTypes: {
    errorType: {
      options: [
        'default',
        'offline',
        'missingData',
        'precedesLaunch',
      ],
      control: {
        type: 'select',
      },
    },
    showBackButton: {
      control: {
        type: 'boolean',
      },
    },
  },
}
