import { isValid, parse } from 'date-fns'

import { Level } from '../../levelTypes'
import { PuzzleResponseSuccess } from '../../api/types'
import { Card, Category, Puzzle } from '../../types'
import { UserContextProps } from '../../../../shared/user/UserContext'

export function getLevel(i: number): Level {
  if (i <= 0) return Level.Level1

  if (i === 1) return Level.Level2

  if (i === 2) return Level.Level3

  return Level.Level4
}

export function convertAPIDataToGameData(
  data: PuzzleResponseSuccess,
): Puzzle {
  const editor = data.editor || 'Wyna Liu'
  const categories = data.categories.map((apiCategory, i) => {
    const level = getLevel(i)
    const cards: Card[] = []
    apiCategory.cards.forEach((card) => {
      cards.push({
        level,
        selected: false,
        originalPosition: card.position,
        currentPosition: card.position,
        content: card.content,
      })
    })
    const category: Category = {
      title: apiCategory.title,
      solved: false,
      cards,
      level,
    }

    return { ...category, found: false, level }
  })

  return { ...data, categories, editor }
}

export const printDate = (user: UserContextProps): Date => {
  let printDate = new Date()

  if (!user.userType.inShortzMode) {
    return printDate
  }

  if (!window.location.pathname.includes('/puzzles/shortz')) {
    return printDate
  }

  const printDateString = window.gameData?.connectionsShortzDate

  if (printDateString) {
    const parsedDate = parse(
      printDateString,
      'yyyy-MM-dd',
      new Date(),
    )

    if (isValid(parsedDate)) {
      printDate = new Date(`${printDateString}T12:00:00`)
    }
  }

  return printDate
}
