import React, { useEffect, useState } from 'react'
import cn from 'classnames'

import { ANIMATION_MS_PER_GUESS, MAX_MISTAKES } from '../../constants'
import { useTheme } from '../Theme'

import styles from './Mistakes.module.scss'

export default function Mistakes({
  mistakes,
  isMistakeIndicatorDisabled = false,
  puzzleSolved,
}: {
  mistakes: number
  isMistakeIndicatorDisabled: boolean
  puzzleSolved: boolean
}) {
  const theme = useTheme()
  const [newMistakes, setNewMistakes] = useState<number>(0)
  const [hideMistakes, setHideMistakes] =
    useState<boolean>(puzzleSolved)
  const mistakesLeft = MAX_MISTAKES - mistakes
  const mistakesLeftBubbles = Array(MAX_MISTAKES - mistakes).fill(
    undefined,
  )

  if (puzzleSolved && !hideMistakes) {
    setTimeout(() => {
      setHideMistakes(true)
    }, ANIMATION_MS_PER_GUESS)
  }

  if (!puzzleSolved && hideMistakes) {
    setHideMistakes(false)
  }

  const areNewMistakesTriggered = newMistakes === mistakes

  /* internal state to track if there has been a new mistake to use for CSS Amimation */
  useEffect(() => {
    if (mistakes) {
      setNewMistakes(mistakes)
    }
  }, [mistakes])

  return hideMistakes ? null : (
    <span
      className={cn(
        styles.mistakesWrapper,
        puzzleSolved ? styles.hideMistakes : styles.showMistakes,
      )}
    >
      <span
        className="visually-hidden"
        aria-atomic="true"
        aria-live="polite"
      >
        {mistakesLeft} mistakes remaining out of {MAX_MISTAKES}
      </span>
      <p
        className={styles.mistakesContent}
        style={{
          color: isMistakeIndicatorDisabled
            ? theme.GAME.INCORRECT.BACKGROUND
            : theme.GAME.INITIAL.COLOR,
        }}
        aria-hidden="true"
      >
        Mistakes remaining:
        <span className={styles.attemptsRemainingBubbles}>
          {mistakesLeftBubbles &&
            mistakesLeftBubbles.map((item, index) => {
              return (
                <span
                  style={{
                    backgroundColor: isMistakeIndicatorDisabled
                      ? theme.GAME.INCORRECT.BACKGROUND
                      : theme.GAME.SELECTED.BACKGROUND,
                  }}
                  key={`bubble-${index}`}
                  className={styles.bubble}
                />
              )
            })}
          {areNewMistakesTriggered && (
            // when there is a new mistake show and then fade the mistake indicator,
            // this effictively replaces the removed mistake bubble
            <span
              style={{
                backgroundColor: isMistakeIndicatorDisabled
                  ? theme.GAME.INCORRECT.BACKGROUND
                  : theme.GAME.SELECTED.BACKGROUND,
              }}
              className={cn(
                styles.bubble,
                styles.bubbleMistakeAnimation,
              )}
            />
          )}
        </span>
      </p>
    </span>
  )
}
