import cn from 'classnames'
import React from 'react'

import { SEND_EMAIL_TYPE } from 'foundation'

import { meetsMinimumVersion } from '../../../../shared/foundation/js/hybrid/detection'
import FeedbackLink from '../../../helpers/FeedbackLink'
import ModalWrapper from '../../../shared/ModalSystem/ModalWrapper'
import type { ModalProps } from '../../../shared/ModalSystem/modalTypes'
import { useTheme } from '../Theme'

import styles from './Settings.module.scss'

const SettingsModal = ({
  close,
  isClosing,
  onRemove,
}: ModalProps) => {
  // Show only if the user is on a hybrid webview above 4.53 of xwd app
  // This check can be deleted once we reach full adoption of xwd 4.53
  const showReportBugLink =
    !window.isHybridWebView ||
    meetsMinimumVersion(window.gamesAppVersion, '4.53')

  const theme = useTheme()

  return (
    <ModalWrapper
      bodyClassName={cn('modal-rules-body', styles.modalWrapper)}
      close={close}
      isClosing={isClosing}
      onRemove={onRemove}
    >
      <div className={styles.dialog}>
        <h2 className={styles.dialogTitle}>SETTINGS</h2>
        <dl>
          <div
            className={styles.description}
            style={{ borderColor: theme.MODALS.BORDER }}
          >
            <dt className={styles.term}>Feedback</dt>
            <dd className={styles.detail}>
              <FeedbackLink
                subject="Connections Feedback"
                useEnhancedHybridDebugInfo
                type={SEND_EMAIL_TYPE.CONNECTIONS}
              >
                Email
              </FeedbackLink>
            </dd>
          </div>
          {showReportBugLink && (
            <div
              className={styles.description}
              style={{ borderColor: theme.MODALS.BORDER }}
            >
              <dt className={styles.term}>Report a Bug</dt>
              <dd className={styles.detail}>
                <FeedbackLink
                  subject="Connections Bug Report"
                  useEnhancedHybridDebugInfo
                  type={SEND_EMAIL_TYPE.CONNECTIONS}
                >
                  Email
                </FeedbackLink>
              </dd>
            </div>
          )}
          <div className={styles.description}>
            <dt className={styles.term}>Questions</dt>
            <a
              href="https://help.nytimes.com/hc/en-us/articles/360029050872-Word-Games-and-Logic-Puzzles"
              target="_blank"
              rel="noreferrer"
            >
              <dd className={styles.detail}>FAQ</dd>
            </a>
          </div>
        </dl>
      </div>
    </ModalWrapper>
  )
}

export default SettingsModal
