import React from 'react'
import { createStore } from 'redux'
import { Provider } from 'react-redux'

import CongratsComponent from '../Congrats'
import { ThemeProvider } from '../../Theme'
import { Level } from '../../../levelTypes'

const perfectGuesses = [
  [Level.Level1, Level.Level1, Level.Level1, Level.Level1],
  [Level.Level2, Level.Level2, Level.Level2, Level.Level2],
  [Level.Level3, Level.Level3, Level.Level3, Level.Level3],
  [Level.Level4, Level.Level4, Level.Level4, Level.Level4],
]

const imperfectGuesses = [
  [Level.Level1, Level.Level2, Level.Level2, Level.Level1],
  [Level.Level1, Level.Level2, Level.Level1, Level.Level1],
  [Level.Level1, Level.Level1, Level.Level1, Level.Level1],
  [Level.Level2, Level.Level2, Level.Level2, Level.Level2],
  [Level.Level4, Level.Level3, Level.Level3, Level.Level4],
  [Level.Level3, Level.Level3, Level.Level4, Level.Level3],
]

const CongratsTemplate = ({
  today,
  numMistakes,
  isPerfect,
  cardsPerCategory,
}) => {
  const perfectPuzzle = isPerfect && numMistakes === 0
  let mistakeCount = perfectPuzzle ? 0 : numMistakes
  if (mistakeCount === 0 && !perfectPuzzle) {
    mistakeCount = 1
  }

  return (
    <Provider store={createStore(() => {})}>
      <ThemeProvider>
        <CongratsComponent
          close={() => {}}
          today={today}
          cardsPerCategory={cardsPerCategory}
          numMistakes={mistakeCount}
          guesses={perfectPuzzle ? perfectGuesses : imperfectGuesses}
        />
      </ThemeProvider>
    </Provider>
  )
}

export const Congrats = CongratsTemplate.bind({})
Congrats.args = {
  today: new Date(),
  numMistakes: 0,
  isPerfect: true,
  cardsPerCategory: 4,
}

export default {
  component: CongratsTemplate,
  title: 'Connections/Modals/Congrats',
  argTypes: {
    today: {
      control: 'date',
      defaultValue: new Date(),
    },
    numMistakes: {
      type: 'select',
      options: [0, 1, 2, 3, 4],
    },
    cardsPerCategory: {
      type: 'select',
      options: [4, 5, 6],
    },
  },
  decorators: [
    (Story) => {
      document.body.classList.add('pz-desktop')
      document.body.classList.add('pz-page')
      return (
        <div
          id="modal-system-portal"
          className="modal-system-container"
        >
          <Story />
        </div>
      )
    },
  ],
}
