import React from 'react'

import { Category } from '../../types'
import { useTheme } from '../Theme'

import { cardSortByAlphaContent } from './helpers'
import styles from './SolvedCategory.module.scss'

function getTextAnimationClass(themeName: string): string {
  return themeName === 'light'
    ? ` ${styles.textFadeInThemeLight}`
    : ''
}

export default ({ category }: { category: Category }) => {
  const { title, cards, level } = category
  const theme = useTheme()

  const themeColors = theme.GAME.LEVELS[category.level]
  const themedTextAnimationClass = getTextAnimationClass(theme.NAME)

  return (
    <section
      className={`${styles.solvedCategory}`}
      style={{
        backgroundColor: themeColors.BACKGROUND,
        color: themeColors.COLOR,
      }}
    >
      <h3
        className={`${styles.categoryTitle}${themedTextAnimationClass}`}
      >
        <span className="visually-hidden">Correct group</span>
        {title}
      </h3>
      <ol>
        {cards.sort(cardSortByAlphaContent).map((card) => (
          <li
            key={`found-category-card-${card.originalPosition}`}
            className={`${styles.cardListItem}${themedTextAnimationClass}`}
          >
            {card.content}
          </li>
        ))}
      </ol>
    </section>
  )
}
