import React from 'react'
import { Story } from '@storybook/react'

import SolvedCategoryComponent from '../SolvedCategory'
import { ThemeProvider } from '../../Theme'
import { Category } from '../../../types'
import { Level } from '../../../levelTypes'

interface Props {
  title: string
  level: Level
  size: 'desktop' | 'mobile'
  cardOne: string
  cardTwo: string
  cardThree: string
  cardFour: string
}

const sizeRecord = {
  desktop: ['80px', '624px'],
  mobile: ['22.5vw', 'calc(24px + 4 * 22.5vw)'],
}

const SolvedCategoryTemplate: Story<Props> = ({
  title = 'Hello',
  size = 'desktop',
  cardOne = 'black',
  cardTwo = 'frost',
  cardThree = 'ma',
  cardFour = 'sparrow',
  level = Level.Level3,
}: Props) => {
  const [h, w] = sizeRecord[size]
  const category: Category = {
    title,
    level,
    solved: { order: 1 },
    cards: [cardOne, cardTwo, cardThree, cardFour]
      .sort()
      .map((c, i) => {
        return {
          content: c,
          selected: false,
          level,
          originalPosition: i,
          currentPosition: i,
        }
      }),
  }

  return (
    <ThemeProvider>
      <div
        style={{
          width: `${w}`,
          height: `${h}`,
          margin: '20px auto',
        }}
      >
        <SolvedCategoryComponent category={category} />
      </div>
    </ThemeProvider>
  )
}

export const SolvedCategory = SolvedCategoryTemplate.bind({})
SolvedCategory.args = {
  title: 'Jacks',
  level: Level.Level3,
  size: 'desktop',
  cardOne: 'black',
  cardTwo: 'frost',
  cardThree: 'ma',
  cardFour: 'sparrow',
}

export default {
  component: SolvedCategory,
  title: 'Connections/Components/Solved Category',
  decorators: [
    (Story: Story) => {
      document.body.classList.add('pz-desktop')
      document.body.classList.add('pz-page')
      return (
        <div
          id="modal-system-portal"
          className="modal-system-container"
        >
          <Story />
        </div>
      )
    },
  ],
  argTypes: {
    size: {
      options: ['desktop', 'mobile'],
      control: {
        type: 'select',
      },
    },
    level: {
      options: Object.values(Level),
      control: {
        type: 'select',
      },
    },
  },
}
