import React, { ReactNode } from 'react'

import { Level } from '../levelTypes'

enum COLORS {
  BLACK = '#000',
  BLUE = '#b0c4ef',
  BLUE_CONTRAST = '#b0c4ef',
  BLUE_LINK = '#2f80ed',
  GREEN = '#a0c35a',
  GREEN_CONTRAST = '#a0c35a',
  GREY = '#e2e2e2',
  GREY_CARD = '#efefe6',
  GREY_INCORRECT = '#5a594ebf',
  GREY_SELECTED = '#5a594e',
  GREY_DISABLED = '#7f7f7f',
  GREY_BORDER = '#d3d6da',
  PURPLE_LIGHT = '#b4a8ff',
  PURPLE = '#ba81c5',
  PURPLE_CONTRAST = '#ba81c5',
  YELLOW = '#f9df6d',
  YELLOW_CONTRAST = '#f9df6d',
  WHITE = '#fff',
  WHITE_TRANSPARENT = 'rgba(255, 255, 255, 0.6)',
}

const LIGHT_THEME = {
  NAME: 'light',
  LOADING_BAR: {
    BACKGROUND: COLORS.WHITE_TRANSPARENT,
    COLOR: COLORS.BLACK,
  },
  WELCOME: {
    // shared welcome moment expects string with game name followed by
    // color
    BACKGROUND: '$connections-periwinkle',
    COLOR: COLORS.BLACK,
  },
  GAME: {
    LEVELS: {
      [Level.Level1]: {
        BACKGROUND: COLORS.YELLOW,
        COLOR: COLORS.BLACK,
      },
      [Level.Level2]: {
        BACKGROUND: COLORS.GREEN,
        COLOR: COLORS.BLACK,
      },
      [Level.Level3]: {
        BACKGROUND: COLORS.BLUE,
        COLOR: COLORS.BLACK,
      },
      [Level.Level4]: {
        BACKGROUND: COLORS.PURPLE,
        COLOR: COLORS.BLACK,
      },
    },
    LEVEL_CONTRAST: [
      COLORS.YELLOW_CONTRAST,
      COLORS.GREEN_CONTRAST,
      COLORS.BLUE_CONTRAST,
      COLORS.PURPLE_CONTRAST,
    ],
    INITIAL: { BACKGROUND: COLORS.GREY_CARD, COLOR: COLORS.BLACK },
    SELECTED: {
      BACKGROUND: COLORS.GREY_SELECTED,
      COLOR: COLORS.WHITE,
    },
    INCORRECT: {
      BACKGROUND: COLORS.GREY_INCORRECT,
      COLOR: COLORS.WHITE,
    },
    MISTAKES: {
      DOT: COLORS.GREY_SELECTED,
    },
  },
  LINK: COLORS.BLUE_LINK,
  MODALS: {
    TEXT: COLORS.BLACK,
    BORDER: COLORS.GREY_BORDER,
  },
  TOAST: {
    BACKGROUND: COLORS.BLACK,
    TEXT: COLORS.WHITE,
  },
  ERROR: { BACKGROUND: COLORS.PURPLE_LIGHT, COLOR: COLORS.BLACK },
  AD: { BACKGROUND: COLORS.PURPLE_LIGHT },
  BUTTONS: {
    CTA: { BACKGROUND: COLORS.BLACK, COLOR: COLORS.WHITE },
    ACTIONS: {
      BACKGROUND: COLORS.WHITE,
      COLOR: COLORS.BLACK,
      BORDER: COLORS.BLACK,
    },
    DISABLED: {
      BACKGROUND: COLORS.WHITE,
      COLOR: COLORS.GREY_DISABLED,
    },
    MENU_HOVER: {
      BACKGROUND: COLORS.GREY_DISABLED,
    },
  },
}

export const ThemeContext = React.createContext(LIGHT_THEME)

function ThemeProvider({ children }: { children?: ReactNode }) {
  return (
    <ThemeContext.Provider value={LIGHT_THEME}>
      {children}
    </ThemeContext.Provider>
  )
}

function useTheme() {
  const context = React.useContext(ThemeContext)

  if (context === undefined) {
    throw new Error('useTheme must be used within a ThemeProvider')
  }

  return context
}

export { ThemeProvider, useTheme }
