import React, { useState, useEffect } from 'react'
import cn from 'classnames'

import useTimeout from '../../../shared/hooks/use-timeout'
import { useTheme } from '../Theme'

import styles from './Toast.module.scss'

type ToastProps = {
  text: string
  durationVisible?: number
  onRemove?: () => void
}

const Toast = ({
  text,
  onRemove,
  durationVisible = 3000,
}: ToastProps) => {
  const theme = useTheme()

  const [fadeIn, setFadeIn] = useState(false)
  const [fadeOut, setFadeOut] = useState(false)

  useEffect(() => {
    // fade in toast on component mount
    setFadeIn(true)
  }, [])

  useTimeout(
    () => setFadeOut(true),
    durationVisible === Infinity ? null : durationVisible,
  )

  return (
    <div
      data-testid="connection-toast"
      className={cn(styles.toast, {
        [styles.fadeIn]: fadeIn,
        [styles.fadeOut]: fadeOut,
      })}
      style={{
        backgroundColor: theme.TOAST.BACKGROUND,
        color: theme.TOAST.TEXT,
      }}
      aria-live="polite"
      onTransitionEnd={() => {
        // call toast callback when fade out animation is complete
        if (onRemove && fadeOut) {
          onRemove()
        }
      }}
    >
      <h2>{text}</h2>
    </div>
  )
}

export default Toast
