import React from 'react'
import {
  render,
  screen,
  act,
  fireEvent,
} from '@testing-library/react'

import { toastMap } from './gameToasts'
import ToastManager from './ToastManager'

const mockDispatch = jest.fn()

jest.mock('react-redux', () => ({
  ...jest.requireActual('react-redux'),
  useSelector: jest.fn((modalName) => modalName),
  useDispatch: () => mockDispatch,
}))

describe('<ToastManager />', () => {
  beforeAll(() => jest.useFakeTimers())
  afterAll(() => jest.useRealTimers())
  beforeEach(() => {
    jest.clearAllMocks()
  })

  afterEach(() => {
    jest.clearAllMocks()
  })
  const renderToastManager = (props: any) => {
    const store = {}

    const board = render(<ToastManager {...props} />)

    return { store, board }
  }

  it('should render Toast passed into ToastManager', () => {
    renderToastManager({
      getOpenToastName: 'alreadyGuessed',
      toastMap,
      onClose: () => {},
      onRemove: () => {},
    })

    const header = screen.getByText('Already guessed!')
    expect(header).toBeTruthy()
  })

  it('should dispatch remove when callback gets invoked after transition end', async () => {
    const removeCallback = jest.fn(() => {})
    renderToastManager({
      getOpenToastName: 'alreadyGuessed',
      toastMap,
      onClose: () => {},
      onRemove: removeCallback,
    })

    // eslint-disable-next-line require-await
    await act(async () => {
      const removeDuration = 4000

      jest.advanceTimersByTime(removeDuration)
      // manually fire native transition end for DOM removal callback in component
      fireEvent.transitionEnd(screen.getByTestId('connection-toast'))
    })

    expect(removeCallback).toHaveBeenCalled()
  })

  it('should render rank title in Toast', () => {
    renderToastManager({
      getOpenToastName: 'revealMistakeTitle',
      toastMap,
      rankTitle: 'Solid!',
    })

    const header = screen.getByText('Solid!')
    expect(header).toBeTruthy()
  })
})
