import React from 'react'
import { createPortal } from 'react-dom'
import { useSelector, useDispatch } from 'react-redux'

import type { ToastManagerProps } from './toastTypes'

export default function ToastWrapper({
  getIsClosing,
  getOpenToastName,
  toastMap,
  onClose,
  portalId,
  onRemove,
  rankTitle,
  ...otherProps
}: ToastManagerProps) {
  const portalRef = React.useRef(document.getElementById(portalId))
  const openToastName = useSelector(getOpenToastName)
  const isClosing = useSelector(getIsClosing)
  const dispatch = useDispatch()

  const close = (isCancelled = false) =>
    dispatch(onClose(isCancelled))

  const remove = () => dispatch(onRemove())

  if (!openToastName) {
    return null
  }

  const ToastComponent = toastMap[openToastName]
  const toast = (
    <ToastComponent
      close={close}
      isClosing={isClosing}
      onRemove={remove}
      rankTitle={rankTitle}
      {...otherProps}
    />
  )

  if (!portalRef.current) {
    return toast
  }

  return createPortal(toast, portalRef.current)
}
