import React from 'react'

import { trackClick } from 'foundation'

import ToolbarAdapter from '../../../shared/ToolbarAdapter/ToolbarAdapter'
import { ConnectionsModal } from '../../store/types'
import ToolbarButton from '../ToolbarButton/ToolbarButton'
import { ToolbarButtonIcon } from '../ToolbarButton/types'
import { getNthDayOfGame } from '../sharedHelpers'

import styles from './Toolbar.module.scss'

export default function Toolbar({
  hide,
  onButtonClick,
  today,
}: {
  hide: boolean
  onButtonClick: (modalName: ConnectionsModal) => void
  today: Date
}) {
  return (
    <ToolbarAdapter isHidden={hide}>
      <nav className={styles.toolbarWrapper}>
        <ul className={styles.toolbar}>
          <ToolbarButton
            icon={ToolbarButtonIcon.SETTINGS}
            aria-label="Settings"
            onClick={() => {
              onButtonClick(ConnectionsModal.SETTINGS)
            }}
          />
          <ToolbarButton
            icon={ToolbarButtonIcon.HELP}
            onClick={() => {
              trackClick({
                name: 'connections',
                label: 'help',
                context: getNthDayOfGame(today),
                moduleName: ['b: 4-8-4'],
              })
              onButtonClick(ConnectionsModal.HOW_TO_PLAY)
            }}
            aria-label="Help"
          />
        </ul>
      </nav>
    </ToolbarAdapter>
  )
}
