import React from 'react'

import styles from './ToolbarButton.module.scss'
import { ToolbarButtonIcon } from './types'

export interface ButtonPropsInitial
  extends React.DetailedHTMLProps<
      React.ButtonHTMLAttributes<HTMLButtonElement>,
      HTMLButtonElement
    >,
    React.AriaAttributes {
  icon: ToolbarButtonIcon
}

type ButtonProps = Omit<ButtonPropsInitial, 'type'>

function classnameByIcon(icon: ToolbarButtonIcon): string {
  switch (icon) {
    case ToolbarButtonIcon.HELP:
      return styles.helpIcon
    case ToolbarButtonIcon.SETTINGS:
      return styles.settingsIcon
    default:
      return ''
  }
}

const MenuButton: React.FC<ButtonProps> = (btnProps) => {
  const { children, icon, ...props } = btnProps

  return (
    <li>
      <button type="button" {...props} className={styles.button}>
        <i className={`${styles.icon} ${classnameByIcon(icon)}`} />
        {children}
      </button>
    </li>
  )
}

export default MenuButton
