import React from 'react'
import { Story } from '@storybook/react'

import { ThemeProvider } from '../../Theme'
import ToolbarButtonComponent from '../ToolbarButton'
import { ToolbarButtonIcon } from '../types'

interface Props {
  disabled: boolean
  hiddenText: string
  icon: ToolbarButtonIcon
}

const ToolbarButtonTemplate: Story<Props> = ({
  disabled = false,
  hiddenText = 'Hello',
  icon = ToolbarButtonIcon.HELP,
}: Props) => {
  return (
    <ThemeProvider>
      <menu style={{ listStyle: 'none' }}>
        <ToolbarButtonComponent disabled={disabled} icon={icon}>
          <span className="visually-hidden">{hiddenText}</span>
        </ToolbarButtonComponent>
      </menu>
    </ThemeProvider>
  )
}

export const ToolbarButton = ToolbarButtonTemplate.bind({})
ToolbarButton.args = {
  hiddenText: 'Hello',
  icon: ToolbarButtonIcon.HELP,
  disabled: false,
}

export default {
  component: ToolbarButton,
  title: 'Connections/Components/Toolbar Button',
  argTypes: {
    icon: {
      options: [ToolbarButtonIcon.SETTINGS, ToolbarButtonIcon.HELP],
      control: {
        type: 'select',
      },
    },
  },
}
