import { Card } from '../types'
import { unplayedPuzzle } from '../__tests__/fixtures/game-data/unplayed-puzzle'

import { getNthDayOfGame, cardSort } from './sharedHelpers'

describe('getNthDayOfGame()', () => {
  it('returns 0 with launch date', () => {
    expect(getNthDayOfGame(new Date(`2023-06-12T00:00:00`))).toEqual(
      0,
    )
  })

  it('returns 1 with day after launch date', () => {
    expect(getNthDayOfGame(new Date(`2023-06-13T00:00:00`))).toEqual(
      1,
    )
  })

  it('returns 1 with day after launch date at 6am', () => {
    expect(getNthDayOfGame(new Date(`2023-06-13T06:00:00`))).toEqual(
      1,
    )
  })

  it('returns 1 with day after launch date at 12pm', () => {
    expect(getNthDayOfGame(new Date(`2023-06-13T12:00:00`))).toEqual(
      1,
    )
  })

  it('returns 1 with day after launch date at 11:59pm', () => {
    expect(getNthDayOfGame(new Date(`2023-06-13T23:59:00`))).toEqual(
      1,
    )
  })

  it('returns 2 with two days after launch date', () => {
    expect(getNthDayOfGame(new Date(`2023-06-14T00:00:00`))).toEqual(
      2,
    )
  })

  it('increments with no arg', () => {
    expect(getNthDayOfGame()).toBeGreaterThan(1)
  })
})

describe('card sorting', () => {
  it('sorts card by current position in order', () => {
    const validCards = unplayedPuzzle.categories[0].cards as Card[]
    // ensure original order is different
    expect(validCards[1].currentPosition).toEqual(5)

    const sortedCards = validCards.sort(cardSort)

    expect(sortedCards[1].currentPosition).toEqual(3)
    expect(sortedCards[2].currentPosition).toEqual(5)
  })
})
