import { ConnectionsModal, ConnectionsToast } from './types'

export enum ActionsEnum {
  OPEN_MODAL = 'OPEN_MODAL',
  CLOSE_MODAL = 'CLOSE_MODAL',
  REMOVE_MODAL = 'REMOVE_MODAL',
  OPEN_TOAST = 'OPEN_TOAST',
  CLOSE_TOAST = 'CLOSE_TOAST',
  REMOVE_TOAST = 'REMOVE_TOAST',
}

export const OPEN_MODAL = 'crossword/modal/OPEN_MODAL'
export const CLOSE_MODAL = 'crossword/modal/CLOSE_MODAL'
export const REMOVE_MODAL = 'crossword/modal/REMOVE_MODAL'

export const OPEN_TOAST = 'crossword/modal/OPEN_TOAST'
export const CLOSE_TOAST = 'crossword/modal/CLOSE_TOAST'
export const REMOVE_TOAST = 'crossword/modal/REMOVE_TOAST'

type OpenModalAction = {
  type: typeof OPEN_MODAL
  payload: {
    name: ConnectionsModal
  }
}

type CloseModalAction = {
  type: typeof CLOSE_MODAL
  payload: {
    isCancelled: boolean // used in analytics middleware
  }
}

type RemoveModalAction = {
  type: typeof REMOVE_MODAL
}

export type ConnectionsModalAction =
  | OpenModalAction
  | CloseModalAction
  | RemoveModalAction

export const openModal = (
  name: ConnectionsModal,
): OpenModalAction => ({
  type: OPEN_MODAL,
  payload: { name },
})

export const closeModal = (
  isCancelled: boolean,
): CloseModalAction => ({
  type: CLOSE_MODAL,
  payload: { isCancelled },
})

export const removeModal = () => ({
  type: REMOVE_MODAL,
})

type OpenToastAction = {
  type: typeof OPEN_TOAST
  payload: {
    name: ConnectionsToast
  }
}

type CloseToastAction = {
  type: typeof CLOSE_TOAST
  payload: {
    isCancelled: boolean // used in analytics middleware
  }
}

type RemoveToastAction = {
  type: typeof REMOVE_TOAST
}

export type ConnectionToastAction =
  | OpenToastAction
  | CloseToastAction
  | RemoveToastAction

export const openToast = (
  name: ConnectionsToast,
): OpenToastAction => ({
  type: OPEN_TOAST,
  payload: { name },
})

export const closeToast = (
  isCancelled: boolean,
): CloseToastAction => ({
  type: CLOSE_TOAST,
  payload: { isCancelled },
})

export const removeToast = () => ({
  type: REMOVE_TOAST,
})
