import { combineReducers, Reducer } from 'redux'

import { ModalState, ToastState } from './types'
import {
  CLOSE_MODAL,
  OPEN_MODAL,
  REMOVE_MODAL,
  CLOSE_TOAST,
  OPEN_TOAST,
  REMOVE_TOAST,
  ConnectionsModalAction,
  ConnectionToastAction,
} from './actions'

const initialModalState: ModalState = {
  name: null,
  isClosing: false,
}

const modal: Reducer<ModalState, ConnectionsModalAction> = (
  state = initialModalState,
  action,
) => {
  switch (action.type) {
    case OPEN_MODAL: {
      return {
        name: action.payload.name,
        isClosing: false,
      }
    }

    case CLOSE_MODAL: {
      return {
        name: state.name,
        isClosing: true,
      }
    }

    case REMOVE_MODAL: {
      return initialModalState
    }

    default:
      return state
  }
}

const initialToastState: ToastState = {
  name: null,
  isClosing: false,
}

const toast: Reducer<ToastState, ConnectionToastAction> = (
  state = initialToastState,
  action,
) => {
  switch (action.type) {
    case OPEN_TOAST: {
      return {
        name: action.payload.name,
        isClosing: false,
      }
    }

    case CLOSE_TOAST: {
      return {
        name: state.name,
        isClosing: true,
      }
    }

    case REMOVE_TOAST: {
      return initialToastState
    }

    default:
      return state
  }
}

export const reducer = combineReducers({
  modal,
  toast,
})

export type ConnectionsStoreState = ReturnType<typeof reducer>
