import { ContextType } from 'react'

import { ThemeContext } from './components/Theme'
import { Level } from './levelTypes'

export type MistakeCount = 0 | 1 | 2 | 3 | 4

export const CongratsTitleByMistakesMade = {
  0: 'Perfect',
  1: 'Great',
  2: 'Solid',
  3: 'Phew',
  4: 'Next Time',
}

export type Puzzle = {
  print_date: string
  id: number
  editor: string
  categories: Category[]
}

export interface Category {
  title: string
  solved: { order: number } | false
  level: Level
  cards: Card[]
}

export interface Card {
  content: string
  originalPosition: number
  level: Level
  selected: boolean
  currentPosition: number
}

export type Guess = { cards: string; correct: boolean }

export type Board = {
  cards: Card[]
  categories: Category[]
  guesses: Guess[]
}

export enum AnimationEnum {
  SHAKE = 'shake',
  BOUNCE = 'bounce',
  SHUFFLE = 'shuffle',
}

export type ThemeContextType = ContextType<typeof ThemeContext>

export type CardsAnimation = false | AnimationEnum

export type CardAnimation =
  | { effect: AnimationEnum.SHAKE }
  | { effect: AnimationEnum.SHUFFLE; selected: boolean }
  | { effect: AnimationEnum.BOUNCE; timeout: number }

export type ConnectionsLSCard = {
  id: number
  selected: boolean
  text: string
  group: string
  solved: boolean | { order: number }
}

export type GameStateProps =
  | number
  | string
  | string[]
  | boolean
  | string[][]
  | ConnectionsLSCard[][]
  | null
  | undefined

export type ConnectionsLSGameState = Partial<{
  [key: string]: GameStateProps
  attemptsRemaining: number
  dayOfTest: number
  gameStarted: boolean
  groupsFound: string[]
  highContrastEnabled: boolean // no longer surfaced or updated
  history: string[][]
  loading: boolean // always false
  playedBefore: boolean
  savedBoard: ConnectionsLSCard[][] | null
  status?: string // this will be set to 'full' if we run out of LS space
}>

export type ConnectionsProgress = {
  currentGameState: Puzzle
  currentProgress: {
    guesses: Guess[]
    playedBefore: boolean
  }
}
