// @ts-nocheck
import isPhone, { IS_PHONE_QUERY } from '../isPhone'

describe('isPhone', () => {
  afterEach(() => {
    jest.restoreAllMocks()
  })
  it('returns false if no window object', () => {
    jest.spyOn(global, 'window', 'get').mockReturnValue(undefined)
    expect(isPhone()).toEqual(false)
  })
  it('returns false if no window.matchMedia', () => {
    jest.spyOn(global, 'window', 'get').mockReturnValue({
      matchMedia: undefined,
    })
    expect(isPhone()).toEqual(false)
  })
  it('returns false if window.matchMedia returns falsey', () => {
    jest.spyOn(global, 'window', 'get').mockReturnValue({
      matchMedia: () => undefined,
    })
    expect(isPhone()).toEqual(false)
  })
  it('passes expected value to window.matchMedia', () => {
    const matchMediaSpy = jest.fn()
    jest.spyOn(global, 'window', 'get').mockReturnValue({
      matchMedia: matchMediaSpy,
    })
    isPhone()
    expect(matchMediaSpy).toHaveBeenCalledWith(IS_PHONE_QUERY)
  })
  it('returns expected value from window.matchMedia.matches', () => {
    jest.spyOn(global, 'window', 'get').mockReturnValue({
      matchMedia: (val) => ({
        matches: val === IS_PHONE_QUERY,
      }),
    })
    jest
      .spyOn(global.navigator, 'userAgent', 'get')
      .mockReturnValue('iPhone')
    expect(isPhone()).toEqual(true)
  })
})
