import React from 'react'

import { navigateBack } from '../../../helpers/navigateBack'

import styles from './Error.module.scss'

export type ErrorName = 'offline' | 'default' | null

const ErrorIcon = ({ errorType }: { errorType?: ErrorName }) => {
  const offlineIcon =
    errorType === 'offline' ? styles.offlineErrorIcon : false

  return (
    <span
      role="img"
      aria-hidden
      className={offlineIcon || styles.defaultErrorIcon}
    />
  )
}

const OfflineMessage = () => (
  <div className={styles.errorContent}>
    <h1 className={styles.errorTitle}>Oh no!</h1>
    <h2 className={styles.errorSubtitle}>You&rsquo;re offline.</h2>
    <p className={styles.errorText}>
      Find a connection and come back.
    </p>
  </div>
)

const DefaultMessage = () => (
  <div className={styles.errorContent}>
    <h1 className={styles.errorTitle}>Oops!</h1>
    <h2 className={styles.errorSubtitle}>Something went wrong.</h2>
    <p className={styles.errorText}>Please try again later.</p>
  </div>
)

interface ErrorProps {
  errorType: ErrorName
  showBackButton?: boolean
}

export default function ({
  errorType,
  showBackButton = false,
}: ErrorProps) {
  // Only show the "Back" button if user was referred internally
  const showCTA =
    showBackButton || document.referrer.includes('nytimes')

  if (!errorType) return null

  const errorOptions = {
    offline: {
      icon: <ErrorIcon errorType="offline" />,
      content: <OfflineMessage />,
    },
    default: {
      icon: <ErrorIcon />,
      content: <DefaultMessage />,
    },
  }

  const { icon, content } =
    errorOptions[errorType] || errorOptions.default

  return (
    <div
      className={styles.container}
      style={{
        backgroundColor: '#b4a8ff',
        color: '#000',
      }}
      role="dialog"
    >
      <div className={styles.errorContainer}>
        {icon}
        {content}
        {showCTA && (
          <button
            className={styles.backButton}
            style={{
              backgroundColor: '#000',
              color: '#fff',
            }}
            type="button"
            data-testid="back"
            onClick={() => {
              navigateBack()
            }}
          >
            Back
          </button>
        )}
      </div>
    </div>
  )
}
