export const SLIDE_TIME_IN_MS = 500

function shrink(e) {
  this.classList.add('shrunk')
  e.preventDefault()
}

function grow(e) {
  this.classList.remove('shrunk')
  e.preventDefault()
}

// Adds mobile touch behaviors so buttons shrink and grow as intended.
export function addShrinkGrowListeners(node) {
  node.addEventListener('pointerdown', shrink, { passive: false })
  node.addEventListener('pointerup', grow, { passive: false })
  node.addEventListener('pointercancel', grow, { passive: false })
  node.addEventListener('pointerout', grow, { passive: false })
}

function darken(e) {
  this.classList.add('touched')
  e.preventDefault()
}

function lighten(e) {
  this.classList.remove('touched')
  e.preventDefault()
}

export function addPressedListeners(node) {
  node.addEventListener('pointerdown', darken, { passive: false })
  node.addEventListener('pointerup', lighten, { passive: false })
  node.addEventListener('pointercancel', lighten, { passive: false })
  node.addEventListener('pointerout', lighten, { passive: false })
}

// fetches pixel position from a node's styles (e.g. 'left: 0px') and converts to an integer
export function parsePosition(node, property) {
  const px = getComputedStyle(node)
    .getPropertyValue(property)
    .replace('px', '')

  return parseInt(px)
}

const ids = [null, null, null, null]
let slidingElementCount = -1
export function slideAnim(item, startPos, endPos) {
  slidingElementCount++ // eslint-disable-line no-plusplus
  let posTop = startPos[0]
  let posLeft = startPos[1]
  const destinationPosTop = endPos[0]
  const destinationPosLeft = endPos[1]
  const distanceToMoveTop = Math.abs(posTop - destinationPosTop)
  const distanceToMoveLeft = Math.abs(posLeft - destinationPosLeft)
  item.style.zIndex = 2
  clearInterval(ids[slidingElementCount])
  const msPerFrame = 10
  const numberOfFrames = SLIDE_TIME_IN_MS / msPerFrame

  const distanceToMoveTopPerFrame = distanceToMoveTop / numberOfFrames
  const distanceToMoveLeftPerFrame =
    distanceToMoveLeft / numberOfFrames

  function frame() {
    // final frameshare
    if (
      Math.abs(posTop - destinationPosTop) < 0.05 &&
      Math.abs(posLeft - destinationPosLeft) < 0.05
    ) {
      clearInterval(ids[slidingElementCount])
      slidingElementCount-- // eslint-disable-line no-plusplus
      item.style.zIndex = 0
    } else {
      // top down movement
      if (posTop > destinationPosTop) {
        posTop -= distanceToMoveTopPerFrame
      } else if (posTop < destinationPosTop) {
        posTop += distanceToMoveTopPerFrame
      }

      // left right movement
      if (posLeft > destinationPosLeft) {
        posLeft -= distanceToMoveLeftPerFrame
      } else if (posLeft < destinationPosLeft) {
        posLeft += distanceToMoveLeftPerFrame
      }
      item.style.top = `${posTop}px`
      item.style.left = `${posLeft}px`
    }
  }

  ids[slidingElementCount] = setInterval(frame, msPerFrame)
}
