const INTERVAL_MS = 200

const ONE_SECOND = 1000
const ONE_MINUTE = ONE_SECOND * 60
const ONE_HOUR = ONE_MINUTE * 60
const ONE_DAY = ONE_HOUR * 24

function padDigit(digit) {
  return digit.toString().padStart(2, '0')
}

function updateTimer(display, target) {
  const now = new Date().getTime()
  const msDiff = Math.floor(target - now)
  let time
  if (msDiff <= 0) {
    time = '00:00:00'
  } else {
    const hours = Math.floor((msDiff % ONE_DAY) / ONE_HOUR)
    const minutes = Math.floor((msDiff % ONE_HOUR) / ONE_MINUTE)
    const seconds = Math.floor((msDiff % ONE_MINUTE) / ONE_SECOND)

    time = `${padDigit(hours)}:${padDigit(minutes)}:${padDigit(
      seconds,
    )}`
  }
  display.textContent = time
}

export function createCountdownTimer() {
  const countdownTimerContainer = document.createElement('div')
  countdownTimerContainer.id = 'timer'

  const countdownTimer = document.createElement('div')
  const targetDate = new Date()
  // Set to tomorrow
  targetDate.setDate(targetDate.getDate() + 1)
  // Set to midnight
  targetDate.setHours(0, 0, 0, 0)
  const targetEpochMS = targetDate.getTime()

  const intervalID = setInterval(() => {
    updateTimer(countdownTimer, targetEpochMS)
  }, INTERVAL_MS)

  // track the intervalID so we can clear it later
  countdownTimerContainer.setAttribute('data-id', intervalID)
  countdownTimerContainer.appendChild(countdownTimer)

  return countdownTimerContainer
}

export function destroyCountdownTimer() {
  const timer = document.getElementById('timer')

  if (timer && timer.dataset.id) {
    const { id } = timer.dataset
    clearInterval(parseInt(id))

    if (timer.parentElement) {
      timer.parentElement.removeChild(timer)
    }
  }
}
