import { browserDetect, isMobileUser } from './deviceIdentifiers'
import { checkLocalStorage } from './freeUpStorage'

const FEEDBACK_LINK = 'mailto:nytgames@nytimes.com'

function capitalize(str) {
  return str.charAt(0).toUpperCase() + str.slice(1)
}

const createQueryString = (obj) => {
  const outStr = []

  Object.keys(obj).forEach((p) => {
    outStr.push(
      `${encodeURIComponent(p)}=${encodeURIComponent(obj[p])}`,
    )
  })

  return `?${outStr.join('&')}`
}

const getFeedbackLink = (gameName = 'Prototype', isBug = false) => {
  const tz = new Date().getTimezoneOffset()
  const feedbackTypeString = isBug ? 'Bug Report' : 'Feedback'
  const puzzleDataVariant =
    window.abra?.getVariant('GAMES_connectionsPuzzleDataV1_1103') ||
    'inactive'
  let used
  let remaining

  try {
    const lsUsage = checkLocalStorage()
    remaining = lsUsage.remaining > 0 ? lsUsage.remaining : 0
    used = lsUsage.used

    // format for feedback
    used =
      used > 1000 ? `${(used / 1000).toFixed(2)} MB` : `${used} KB`
    remaining =
      remaining > 1000
        ? `${(remaining / 1000).toFixed(2)} MB`
        : `${remaining} KB`
  } catch (e) {
    console.log(e)
    // noop
  }

  const body = `\r\n\r\n
--
Device summary:
Page: /games/${gameName.toLowerCase()}
Platform: ${isMobileUser() ? 'Web (Mobile)' : 'Web (Desktop)'} 
Browser: ${capitalize(browserDetect())}
Screen Resolution: ${window.screen.width} x ${window.screen.height}
Viewport Size: ${document.documentElement.clientWidth} x ${
    document.documentElement.clientHeight
  }
Timezone: ${`UTC${tz > 0 ? '' : '+'}${tz / -60}`}
${used && `LS Used: ${used}`}
${remaining && `LS Available: ${remaining}`}
Build: 4-8-4
Puzzle Data Variant: ${puzzleDataVariant}
`

  return (
    FEEDBACK_LINK +
    createQueryString({
      subject: `${gameName} ${feedbackTypeString}`,
      body,
    })
  )
}

export default getFeedbackLink
