import initGTM from './GTM'
import { setUpEvents } from './modal'
import { renderToolbar, renderPuzzleDate } from './toolbar'
import Analytics from './analytics'
import {
  getNthDayOfTest,
  getSavedState,
  resetGameState,
  setGameState,
  updateGameState,
} from './game-state'
import {
  loadTodaysPuzzle,
  addFeedbackLinks,
  addListenersToUIButtons,
} from './gameManager'
import {
  addListenersToItemButtons,
  openModalConnections,
  addModalEventListeners,
  setSubmitButtonActive,
} from './gui'

export default function startGame() {
  initGTM()

  setUpEvents()
  addListenersToItemButtons()
  addModalEventListeners()
  addFeedbackLinks()
  setSubmitButtonActive(false)

  // update dates
  // document.getElementById('todays-date-title').innerHTML =
  //   todaysDateAsString()

  // load saved data
  const savedState = getSavedState()
  const { playedBefore = false, dayOfTest = 0 } = savedState

  const localStorageIsFull =
    savedState.status && savedState.status === 'full'

  // check for an in-progress game
  if (!localStorageIsFull) {
    const gameIsInProgress =
      dayOfTest && dayOfTest === getNthDayOfTest()

    // replace global game state with saved state
    if (gameIsInProgress) {
      setGameState(savedState)
    }
  } else {
    // Try to reset local storage in case more space has become available.
    resetGameState()
  }

  if (!playedBefore) {
    openModalConnections('help')
    try {
      Analytics.help()
    } catch (e) {
      console.log(e)
    }
    updateGameState('playedBefore', true)
  }

  renderToolbar('Connections', true, true, true)
  renderPuzzleDate()
  addListenersToUIButtons()

  // By default, load puzzle by day.
  loadTodaysPuzzle()
  // renderSettingToggles(savedState.highContrastEnabled)
}
