import { isFirefox, isMobileUser } from './deviceIdentifiers'

const { clipboard } = navigator

// This function opens the "navigator" drawer on mobile devices
// and copies text to the user's clipboard on desktop web.

// Based off phoenix android sharing code:
// https://github.com/nytimes/games-phoenix/blob/main/src/games/wordle/js/components/Stats/share.ts#L54
function androidShare(message, onCopy, onFail, event) {
  try {
    const { target } = event
    // use textarea instead of input so \n works
    const tempInput = document.createElement('textarea')
    tempInput.style.position = 'absolute'
    tempInput.style.left = '-1000px'
    tempInput.style.top = '-1000px'
    // append faux input to parent element so that it is not triggered as outside current modal for a11y
    target.parentElement.appendChild(tempInput)
    tempInput.value = message
    tempInput.select()
    document.execCommand('copy')
    target.parentElement.removeChild(tempInput)
    onCopy()
  } catch (e) {
    onFail(e)
  }
}

export function share(message, onCopy, onFail, event) {
  const shareData = {
    text: message,
  }

  const isAndroid = /android/i.test(navigator.userAgent)
  const canShareNatively =
    !isFirefox() &&
    navigator.share !== undefined &&
    !!navigator.canShare &&
    navigator.canShare(shareData)

  try {
    if (isMobileUser() && canShareNatively) {
      navigator.share(shareData)
    } else if (isAndroid) {
      // Android doesn't always return true from isMobileUser
      if (canShareNatively) {
        navigator.share(shareData)
      } else {
        androidShare(message, onCopy, onFail, event)
      }
    } else {
      clipboard.writeText(message).then(onCopy, onFail)
    }
  } catch (e) {
    // If for some reason an android device hit the first "if" in the try
    // and failed on navigator.share, we'll re-attempt with the special Android
    // copy to clipboard and otherwise fall back to clipboard.writeText.
    if (isAndroid) {
      androidShare(message, onCopy, onFail, event)
    } else {
      onFail(e)
    }
  }
}
