// To add a toolbar to your game, simply include a <div> with an id of toolbar
// in your index html, include a script tag that links to this script (nav.js),
// and call renderToolbar() in your onload function.
// import {
//   createNavButton,
//   renderLogoNavAndTitleBar,
//   renderNav,
// } from './nav'

// By default, the button's onclick just opens the specified
// modal. Additional event listeners (like analytics) can be
// added from your game's scripts.
const createToolbarIconButton = (type) => {
  const bt = document.createElement('button')
  bt.id = `${type}-button`
  bt.setAttribute('aria-label', type)
  bt.classList.add('toolbar-button')

  if (!document.getElementById(`${type}-modal`)) {
    throw new Error(
      `Missing modal with id #${type}-modal. Please add one and try again.`,
    )
  }
  bt.addEventListener('click', () => window.openModal(type))

  const icon = document.createElement('i')
  icon.classList.add(`${type}-icon`)

  bt.appendChild(icon)
  return bt
}

// Elements to be rendered in the toolbar
// Left, center, and right should each be an array of HTML elements
// help and settings are bools that default to false. Nav defaults
// to true.
export const renderToolbar = (
  game,
  help = false,
  settings = false,
  nav = true,
  left = [],
  center = [],
  right = [],
) => {
  if (settings) right.push(createToolbarIconButton('settings'))

  if (help) right.push(createToolbarIconButton('help'))
  const toolbar = document.getElementById('toolbar')

  const toolbarContainer = document.createElement('div')
  toolbarContainer.classList.add('toolbar-container')

  const toolbarContent = document.createElement('div')
  toolbarContent.classList.add('toolbar-content')

  // left
  const toolbarLeft = document.createElement('div')
  toolbarLeft.classList.add('toolbar-left')
  toolbarLeft.id = 'toolbar-left'

  left.forEach((item) => toolbarLeft.appendChild(item))

  // center
  const toolbarCenter = document.createElement('div')
  toolbarCenter.classList.add('toolbar-center')
  toolbarCenter.id = 'toolbar-center'
  center.forEach((item) => toolbarCenter.appendChild(item))

  // right
  const toolbarRight = document.createElement('div')
  toolbarRight.classList.add('toolbar-right')
  toolbarRight.id = 'toolbar-right'
  right.forEach((item) => toolbarRight.appendChild(item))

  toolbarContent.appendChild(toolbarLeft)
  toolbarContent.appendChild(toolbarCenter)
  toolbarContent.appendChild(toolbarRight)

  toolbarContainer.appendChild(toolbarContent)
  toolbar.appendChild(toolbarContainer)
}

// e.g. "reveal" or other game features
export const createToolbarTextButton = (text, modalName) => {
  const bt = document.createElement('button')
  bt.innerText = text
  bt.id = `${modalName}-button`
  bt.setAttribute('aria-label', text)
  bt.classList.add(`toolbar-button`)

  if (modalName) {
    bt.addEventListener('click', () => window.openModal(modalName))
  }

  const icon = document.createElement('i')
  icon.classList.add(`${text}-icon`)

  bt.appendChild(icon)
  return bt
}

export const renderPuzzleDate = () => {
  const today = new Date()
  const stringifiedDate = `${today.toLocaleString('default', {
    month: 'long',
  })} ${today.getDate()}, ${today.getFullYear()}`

  const dateElement = document.querySelector('.pz-game-date')

  if (dateElement) {
    dateElement.innerText = stringifiedDate
  }
}
