/* eslint-disable prefer-rest-params, no-extend-native, func-names, no-plusplus */
// JS Date is _insane_. Add 1 to zero-indexed month to get accurate # of days in that month
const getDaysInMonth = function getDaysInMonth(date) {
  return new Date(
    date.getFullYear(),
    date.getMonth() + 1,
    0,
  ).getDate()
}

// startDate format: 'MM/DD/YYY'
export const getNthDayOfTest = function getNthDayOfTest(
  startDateParam,
) {
  // Starts at 0
  const startOfTest = new Date(startDateParam)
  const today = new Date()

  const startDate = startDateParam || startOfTest.getDate()

  const todaysDate = today.getDate()

  const startMonth = startOfTest.getMonth()
  const todaysMonth = today.getMonth()
  const sameMonth = startMonth === todaysMonth

  const startYear = startOfTest.getFullYear()
  const todaysYear = today.getFullYear()
  const sameYear = todaysYear === startYear

  if (todaysDate === startDate) {
    return 0
  }

  if (sameYear && sameMonth && todaysDate > startDate) {
    return todaysDate - startDate
  }

  const remainderOfStartMonth =
    getDaysInMonth(startOfTest) - startDate

  return remainderOfStartMonth + todaysDate
}

// Rendering + Animation
const animate = function animate(el, animation) {
  const duration =
    arguments.length > 2 && arguments[2] !== undefined
      ? arguments[2]
      : 1000

  el.classList.toggle(`${animation}`)
  setTimeout(function timeout() {
    return el.classList.toggle(`${animation}`)
  }, duration)
}

// Array Manipulation Help
Array.prototype.randomInto = function randomInto() {
  return this[Math.floor(Math.random() * this.length)]
}

// seeded random, expects a global constiable called RANDOM_SEED
Array.prototype.seededRandomInto = function seededRandomInto() {
  if (typeof window.RANDOM_SEED === 'undefined') {
    window.RANDOM_SEED = Math.floor(Math.random() * 10000)
    window.START_SEED = window.RANDOM_SEED
  }

  function random() {
    const x = Math.sin(window.RANDOM_SEED++) * 10000
    return x - Math.floor(x)
  }

  return this[Math.floor(random() * this.length)]
}

function shuffle(array) {
  let currentIndex = array.length
  let temporaryValue
  let randomIndex

  // While there remain elements to shuffle...
  while (currentIndex !== 0) {
    // Pick a remaining element...
    randomIndex = Math.floor(Math.random() * currentIndex)
    currentIndex -= 1

    // And swap it with the current element.
    temporaryValue = array[currentIndex]
    array[currentIndex] = array[randomIndex]
    array[randomIndex] = temporaryValue
  }

  return array
}

// Promise-returning XHR Method
function makeRequest(method, url) {
  return new Promise(function (resolve, reject) {
    const xhr = new XMLHttpRequest()
    xhr.open(method, url)
    xhr.onload = function () {
      if (this.status >= 200 && this.status < 300) {
        resolve(xhr.response)
      } else {
        reject(
          new Error({
            status: this.status,
            statusText: xhr.statusText,
          }),
        )
      }
    }

    xhr.onerror = function () {
      reject(
        new Error({
          status: this.status,
          statusText: xhr.statusText,
        }),
      )
    }
    xhr.send()
  })
}

// Say goodbye just once
function mustWeSayGoodbye(game) {
  try {
    const key = `${game}-bid-farewell`
    const saidGoodbye = localStorage.getItem(key)
    localStorage.setItem(key, 'yes')
    return !saidGoodbye
  } catch (e) {
    console.error('localStorage error')
    return false
  }
}

// Show Tutorial just once
function mustWeShowTutorial(game) {
  try {
    const key = `${game}-tutorial-completed`
    return localStorage.getItem(key)
  } catch (e) {
    console.error('localStorage error')
    return false
  }
}

function markTutorialCompleted(game) {
  try {
    const key = `${game}-tutorial-completed`
    localStorage.setItem(key, 'true')
    return
  } catch (e) {
    console.error('localStorage error')
  }
}

export function todaysDateAsString() {
  const today = new Date()
  return `${today.toLocaleString('default', {
    month: 'long',
  })} ${today.getDate()}, ${today.getFullYear()}`
}
