import React from 'react'
import { mount, shallow } from 'enzyme'
import { createStore } from 'redux'
import { Provider } from 'react-redux'

import { useUser } from 'user'

import PuzzleCard from '../../../shared/hub/PuzzleCard/PuzzleCard'

import CardView from './CardView'

jest.mock('foundation', () => ({}))

jest.mock('user', () => ({
  useUser: jest.fn().mockReturnValue({ userType: {} }),
}))

describe('ARCHIVE VIEWER / CARD VIEW', () => {
  test('renders island cards', () => {
    // pass in 3 puzzle objects
    const view = shallow(
      <CardView puzzles={[{ id: 1 }, { id: 2 }, { id: 3 }]} />,
    )

    // renders 3 puzzle cards
    expect(view.find(PuzzleCard)).toHaveLength(3)
  })

  test('renders no cards if no puzzles are passed in', () => {
    // pass in an empty array
    const view = shallow(<CardView puzzles={[]} />)

    // renders 0 puzzle cards
    expect(view.find(PuzzleCard)).toHaveLength(0)
  })

  test('renders loading animation while loading puzzles', () => {
    // puzzle data is null
    const view = shallow(<CardView puzzles={null} />)

    // renders loading class
    expect(view.find('.archive_is-loading')).toHaveLength(1)
  })

  test('sends subscribed user to the correct puzzle', () => {
    useUser.mockReturnValue({
      userType: {
        regiId: 'g',
        hasXwd: true,
        isLoggedIn: true,
      },
    })
    const view = mount(
      <Provider store={createStore(() => {})}>
        <CardView
          puzzles={[
            {
              formatType: 'Normal',
              percentFilled: 0,
              printDate: '2021-06-18',
              publishType: 'Daily',
              puzzleId: 19306,
            },
          ]}
        />
      </Provider>,
    )

    const cardLink = view
      .find(PuzzleCard)
      .find('.puzzleAction')
      .props().href

    expect(cardLink).toEqual('/crosswords/game/daily/2021/06/18')
  })
})
