import React from 'react'
import propTypes from 'prop-types'

import { useUser } from 'user'

import PuzzleCard from '../../../shared/hub/PuzzleCard/PuzzleCard'
import createUrls from '../../../shared/hub/utils/createUrls'
import { formatDate } from '../../../shared/hub/utils/time'

import { prettyJoin } from './utils'

export const makeLink = (url, label) =>
  url ? <a href={url}>{label}</a> : '—'

const ListItem = ({ puzzle }) => {
  const { userType } = useUser()

  const { author, publishType, printDate, title } = puzzle
  const isDailyOrMini = ['Daily', 'Mini'].includes(publishType)

  const date = formatDate(printDate, '{nyt-m} D, YYYY')

  const newTitle = isDailyOrMini
    ? formatDate(puzzle.printDate, 'dddd')
    : title
  const formattedConstructors = prettyJoin(author.split(' and '))

  const urls = createUrls(puzzle)
  const puzzlePDF = makeLink(
    urls.newspaper.puzzle || urls.generated.puzzle,
    'Puzzle',
  )

  const solutionPDF = makeLink(
    urls.newspaper.solution || urls.generated.solution,
    'Solution',
  )

  const playURL = makeLink(
    urls.play || urls.newspaper.puzzle,
    newTitle,
  )

  return (
    <div>
      <div className="archive_list-item archive_list-columns">
        <div className="archive_icon-container">
          <PuzzleCard puzzle={puzzle} type="Icon" user={userType} />
        </div>
        <div className="archive_title">{playURL}</div>
        <div className="archive_date">{date}</div>
        <div className="archive_author">{formattedConstructors}</div>
        <div className="archive_puzzle-actions">
          <div className="archive-puzzle-pdf">{puzzlePDF}</div>
          <div className="archive-solutions-pdf">{solutionPDF}</div>
        </div>
      </div>
      <div className="archive_mobile-list-item">
        <div className="archive_icon-container">
          <PuzzleCard puzzle={puzzle} type="Icon" user={userType} />
        </div>
        <div>
          <div className="archive_top">
            <div className="archive_title">{newTitle}</div>
            <div className="archive_date">{date}</div>
          </div>
          <div className="archive_author">{`By ${formattedConstructors}`}</div>
        </div>
      </div>
    </div>
  )
}

ListItem.propTypes = {
  puzzle: propTypes.shape({
    author: propTypes.string,
    publishType: propTypes.string,
    printDate: propTypes.string,
    title: propTypes.string,
  }),
}

export default ListItem
