import React from 'react'
import { shallow } from 'enzyme'

import PuzzleCard from '../../../shared/hub/PuzzleCard/PuzzleCard'

import ListItem, { makeLink } from './ListItem'

jest.mock('user', () => ({
  useUser: jest.fn().mockReturnValue({ userType: {} }),
}))

describe('ARCHIVE VIEWER / LIST ITEM', () => {
  let defaultProps

  beforeEach(() => {
    defaultProps = {
      puzzle: {
        author: 'Kitten',
        publishType: 'Daily',
        printDate: '2021-05-01',
        title: '',
      },
    }
  })

  test('renders PuzzleCard', () => {
    const view = shallow(<ListItem {...defaultProps} />)
    // we expect 2 puzzle cards, one is hidden by default for mobile
    // devices
    expect(view.find(PuzzleCard)).toHaveLength(2)
  })

  test('renders correct date format', () => {
    const view = shallow(<ListItem {...defaultProps} />)

    expect(view.find('.archive_date').first().text()).toEqual(
      'May 1, 2021',
    )
  })

  describe('LIST ITEM / MAKELINK', () => {
    test('renders a link if url is provided', () => {
      const link = makeLink('/kittens', 'kittens link')
      expect(link).toEqual(<a href="/kittens">kittens link</a>)
    })

    test('returns a string - if url is not provided', () => {
      const link = makeLink('', 'kittens link')
      expect(link).toEqual('—')
    })

    test('renders an empty link if no label is provided', () => {
      const link = makeLink('/kittens', '')
      expect(link.props.children).toHaveLength(0)
    })
  })
})
