import React from 'react'
import propTypes from 'prop-types'
import moment from 'moment'
import cn from 'classnames'

import ListItem from './ListItem'

export const SORT_ASC = 'SORT_ASC'
export const SORT_DESC = 'SORT_DESC'

const sortByDate = (direction) => (a, b) => {
  if (direction === SORT_ASC) {
    return moment(a.printDate).isAfter(moment(b.printDate)) ? 1 : -1
  }

  return moment(a.printDate).isBefore(moment(b.printDate)) ? 1 : -1
}

const getTypeHeader = (type) => {
  if (type === 'bonus') return 'TITLE'

  if (['mini', 'daily'].includes(type)) return 'DAY OF WEEK'

  return 'TYPE'
}

const getSortSymbol = (sort) => (sort === SORT_ASC ? '▲' : '▼')

/* eslint-disable react/no-array-index-key */
const ListView = ({ puzzles, type, setSort, sort }) => (
  <div className="archive_list-view">
    <div className="archive_list-view-header archive_list-columns">
      <div className="archive_align-center" />
      <div>{getTypeHeader(type)}</div>
      <div
        className="archive_date-sort-toggle"
        role="button"
        onClick={() => {
          setSort(sort === SORT_DESC ? SORT_ASC : SORT_DESC)
        }}
      >
        DATE
        <span className="archive_arrow">{getSortSymbol(sort)}</span>
      </div>
      <div>CONSTRUCTOR</div>
      <div />
    </div>
    <div
      className={cn('archive_viewer-content', {
        isLoading: !puzzles,
      })}
    >
      {(puzzles || []).sort(sortByDate(sort)).map((puzz, idx) => (
        <ListItem puzzle={puzz} key={idx} />
      ))}
    </div>
  </div>
)
/* eslint-enable react/no-array-index-key */

ListView.propTypes = {
  puzzles: propTypes.arrayOf(propTypes.shape({})),
  type: propTypes.string,
  setSort: propTypes.func,
  sort: propTypes.string,
}

export default ListView
