import React from 'react'
import { shallow } from 'enzyme'

import { trackImpression } from '../../helpers/tracking'

import { Upsell } from './Upsell'

jest.mock('foundation', () => ({
  userType: {
    hasXwd: true,
  },
}))

jest.mock('../../helpers/tracking', () => ({
  trackImpression: jest.fn(),
}))

describe('ARCHIVE VIEWER / UPSELL', () => {
  test('emits analytic tracking event', () => {
    // render the Upsell component
    shallow(
      <Upsell
        loginUrl="/brownies"
        subscribeUrl="/subscribe/brownie"
      />,
    )

    // verify trackImpression was called with the
    // expected parameters
    expect(trackImpression).toHaveBeenCalledWith(
      'hardpaywall',
      'archive',
    )
  })

  test('renders subscribe link', () => {
    // render the Upsell component
    const view = shallow(
      <Upsell
        loginUrl="/brownies"
        subscribeUrl="/subscribe/brownie"
      />,
    )

    // subscribe button is visible
    expect(view.find('.archive_subscribe-button')).toHaveLength(1)
  })

  test('renders login link', () => {
    // render the Upsell component
    const view = shallow(
      <Upsell
        loginUrl="/brownies"
        subscribeUrl="/subscribe/brownie"
      />,
    )

    // subscribe button is visible
    expect(view.find('.archive_tiny-text')).toHaveLength(1)
  })
})
