import React from 'react'
import propTypes from 'prop-types'
import { compose } from 'redux'

import { withUser } from 'user'

import {
  GRID_MODE,
  LIST_MODE,
} from '../../shared/ModeToggle/ModeToggle'

import withArchiveData from './withArchiveData'
import CardView from './CardView'
import CalendarView from './CalendarView'
import ListView from './ListView'

const isEmpty = (puzzles) => puzzles && puzzles.length === 0

export const getViewStyle = ({ mode, type }) => {
  if (mode === LIST_MODE) return ListView

  return ['daily', 'mini'].includes(type) ? CalendarView : CardView
}

export const SimpleView = ({ mode, puzzles, type, ...props }) => {
  const ViewComponent = getViewStyle({ mode, type })

  return isEmpty(puzzles) ? (
    <div className="archive_empty-state">
      <p className="archive_empty-state-message">
        There are no puzzles here yet
      </p>
    </div>
  ) : (
    <ViewComponent
      mode={mode}
      puzzles={puzzles}
      type={type}
      {...props}
    />
  )
}

SimpleView.propTypes = {
  mode: propTypes.oneOf([GRID_MODE, LIST_MODE]),
  puzzles: propTypes.arrayOf(propTypes.object),
  type: propTypes.string,
}

const View = compose(withUser, withArchiveData)(SimpleView)

export default View
