import React from 'react'
import { shallow } from 'enzyme'

import {
  GRID_MODE,
  LIST_MODE,
} from '../../shared/ModeToggle/ModeToggle'

import CardView from './CardView'
import CalendarView from './CalendarView'
import ListView from './ListView'
import { SimpleView, getViewStyle } from './View'

jest.mock('foundation', () => ({}))

jest.mock('user', () => ({
  withUser: jest.fn((Component) => (props) => <Component />),
}))

describe('ARCHIVE VIEWER / VIEW', () => {
  describe('UTIL: getViewStyle', () => {
    test('returns calendar view for daily & mini in grid mode', () => {
      const DailyView = getViewStyle({
        mode: GRID_MODE,
        type: 'daily',
      })
      const MiniView = getViewStyle({ mode: GRID_MODE, type: 'mini' })

      expect(DailyView).toBe(CalendarView)
      expect(MiniView).toBe(CalendarView)
    })

    test('returns card view for alt puzzles (bonus) in grid mode', () => {
      const BonusView = getViewStyle({
        mode: GRID_MODE,
        type: 'bonus',
      })
      expect(BonusView).toBe(CardView)
    })

    test('renders list view for any puzzle in list mode', () => {
      const MiniView = getViewStyle({
        mode: LIST_MODE,
        type: 'mini',
      })
      expect(MiniView).toBe(ListView)
    })

    test('defaults to card view if mode and type are not provided', () => {
      const DefaultView = getViewStyle({ mode: null, type: null })
      expect(DefaultView).toBe(CardView)
    })
  })

  test('renders empty view when puzzles are empty', () => {
    const wrapper = shallow(
      <SimpleView mode={LIST_MODE} puzzles={[]} type="daily" />,
    )

    expect(wrapper.find('.archive_empty-state-message')).toHaveLength(
      1,
    )
  })
})
