import { env, xhr } from 'foundation' // eslint-disable-line

import logger from '../../shared/utils/clientLogger'
import { getStartOf, getEndOf } from '../../../shared/hub/utils/time'
import { camelizeKeysDeep } from '../../../shared/hub/utils/miscellany'

const paramsMap = {
  mini: { publish_type: 'mini' },
  daily: { publish_type: 'daily' },
  bonus: { publish_type: 'bonus' },
}

export const paramsToQuerystring = (params) => {
  return Object.keys(params)
    .map((key) => {
      return `${key}=${encodeURIComponent(params[key])}`
    })
    .join('&')
}

const fetchArchivePuzzles = (user, type, year, month) => {
  const startDate = getStartOf(year, month)
  const endDate = getEndOf(year, month)

  const baseUrl = `${env.api}/svc/crosswords/v3/${user.regiId}/puzzles.json`

  const params = {
    ...paramsMap[type],
    sort_order: 'asc',
    sort_by: 'print_date',
    date_start: startDate,
    date_end: endDate,
  }

  const querystring = paramsToQuerystring(params)
  const url = `${baseUrl}?${querystring}`

  return xhr
    .get(url)
    .then((response) => camelizeKeysDeep(response.results))
    .catch((error) => {
      logger.error('failed to fetch archive puzzles', error.stack)
    })
}

export default fetchArchivePuzzles
