import { env, xhr } from 'foundation'

import logger from '../../shared/utils/clientLogger'

import fetchArchivePuzzles, {
  paramsToQuerystring,
} from './fetchArchivePuzzles'

const BASE_URL = `${env.api}/svc/crosswords/v3`

jest.mock('foundation', () => ({
  env: {
    api: 'host',
  },
  xhr: {
    get: jest.fn(),
  },
}))

jest.mock('../../shared/utils/clientLogger', () => ({
  error: jest.fn(),
}))

describe('fetchArchivePuzzles function', () => {
  let user

  beforeEach(() => {
    jest.resetAllMocks()
    user = { regiId: 'uid' }
    xhr.get.mockReturnValue(
      Promise.resolve({
        results: [1, 2, 3],
      }),
    )
  })

  test('with month', () => {
    expect.assertions(2)

    const type = 'daily'
    const year = 2016
    const month = 0

    const promise = fetchArchivePuzzles(user, type, year, month)
    const querystring = paramsToQuerystring({
      publish_type: type,
      sort_order: 'asc',
      sort_by: 'print_date',
      date_start: '2016-01-01',
      date_end: '2016-01-31',
    })

    const url = `${BASE_URL}/${user.regiId}/puzzles.json?${querystring}`
    expect(xhr.get).toHaveBeenCalledWith(url)

    return promise.then((puzzles) => {
      expect(puzzles).toMatchObject([1, 2, 3])
    })
  })

  test('without month', () => {
    expect.assertions(2)

    const type = 'bonus'
    const year = 2016
    const month = undefined

    const promise = fetchArchivePuzzles(user, type, year, month)
    const querystring = paramsToQuerystring({
      publish_type: type,
      sort_order: 'asc',
      sort_by: 'print_date',
      date_start: '2016-01-01',
      date_end: '2016-12-31',
    })

    const url = `${BASE_URL}/${user.regiId}/puzzles.json?${querystring}`
    expect(xhr.get).toHaveBeenCalledWith(url)

    return promise.then((puzzles) => {
      expect(puzzles).toMatchObject([1, 2, 3])
    })
  })

  test('fetch fails', () => {
    expect.assertions(1)

    const err = new Error()
    xhr.get.mockReturnValue(Promise.reject(err))

    const type = 'daily'
    const year = 2016
    const month = 0

    const promise = fetchArchivePuzzles(user, type, year, month)

    return promise.then(() => {
      expect(logger.error).toHaveBeenCalledWith(
        'failed to fetch archive puzzles',
        err.stack,
      )
    })
  })
})
