import { xhr } from 'foundation'

import logger from '../../shared/utils/clientLogger'

import fetchDate from './fetchDate'

jest.mock('foundation', () => ({
  env: {
    api: 'host',
  },
  xhr: {
    get: jest.fn(),
  },
}))

jest.mock('../../shared/utils/clientLogger', () => ({
  error: jest.fn(),
}))

describe('fetchDate', () => {
  beforeEach(() => {
    jest.resetAllMocks()
  })

  it('returns the correct date when expected', () => {
    xhr.get.mockReturnValue(
      Promise.resolve({
        results: { current: { print_date: 'a test date' } },
      }),
    )

    fetchDate().then((res) => {
      const url = 'host/svc/crosswords/v2/oracle/daily.json'
      expect(xhr.get).toHaveBeenCalledWith(url)

      expect(res).toEqual('a test date')
    })
  })

  it('returns undefined if the correct nested data is missing', () => {
    xhr.get.mockReturnValue(
      Promise.resolve({
        results: { current: {} },
      }),
    )

    fetchDate().then((res) => {
      const url = 'host/svc/crosswords/v2/oracle/daily.json'
      expect(xhr.get).toHaveBeenCalledWith(url)

      expect(res).toEqual(undefined)
    })
  })

  it('logs an error if the call fails', () => {
    xhr.get.mockReturnValue(Promise.reject(new Error('test error')))

    fetchDate().catch(() => {
      expect(logger.error).toHaveBeenCalledWith('test error')
    })
  })
})
