import { combineReducers } from 'redux'

import convertToV6 from '../../../../shared/hub/utils/convertToV6'
import {
  CHANGE_BLOCK_OPACITY,
  CHANGE_PRINT_OPTION,
  LOAD_PRINT_PREFS,
  SELECT_PUZZLE,
  CHANGE_PRINT_LAYOUT,
  GET_USER_ID,
} from '../../../../shared/hub/store/constants'

export const defaultPrintOptions = {
  selectedPuzzle: {},
  isGeneratable: false,
  version: 'puzzle',
  showBlack: false,
  showSpoiler: true,
}

// For now, add (don't replace) v6 key/value pairs to v2 data format since other parts of the app reference v2 keys
const printOptionsReducer = (state = defaultPrintOptions, action) => {
  const { payload, type } = action
  switch (type) {
    case SELECT_PUZZLE:
      return {
        ...convertToV6(state, action.payload),
        version: 'puzzle', // default to puzzle for each newly selected puzzle
      }
    case CHANGE_PRINT_OPTION:
      return {
        ...state,
        ...payload,
      }
    default:
      return state
  }
}

const defaultPrintPrefs = {
  opacity: 100,
  layout: undefined,
}

const printPrefsReducer = (state = defaultPrintPrefs, action) => {
  const { type, payload } = action
  switch (type) {
    case LOAD_PRINT_PREFS:
      return payload || state
    case CHANGE_PRINT_LAYOUT:
    case CHANGE_BLOCK_OPACITY: {
      return {
        ...state,
        ...payload,
      }
    }
    default:
      return state
  }
}

const userReducer = (state = {}, { type, payload }) => {
  switch (type) {
    case GET_USER_ID:
      return { ...state, id: payload }
    default:
      return state
  }
}

export const defaultState = {
  ...defaultPrintOptions,
  ...defaultPrintPrefs,
  user: {},
}

export default combineReducers({
  printOptions: printOptionsReducer,
  printPrefs: printPrefsReducer,
  user: userReducer,
})
