import React, { useEffect, useState } from 'react'
import propTypes from 'prop-types'

import { fetchStatsAndStreaks } from '../../../shared/hub/api/api'

export const StatsWrapper = ({ Component, user, ...props }) => {
  const [streakDates, setStreakDates] = useState([[]])

  const userId = user.userType.regiId || ''

  useEffect(() => {
    let unmounted = false

    if (!userId) return

    fetchStatsAndStreaks(userId).then((res) => {
      if (!unmounted && !!res.streaks.dates) {
        setStreakDates(res.streaks.dates)
      }
    })

    return () => {
      unmounted = true
    }
  }, [userId])

  return (
    <Component {...props} streakDates={streakDates} user={user} />
  )
}

StatsWrapper.propTypes = {
  Component: propTypes.func,
  user: propTypes.shape({
    userType: propTypes.shape({ regiId: propTypes.string }),
  }).isRequired,
}

const withStatsAndStreaks = (Component) => (props) =>
  <StatsWrapper {...props} Component={Component} />

export default withStatsAndStreaks
