import React from 'react'
import { shallow } from 'enzyme'

import { fetchStatsAndStreaks } from '../../../shared/hub/api/api'

import { StatsWrapper } from './withStatsAndStreaks'

jest.mock('foundation', () => ({}))

jest.mock('user', () => ({
  withUser: jest.fn((Component) => (props) => <Component />),
}))

jest.mock('../../../shared/hub/api/api', () => ({
  fetchStatsAndStreaks: jest.fn(() => ({
    streaks: {
      dates: [
        ['1', '2'],
        ['3', '4'],
      ],
    },
  })),
}))

describe('WRAPPER: withStatsAndStreaks', () => {
  const defaultProps = {
    Component: () => <div id="test-component" />,
    user: { userType: {} },
  }

  it('uses an empty nested array as a default value', () => {
    const wrapper = shallow(<StatsWrapper {...defaultProps} />)
    const { streakDates } = wrapper.props()

    expect(Array.isArray(streakDates)).toBeTruthy()
    expect(streakDates).toHaveLength(1)
    expect(streakDates[0]).toHaveLength(0)
  })

  it('does not fetch stats & streaks without a user ID', () => {
    const wrapper = shallow(<StatsWrapper {...defaultProps} />)

    setTimeout(() => {
      const { streakDates } = wrapper.props()
      expect(streakDates[0]).toHaveLength(0)
    }, 5000)
  })

  it('fetches stats & streaks if there is a user ID', () => {
    const wrapper = shallow(
      <StatsWrapper
        {...defaultProps}
        user={{ userType: { regiId: '1234' } }}
      />,
    )

    setTimeout(() => {
      expect(wrapper.props().streakDates[0]).toHaveLength(2)
    }, 5000)
  })

  it('only updates stats & streaks with valid data', () => {
    fetchStatsAndStreaks.mockImplementation(() => ({ streaks: null }))
    const wrapper = shallow(
      <StatsWrapper
        {...defaultProps}
        user={{ userType: { regiId: '1234' } }}
      />,
    )

    setTimeout(() => {
      expect(wrapper.props().streakDates[0]).toHaveLength(0)
    }, 5000)
  })
})
