import React from 'react'
import { shallow } from 'enzyme'

import withTodaysDate from './withTodaysDate'

jest.mock('foundation', () => ({
  userType: {
    hasXwd: true,
  },
}))

jest.mock('moment', () => ({
  __esModule: true,
  default: (date) => date || 'a test date',
}))

jest.mock('./fetchDate', () => {
  return Promise.resolve('test date from a fake server')
})

describe('WRAPPER: withTodaysDate', () => {
  const MockComponent = () => <div />

  it('uses the current moment as a default date', () => {
    const WrappedMock = withTodaysDate(MockComponent)
    const wrapper = shallow(<WrappedMock />)

    expect(wrapper.props().todaysDate).toEqual('a test date')
  })

  it('updates the date once a truthy response returns from the server', () => {
    const WrappedMock = withTodaysDate(MockComponent)
    const wrapper = shallow(<WrappedMock />)

    setTimeout(() => {
      expect(wrapper.props().todaysDate).toEqual(
        'test date from a fake server',
      )
    }, 5000)
  })
})
