import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'

import Milestone from '../Juice/Milestone'

import Board from './Board'
import Zoomable from './Zoomable'

jest.mock('./Cells', () => () => 'Cells')

describe('COMPONENT: Board', () => {
  const makeStore = (
    mockOverlay = {},
    isSolved = false,
    isMini = false,
  ) => ({
    getState: () => ({
      cells: [],
      puzzle: {
        data: {
          meta: {
            publishStream: isMini ? 'mini' : 'daily',
          },
          overlays: { ...mockOverlay },
          dimensions: {},
          board: {
            name: '',
            attributes: {},
            children: [
              {}, // defGroup
              { children: [] }, // cellGroup
              { attributes: {}, children: [{}, {}] }, // lineGroup
            ],
          },
        },
      },
      status: {
        isSolved,
      },
    }),
    subscribe: jest.fn(),
    dispatch: jest.fn(),
  })

  const getWrapper = (store = makeStore(), customProps) => {
    const props = {
      isMobile: false,
      ...customProps,
    }

    return mount(
      <Provider store={store}>
        <Board {...props} />
      </Provider>,
    )
  }

  it('renders a Zoomable component', () => {
    const wrapper = getWrapper()
    expect(wrapper.find(Zoomable)).toHaveLength(1)
  })

  it('renders an overlay if expected', () => {
    const wrapper = getWrapper(makeStore({ beforeStart: true }, true))
    expect(wrapper.find('image')).toHaveLength(1)
  })

  it('does not render an overlay if none is provided', () => {
    const wrapper = getWrapper()
    expect(wrapper.find('image')).toHaveLength(0)
  })

  it('renders a milestone only for daily users', () => {
    const dailyUser = getWrapper()
    const miniUser = getWrapper(makeStore({}, false, true))
    const mobileUser = getWrapper(makeStore(), { isMobile: true })

    expect(dailyUser.find(Milestone)).toHaveLength(1)
    expect(miniUser.find(Milestone)).toHaveLength(0)
    expect(mobileUser.find(Milestone)).toHaveLength(0)
  })
})
