import React from 'react'
import cn from 'classnames'
import { useSelector } from 'react-redux'

import {
  getExternalCells,
  getIsMini,
  getPuzzleBoard,
  getPuzzleDimensions,
} from '../../store/state/puzzle/puzzleSelectors'
import Milestone from '../Juice/Milestone'
import { getCurrentOverlay } from '../../store/state/status/statusSelectors'

import Zoomable from './Zoomable'
import Cells from './Cells'
import Lines from './Lines'
import Defs from './Defs'

const BOARD_ID = 'xwd-board'

type BoardProps = {
  isMobile: boolean
}

const Board = ({ isMobile }: BoardProps) => {
  const externalCells = useSelector(getExternalCells)
  const overlay = useSelector(getCurrentOverlay)
  const svg = useSelector(getPuzzleBoard)
  const dimensions = useSelector(getPuzzleDimensions)
  const isMini = useSelector(getIsMini)

  if (!svg || !dimensions) {
    return null
  }

  const { attributes, children } = svg
  const [defGroup, cellGroup, lineGroup] = children
  const {
    attributes: lineGroupAttrs,
    children: [grid, frame],
  } = lineGroup

  return (
    <section
      className={cn('xwd__board', {
        xwd__mobile: isMobile,
        xwd__desktop: !isMobile,
      })}
      aria-label="Game Board"
    >
      <Zoomable className="xwd__board--content">
        <svg
          id={BOARD_ID}
          className="xwd__svg"
          preserveAspectRatio="xMidYMin meet"
          aria-label="Puzzle Board for the Crossword"
          {...attributes}
        >
          {/* This <use> forces browsers that refuse to repaint the board and cursor correctly to do so */}
          <use xlinkHref="#checked" />
          <Defs assistShapes={defGroup.children} />
          <Cells
            attributes={cellGroup.attributes}
            cellBoard={cellGroup.children}
            dimensions={dimensions}
          />
          <Lines
            group={lineGroupAttrs}
            grid={grid.attributes}
            frame={frame.attributes}
            externalCells={externalCells}
            dimensions={dimensions}
          />
          {overlay && (
            <image
              xlinkHref={`${overlay}`}
              width="100%"
              height="100%"
              className="xwd__overlay"
            />
          )}
        </svg>
        {!isMobile && !isMini && <Milestone boardId={BOARD_ID} />}
      </Zoomable>
    </section>
  )
}

export default Board
