import React from 'react'
import { mount } from 'enzyme'

import Zoomable from './Zoomable'

describe('Zoomable', () => {
  const getWrapper = () =>
    mount(
      <Zoomable className="zoom">
        <span />
      </Zoomable>,
    )

  it('should have initial styling', () => {
    const wrapper = getWrapper()
    const { style } = wrapper.find('div.zoom').props()

    expect(style).toHaveProperty('transition', 'transform 0s')
    expect(style).toHaveProperty(
      'transform',
      'translate(0px, 0px) scale(1)',
    )
  })

  it('should not pan if not zoomed', () => {
    const wrapper = getWrapper()
    const instance = wrapper.instance()
    // @ts-ignore
    instance.handleMove({ deltaX: 42, deltaY: 42, scale: 1 })
    const { style } = wrapper.find('div.zoom').props()

    expect(style).toHaveProperty('transition', 'transform 0s')
    expect(style).toHaveProperty(
      'transform',
      'translate(0px, 0px) scale(1)',
    )
  })

  it('should pan if zoomed', () => {
    const wrapper = getWrapper()
    const instance = wrapper.instance()
    // @ts-ignore
    instance.handleStart({ deltaX: 20, deltaY: 20 })
    // @ts-ignore
    instance.handleMove({ deltaX: 62, deltaY: 62, scale: 2 })
    wrapper.update()
    const { style } = wrapper.find('div.zoom').props()

    expect(style).toHaveProperty('transition', 'transform 0s')
    expect(style).toHaveProperty(
      'transform',
      'translate(42px, 42px) scale(2)',
    )
  })

  it('should not scale beyond 2 once gesture ends', () => {
    const wrapper = getWrapper()
    const instance = wrapper.instance()
    // @ts-ignore
    instance.handleMove({ deltaX: 0, deltaY: 0, scale: 42 })
    // @ts-ignore
    instance.handleEnd()
    wrapper.update()
    const { style } = wrapper.find('div.zoom').props()

    expect(style).toHaveProperty('transition', 'transform 0.5s')
    expect(style).toHaveProperty(
      'transform',
      'translate(0px, 0px) scale(2)',
    )
  })
})
