import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import { ClueState } from '../../store/state/clues/cluesTypes'

import ClueBarDesktop from './ClueBarDesktop'

describe('<ClueBarDesktop />', () => {
  const defaultClue: Partial<ClueState> = {
    label: '1',
    text: 'Oboe, probably',
  }

  const getWrapper = (clue = defaultClue, isModalOpen = false) => {
    const store = {
      dispatch: jest.fn(),
      subscribe: jest.fn(),
      getState: () => ({
        clues: [clue],
        selection: { clue: 0 },
        modal: { name: isModalOpen ? 'hey' : null },
      }),
    }

    return mount(
      // @ts-ignore
      <Provider store={store}>
        <ClueBarDesktop />
      </Provider>,
    )
  }

  afterEach(jest.clearAllMocks)

  it('should be blank if obscured', () => {
    const wrapper = getWrapper(defaultClue, true)
    expect(
      wrapper.find('.xwd__clue-bar-desktop--bar').children(),
    ).toHaveLength(0)
  })

  it('should not apply long classname to short clue', () => {
    const wrapper = getWrapper()
    expect(
      wrapper
        .find('.xwd__clue-bar-desktop--text')
        .props()
        .className?.includes('long'),
    ).toBe(false)
  })

  it('should apply long classname to long clue', () => {
    const repeat = (n: number, s: string) => Array(n).fill(s).join('')
    const wrapper = getWrapper({ label: '1', text: repeat(201, 'a') })
    expect(
      wrapper
        .find('.xwd__clue-bar-desktop--text')
        .props()
        .className?.includes('long'),
    ).toBe(true)
  })

  it('should default to a space after label', () => {
    const wrapper = getWrapper()
    expect(
      wrapper.find('.xwd__clue-bar-desktop--number').text(),
    ).toEqual('1 ')
  })

  it('should use direction if available', () => {
    const wrapper = getWrapper({ label: '42', direction: '→' })
    expect(
      wrapper.find('.xwd__clue-bar-desktop--number').text(),
    ).toEqual('42→')
  })
})
