import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import ClueBarMobile from './ClueBarMobile'

jest.mock('../../store/state/selection/selectionSelectors', () => ({
  getSelectedClue: jest.fn(() => ({ text: 'Oboe, probably' })),
}))

jest.mock('../../store/state/selection/selectionActions', () => ({
  navigate: jest.fn((dir) => `NAVIGATE ${dir}`),
  switchDirection: jest.fn(() => 'SWITCH DIRECTION'),
}))

describe('<ClueBarMobile />', () => {
  const dispatch = jest.fn()

  const getWrapper = () => {
    const store = {
      dispatch,
      subscribe: jest.fn(),
      getState: () => ({}),
    }

    return mount(
      // @ts-ignore
      <Provider store={store}>
        <ClueBarMobile />
      </Provider>,
    )
  }

  afterEach(jest.clearAllMocks)

  it('should have the clue text dangerouslySet', () => {
    const wrapper = getWrapper()
    const clueTextDiv = wrapper.find(
      '[aria-label="switch direction"]',
    )
    expect(clueTextDiv.props().dangerouslySetInnerHTML).toEqual({
      __html: 'Oboe, probably',
    })
  })

  it('should dispatch a navigate backwards action on click of left chevron', () => {
    const wrapper = getWrapper()
    const leftChevron = wrapper
      .find('.xwd__clue-bar-mobile--jump')
      .at(0)
    leftChevron.simulate('click')
    expect(dispatch).toHaveBeenCalledWith('NAVIGATE PreviousClue')
  })

  it('should dispatch a navigate forwards action on click of right chevron', () => {
    const wrapper = getWrapper()
    const rightChevron = wrapper
      .find('.xwd__clue-bar-mobile--jump')
      .at(1)
    rightChevron.simulate('click')
    expect(dispatch).toHaveBeenCalledWith('NAVIGATE NextClue')
  })

  it('should dispatch a switch direction action on click of clue text', () => {
    const wrapper = getWrapper()
    const clueTextDiv = wrapper.find(
      '[aria-label="switch direction"]',
    )
    clueTextDiv.simulate('click')
    expect(dispatch).toHaveBeenCalledWith('SWITCH DIRECTION')
  })
})
