import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'

import { ClueListState } from '../../store/state/puzzle/puzzleTypes'
import { ClueState } from '../../store/state/clues/cluesTypes'

import ClueList from './ClueList'

jest.mock('responsive', () => ({
  isMobile: false,
}))

jest.mock('./Clue/Clue', () => () => (
  <div className="xwd__clue--li">Clue</div>
))

describe('CLUELIST', () => {
  const clueLists: ClueListState = {
    clues: [0, 1],
    cells: [0, 1],
    index: 0,
    prev: 1,
    next: 1,
    name: 'Across',
  }

  const clues: ClueState[] = [
    {
      list: 0,
      cells: [0, 1],
      direction: 'Across',
      label: '1',
      text: 'Dip for chips',
      index: 0,
      prev: 1,
      next: 1,
      unfilledCount: 5,
      isImageClue: false,
      alternativeAriaLabelText: '',
    },
    {
      list: 0,
      cells: [1, 2],
      direction: 'Across',
      label: '2',
      text: 'Popular plant',
      index: 1,
      prev: 2,
      next: 2,
      unfilledCount: 5,
      isImageClue: false,
      alternativeAriaLabelText: '',
    },
  ]

  const makeStore = (isModalOpen: boolean) => {
    return {
      getState: () => ({
        clueLists,
        clues,
        transient: {
          isReady: false,
          doEscape: false,
        },
        modal: { name: isModalOpen ? 'hey' : null },
      }),
      dispatch: jest.fn(),
      subscribe: jest.fn(),
    }
  }

  const createWrapper = (isModalOpen: boolean) => {
    const store = makeStore(isModalOpen)
    return mount(
      // @ts-ignore
      <Provider store={store}>
        <ClueList list={clueLists} />
      </Provider>,
    )
  }

  afterEach(() => jest.clearAllMocks)

  it('renders clues', () => {
    const wrapper = createWrapper(false)
    expect(wrapper.find('.xwd__clue--li')).toHaveLength(2)
  })

  it('renders list title', () => {
    const wrapper = createWrapper(false)
    expect(wrapper.find('h3.xwd__clue-list--title').text()).toEqual(
      'Across',
    )
  })

  it('adds obscured class', () => {
    const wrapper = createWrapper(true)
    expect(wrapper.find('ol.xwd__clue-list--obscured')).toHaveLength(
      1,
    )
  })
})
