import React from 'react'
import { useSelector, useDispatch } from 'react-redux'
import cn from 'classnames'

import { isMobile } from 'responsive'

import { selectClue } from '../../store/state/selection/selectionActions'
import { ClueListState } from '../../store/state/puzzle/puzzleTypes'
import { getAllClues } from '../../store/state/puzzle/puzzleSelectors'
import { getIsModalOpen } from '../../store/state/modal/modalSelectors'

import Clue from './Clue/Clue'

type ClueListProps = {
  list: ClueListState
}

export default function ClueList({ list }: ClueListProps) {
  const clues = useSelector(getAllClues)
  const isModalOpen = useSelector(getIsModalOpen)

  const dispatch = useDispatch()
  const handleClueClick = (
    clueIndex: number,
    isSelected: boolean,
  ) => {
    dispatch(selectClue(clueIndex, isSelected))
  }

  const listClasses = cn('xwd__clue-list--list', {
    'xwd__clue-list--obscured': isModalOpen,
  })

  const wrapperClass = `xwd__clue-list--wrapper${
    isMobile ? '-mobile' : ''
  }`

  return (
    <div className={wrapperClass}>
      <h3 className="xwd__clue-list--title">{list.name}</h3>
      <ol className={listClasses}>
        {list.clues.map((clueIndex) => {
          const { label, text, index, direction } = clues[clueIndex]
          return (
            <Clue
              clickHandler={handleClueClick}
              index={index}
              label={label}
              text={text}
              key={`${label}${direction}`}
              isModalOpen={isModalOpen}
            />
          )
        })}
      </ol>
    </div>
  )
}
