import React from 'react'
import cn from 'classnames'

import useTimeout from '../../../shared/hooks/use-timeout'
import useInterval from '../../../shared/hooks/use-interval'
import { useHiddenHeader } from '../../../shared/hooks/use-hidden-header'

export default function CrosswordLoading() {
  useHiddenHeader()
  // not the usual way to get isMini, but presumably puzzle data hasn't loaded yet
  const isMini = window.gameData?.stream === 'mini'
  const [isShowing, setShowing] = React.useState(false)
  const [fill, setFill] = React.useState(10)

  // the loading bar doesn't show until 300ms have passed, to avoid flicker when all is healthy
  useTimeout(() => setShowing(true), 300)

  useInterval(
    () => {
      // every 30ms, there is a 1/6 chance fill will grow
      if (fill < 100 && Math.random() < 1 / 6) {
        setFill(fill + Math.random() * 15)
      }
    },
    isShowing ? 30 : null,
  )

  const fakeLoadingBar = (
    <div className="xwd--loading-bar">
      <div
        className="xwd--loading-bar__fill"
        style={{
          right: `${Math.max(100 - fill, 0)}%`,
        }}
      />
    </div>
  )

  return (
    <div className={cn('xwd__loading', { mini: isMini })}>
      {isShowing && fakeLoadingBar}
    </div>
  )
}
