import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'

import * as userThunks from '../../store/thunks/userThunks'

import CrosswordPage, { updateFocus } from './CrosswordPage'

window.scrollTo = jest.fn()

jest.mock('foundation', () => ({
  env: { version: 'test' },
  xhr: {
    request: jest.fn(() => Promise.resolve(true)),
  },
}))

jest.mock('responsive', () => ({
  _esModule: true,
  isMobile: false,
}))

jest.mock('../../store/state/puzzle/puzzleSelectors', () => ({
  ...jest.requireActual('../../store/state/puzzle/puzzleSelectors'),
  getIsMini: jest.fn(() => false),
}))

jest.mock('user', () => ({
  useUser: jest.fn(() => ({
    userType: {
      isLoggedIn: true,
      hasXwd: true,
      hasDigi: true,
      hasHd: true,
      inShortzMode: true,
      entitlement: 'sub,cr',
      regiId: '1111111',
    },
    hasLoaded: true,
  })),
}))

// need to mock or else test doesn't run due to redux's compose?
jest.mock('../Modals/CongratsModal/CongratsModal.tsx', () => (
  <div>Congrats</div>
))

const makeStore = () => ({
  getState: () => ({
    puzzle: {
      data: {
        board: {
          children: [
            {}, // defGroup
            { children: [] }, // cellGroup
            { attributes: {}, children: [{}, {}] }, // lineGroup
          ],
        },
        clueLists: [],
        dimensions: {},
        meta: {},
        overlays: {
          beforeStart: false,
        },
      },
      hasLoaded: true,
    },
    cells: [],
    modal: {
      type: null,
    },
    selection: {},
    status: {
      isSolved: false,
    },
    toolbar: {
      activeMenu: null,
      inRebusMode: false,
    },
    timer: {},
    transient: {
      isReady: true,
      doEscape: false,
    },
    user: {
      settings: {},
    },
  }),
  subscribe: jest.fn(),
  dispatch: jest.fn(),
})

const getWrapper = (store = makeStore()) => {
  return mount(
    <Provider store={store}>
      <CrosswordPage />
    </Provider>,
  )
}

describe('COMPONENT: CrosswordPage', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('renders a Layout regardless of mode', () => {
    const wrapper = getWrapper()

    expect(wrapper.find('main')).toHaveLength(1)
  })

  it('updates user info (but not leaderboard info) for daily users', () => {
    const store = makeStore(true)
    const userThunkSpy = jest.spyOn(userThunks, 'recallUserSettings')

    getWrapper(store)

    expect(userThunkSpy).toHaveBeenCalledTimes(1)
  })

  describe('Helper: updateFocus', () => {
    const defaultProps = {
      inRebusMode: false,
      modalIsOpen: false,
      isReady: true,
    }
    it('sets focus classes on our ref', () => {
      const testRef = {}
      updateFocus({ ...defaultProps, isReady: false, ref: testRef })

      expect(testRef.className.includes('xwd__franklin')).toBe(true)
    })

    it('focuses and scrolls', () => {
      const testRef = { focus: jest.fn() }
      updateFocus({ ...defaultProps, ref: testRef })

      expect(testRef.focus).toHaveBeenCalledTimes(1)
    })

    it('skips focusing and scrolling if a modal is open', () => {
      const testRef = { focus: jest.fn() }
      updateFocus({
        ...defaultProps,
        modalIsOpen: true,
        ref: testRef,
      })

      expect(testRef.focus).toHaveBeenCalledTimes(0)
    })

    it('skips focusing and scrolling if rebus mode is open', () => {
      const testRef = { focus: jest.fn() }
      updateFocus({
        ...defaultProps,
        inRebusMode: true,
        ref: testRef,
      })

      expect(testRef.focus).toHaveBeenCalledTimes(0)
    })
  })
})
