import React from 'react'
import cn from 'classnames'
import { useSelector } from 'react-redux'

import { getPuzzleId } from '../../store/state/puzzle/puzzleSelectors'
import { trackModuleInteraction } from '../../store/utils/tracker'

export type EditorialCardProps = {
  kicker?: string
  headline: string
  byline?: string
  summary?: string
  thumbURL?: string
  url: string
  type: 'secondaryCard' | 'featuredCard'
}

export default function EditorialCard({
  kicker,
  headline,
  byline,
  summary,
  thumbURL,
  url = 'https://www.nytimes.com/crosswords',
  type = 'secondaryCard',
}: EditorialCardProps) {
  const id = useSelector(getPuzzleId)

  return (
    <a
      className={cn(
        `xwd__editorial-content--${type}`,
        'xwd__editorial-content--editorialCard',
      )}
      href={url}
      onClick={() =>
        trackModuleInteraction(
          url,
          id,
          'game-page',
          'wordplay-content',
          url,
        )
      }
      target="_blank"
      rel="noopener noreferrer"
      tabIndex={0}
    >
      {thumbURL && (
        <div className="xwd__editorial-content--imgContainer">
          <img src={thumbURL} alt={headline} />
        </div>
      )}
      <div className="xwd__editorial-content--meta">
        {kicker && (
          <p className="xwd__editorial-content--kicker">{kicker}</p>
        )}
        {headline && <h2>{headline}</h2>}
        {summary && (
          <p className="xwd__editorial-content--summary">{summary}</p>
        )}
        {byline && (
          <p className="xwd__editorial-content--byline">{byline}</p>
        )}
      </div>
    </a>
  )
}
