import React, { useState, useEffect } from 'react'
import { createPortal } from 'react-dom'
import { useSelector } from 'react-redux'

import { isMobile } from 'responsive'
import { useUser } from 'user'

import getEditorialContent from '../../store/utils/editorialContentApi'
import {
  getPublicationDate,
  getIsMini,
} from '../../store/state/puzzle/puzzleSelectors'
import logger from '../../../shared/utils/clientLogger'

import SubGameplayGrid from './SubGameplayGrid'
import EditorialCard from './EditorialCard'

export type ArticleData = {
  kicker?: string
  headline: string
  byline?: string
  summary?: string
  thumbURL?: string
  url: string
}

export type EditorialData = {
  featuredArticle: ArticleData
  secondaryArticles: ArticleData[]
}

export default function EditorialContent() {
  const [editorialContent, setEditorialContent] = useState<
    EditorialData | undefined
  >(undefined)

  const currentDate = useSelector(getPublicationDate)
  const { userType } = useUser()
  const isMini = useSelector(getIsMini)

  useEffect(() => {
    if (!currentDate) return

    getEditorialContent(currentDate, userType)
      .then((editorialData) => {
        setEditorialContent(editorialData)
      })
      .catch((err: string) => {
        logger.warn(err)
      })
  }, [currentDate])

  const portalRef = React.useRef(
    document.getElementById('portal-editorial-content'),
  )

  if (
    isMini ||
    isMobile ||
    !portalRef.current ||
    !editorialContent?.featuredArticle
  ) {
    return null
  }

  return createPortal(
    <div>
      <SubGameplayGrid>
        <EditorialCard
          type="featuredCard"
          kicker={editorialContent.featuredArticle.kicker}
          headline={editorialContent.featuredArticle.headline}
          byline={editorialContent.featuredArticle.byline}
          summary={editorialContent.featuredArticle.summary}
          thumbURL={editorialContent.featuredArticle.thumbURL}
          url={editorialContent.featuredArticle.url}
        />

        {editorialContent.secondaryArticles &&
          editorialContent.secondaryArticles.map((article) => (
            <EditorialCard
              key={article.url}
              type="secondaryCard"
              kicker={article.kicker}
              headline={article.headline}
              byline={article.byline}
              summary={article.summary}
              thumbURL={article.thumbURL}
              url={article.url}
            />
          ))}
      </SubGameplayGrid>
    </div>,
    portalRef.current,
  )
}
