import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'

import { getCurrentPuzzle } from '../../../../shared/hub/store/selectors'

import SubGameplayGrid, {
  SubGameplayGridProps,
} from './SubGameplayGrid'

jest.mock('../../../../shared/hub/store/selectors', () => ({
  getCurrentPuzzle: jest.fn((state) => ({ modal: {} })),
}))

describe('EDITORIAL CONTENT: SUBGAMEPLAY GRID', () => {
  const makeStore = () => ({
    getState: () => ({
      modal: {
        name: 'name',
      },
    }),
    subscribe: jest.fn(),
    dispatch: jest.fn(),
  })

  const getWrapper = (
    store = makeStore(),
    customProps: SubGameplayGridProps,
  ) => {
    return mount(
      // @ts-ignore
      <Provider store={store}>
        <SubGameplayGrid {...customProps} />
      </Provider>,
    )
  }

  const props = {
    children: <div>This is a Mock Div</div>,
  }

  it('should show child', () => {
    const wrapper = getWrapper(makeStore(), props)
    expect(wrapper.text().includes('This is a Mock Div')).toBe(true)
  })

  it('should not be tabbable if modal is open', () => {
    // @ts-ignore
    getCurrentPuzzle.mockImplementation((state) => ({
      modal: { type: true },
    }))
    const wrapper = getWrapper(makeStore(), props)
    expect(wrapper.html().includes('tabindex="-1"'))
  })

  it('should be tabbable if modal is not open', () => {
    // @ts-ignore
    getCurrentPuzzle.mockImplementation((state) => ({ modal: {} }))
    const wrapper = getWrapper(makeStore(), props)
    expect(wrapper.html().includes('tabindex="0"'))
  })
})
