export const createMilestoneAnimation = (
  canvasElm: HTMLCanvasElement | null,
  canvasSize: number,
) => {
  const ctx = canvasElm?.getContext('2d')

  if (!ctx) return

  ctx.scale(2, 2) // for retina

  const animate = () => {
    const width = canvasSize
    const height = canvasSize
    const rate = 1

    let innerRadius = 0
    let outerRadius = 15

    const cx = width / 2
    const cy = height / 2

    ctx.lineWidth = 4
    ctx.lineCap = 'round'
    ctx.strokeStyle = '#4F85E5'

    const drawLine = (innerRadius: number, outerRadius: number) => {
      ctx.moveTo(innerRadius, 0)
      ctx.lineTo(innerRadius + Math.max(outerRadius, 0), 0)
    }

    const frame = () => {
      ctx.clearRect(0, 0, width, height)
      ctx.save()
      ctx.translate(cx, cy)

      outerRadius -= rate
      innerRadius += rate * 1.75

      if (outerRadius >= -4) {
        ctx.beginPath()
        for (let i = 0; i < 8; i += 1) {
          drawLine(innerRadius, outerRadius)
          ctx.rotate(Math.PI / 4)
        }
        ctx.stroke()
        ctx.restore()
        requestAnimationFrame(frame)
      } else {
        ctx.restore()
      }
    }

    frame()
  }

  return animate
}
