import React from 'react'
import { shallow } from 'enzyme'

import useScreenSizeWarning from '../../../shared/hooks/use-screen-size-warning'

import LandscapeWarning from './LandscapeWarning'

jest.mock('foundation', () => ({
  env: 'development',
  mobileNavTools: {
    activate: jest.fn(),
    deactivate: jest.fn(),
  },
}))

jest.mock('react-redux', () => ({
  useDispatch: jest.fn(),
  useSelector: jest.fn((func) => func()),
}))

jest.mock('../../store/state/modal/modalSelectors', () => ({
  getIsModalOpen: jest.fn(),
}))

jest.mock('../../store/state/status/statusSelectors', () => ({
  getGameStatus: jest.fn(() => ({ isSolved: false })),
}))

jest.mock('../../../shared/hooks/use-screen-size-warning', () => ({
  __esModule: true,
  ...jest.requireActual(
    '../../../shared/hooks/use-screen-size-warning',
  ),
  default: jest.fn(() => true),
}))

describe('COMPONENT: LandscapeWarning', () => {
  beforeEach(() => {
    useScreenSizeWarning.mockImplementation(() => true)
  })

  it('should return null for appropriate screen sizes', () => {
    useScreenSizeWarning.mockImplementation(() => false)

    const wrapper = shallow(<LandscapeWarning inRebusMode={false} />)

    expect(wrapper.find('.xwd__landscape-warning')).toHaveLength(0)
  })

  it('should render a landscape warning for screens that are too small', () => {
    const wrapper = shallow(<LandscapeWarning inRebusMode={false} />)

    expect(wrapper.find('.xwd__landscape-warning')).toHaveLength(1)
  })

  it('should return null if the user is in rebus mode', () => {
    const wrapper = shallow(<LandscapeWarning inRebusMode />)

    expect(wrapper.find('.xwd__landscape-warning')).toHaveLength(0)
  })
})
