import React, { useEffect } from 'react'
import { useDispatch, useSelector } from 'react-redux'

import { mobileNavTools } from 'foundation'

import { getIsModalOpen } from '../../store/state/modal/modalSelectors'
import { getGameStatus } from '../../store/state/status/statusSelectors'
import {
  pauseTimer,
  unpauseTimer,
} from '../../store/state/timer/timerActions'
import useScreenSizeWarning, {
  CheckScreenSize,
} from '../../../shared/hooks/use-screen-size-warning'
import Icon from '../../../../shared/components/Icon/Icon'

const checkScreenSize: CheckScreenSize = ({
  winHeight,
  winWidth,
}) => {
  const aspectRatio = winWidth / winHeight
  const flatTablet = winHeight <= 650 && aspectRatio > 1.8
  const tinyPhone = winHeight < 400 && aspectRatio > 1

  return flatTablet || tinyPhone
}

type LandscapeWarningProps = {
  inRebusMode: boolean
}

const LandscapeWarning = ({
  inRebusMode = false,
}: LandscapeWarningProps) => {
  const showScreenSizeWarning = useScreenSizeWarning(checkScreenSize)
  const modalIsOpen = useSelector(getIsModalOpen)
  const { isSolved } = useSelector(getGameStatus)
  const dispatch = useDispatch()

  // The timer should pause and the game toolbar should be hidden
  // if a user is seeing the landscape warning
  useEffect(() => {
    if (showScreenSizeWarning) {
      dispatch(pauseTimer())
      mobileNavTools.deactivate()
    } else {
      dispatch(unpauseTimer())
      mobileNavTools.activate()
    }
  }, [showScreenSizeWarning])

  if (!showScreenSizeWarning || inRebusMode) return null

  return (
    <div className="xwd__landscape-warning">
      <Icon icon="rotate" />
      <p>
        Oh no! We can’t fit everything on your screen.
        <br />
        <span>Please rotate your device.</span>
      </p>
    </div>
  )
}

export default LandscapeWarning
