import {
  CHECK,
  CLEAR,
  REVEAL,
} from '../../../store/state/cells/cellsActions'
import {
  ENABLE_AUTOCHECK,
  RESET_GAME,
} from '../../../store/state/status/statusActions'
import { ExecutedActionType } from '../../../store/thunks/statusThunks'

const streakWarning =
  'You can reveal or check a part of this puzzle, but this will exclude this puzzle from a streak.'

const getConfirmParams = (
  actionType: ExecutedActionType,
  needToWarn: boolean,
): { title: string; text: string; buttonLabel: string } => {
  switch (actionType) {
    case CHECK:
      return {
        title: 'Feeling stuck?',
        text: streakWarning,
        buttonLabel: 'Check anyway',
      }
    case RESET_GAME:
      if (needToWarn) {
        return {
          title:
            'Resetting the timer will exclude this puzzle from a streak.',
          text: 'Streaks are formed by solving The Crossword within a day of its publish date and without help.',
          buttonLabel: 'Reset timer',
        }
      }

      return {
        title: '',
        text: 'Are you sure you want to start over?',
        buttonLabel: 'Start over',
      }
    case REVEAL:
      if (needToWarn) {
        return {
          title: 'Feeling stuck?',
          text: streakWarning,
          buttonLabel: 'Reveal anyway',
        }
      }

      return {
        title: '',
        text: 'Are you sure you want to reveal the puzzle?',
        buttonLabel: 'Reveal',
      }
    case CLEAR:
      return {
        title: '',
        text: 'Are you sure you want to erase the puzzle?',
        buttonLabel: 'Erase',
      }

    case ENABLE_AUTOCHECK:
      return {
        title: 'Feeling stuck?',
        text: streakWarning,
        buttonLabel: 'Use autocheck',
      }

    default:
      return {
        title: '',
        text: 'Are you sure you want to do that?',
        buttonLabel: 'Confirm',
      }
  }
}

export default getConfirmParams
