import React from 'react'

import ModalWrapper from '../../../../shared/ModalSystem/ModalWrapper'
import { Title } from '../../../../shared/moments/components/subcomponents'
import type { ModalProps } from '../../../../shared/ModalSystem/modalTypes'

import GetAppLink from './GetAppLink'
import { getAnchorTag } from './helper'

type GuideCongratsProps = ModalProps & {
  displayAppLink: boolean
  appCta: string
  showTimer: boolean
  puzzleId: number
  puzzleTitle: string
  formattedSolveTime: string
}

export default function GuideCongrats({
  displayAppLink,
  appCta,
  close,
  showTimer,
  puzzleId,
  puzzleTitle,
  formattedSolveTime,
  isClosing,
  onRemove,
}: GuideCongratsProps) {
  const timeString = (
    <span>
      in <span className="xwd__bold">{formattedSolveTime}</span>
    </span>
  )

  const isIOSNewsreader = window.newsreaderAppPlatform === 'ios'

  return (
    <ModalWrapper
      buttons={[
        {
          label: 'Back to the guide',
          link: `https://www.nytimes.com/guides/crosswords/how-to-solve-a-crossword-puzzle#${getAnchorTag(
            puzzleId,
          )}`,
        },
      ]}
      close={close}
      footer={displayAppLink && <GetAppLink appCta={appCta} />}
      isClosing={isClosing}
      onRemove={onRemove}
      containerClassName={
        isIOSNewsreader ? 'container-with-inset' : ''
      }
    >
      <div className="xwd__congrats-modal--content">
        <div className="xwd__illustration" />
        <Title size="large" text="Super Solving" />
        <div className="xwd__center">
          You solved the{' '}
          <span className="xwd__bold">{puzzleTitle}</span> Mini{' '}
          {showTimer && timeString}.
        </div>
      </div>
    </ModalWrapper>
  )
}
