import React, { useEffect } from 'react'

import { trackImpression } from '../../../../store/utils/tracker'

import SubscribeToPlay from './SubscribeToPlay'
import NextGameSuggestion from './NextGameSuggestion'

type PromotionalContentProps = {
  appCta: string
  isMini: boolean
  registeredNonSub: boolean
  hasXwd: boolean
}

export default function PromotionalContent({
  appCta,
  isMini,
  hasXwd,
  registeredNonSub,
}: PromotionalContentProps) {
  const showNextGameSuggestion =
    isMini && !hasXwd && !registeredNonSub
  const eventLabel = isMini ? 'mini-modal' : 'game-modal'
  const isNewsreader = !!window.newsreaderAppPlatform
  const eventRegion = isMini
    ? 'mini-congrats-modal'
    : 'daily-congrats-modal'
  const typePuzzle = isMini ? 'mini' : 'daily'
  const newsreader = isNewsreader && 'Newsreader'
  const subscribeLinkContext = `${typePuzzle}Congrats${newsreader}`

  useEffect(() => {
    if (!hasXwd) {
      trackImpression('softpaywall', eventRegion, appCta)
    }
  }, [hasXwd])

  if (showNextGameSuggestion) {
    return <NextGameSuggestion />
  }

  if (registeredNonSub) {
    const message =
      'Have you played our new matching game? It’s mesmerizing.'

    return SubscribeToPlay({
      message,
      eventLabel,
      clickLabel: 'tiles',
      subscribeButtonTxt: 'Try Tiles >>',
      subscribeLinkContext,
    })
  }

  const message =
    'Want to be a better solver? Up your game with puzzles for every skill level.'

  return SubscribeToPlay({
    message,
    eventLabel,
    clickLabel: 'hub',
    subscribeButtonTxt: 'More Puzzles',
    subscribeLinkContext,
  })
}
