import React from 'react'

import {
  trackModuleInteraction,
  trackImpression,
} from '../../../../store/utils/tracker'
import { getSubscribeLink } from '../../../../../helpers/subscribeLinks'
import {
  isDeepLink,
  openDeepLink,
} from '../../../../../helpers/hybridLinkHelpers'

type SubscribeToPlayProps = {
  message: string
  eventLabel: string
  clickLabel: string
  subscribeLinkContext: string
  subscribeButtonTxt?: string
}

const SubscribeToPlay = ({
  message,
  subscribeLinkContext,
  subscribeButtonTxt,
  eventLabel,
  clickLabel,
}: SubscribeToPlayProps) => {
  const clickHandlers = {
    spellingBee: () => {
      trackModuleInteraction('click', '', eventLabel, 'spelling-bee')
      window.location.href = '/puzzles/spelling-bee'
    },
    tiles: () => {
      trackModuleInteraction('click', '', eventLabel, 'tiles')
      window.location.href = '/puzzles/tiles'
    },
    hub: () => {
      window.location.href = window.navigationLinks.hub
    },
  } as Record<string, () => void>
  const href = getSubscribeLink(subscribeLinkContext, window)
  const linkClick = (e: React.MouseEvent<HTMLAnchorElement>) => {
    const link = e.currentTarget.getAttribute('href') || ''
    const deepLink = isDeepLink(link)
    if (clickLabel) {
      const clickHandler = clickHandlers[clickLabel]
      clickHandler()
    } else if (link && deepLink) {
      openDeepLink(link)
      trackModuleInteraction('click', '', eventLabel, 'subscribe')
    } else if (link && !deepLink) {
      window.location.href = link
    }
  }

  return (
    <div className="xwd__promotional-content--subscriptionUpsell">
      <div className="xwd__promotional-content--minimodalMessage">
        {message}
      </div>
      <a
        href={href}
        onClick={linkClick}
        className="xwd__promotional-content--link"
      >
        {subscribeButtonTxt || 'Subscribe To Play'}
      </a>
    </div>
  )
}

export default SubscribeToPlay
