import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import { MetaState } from '../../../store/state/puzzle/puzzleTypes'

import InfoModal from './InfoModal'

jest.mock('foundation', () => ({
  env: { version: 'test' },
}))

type Settings = {
  isReady: boolean
  meta: Partial<MetaState>
}
const makeStore = (settings: Settings) => {
  return {
    getState: () => ({
      transient: {
        isReady: settings.isReady,
        isObscured: false,
        doEscape: false,
      },
      puzzle: {
        data: {
          meta: settings.meta,
        },
      },
      user: {},
    }),
    dispatch: jest.fn(),
    subscribe: jest.fn(),
  }
}

const createWrapper = (settings: Settings) => {
  const store = makeStore(settings)
  return mount(
    // @ts-ignore
    <Provider store={store}>
      <InfoModal
        close={jest.fn()}
        isClosing={false}
        onRemove={jest.fn()}
      />
    </Provider>,
  )
}

describe('Info Modal', () => {
  it('renders mini title if type is mini', () => {
    const settings = {
      isReady: false,
      meta: {
        notes: [{ text: 'Notes here....', spoiler: false }],
        publishStream: 'mini',
      },
    }
    const wrapper = createWrapper(settings)
    expect(wrapper.find('.pz-moment__title.medium').text()).toEqual(
      'Puzzle Info',
    )
    expect(wrapper.find('.pz-moment__title.large').text()).toEqual(
      'The Mini Crossword',
    )
  })

  it('renders daily title', () => {
    const settings = {
      isReady: false,
      meta: {
        notes: [{ text: 'Notes here....', spoiler: false }],
        publishStream: 'daily',
      },
    }
    const wrapper = createWrapper(settings)
    expect(wrapper.find('.pz-moment__title.medium').text()).toEqual(
      'Puzzle Info',
    )
    expect(wrapper.find('.pz-moment__title.large').text()).toEqual(
      'The Crossword',
    )
  })

  it('renders notes component', () => {
    const settings = {
      isReady: false,
      meta: {
        notes: [{ text: 'Notes here....', spoiler: false }],
        publishStream: 'daily',
      },
    }
    const wrapper = createWrapper(settings)
    expect(wrapper.find('h3.xwd__notes--title').text()).toEqual(
      'Note',
    )
    expect(wrapper.find('Notes')).toHaveLength(1)
  })

  it('does not render notes component when no notes are present', () => {
    const settings = {
      isReady: false,
      meta: {
        publishStream: 'daily',
      },
    }
    const wrapper = createWrapper(settings)
    expect(wrapper.find('Notes')).toHaveLength(0)
  })
})
