import React from 'react'
import { useSelector } from 'react-redux'

import type { ModalProps } from '../../../../shared/ModalSystem/modalTypes'
import { getPuzzleMetadata } from '../../../store/state/puzzle/puzzleSelectors'
import { getTitleFormatted } from '../../PuzzleDetails/PuzzleDetails'
import Notes from '../../PuzzleHeader/Notes'
import ModalWrapper from '../../../../shared/ModalSystem/ModalWrapper'
import { Title } from '../../../../shared/moments/components/subcomponents'
import DateAndBylineFooter from '../DateAndBylineFooter'

export default function InfoModal({
  close,
  isClosing,
  onRemove,
}: ModalProps) {
  const meta = useSelector(getPuzzleMetadata)

  if (!meta) {
    return null
  }

  const { notes, publishStream, title } = meta

  return (
    <ModalWrapper
      bodyClassName="xwd__info-modal--wrapper"
      close={close}
      isClosing={isClosing}
      onRemove={onRemove}
    >
      <div className="xwd__info-modal">
        <Title size="medium" text="Puzzle Info" />
        <Title
          size="large"
          text={getTitleFormatted(title, publishStream)}
        />
        <DateAndBylineFooter meta={meta} isInfo />
      </div>
      {notes && <Notes notes={notes} />}
    </ModalWrapper>
  )
}
