import React from 'react'
import cn from 'classnames'

export type ModalButtonConfig = {
  label: string
  clickHandler?: () => void
  link?: string
  className?: string
  disabled?: boolean
}

type ModalButtonsProps = {
  buttons: ModalButtonConfig[]
  close: (e: React.MouseEvent) => void
  wrapperClassName?: string
}

export default function ModalButtons({
  buttons,
  close,
  wrapperClassName = '',
}: ModalButtonsProps) {
  const renderButton = (conf: ModalButtonConfig) => (
    <button
      key={conf.label}
      type="button"
      onClick={conf.clickHandler || close}
      className={cn('pz-moment__button', conf.className)}
      disabled={!!conf.disabled}
      aria-disabled={!!conf.disabled}
      aria-label={conf.label}
    >
      <span>{conf.label}</span>
    </button>
  )

  const renderLink = (conf: ModalButtonConfig) => (
    <a
      key={conf.label}
      href={conf.link}
      onClick={conf.clickHandler}
      className={cn('xwd__modal--button', conf.className)}
      tabIndex={0}
    >
      <div role="button" aria-label={conf.label}>
        <span>{conf.label}</span>
      </div>
    </a>
  )

  return (
    <div
      className={cn('xwd__modal--button-container', wrapperClassName)}
    >
      {buttons.map((config) =>
        config.link ? renderLink(config) : renderButton(config),
      )}
    </div>
  )
}
