import React from 'react'
import { mount, shallow } from 'enzyme'
import { Provider } from 'react-redux'

import ModalWrapper from '../../../../shared/ModalSystem/ModalWrapper'

import ShareModal from './ShareModal'

jest.mock('foundation', () => ({
  userType: {
    hasXwd: true,
  },
}))

jest.mock('../../../store/state/user/userSelectors', () => ({
  getCurrentUserSettings: () => ({
    showTimer: true,
    soundOn: true,
  }),
}))

jest.mock('../../../store/state/status/statusSelectors', () => ({
  getGoldStarEligibility: () => true,
}))

jest.mock('../../../store/utils/tracker', () => ({
  trackModuleInteraction: jest.fn(),
  trackImpression: jest.fn(),
}))

jest.mock('responsive', () => ({
  isMobile: true,
}))

const mockDispatch = jest.fn()

const mockStore = (config) => {
  return {
    default: jest.fn(),
    subscribe: jest.fn(),
    dispatch: mockDispatch,
    getState: () => ({
      puzzle: {
        data: {
          meta: {
            publicationDate: '10',
            id: config.puzzleId || 0,
            publishStream: 'foo',
          },
        },
      },
      timer: {
        totalElapsedTime: 10,
        sessionStartTimestamp: 5,
      },
      stats: {
        streaks: {
          currentStreak: config?.currentStreak || 0,
          verticalStreaks: config?.verticalStreaks,
        },
      },
    }),
  }
}

describe('SHARE MODAL', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('renders share modal', () => {
    const store = mockStore({})
    const view = mount(
      <Provider store={store}>
        <ShareModal />
      </Provider>,
    )
    expect(view.find(ShareModal).length).toBe(1)
    expect(view.find(ModalWrapper).length).toBe(1)
    expect(view.find('img').length).toBe(1) // tout image
    expect(view.find('ul li').length).toBe(5) // 5 share things
    expect(view.find('ul li a').length).toBe(4) // four are links
    expect(view.find('ul li button').length).toBe(1) // one is a button
  })
})
