import React from 'react'

export type FormFieldProps = {
  type?: string
  id?: string
  name: string
  value?: string
  label?: string
  checked?: boolean
  disabled?: boolean
  onChange?: (e: React.ChangeEvent<HTMLInputElement>) => void
  tabIndex?: number
  subText?: string
  showSubText?: boolean
  subTextClass?: string
}

export const FormField = ({
  type,
  id,
  name,
  value,
  label,
  checked,
  disabled,
  onChange,
  tabIndex = 0,
  showSubText = false,
  subText,
  subTextClass,
}: FormFieldProps) => {
  const controlProps = onChange
    ? { defaultChecked: checked, onChange }
    : { checked, readOnly: true }

  return (
    <label htmlFor={id}>
      <input
        type={type}
        id={id}
        name={name}
        value={value}
        disabled={disabled}
        tabIndex={tabIndex}
        {...controlProps}
      />
      <span>{label}</span>
      {showSubText && <div className={subTextClass}>{subText}</div>}
    </label>
  )
}
