import React from 'react'
import { shallow } from 'enzyme'

import Notes from './Notes'

describe('Notes', () => {
  it('should render the revealer if note is a spoiler', () => {
    const notes = [{ text: 'I am a spoiler', spoiler: true }]
    const wrapper = shallow(<Notes notes={notes} />)
    expect(wrapper.text().includes('I am a spoiler')).toBeFalsy()
    expect(wrapper.text().includes('Reveal Answer')).toBeTruthy()
  })

  it('should render the note if not a spoiler', () => {
    const notes = [{ text: 'I am not a spoiler', spoiler: false }]
    const wrapper = shallow(<Notes notes={notes} />)
    expect(wrapper.find('#note-text')).toHaveLength(1)
    expect(wrapper.text().includes('Reveal Answer')).toBeFalsy()
  })

  it('should reveal a spoiler when revealer is clicked', () => {
    const notes = [{ text: 'I am a spoiler', spoiler: true }]
    const wrapper = shallow(<Notes notes={notes} />)
    wrapper
      .find('button')
      .simulate('click', { preventDefault: () => {} })
    expect(wrapper.find('#note-text')).toHaveLength(1)
    expect(wrapper.text().includes('Reveal Answer')).toBeFalsy()
  })
})
