import React from 'react'
import cn from 'classnames'

import { isMobile } from 'responsive'

type NotesProps = {
  notes: Array<{ text: string; spoiler: boolean }>
}

export default function Notes({ notes }: NotesProps) {
  const [isSpoiled, setSpoiled] = React.useState(false)

  const reveal = (event: React.MouseEvent<HTMLButtonElement>) => {
    setSpoiled(true)
    event.preventDefault()
  }

  const revealer = (
    <p key="revealer" className="xwd__notes--revealer">
      <button type="button" onClick={reveal}>
        Reveal Answer
      </button>
    </p>
  )

  if (!notes || !notes.length) {
    return null
  }

  return (
    <aside className="xwd__notes--wrapper">
      <h3 className="xwd__notes--title">Note</h3>
      <div
        className={cn({ 'xwd__notes--content-container': !isMobile })}
      >
        {notes.map((note) => {
          const noteClasses = cn('xwd__notes--content', {
            'xwd__notes--spoiler': note.spoiler,
            'xwd__notes--spoiled': note.spoiler && isSpoiled,
          })

          const content = (
            <div key={note.text} className={noteClasses}>
              {note.spoiler && <div>ANSWER</div>}
              <p
                id="note-text"
                dangerouslySetInnerHTML={{ __html: note.text }}
              />
            </div>
          )

          return note.spoiler && !isSpoiled ? revealer : content
        })}
      </div>
    </aside>
  )
}
