import React from 'react'
import { createPortal } from 'react-dom'
import { useSelector } from 'react-redux'
import cn from 'classnames'

import {
  getPuzzleMetadata,
  getIsMini,
} from '../../store/state/puzzle/puzzleSelectors'
import PuzzleDetails from '../PuzzleDetails/PuzzleDetails'

import PrintAndDownloadTools from './PrintAndDownloadTools'
import Notes from './Notes'

export default function PuzzleHeader() {
  const meta = useSelector(getPuzzleMetadata)

  const portalRef = React.useRef(
    document.getElementById('portal-game-header'),
  )
  const isMini = useSelector(getIsMini)
  const isNewsReader = !!window.newsreaderAppPlatform
  const displayPrintDownloadTools = !isMini && !isNewsReader

  if (!portalRef.current || !meta) return null

  const { notes, publishStream, ...info } = meta

  return createPortal(
    <header className="xwd__header--wrapper">
      <div
        className={cn('xwd__header--row', {
          'xwd__header--fullwidth': isMini,
        })}
      >
        <div className="xwd__header--puzzle-details-container">
          <PuzzleDetails {...info} />
          {notes && <Notes notes={notes} />}
        </div>
        {displayPrintDownloadTools && (
          <div className="xwd__header--tools-container">
            <PrintAndDownloadTools />
          </div>
        )}
      </div>
    </header>,
    portalRef.current,
  )
}
