import React from 'react'
import { mount } from 'enzyme'

import * as responsive from 'responsive'

import { TimerBase } from './Timer'

responsive.isMobile = false
Object.defineProperty(document, 'hidden', { value: true })

const defaultProps = {
  shouldBePaused: false,
  totalElapsedTime: 100,
  sessionStartTimestamp: 50,
  timerIsVisible: true,
  start: jest.fn(),
  stop: jest.fn(),
  pauseFailsafe: jest.fn(),
  clickHandler: jest.fn(),
}

const getWrapper = () => mount(<TimerBase {...defaultProps} />)

describe('TIMER', () => {
  afterEach(jest.clearAllMocks)

  test('timer pauses when modal opens', () => {
    const view = getWrapper()
    const instance = view.instance()
    expect(instance.props.shouldBePaused).toBe(false)
    instance.startTicking()
    expect(instance.interval).toBeDefined()
    view.setProps({ shouldBePaused: true }) // modal opens, etc

    expect(defaultProps.stop).toHaveBeenCalled()
    expect(instance.interval).toBeUndefined()
    expect(instance.props.shouldBePaused).toBe(true)
  })

  test('timer resumes when modal closes', () => {
    const view = getWrapper()
    const instance = view.instance()
    expect(instance.props.shouldBePaused).toBe(false)
    instance.startTicking()
    instance.stopTicking()
    instance.startTicking = jest.fn()
    view.setProps({ shouldBePaused: false }) // modal opens, etc
    instance.forceUpdate()

    expect(instance.startTicking).toHaveBeenCalled()
    expect(instance.props.shouldBePaused).toBe(false)
  })

  test('clickHandler is called when handleBlur is called and if on mobile', () => {
    responsive.isMobile = true
    const view = getWrapper()
    const instance = view.instance()
    instance.startTicking() // keeps from executing the first if statement in handleBlur
    instance.handleBlur()
    expect(defaultProps.clickHandler).toHaveBeenCalled()
  })
})
