import React from 'react'
import { shallow } from 'enzyme'

import HelpMenu from './HelpMenu'
import { menuData, mobileMenuData } from './helpMenuData'

jest.mock('../../providers/ShortzModeProvider', () => ({
  useShortzMode: jest.fn(() => ({ inShortzMode: false })),
}))
jest.mock('responsive', () => ({
  isMobile: false,
}))
jest.mock('foundation', () => ({ track: jest.fn() }))
const clearItems = menuData[0].items
const checkItems = menuData[2].items

const itemHandler = jest.fn()

describe('HelpMenu Component', () => {
  it('renders component with items provided as buttons', () => {
    const wrapper = shallow(
      <HelpMenu
        itemHandler={itemHandler}
        items={clearItems}
        isAutocheckOn
      />,
    )
    expect(wrapper.find('button.xwd__menu--btnlink')).toHaveLength(
      clearItems.length,
    )
  })
  it('adds disable class for items that need to be disabled during autocheck mode', () => {
    const wrapper = shallow(
      <HelpMenu
        itemHandler={itemHandler}
        items={checkItems}
        isAutocheckOn
      />,
    )
    expect(wrapper.find('button.xwd__menu--btnlink')).toHaveLength(
      checkItems.length,
    )
    expect(wrapper.find('li.xwd__menu--item-disabled')).toHaveLength(
      3,
    )
  })
  it('adds checked class for auto checked menu items', () => {
    const wrapper = shallow(
      <HelpMenu
        itemHandler={itemHandler}
        items={checkItems}
        isAutocheckOn
      />,
    )
    expect(wrapper.find('li.xwd__menu--item-checked')).toHaveLength(1)
  })
  it('does not display items that are only for shortzMode', () => {
    const shortzOnlyItems = [
      mobileMenuData[4],
      mobileMenuData[5],
      mobileMenuData[6],
    ]

    const wrapper = shallow(
      <HelpMenu
        itemHandler={itemHandler}
        items={shortzOnlyItems}
        isAutocheckOn={false}
      />,
    )
    expect(wrapper.find('li')).toHaveLength(0)
  })
})
