import React, { useState } from 'react'
import cn from 'classnames'

import { Scope } from '../../../store/state/cells/cellsTypes'
import { useShortzMode } from '../../providers/ShortzModeProvider'
import type { ToolbarAction } from '../Toolbar'

import { MenuItem } from './helpMenuData'

type executeAction = (action: ToolbarAction, scope?: Scope) => void

type HelpMenuProps = {
  itemHandler: executeAction
  items: Partial<MenuItem>[]
  isAutocheckOn: boolean
}

export default function HelpMenu(props: HelpMenuProps) {
  const { itemHandler, items, isAutocheckOn } = props
  const [submenuOpen, setSubmenuOpen] = useState(false)
  const { inShortzMode } = useShortzMode()

  function handleItemClick(
    event: React.MouseEvent,
    item: Partial<MenuItem>,
    execute: executeAction,
  ) {
    const { action, scope } = item
    if (action) {
      execute(action, scope)
    } else {
      setSubmenuOpen(!submenuOpen)
      event.stopPropagation()
    }
    event.preventDefault()
  }

  return (
    <ul className="xwd__menu--container">
      {items.map((item) => {
        if (item.shortzOnly && !inShortzMode) return null
        const primaryItem = !item.secondary
        const isVisible = submenuOpen !== primaryItem
        const disableItem =
          isAutocheckOn && item.disabledDuringAutocheck
        const checked = isAutocheckOn && item.label === 'Autocheck'

        return (
          <li
            className={cn('xwd__menu--item', {
              'xwd__menu--item-disabled': disableItem,
              'xwd__menu--item-checked': checked,
              'xwd__menu--item-display': isVisible,
              'xwd__menu--item-hide': !isVisible,
            })}
            key={item.label}
            title={item.title}
          >
            <button
              type="button"
              className="xwd__menu--btnlink"
              onClick={(e) => {
                handleItemClick(e, item, itemHandler)
              }}
            >
              {item.label}
            </button>
          </li>
        )
      })}
    </ul>
  )
}
