import {
  CHECK,
  CLEAR,
  REVEAL,
  GUESS,
} from '../../../store/state/cells/cellsActions'
import {
  DEBUG_REVEAL,
  RESET_GAME,
} from '../../../store/state/status/statusActions'
import { toggleAutocheck } from '../../../store/thunks/statusThunks'
import { Scope } from '../../../store/state/cells/cellsTypes'

export type MenuAction =
  | typeof CHECK
  | typeof CLEAR
  | typeof REVEAL
  | typeof GUESS
  | typeof DEBUG_REVEAL
  | typeof RESET_GAME
  | (() => void)

export type MenuItem = {
  action: MenuAction
  label?: string
  scope?: Scope
  title?: string
  disabledDuringAutocheck?: boolean
  shortzOnly?: boolean
  secondary?: boolean
}

export type Menu = {
  label: string
  items: MenuItem[]
}

export const menuData: Menu[] = [
  {
    label: 'clear',
    items: [
      {
        action: CLEAR,
        scope: Scope.Unchecked,
        label: 'Incomplete',
        title:
          'Won’t clear letters that are part of completed crossing words',
      },
      { action: CLEAR, scope: Scope.Word, label: 'Word' },
      { action: CLEAR, scope: Scope.Puzzle, label: 'Puzzle' },
      {
        action: RESET_GAME,
        scope: Scope.Puzzle,
        label: 'Puzzle & Timer',
      },
    ],
  },
  {
    label: 'reveal',
    items: [
      { action: REVEAL, scope: Scope.Letter, label: 'Square' },
      { action: REVEAL, scope: Scope.Word, label: 'Word' },
      { action: REVEAL, scope: Scope.Puzzle, label: 'Puzzle' },
      {
        action: DEBUG_REVEAL,
        scope: Scope.Fifty,
        label: '49.9%',
        shortzOnly: true,
      },
      {
        action: DEBUG_REVEAL,
        scope: Scope.SeventyFive,
        label: '74.9%',
        shortzOnly: true,
      },
      { action: DEBUG_REVEAL, label: '99.9%', shortzOnly: true },
    ],
  },
  {
    label: 'check',
    items: [
      { action: toggleAutocheck, label: 'Autocheck' },
      {
        action: CHECK,
        scope: Scope.Letter,
        label: 'Square',
        disabledDuringAutocheck: true,
      },
      {
        action: CHECK,
        scope: Scope.Word,
        label: 'Word',
        disabledDuringAutocheck: true,
      },
      {
        action: CHECK,
        scope: Scope.Puzzle,
        label: 'Puzzle',
        disabledDuringAutocheck: true,
      },
    ],
  },
]

export const mobileMenuData: Partial<MenuItem>[] = [
  { action: toggleAutocheck, label: 'Autocheck' },
  {
    action: CHECK,
    scope: Scope.Letter,
    label: 'Check Square',
    disabledDuringAutocheck: true,
  },
  {
    action: CHECK,
    scope: Scope.Word,
    label: 'Check Word',
    disabledDuringAutocheck: true,
  },
  {
    action: CHECK,
    scope: Scope.Puzzle,
    label: 'Check Puzzle',
    disabledDuringAutocheck: true,
  },
  {
    action: DEBUG_REVEAL,
    scope: Scope.Fifty,
    label: '49.9%',
    shortzOnly: true,
  },
  {
    action: DEBUG_REVEAL,
    scope: Scope.SeventyFive,
    label: '74.9%',
    shortzOnly: true,
  },
  { action: DEBUG_REVEAL, label: '99.9%', shortzOnly: true },
  { label: 'More 〉' },
  {
    action: CLEAR,
    scope: Scope.Unchecked,
    label: 'Clear Incomplete',
    secondary: true,
  },
  {
    action: CLEAR,
    scope: Scope.Word,
    label: 'Clear Word',
    secondary: true,
  },
  {
    action: RESET_GAME,
    scope: Scope.Puzzle,
    label: 'Reset Puzzle',
    secondary: true,
  },
  {
    action: REVEAL,
    scope: Scope.Letter,
    label: 'Reveal Square',
    secondary: true,
  },
  {
    action: REVEAL,
    scope: Scope.Word,
    label: 'Reveal Word',
    secondary: true,
  },
  {
    action: REVEAL,
    scope: Scope.Puzzle,
    label: 'Reveal Puzzle',
    secondary: true,
  },
  { label: '〈 Back', secondary: true },
]
