import React from 'react'
import * as redux from 'react-redux'
import { shallow } from 'enzyme'

import Tool from './Tool'

describe('Tool Component', () => {
  it('renders tool component with appropriate class names', () => {
    const wrapper = shallow(
      <Tool
        clickHandler={jest.fn()}
        icon="pencil"
        ariaLabel="Edit"
        isAutocheckOn={false}
        active
      />,
    )
    expect(wrapper.find('i.pencil')).toHaveLength(1)
    expect(wrapper.find('li.xwd__tool--autocheck')).toHaveLength(0)
    expect(wrapper.find('li.xwd__tool--texty')).toHaveLength(0)
    expect(wrapper.find('li.xwd__tool--active')).toHaveLength(1)
  })

  it('triggers the clickHandler prop on the button click event', () => {
    const mockClickHandler = jest.fn()
    const mockedEvent = {
      stopPropagation: () => {},
    }

    const wrapper = shallow(
      <Tool
        clickHandler={mockClickHandler}
        icon="pencil"
        ariaLabel="Edit"
        isAutocheckOn={false}
        active
      />,
    )
    wrapper.find('button').simulate('click', mockedEvent)
    expect(mockClickHandler.mock.calls.length).toEqual(1)
  })
})
