import React from 'react'
import cn from 'classnames'

type ClickHandler =
  | (() => void)
  | ((
      event: React.MouseEvent<HTMLElement>,
    ) => React.MouseEvent<HTMLElement>)

type ToolProps = {
  clickHandler: ClickHandler
  icon?: string
  ariaLabel?: string
  label?: string
  active?: boolean
  open?: boolean
  isAutocheckOn?: boolean
  children?: React.ReactNode
}

export default function Tool(props: ToolProps) {
  const {
    clickHandler,
    icon,
    ariaLabel,
    label,
    active,
    open,
    isAutocheckOn,
    children,
  } = props

  const toolClasses = cn('xwd__tool--button', {
    'xwd__tool--texty': !icon,
    'xwd__tool--active': active,
    'xwd__tool--open': open,
    'xwd__tool--autocheck': isAutocheckOn,
  })

  return (
    <li className={toolClasses}>
      <button
        type="button"
        aria-label={ariaLabel || label}
        onClick={(event: React.MouseEvent<HTMLElement>) => {
          event.stopPropagation()
          clickHandler(event)
        }}
      >
        {!label && <i className={icon} />}
        {label}
      </button>
      {children}
    </li>
  )
}
