import React from 'react'

import Tool from './Tool/Tool'
import HelpMenu from './HelpMenu/HelpMenu'
import { Menu } from './HelpMenu/helpMenuData'
import type { ToggleType, ToolbarAction } from './Toolbar'

type ToolMenuProps = {
  autoCheckEnabled: boolean
  activeMenu: string | null
  execute: (action: ToolbarAction) => void
  toggleMenuAction: (type: ToggleType, menu?: string) => void
  menuData: Menu[]
}

export default function ToolMenu(props: ToolMenuProps) {
  const {
    autoCheckEnabled,
    activeMenu,
    execute,
    toggleMenuAction,
    menuData,
  } = props

  return (
    <div className="xwd__toolbar--expandedMenu">
      {menuData.map((menu) => {
        let { label } = menu

        const { items } = menu
        const action = label.toUpperCase()
        const isAutocheckOn = label === 'check' && autoCheckEnabled

        label = isAutocheckOn ? 'autocheck' : label
        return (
          <Tool
            open={activeMenu === action}
            label={label}
            clickHandler={() =>
              toggleMenuAction('MENU', menu.label.toUpperCase())
            }
            isAutocheckOn={isAutocheckOn}
            key={label}
          >
            <HelpMenu
              items={items}
              itemHandler={execute}
              isAutocheckOn={isAutocheckOn}
            />
          </Tool>
        )
      })}
    </div>
  )
}
