import '../../shared/shared-styles'
import '../../shared/shared-scripts'

import React from 'react'
import ReactDOM from 'react-dom'
import { Provider } from 'react-redux'

import { getGameData } from 'foundation'
import { UserProvider } from 'user'
import ClientSideScripts from 'shared/components/ClientSideScripts'

import './index.scss'

import AbraProviderWithUser from '../../shared/abra/AbraProviderWithUser'

import setUpStore from './store'
import CrosswordPage from './components/CrosswordPage/CrosswordPage'
import { ShortzModeProvider } from './components/providers/ShortzModeProvider'
import { manageXWDBrowserStorage } from './store/utils/forageUtils'
import { addMeta } from './utils/misc'

try {
  /**
   * This function must be called before every crossword game to ensure
   * the user's browser storage is tidy.
   */
  manageXWDBrowserStorage()
} catch (e) {
  // Fail silently if storage is corrupt
}

const gameRoot = document.getElementById('pz-game-root')
// for fixing viewport size on iOS newsreader - previously done in Head.js#L27
addMeta()

const CrosswordRoot = () => (
  <>
    <ClientSideScripts />
    <UserProvider>
      <AbraProviderWithUser>
        <ShortzModeProvider>
          <Provider store={setUpStore(getGameData())}>
            <CrosswordPage />
          </Provider>
        </ShortzModeProvider>
      </AbraProviderWithUser>
    </UserProvider>
  </>
)

ReactDOM.render(<CrosswordRoot />, gameRoot)
