import { compose, applyMiddleware, createStore } from 'redux'
import thunk from 'redux-thunk'

import crossware from './middleware/crossware'
import analyticsTracking from './middleware/analyticsTracking'
import fillMonitor from './middleware/fillMonitor'
import persistGame from './middleware/persistGame'
import persistPreferences from './middleware/persistPreferences'
import { rootReducer } from './state/crosswordReducer'
import { loadPuzzle } from './thunks/puzzleThunks'

const hasDevTools =
  typeof window.__REDUX_DEVTOOLS_EXTENSION__ !== 'undefined'

type ServerData = {
  filename: string
  stream: string
}

export default function ({ filename, stream }: ServerData) {
  const middleware = [applyMiddleware(thunk, persistPreferences)]

  middleware.push(
    applyMiddleware(
      persistGame,
      crossware,
      fillMonitor,
      analyticsTracking,
    ),
  )

  if (hasDevTools) {
    middleware.push(window.__REDUX_DEVTOOLS_EXTENSION__())
  }

  const store = createStore(rootReducer, compose(...middleware))

  // @ts-ignore
  store.dispatch(loadPuzzle(filename, stream))

  return store
}
