import { CrosswordAction } from '../state/crosswordAction'
import { CHECK, CLEAR, REVEAL } from '../state/cells/cellsActions'
import {
  CLOSE_MODAL,
  REMOVE_MODAL,
  CrosswordModalAction,
} from '../state/modal/modalActions'
import { RESET_GAME } from '../state/status/statusActions'
import {
  PAUSE_TIMER,
  RESUME_TIMER,
} from '../state/timer/timerActions'
import { TOGGLE_PENCIL } from '../state/toolbar/toolbarActions'
import { CrosswordStoreState } from '../state/crosswordReducer'
import { trackModuleInteraction } from '../utils/tracker'
import { Scope } from '../state/cells/cellsTypes'
import {
  getIsMini,
  getPuzzleId,
} from '../state/puzzle/puzzleSelectors'

import { CrosswordMiddleware } from './type'

const trackScopedActions = (
  scope: Scope | undefined,
  id: number,
  eventAction: string,
  prefix: string,
  word?: string,
) => {
  switch (scope) {
    case Scope.Unchecked:
      trackModuleInteraction(
        'click',
        id,
        eventAction,
        `${prefix}-incomplete`,
      )
      break
    case Scope.Letter:
      trackModuleInteraction(
        'click',
        id,
        eventAction,
        `${prefix}-square`,
      )
      break
    case Scope.Word:
      trackModuleInteraction(
        'click',
        id,
        eventAction,
        `${prefix}-word`,
        word,
      )
      break
    case Scope.Puzzle:
      trackModuleInteraction(
        'click',
        id,
        eventAction,
        `${prefix}-puzzle`,
      )
      break
    default:
      break
  }
}

const trackWritingMode = (
  id: number,
  eventAction: string,
  state: CrosswordStoreState,
) => {
  // this runs when inPencilMode is about to be toggled
  const writingMode = state.toolbar.inPencilMode ? 'pen' : 'pencil'
  trackModuleInteraction('click', id, eventAction, writingMode)
}

const trackClearModalActions = (
  action: CrosswordModalAction,
  id: number,
  eventAction: string,
  state: CrosswordStoreState,
) => {
  const actionType = state.modal.config?.actionType || ''
  const isCancelled =
    (action.type !== REMOVE_MODAL &&
      'isCancelled' in action.payload &&
      action.payload.isCancelled) ||
    false

  if ([CLEAR, RESET_GAME].includes(actionType) && isCancelled) {
    trackModuleInteraction('click', id, eventAction, 'clear-cancel')
  }
}

const analyticsTracking: CrosswordMiddleware =
  (store) => (next) => (action: CrosswordAction) => {
    const state = store.getState()
    const isMini = getIsMini(store.getState())
    const id = getPuzzleId(state) || 0
    const eventAction = isMini ? 'mini-page' : 'game-page'

    switch (action.type) {
      case REVEAL: {
        // Include the revealed word.
        const revealedWord = (action.payload.cellsInScope || [])
          .map((c) => state.cells[c].answer)
          .join('')
        trackScopedActions(
          action.payload.scope,
          id,
          eventAction,
          'reveal',
          revealedWord,
        )
        break
      }
      case CHECK:
        trackScopedActions(
          action.payload.scope,
          id,
          eventAction,
          'check',
        )
        break
      case CLEAR:
        trackScopedActions(
          action.payload.scope,
          id,
          eventAction,
          'clear',
        )
        break
      case TOGGLE_PENCIL:
        trackWritingMode(id, eventAction, state)
        break
      case CLOSE_MODAL:
        trackClearModalActions(action, id, eventAction, state)
        break
      case RESET_GAME:
        trackModuleInteraction(
          'click',
          id,
          eventAction,
          'clear-confirm',
        )
        break
      case PAUSE_TIMER:
        trackModuleInteraction('click', id, eventAction, 'stop-timer')
        break
      case RESUME_TIMER:
        trackModuleInteraction(
          'click',
          id,
          eventAction,
          'start-timer',
        )
        break
      default:
        break
    }

    return next(action)
  }

export default analyticsTracking
