import { CellState } from '../../state/cells/cellsTypes'

/*
 * given an initial cell index, a direction, cells, a grid width, and a predicate
 * returns the cell object, if any, that satisfies the predicate in the given direction
 */
const getRowRange = (initialCell: number, gridWidth: number) => {
  const rowStart = Math.floor(initialCell / gridWidth) * gridWidth
  const rowEnd = rowStart + gridWidth - 1
  return [rowStart, rowEnd]
}

const getColRange = (cells: CellState[]) => [0, cells.length - 1]

const getCellByDirection = (
  initialCell: number,
  direction: 'Up' | 'Down' | 'Left' | 'Right',
  cells: CellState[],
  gridWidth: number,
  predicate: (cell: CellState) => boolean,
) => {
  // prevent upstream data from creating an infinite loop
  if (typeof gridWidth !== 'number' || gridWidth < 1) {
    throw new Error('gridwidth must be a positive number')
  }

  let increment
  let range

  switch (direction) {
    case 'Up':
      increment = -gridWidth
      range = getColRange(cells)
      break
    case 'Down':
      increment = gridWidth
      range = getColRange(cells)
      break
    case 'Right':
      increment = 1
      range = getRowRange(initialCell, gridWidth)
      break
    case 'Left':
      increment = -1
      range = getRowRange(initialCell, gridWidth)
      break
    default:
    // the default branch is unreachable,
    // but making 'Left' the default is not clear
  }

  if (!increment || !range) {
    return
  }

  for (
    let i = initialCell + increment;
    i >= range[0] && i <= range[1];
    i += increment
  ) {
    if (predicate(cells[i])) return cells[i]
  }
}

export default getCellByDirection
