// Intercept puzzle actions and check if the cursor needs to move in response.
// If it does, calculate the new selection and, if it differs from the existing
// one, attach it to the action for reducers to apply to their slices of the state.
// Basically a meta-reducer with access to the full state.

import { CrosswordMiddleware } from '../type'

import gamesMachine from './gamesMachine'

const crossware: CrosswordMiddleware =
  (store) => (next) => (action) => {
    const newSelection = gamesMachine(store.getState(), action)
    // If the selection has not changed, don't pass it along
    if (!newSelection) return next(action)

    return next({
      ...action,
      selection: newSelection,
    })
  }

export default crossware
