import { isNavigable } from '../../utils/cellUtils'
import { CrosswordStoreState } from '../../state/crosswordReducer'
import { SelectionState } from '../../state/selection/selectionTypes'

import getClueFromCell from './getClueFromCell'
import getCellByDirection from './getCellByDirection'
import move from './mover'

const followArrow = (
  state: CrosswordStoreState,
  direction: 'Up' | 'Down' | 'Left' | 'Right',
  preferredClueListIndex?: number,
): SelectionState | null => {
  const { cells, clues, puzzle, selection } = state
  const currentCell = selection.cell || 0
  const gridWidth = puzzle.data?.dimensions.columnCount || 0

  const newCell = getCellByDirection(
    currentCell,
    direction,
    cells,
    gridWidth,
    isNavigable,
  )

  if (!newCell) return null // Nowhere to go, nothing to do

  const newClue = getClueFromCell(
    newCell,
    clues,
    typeof preferredClueListIndex !== 'undefined'
      ? preferredClueListIndex
      : selection.clueList,
  )

  return {
    ...selection,
    cell: newCell.index,
    cellClues: newCell.clues,
    clue: newClue.index,
    clueCells: newClue.cells,
    clueList: newClue.list ?? null,
  }
}

const navigate = (
  state: CrosswordStoreState,
  direction?: string,
  preferredClueListIndex?: number,
): SelectionState | null => {
  switch (direction) {
    case 'Up':
    case 'Down':
    case 'Left':
    case 'Right':
      return followArrow(state, direction, preferredClueListIndex)
    default:
      return move(state, direction)
  }
}

export default navigate
