import getClueFromCell from '../getClueFromCell'

describe('get clue from cell', () => {
  test('do not rotate if the preferred clue list is available', () => {
    const clue = getClueFromCell(
      { clues: [0, 1, 2] },
      [{ list: 0 }, { list: 1 }, { list: 2 }],
      1,
    )
    expect(clue).toMatchObject({ list: 1 })
  })

  test('do not rotate if clueless', () => {
    const clue = getClueFromCell(
      { clues: [] },
      [{ list: 0 }, { list: 1 }, { list: 2 }],
      1,
    )
    expect(clue).toMatchObject({ list: 1 })
  })

  test('if only higher clue lists are available, rotate as little as posible', () => {
    const clue = getClueFromCell(
      { clues: [1, 2] },
      [{ list: 0 }, { list: 1 }, { list: 2 }],
      0,
    )
    expect(clue).toMatchObject({ list: 1 })
  })

  test('if only lower clue lists are available stop rotating as early as possible', () => {
    const clue = getClueFromCell(
      { clues: [0, 1] },
      [{ list: 0 }, { list: 1 }, { list: 2 }],
      3,
    )
    expect(clue).toMatchObject({ list: 0 })
  })

  test('if lower clue lists and higher clue lists are available, choose the lowest one on the higher side', () => {
    const clue = getClueFromCell(
      { clues: [0, 2, 3] },
      [{ list: 0 }, { list: 1 }, { list: 2 }, { list: 3 }],
      1,
    )
    expect(clue).toMatchObject({ list: 2 })
  })
})
