import { UserType } from 'foundation'

import { PUZZLE_READY } from '../state/transient/transientActions'
import {
  CHANGE_BLOCK_OPACITY,
  CHANGE_PRINT_LAYOUT,
  CHANGE_SETTING,
  RESET_TO_DEFAULTS,
} from '../state/user/userActions'
import { getCurrentUser } from '../state/user/userSelectors'
import { storeUserPrefs } from '../utils/forageUtils'

import { CrosswordMiddleware } from './type'

const POTENTIAL_SYNC_ACTIONS = [
  CHANGE_SETTING,
  RESET_TO_DEFAULTS,
  CHANGE_BLOCK_OPACITY,
  CHANGE_PRINT_LAYOUT,
]

const persistPreferencesMiddleware: CrosswordMiddleware = (store) => {
  let userType: UserType

  return (next) => (action) => {
    const { type } = action

    if (type === PUZZLE_READY) {
      userType = action.payload.user
      return next(action)
    }

    const result = next(action)

    if (userType && POTENTIAL_SYNC_ACTIONS.includes(type)) {
      storeUserPrefs(getCurrentUser(store.getState()), userType)
    }

    return result
  }
}

export default persistPreferencesMiddleware
