import persistPreferences from '../persistPreferences'
import {
  CHANGE_SETTING,
  RESET_TO_DEFAULTS,
} from '../../state/user/userActions'
import { getCurrentUser } from '../../state/user/userSelectors'

jest.mock('../../utils/forageUtils', () => ({
  storeUserPrefs: jest.fn(),
}))

jest.mock('../../state/user/userSelectors', () => ({
  getCurrentUser: jest.fn(),
}))

describe('middleware: persist user preferences', () => {
  let user
  let getState
  let next
  let middleware

  beforeEach(() => {
    jest.resetAllMocks()
    next = jest.fn()
    getState = jest.fn()
    user = { id: 123 }

    next.mockImplementation((action) => {
      /** make sure next is fired first */
      getState.mockReturnValue({ user })
      getCurrentUser.mockImplementation((state) => state.user)
      return action.payload
    })

    middleware = persistPreferences({ getState })(next)
  })

  test('actions are defined', () => {
    expect(typeof CHANGE_SETTING).toBe('string')
    expect(typeof RESET_TO_DEFAULTS).toBe('string')
  })

  test('stores preferences when user changes setting', () => {
    const action = { type: CHANGE_SETTING, payload: { data: true } }
    expect(middleware(action)).toMatchObject({ data: true })
    expect(next).toHaveBeenCalledWith(action)
  })

  test('stores preferences when user restores default settings', () => {
    const action = {
      type: RESET_TO_DEFAULTS,
      payload: { data: true },
    }
    expect(middleware(action)).toMatchObject({ data: true })
    expect(next).toHaveBeenCalledWith(action)
  })

  test('skips other actions', () => {
    const action = { type: 'unknown', payload: { data: true } }
    expect(middleware(action)).toMatchObject({ data: true })
  })
})
