import { CLEAR, GUESS, REVEAL } from '../cells/cellsActions'
import { RECALCULATE_COUNTS } from '../progressActions'
import { RESET_GAME } from '../status/statusActions'
import {
  CellState,
  MultiCellActionPayload,
} from '../cells/cellsTypes'

import cluesReducer from './cluesReducer'

const multiCellPayload: MultiCellActionPayload = {
  cellsInScope: [],
  affectedCells: [],
  blankDeltas: [],
  incorrectDeltas: [],
  now: 1631735116,
}

const guessActionPayload = {
  index: 1,
  value: 'L',
  blankDelta: 10,
  incorrectDelta: 3,
  inPencilMode: true,
  autocheckEnabled: true,
  fromRebus: false,
  now: 1631735116,
}

const cluesState = [
  {
    list: 2,
    cells: [1, 2, 3, 4],
    direction: 'Across',
    label: '25',
    text: '',
    index: 4,
    prev: 3,
    next: 5,
    unfilledCount: 60,
    isImageClue: false,
    alternativeAriaLabelText: '',
  },
]

describe('Clues reducer', () => {
  it('returns initial state', () => {
    const reveal = cluesReducer(undefined, {
      type: REVEAL,
      payload: multiCellPayload,
    })
    expect(reveal).toEqual([])
  })
  it('recalculates the count and returns the unfilledCount based on number of blank cells and returns clue data', () => {
    const clueCellsData = [
      {
        cells: [0, 1, 2, 3],
        direction: 'Across',
        label: '35',
        text: 'What free apps often come with',
        type: 1,
        index: 0,
        next: 1,
        prev: 0,
        unfilledCount: 0,
        isImageClue: false,
        alternativeAriaLabelText: '',
      },
    ]

    const recalculateCounts = cluesReducer(cluesState, {
      type: RECALCULATE_COUNTS,
      payload: {
        clues: clueCellsData,
        cells: [
          { type: 1, guess: '' } as CellState,
          { type: 0, guess: 'A' } as CellState,
          { type: 4, guess: '' } as CellState,
          { guess: 'A', type: 1 } as CellState,
        ],
      },
    })
    expect(recalculateCounts[0]).toHaveProperty('unfilledCount', 1)
    expect(recalculateCounts[0].cells).toEqual(clueCellsData[0].cells)
    expect(recalculateCounts[0].label).toEqual(clueCellsData[0].label)
  })
  it('uses the guess to change the unfilled count and returns clue state', () => {
    const guess = cluesReducer(cluesState, {
      type: GUESS,
      payload: guessActionPayload,
    })
    expect(guess[0].unfilledCount).toBe(70)
  })
  it('returns the clue state when triggering a guess', () => {
    const guess = cluesReducer(cluesState, {
      type: GUESS,
      payload: guessActionPayload,
    })
    expect(guess[0].cells).toEqual(cluesState[0].cells)
    expect(guess[0].direction).toEqual(cluesState[0].direction)
    expect(guess[0].index).toEqual(cluesState[0].index)
    expect(guess[0].prev).toEqual(cluesState[0].prev)
    expect(guess[0].next).toEqual(cluesState[0].next)
  })
  it('updates the unfilled count and returns clue state', () => {
    const clear = cluesReducer(cluesState, {
      type: CLEAR,
      payload: multiCellPayload,
    })
    expect(clear[0].unfilledCount).toBe(60)
    expect(clear[0].cells).toEqual(cluesState[0].cells)
    expect(clear[0].direction).toEqual(cluesState[0].direction)
  })
  it('Resets unfilled count to the original clue cell length', () => {
    const resetGame = cluesReducer(cluesState, {
      type: RESET_GAME,
      payload: multiCellPayload,
    })
    expect(resetGame[0].unfilledCount).toBe(4)
  })
})
