import { Reducer } from 'redux'

import type { CrosswordAction } from '../crosswordAction'
import { RECALCULATE_COUNTS } from '../progressActions'
import { GUESS, CLEAR, REVEAL } from '../cells/cellsActions'
import { PUZZLE_LOADED } from '../puzzle/puzzleActions'
import { DEBUG_REVEAL, RESET_GAME } from '../status/statusActions'
import { isBlank } from '../../utils/cellUtils'
import { CellState } from '../cells/cellsTypes'

import { ClueState } from './cluesTypes'

const reducer: Reducer<ClueState[], CrosswordAction> = (
  state = [],
  action,
) => {
  switch (action.type) {
    case PUZZLE_LOADED: {
      return action.payload.clues
    }

    case RECALCULATE_COUNTS: {
      const { cells, clues } = action.payload
      return clues.map((clue: ClueState) => {
        const clueCells = clue.cells
          .map((i) => cells[i])
          .filter((cell) => !!cell) as CellState[]
        const unfilledCount = clueCells.filter(isBlank).length
        return { ...clue, unfilledCount }
      })
    }

    case GUESS: {
      const { index, blankDelta = 0 } = action.payload
      return state.map((clue) => {
        if (
          typeof index !== 'number' ||
          !clue.cells.includes(index) ||
          !blankDelta
        ) {
          return clue
        }

        return {
          ...clue,
          unfilledCount: clue.unfilledCount + blankDelta,
        }
      })
    }

    case RESET_GAME: {
      return state.map((clue) => ({
        ...clue,
        unfilledCount: clue.cells.length,
      }))
    }

    case CLEAR:
    case REVEAL:
    case DEBUG_REVEAL: {
      const { blankDeltas, affectedCells } = action.payload
      return state.map((clue) => {
        const isInCurrentClue = (int: number) =>
          clue.cells.includes(int)

        const unfilledCount = blankDeltas
          .filter((_, i) => {
            const affectedCell = affectedCells[i]
            return isInCurrentClue(affectedCell)
          })
          .reduce((sum, delta) => sum + delta, clue.unfilledCount)

        return {
          ...clue,
          unfilledCount,
        }
      })
    }

    default:
      return state
  }
}

export default reducer
