import { CrosswordModalConfig, CrosswordModal } from './modalTypes'

export const OPEN_MODAL = 'crossword/modal/OPEN_MODAL'
export const CLOSE_MODAL = 'crossword/modal/CLOSE_MODAL'
export const REMOVE_MODAL = 'crossword/modal/REMOVE_MODAL'

type OpenModalAction = {
  type: typeof OPEN_MODAL
  payload: {
    name: CrosswordModal
    config?: CrosswordModalConfig
  }
}

type CloseModalAction = {
  type: typeof CLOSE_MODAL
  payload: {
    isCancelled: boolean // used in analytics middleware
  }
}

type RemoveModalAction = {
  type: typeof REMOVE_MODAL
}

export type CrosswordModalAction =
  | OpenModalAction
  | CloseModalAction
  | RemoveModalAction

export const openModal = (
  name: CrosswordModal,
  config?: CrosswordModalConfig,
): OpenModalAction => ({
  type: OPEN_MODAL,
  payload: { name, config },
})

export const closeModal = (
  isCancelled: boolean,
): CloseModalAction => ({
  type: CLOSE_MODAL,
  payload: { isCancelled },
})

export const removeModal = () => ({
  type: REMOVE_MODAL,
})
