import type { CrosswordStoreState } from './crosswordReducer'
import { SelectionState } from './selection/selectionTypes'

export const APPLY_PROGRESS = 'crossword/progress/APPLY_PROGRESS'
export const RECALCULATE_COUNTS = 'crossword/progress/RECALC_COUNTS'

export const syncableKeys = [
  'cells',
  'status',
  'timer',
  'selection',
] as const

type SyncableKeysTuple = typeof syncableKeys
type SyncableKeys = SyncableKeysTuple[number]

// the object kept in local storage
export type LocalProgress = Pick<CrosswordStoreState, SyncableKeys>

// the parsed output of the api call. an incomplete version of LocalProgress
export type RemoteProgress = {
  lastCommitID: string
  cells: CrosswordStoreState['cells']
  status: Partial<CrosswordStoreState['status']>
  timer: Partial<CrosswordStoreState['timer']>
}

export type ApplyProgressPayload = LocalProgress | RemoteProgress

type ApplyProgressAction = {
  type: typeof APPLY_PROGRESS
  payload: ApplyProgressPayload
  selection?: SelectionState
}

type RecalculateCountsAction = {
  type: typeof RECALCULATE_COUNTS
  payload: Pick<CrosswordStoreState, 'cells' | 'clues'>
}

export type CrosswordProgressActions =
  | ApplyProgressAction
  | RecalculateCountsAction
