import { CellState } from '../cells/cellsTypes'
import { ClueState } from '../clues/cluesTypes'

import { PuzzleData } from './puzzleTypes'

export const PUZZLE_LOADED = 'crossword/puzzle/PUZZLE_LOADED'
export const PUZZLE_ERROR = 'crossword/puzzle/PUZZLE_ERROR'

type PuzzleLoadedAction = {
  type: typeof PUZZLE_LOADED
  payload: {
    cells: CellState[]
    clues: ClueState[]
    puzzle: PuzzleData
  }
}

type PuzzleErrorAction = {
  type: typeof PUZZLE_ERROR
  payload: {
    status: number
  }
}

export type CrosswordPuzzleAction =
  | PuzzleLoadedAction
  | PuzzleErrorAction

export const puzzleLoaded = (
  cells: CellState[],
  clues: ClueState[],
  puzzle: PuzzleData,
): PuzzleLoadedAction => ({
  type: PUZZLE_LOADED,
  payload: { cells, clues, puzzle },
})

export const puzzleError = (status: number): PuzzleErrorAction => ({
  type: PUZZLE_ERROR,
  payload: { status },
})
