export type BoardState = {
  name: string
  attributes: Record<string, string | number>
  styles?: Array<{ name: string; value: string }>
  index?: number
  content?: string
  children: BoardState[]
}

export type ClueListState = {
  clues: number[]
  name: string
  cells: number[]
  index: number
  prev: number
  next: number
}

export type ClueListsState = ClueListState[]

export type MetaState = {
  category: number
  constructors: string[]
  copyright: string
  editor: string
  id: number
  lastUpdated: string
  publicationDate: string
  relatedContent: {
    text: string
    url: string
  }
  goldStarCutoff: string
  publishStream: string
  title?: string
  notes?: Array<{ text: string; spoiler: boolean }>
  subcategory?: number
  formatType?: string
}

export type DimensionsState = {
  rowCount: number
  columnCount: number
  aspectRatio: number
  cellSize: number
}

export type OverlaysState = {
  beforeStart: string
  afterSolve: string
}

export type PuzzleData = {
  board: BoardState
  clueLists: ClueListsState
  meta: MetaState
  dimensions: DimensionsState
  overlays: OverlaysState
}

export type PuzzleState = {
  data: PuzzleData | null
  hasLoaded: boolean
  error: {
    status: number
  } | null
}
