import { SelectionState } from './selectionTypes'

export const NAVIGATE = 'crossword/selection/NAVIGATE'
export const SELECT_CELL = 'crossword/selection/SELECT_CELL'
export const SELECT_CLUE = 'crossword/selection/SELECT_CLUE'
export const SWITCH_DIRECTION = 'crossword/selection/SWITCH_DIRECTION'

type NavigateAction = {
  type: typeof NAVIGATE
  payload: {
    direction?: string
  }
  selection?: SelectionState
}

type SelectCellAction = {
  type: typeof SELECT_CELL
  payload: { index: number }
  selection?: SelectionState
}

type SelectClueAction = {
  type: typeof SELECT_CLUE
  payload: {
    index: number
    direction: string
  }
  selection?: SelectionState
}

type SwitchDirectionAction = {
  type: typeof SWITCH_DIRECTION
  payload?: { index: number }
  selection?: SelectionState
}

export type CrosswordSelectionAction =
  | NavigateAction
  | SelectCellAction
  | SelectClueAction
  | SwitchDirectionAction

// ACTION CREATORS
export const switchDirection = (): SwitchDirectionAction => ({
  type: SWITCH_DIRECTION,
})

export const navigate = (direction?: string): NavigateAction => ({
  type: NAVIGATE,
  payload: { direction },
})

export const selectCell = (
  index: number,
  alreadySelected: boolean,
): SwitchDirectionAction | SelectCellAction => {
  if (alreadySelected) {
    return { type: SWITCH_DIRECTION }
  }

  return {
    type: SELECT_CELL,
    payload: { index },
  }
}

export const selectClue = (
  index: number,
  isSelected: boolean,
): NavigateAction | SelectClueAction => {
  const direction = 'ClueStart'

  if (isSelected) {
    return {
      type: NAVIGATE,
      payload: { direction },
    }
  }

  return {
    type: SELECT_CLUE,
    payload: { index, direction },
  }
}
