import { createSelector } from 'reselect'

import { CrosswordStoreState } from '../crosswordReducer'
import {
  getAllCells,
  getAllClueLists,
  getAllClues,
} from '../puzzle/puzzleSelectors'

export const getCurrentSelection = (state: CrosswordStoreState) =>
  state.selection

export const getSelectedCellIndex = createSelector(
  getCurrentSelection,
  (selection) => selection.cell,
)

export const getSelectedCell = createSelector(
  [getAllCells, getSelectedCellIndex],
  (cells, cellIndex) =>
    typeof cellIndex === 'number' ? cells[cellIndex] : null,
)

export const getSelectedClue = createSelector(
  [getAllClues, getCurrentSelection],
  (clues, selection) =>
    typeof selection.clue === 'number' ? clues[selection.clue] : null,
)

export const getSelectedClueList = createSelector(
  [getAllClueLists, getCurrentSelection],
  (clueLists, selection) =>
    typeof selection.clueList === 'number'
      ? clueLists[selection.clueList]
      : null,
)

export const getSelectedClueCells = createSelector(
  getCurrentSelection,
  (selection) => selection.clueCells,
)

export const getSelectedRelatedCells = createSelector(
  getCurrentSelection,
  (selection) => selection.relatedCells,
)
