import {
  CellState,
  MultiCellActionPayload,
} from '../cells/cellsTypes'
import { SelectionState } from '../selection/selectionTypes'

export const SET_INITIAL_CELL_STATUS =
  'crossword/status/SET_INITIAL_CELL_STATUS'
export const RESET_GAME = 'crossword/status/RESET_GAME'
export const DEBUG_REVEAL = 'crossword/status/DEBUG_REVEAL'
export const MARK_SOLVED = 'crossword/status/MARK_SOLVED'
export const ENABLE_AUTOCHECK = 'crossword/status/ENABLE_AUTOCHECK'
export const DISABLE_AUTOCHECK = 'crossword/status/DISABLE_AUTOCHECK'
export const TRACK_PROGRESS = 'crossword/status/TRACK_PROGRESS'
export const MARK_FILLED = 'crossword/status/MARK_FILLED'
export const UNMARK_FILLED = 'crossword/status/UNMARK_FILLED'

type ResetGameAction = {
  type: typeof RESET_GAME
  payload: MultiCellActionPayload
  selection?: SelectionState
}

type DebugRevealAction = {
  type: typeof DEBUG_REVEAL
  payload: MultiCellActionPayload & { index: number }
  selection?: SelectionState
}

type MarkSolvedAction = {
  type: typeof MARK_SOLVED
  payload: {
    now: number
  }
}

type EnableAutocheckAction = {
  type: typeof ENABLE_AUTOCHECK
  payload: MultiCellActionPayload
}

type DisableAutocheckAction = {
  type: typeof DISABLE_AUTOCHECK
  payload: MultiCellActionPayload
}

type TrackProgressAction = {
  type: typeof TRACK_PROGRESS
  payload: {
    currentProgress: number
  }
}

type MarkFilledAction = {
  type: typeof MARK_FILLED
  payload: {
    now: number
  }
}

type UnmarkFilledAction = {
  type: typeof UNMARK_FILLED
  payload: {
    now: number
  }
}

type SetInitialCellStatusAction = {
  type: typeof SET_INITIAL_CELL_STATUS
  payload: {
    cells: CellState[]
  }
}

export type CrosswordStatusAction =
  | ResetGameAction
  | DebugRevealAction
  | MarkSolvedAction
  | EnableAutocheckAction
  | DisableAutocheckAction
  | TrackProgressAction
  | MarkFilledAction
  | UnmarkFilledAction
  | SetInitialCellStatusAction

export const setInitialCellStatus = (
  cells: CellState[],
): SetInitialCellStatusAction => ({
  type: SET_INITIAL_CELL_STATUS,
  payload: { cells },
})
