import { MultiCellActionPayload } from '../cells/cellsTypes'
import { APPLY_PROGRESS } from '../progressActions'

import { RESET_GAME, TRACK_PROGRESS } from './statusActions'
import statusReducer from './statusReducer'

const applyProgressPayload = {
  affectedCells: [],
  status: {
    firsts: {},
    isSolved: false,
    blankCells: 8,
  },
  cells: Array(10).fill({ type: 2 }),
}

const multiCellPayload: MultiCellActionPayload = {
  cellsInScope: [],
  affectedCells: [],
  blankDeltas: [],
  incorrectDeltas: [],
  now: 1,
}

const clearStatus = {
  firsts: { timerReset: 1 },
  isSolved: false,
  isFilled: false,
  autocheckEnabled: false,
  blankCells: 0,
  incorrectCells: 0,
  lastCommitID: null,
  currentProgress: 0,
}

describe('status reducer', () => {
  it('should return updated current progess', () => {
    const trackProgress = statusReducer(undefined, {
      type: TRACK_PROGRESS,
      payload: { currentProgress: 2 },
    })
    expect(trackProgress.currentProgress).toBe(2)
  })
  it('should have a cleared status after resetting game', () => {
    const resetGame = statusReducer(undefined, {
      type: RESET_GAME,
      payload: multiCellPayload,
    })
    expect(resetGame).toMatchObject(clearStatus)
  })
  it('should return a restored progress value', () => {
    expect(
      statusReducer(undefined, {
        type: APPLY_PROGRESS,
        // @ts-ignore
        payload: applyProgressPayload,
      }).currentProgress,
    ).toBe(1)
  })
})
