import moment from 'moment'

import { getGoldStarEligibility } from './statusSelectors'

describe('get gold star eligibility', () => {
  const getState = (status, meta, settings) => ({
    status,
    puzzle: {
      data: {
        meta,
      },
    },
    user: { settings },
  })

  test('respect force gold star option', () => {
    expect(
      getGoldStarEligibility(
        getState(
          { firsts: {} },
          {
            goldStarCutoff: moment().add(1, 'days'),
            publishStream: 'daily',
          },
          { forceGoldStarEligibility: true },
        ),
      ),
    ).toBe(true)
  })

  test('rejects if user has reset timer', () => {
    expect(
      getGoldStarEligibility(
        getState(
          { firsts: { timerReset: moment() } },
          {
            goldStarCutoff: moment().add(1, 'days'),
            publishStream: 'daily',
          },
          { forceGoldStarEligibility: false },
        ),
      ),
    ).toBe(false)
  })

  test('rejects if user has revealed answers', () => {
    expect(
      getGoldStarEligibility(
        getState(
          { firsts: { revealed: moment() } },
          {
            goldStarCutoff: moment().add(1, 'days'),
            publishStream: 'daily',
          },
          { forceGoldStarEligibility: false },
        ),
      ),
    ).toBe(false)
  })

  test('rejects if user has checked answers', () => {
    expect(
      getGoldStarEligibility(
        getState(
          { firsts: { checked: moment() } },
          {
            goldStarCutoff: moment().add(1, 'days'),
            publishStream: 'daily',
          },
          { forceGoldStarEligibility: false },
        ),
      ),
    ).toBe(false)
  })

  test('rejects if cutoff has passed', () => {
    expect(
      getGoldStarEligibility(
        getState(
          { firsts: {} },
          {
            goldStarCutoff: moment().subtract(1, 'days'),
            publishStream: 'daily',
          },
          { forceGoldStarEligibility: false },
        ),
      ),
    ).toBe(false)
  })

  test('accepts if cutoff has not passed', () => {
    expect(
      getGoldStarEligibility(
        getState(
          { firsts: {} },
          {
            goldStarCutoff: moment().add(1, 'days'),
            publishStream: 'daily',
          },
          { forceGoldStarEligibility: false },
        ),
      ),
    ).toBe(true)
  })

  test('rejects if the puzzle is a mini', () => {
    expect(
      getGoldStarEligibility(
        getState(
          { firsts: {} },
          { publishStream: 'mini' },
          { forceGoldStarEligibility: true },
        ),
      ),
    ).toBe(false)
  })
})
