import moment from 'moment'

export const RESUME_TIMER = 'crossword/timer/RESUME_TIMER'
export const PAUSE_TIMER = 'crossword/timer/PAUSE_TIMER'
export const COMMIT_PROGRESS = 'crossword/timer/COMMIT_PROGRESS'

type ResumeTimerAction = {
  type: typeof RESUME_TIMER
  payload: {
    now: number
  }
}

type PauseTimerAction = {
  type: typeof PAUSE_TIMER
  payload: {
    now: number
    isLeavingGame?: boolean
  }
}

type CommitProgressAction = {
  type: typeof COMMIT_PROGRESS
  payload: {
    now: number
  }
}

export type CrosswordTimerAction =
  | ResumeTimerAction
  | PauseTimerAction
  | CommitProgressAction

// ACTION CREATORS
export const updateTimer = (
  action:
    | typeof RESUME_TIMER
    | typeof PAUSE_TIMER
    | typeof COMMIT_PROGRESS,
  isLeavingGame?: boolean,
): CrosswordTimerAction => {
  if (action === RESUME_TIMER || action === COMMIT_PROGRESS) {
    return {
      type: action,
      payload: { now: moment().unix() },
    }
  }

  return {
    type: action,
    payload: {
      now: moment().unix(),
      isLeavingGame,
    },
  }
}

export const forceCommit = () => updateTimer(COMMIT_PROGRESS)

export const unpauseTimer = () => updateTimer(RESUME_TIMER)

export const pauseTimer = (isLeavingGame = false) =>
  updateTimer(PAUSE_TIMER, isLeavingGame)
