export const TOGGLE_PENCIL = 'crossword/toolbar/TOGGLE_PENCIL_MODE'
export const PENCIL_ON = 'crossword/toolbar/PENCIL_MODE_ON'
export const PENCIL_OFF = 'crossword/toolbar/PENCIL_MODE_OFF'
export const ENTER_REBUS = 'crossword/toolbar/ENTER_REBUS_MODE'
export const EXIT_REBUS = 'crossword/toolbar/EXIT_REBUS_MODE'
export const UPDATE_REBUS = 'crossword/toolbar/UPDATE_REBUS'
export const TOGGLE_HELP_MENU = 'crossword/toolbar/TOGGLE_HELP_MENU'

type TogglePencilAction = { type: typeof TOGGLE_PENCIL }

type PencilOnAction = { type: typeof PENCIL_ON }

type PencilOffAction = { type: typeof PENCIL_OFF }

type EnterRebusAction = {
  type: typeof ENTER_REBUS
  payload: {
    initialValue: string
  }
}

type ExitRebusAction = { type: typeof EXIT_REBUS }

type UpdateRebusAction = {
  type: typeof UPDATE_REBUS
  payload: string
}

type ToggleMenuAction = {
  type: typeof TOGGLE_HELP_MENU
  payload: {
    menu: string | null
  }
}

export type CrosswordToolbarAction =
  | TogglePencilAction
  | PencilOnAction
  | PencilOffAction
  | EnterRebusAction
  | ExitRebusAction
  | UpdateRebusAction
  | ToggleMenuAction

// ACTION CREATORS
export const togglePencil = (): TogglePencilAction => ({
  type: TOGGLE_PENCIL,
})

export const usePencil = (): PencilOnAction => ({ type: PENCIL_ON })

export const usePen = (): PencilOffAction => ({ type: PENCIL_OFF })

export const toggleHelpMenu = (
  menu: string | null,
): ToggleMenuAction => ({
  type: TOGGLE_HELP_MENU,
  payload: { menu },
})

export const openRebus = (
  initialValue: string,
): EnterRebusAction => ({
  type: ENTER_REBUS,
  payload: { initialValue },
})

export const updateRebus = (value: string): UpdateRebusAction => ({
  type: UPDATE_REBUS,
  payload: value,
})
