import { Reducer } from 'redux'

import type { CrosswordAction } from '../crosswordAction'

import {
  ENTER_REBUS,
  EXIT_REBUS,
  UPDATE_REBUS,
  PENCIL_OFF,
  PENCIL_ON,
  TOGGLE_HELP_MENU,
  TOGGLE_PENCIL,
} from './toolbarActions'
import { ToolbarState } from './toolbarTypes'

const initialState: ToolbarState = {
  activeMenu: null,
  inPencilMode: false,
  inRebusMode: false,
  rebusValue: '',
}

const reducer: Reducer<ToolbarState, CrosswordAction> = (
  state = initialState,
  action,
) => {
  switch (action.type) {
    case ENTER_REBUS: {
      return {
        ...state,
        inRebusMode: true,
        rebusValue: action.payload.initialValue,
      }
    }

    case EXIT_REBUS: {
      return {
        ...state,
        inRebusMode: false,
        rebusValue: '',
      }
    }

    case UPDATE_REBUS: {
      return {
        ...state,
        rebusValue: action.payload,
      }
    }

    case TOGGLE_PENCIL: {
      return {
        ...state,
        inPencilMode: !state.inPencilMode,
      }
    }

    case PENCIL_ON: {
      return {
        ...state,
        inPencilMode: true,
      }
    }

    case PENCIL_OFF: {
      return {
        ...state,
        inPencilMode: false,
      }
    }

    case TOGGLE_HELP_MENU: {
      const { menu } = action.payload
      return {
        ...state,
        activeMenu: menu === state.activeMenu ? null : menu,
      }
    }

    default:
      return state
  }
}

export default reducer
