import { defaultUserType } from '../../../../../shared/user/userHelpers'

import {
  ESCAPE_PUZZLE,
  PUZZLE_READY,
  PUZZLE_SYNCED,
} from './transientActions'
import transientReducer from './transientReducer'

jest.mock('foundation', () => ({
  env: {
    name: 'dev',
  },
}))

const basicCrosswordPayload = {
  now: 1631733110,
  user: defaultUserType,
}

const anotherBasicCrosswordPayload = {
  now: 1631733110,
  commitID: '123345',
}

const transientState = {
  isReady: false,
  isSynced: true,
  doEscape: true,
}

describe('Transient reducer', () => {
  it('puzzle ready sets isReady flag to true', () => {
    const puzzleReady = transientReducer(transientState, {
      type: PUZZLE_READY,
      payload: basicCrosswordPayload,
    })
    expect(puzzleReady.isReady).toBe(true)
  })
  it('puzzle syncing sets isSynced flag to true', () => {
    const puzzleSynced = transientReducer(undefined, {
      type: PUZZLE_SYNCED,
      payload: anotherBasicCrosswordPayload,
    })
    expect(puzzleSynced.isSynced).toBe(true)
  })
  it('escape puzzle changes turns off doEscape flag', () => {
    const escapePuzzle = transientReducer(transientState, {
      type: ESCAPE_PUZZLE,
      payload: false,
    })
    expect(escapePuzzle.doEscape).toBe(false)
  })
})
