import {
  CrosswordSettings,
  CrosswordPrintPrefs,
  mobileSettings,
  desktopSettings,
  PrintLayoutOptions,
} from './userTypes'

export const CHANGE_SETTING = 'crossword/user/CHANGE_SETTING'
export const LOAD_SETTINGS = 'crossword/user/LOAD_SETTINGS'
export const RESET_TO_DEFAULTS = 'crossword/user/RESET_TO_DEFAULTS'
export const LOAD_PRINT_PREFS = 'crossword/user/LOAD_PRINT_PREFS'
export const CHANGE_BLOCK_OPACITY =
  'crossword/user/CHANGE_BLOCK_OPACITY'
export const CHANGE_PRINT_LAYOUT =
  'crossword/user/CHANGE_PRINT_LAYOUT'

type ChangeSettingAction = {
  type: typeof CHANGE_SETTING
  payload: Partial<CrosswordSettings>
}

type LoadSettingsAction = {
  type: typeof LOAD_SETTINGS
  payload: CrosswordSettings
}

type ResetSettingsAction = {
  type: typeof RESET_TO_DEFAULTS
  payload: CrosswordSettings
}

type LoadPrintPrefsAction = {
  type: typeof LOAD_PRINT_PREFS
  payload: CrosswordPrintPrefs
}

type ChangeBlockOpacityAction = {
  type: typeof CHANGE_BLOCK_OPACITY
  payload: Partial<CrosswordPrintPrefs>
}

type ChangePrintLayoutAction = {
  type: typeof CHANGE_PRINT_LAYOUT
  payload: Partial<CrosswordPrintPrefs>
}

export type CrosswordUserAction =
  | ChangeSettingAction
  | LoadSettingsAction
  | ResetSettingsAction
  | LoadPrintPrefsAction
  | ChangeBlockOpacityAction
  | ChangePrintLayoutAction

export const changeUserSetting = (
  setting: Partial<CrosswordSettings>,
): ChangeSettingAction => ({
  type: CHANGE_SETTING,
  payload: setting,
})

export const resetToDefaults = (
  isMobile: boolean,
): ResetSettingsAction => ({
  type: RESET_TO_DEFAULTS,
  payload: isMobile ? mobileSettings : desktopSettings,
})

export const changePrintOpacity = (
  opacity: number,
): ChangeBlockOpacityAction => ({
  type: CHANGE_BLOCK_OPACITY,
  payload: { opacity },
})

export const changePrintLayout = (
  layout: PrintLayoutOptions,
): ChangePrintLayoutAction => ({
  type: CHANGE_PRINT_LAYOUT,
  payload: { layout },
})
