import userReducer from './userReducer'
import {
  CrosswordPrintPrefs,
  CrosswordSettings,
  PrintLayoutOptions,
} from './userTypes'

const basicCrosswordSettings: CrosswordSettings = {
  onSwitch: 'stay',
  jumpBack: false,
  skipFilled: false,
  skipPenciled: false,
  showTimer: false,
  suppressDisqualificationWarnings: false,
  spaceTriggers: 'clear',
  backspaceAcrossWords: false,
  autoAdvance: false,
  soundOn: false,
  showMilestones: false,
  forceGoldStarEligibility: false,
}

const printPrefs: CrosswordPrintPrefs = {
  opacity: 5,
  layout: PrintLayoutOptions.southpaw,
}

const userState = {
  settings: basicCrosswordSettings,
  printPrefs,
}

describe('User reducer', () => {
  it('changes settings', () => {
    const changeSetting = userReducer(undefined, {
      type: 'crossword/user/CHANGE_SETTING',
      payload: basicCrosswordSettings,
    })
    expect(changeSetting.settings).toMatchObject(
      basicCrosswordSettings,
    )
  })

  it('combines settings based on current and updated user settings', () => {
    const changeSetting = userReducer(userState, {
      type: 'crossword/user/CHANGE_SETTING',
      payload: basicCrosswordSettings,
    })
    expect(changeSetting.settings).toMatchObject(
      basicCrosswordSettings,
    )
    expect(changeSetting.printPrefs).toMatchObject(
      userState.printPrefs,
    )
  })
})
