import { Reducer } from 'redux'

import type { CrosswordAction } from '../crosswordAction'

import {
  CHANGE_BLOCK_OPACITY,
  CHANGE_SETTING,
  LOAD_SETTINGS,
  RESET_TO_DEFAULTS,
  CHANGE_PRINT_LAYOUT,
  LOAD_PRINT_PREFS,
} from './userActions'
import {
  mobileSettings,
  defaultPrintPrefs,
  UserState,
} from './userTypes'

const initialState: UserState = {
  settings: mobileSettings,
  printPrefs: defaultPrintPrefs,
}

const reducer: Reducer<UserState, CrosswordAction> = (
  state = initialState,
  action,
) => {
  switch (action.type) {
    case CHANGE_SETTING: {
      return {
        ...state,
        settings: {
          ...state.settings,
          ...action.payload,
        },
      }
    }

    case LOAD_SETTINGS:
    case RESET_TO_DEFAULTS: {
      return {
        ...state,
        settings: { ...action.payload },
      }
    }

    case LOAD_PRINT_PREFS: {
      return {
        ...state,
        printPrefs: action.payload,
      }
    }

    case CHANGE_PRINT_LAYOUT:
    case CHANGE_BLOCK_OPACITY: {
      return {
        ...state,
        printPrefs: {
          ...state.printPrefs,
          ...action.payload,
        },
      }
    }

    default:
      return state
  }
}

export default reducer
