export type CrosswordSettings = {
  onSwitch: string
  jumpBack: boolean
  skipFilled: boolean
  skipPenciled: boolean
  showTimer: boolean
  suppressDisqualificationWarnings: boolean
  spaceTriggers: 'toggle' | 'clear'
  backspaceAcrossWords: boolean
  autoAdvance: boolean
  soundOn: boolean
  showMilestones?: boolean
  forceGoldStarEligibility: boolean
  speedUpSyncInterval?: boolean
  suppressAutocheckNotice?: boolean
}

export enum PrintLayoutOptions {
  standard = 'standard',
  southpaw = 'southpaw',
  large_print = 'large_print',
}

export type CrosswordPrintPrefs = {
  opacity: number
  layout: PrintLayoutOptions
}

export type UserState = {
  settings: CrosswordSettings
  printPrefs: CrosswordPrintPrefs
}

// DEFAULTS
const commonSettings = {
  onSwitch: 'stay',
  jumpBack: true,
  skipFilled: true,
  skipPenciled: false,
  showTimer: true,
  suppressDisqualificationWarnings: false,
  forceGoldStarEligibility: false,
  speedUpSyncInterval: false,
  suppressAutocheckNotice: false,
}

export const mobileSettings: CrosswordSettings = {
  ...commonSettings,
  spaceTriggers: 'toggle',
  backspaceAcrossWords: true,
  autoAdvance: true,
  soundOn: false,
}

export const desktopSettings: CrosswordSettings = {
  ...commonSettings,
  spaceTriggers: 'clear',
  backspaceAcrossWords: false,
  autoAdvance: false,
  soundOn: true,
  showMilestones: true,
}

export const defaultPrintPrefs = {
  opacity: 100,
  layout: PrintLayoutOptions.standard,
}
