import { UserType } from 'foundation'

import { fetchLocalProgress } from '../utils/forageUtils'
import { fetchRemoteProgress } from '../utils/remoteUtils'
import { switchDirection } from '../state/selection/selectionActions'
import logger from '../../../shared/utils/clientLogger'
import { getPuzzleId } from '../state/puzzle/puzzleSelectors'
import { parseApiProgress } from '../utils/syncGameState'

import { CrosswordThunk, isLocalLatest } from './helpers'
import { markSyncedAndStart } from './transientThunks'
import { applyProgress } from './progressThunks'
import { guess } from './statusThunks'

export const recallPuzzleProgress =
  (userType: UserType): CrosswordThunk =>
  (dispatch, getState) => {
    const state = getState()
    const puzzleID = getPuzzleId(state)

    if (!puzzleID) {
      return
    }

    /**
     * In case the progress fetching fails
     * we want the user to still be able to play
     */
    const localPromise = fetchLocalProgress(userType, puzzleID).catch(
      () => {
        logger.debug('error fetching local progress')
        return null
      },
    )

    const remotePromise = fetchRemoteProgress(
      userType,
      puzzleID,
      parseApiProgress,
    ).catch(() => {
      logger.debug('error fetching remote progress')
      return null
    })

    /**
     * fetch the local game and the remote game,
     * then select the latest progress, preferring local
     */
    Promise.all([localPromise, remotePromise]).then(
      ([localProgress, remoteProgress]) => {
        const local = isLocalLatest(localProgress, remoteProgress)
        const progress = local ? localProgress : remoteProgress
        const lastCommitID = local
          ? localProgress?.status?.lastCommitID
          : remoteProgress?.lastCommitID

        if (progress) {
          dispatch(applyProgress(progress))
        }

        dispatch(markSyncedAndStart(userType, lastCommitID))
      },
    )
  }

export const spaceBar =
  (): CrosswordThunk => (dispatch, getState) => {
    const { user } = getState()
    const { settings } = user
    const spaceShouldSwitchDirection =
      settings.spaceTriggers === 'toggle'

    if (spaceShouldSwitchDirection) return dispatch(switchDirection())

    return dispatch(guess(''))
  }
