import { enterRebus, exitRebus } from '../toolbarThunks'
import { convertRebusToGuess } from '../helpers'
import { trackModuleInteraction } from '../../utils/tracker'
import {
  EXIT_REBUS,
  openRebus,
} from '../../state/toolbar/toolbarActions'
import { getSelectedCell } from '../../state/selection/selectionSelectors'

jest.mock('foundation', () => ({
  env: { version: 'test' },
}))

jest.mock('../helpers', () => ({
  ...jest.requireActual,
  convertRebusToGuess: jest.fn(),
}))

jest.mock('../../state/selection/selectionSelectors', () => ({
  getSelectedCell: jest.fn(),
}))

jest.mock('../../state/puzzle/puzzleSelectors', () => ({
  getPuzzleId: jest.fn(),
  getIsMini: jest.fn(() => false),
}))

jest.mock('../../state/status/statusSelectors', () => ({
  getPercentFilled: jest.fn(),
}))

jest.mock('../../state/toolbar/toolbarActions', () => ({
  ...jest.requireActual,
  openRebus: jest.fn(),
}))

jest.mock('../../utils/tracker', () => ({
  trackModuleInteraction: jest.fn(),
}))

const dispatch = jest.fn()

describe('toolbar thunks', () => {
  beforeEach(() => {
    jest.resetAllMocks()
  })

  describe('enterRebus', () => {
    it('opens the rebus and fires tracking if the cell is not locked', () => {
      const getState = () => {}
      // @ts-ignore
      getSelectedCell.mockImplementation(() => ({
        cell: { confirmed: true },
        guess: 'thingOne',
      }))

      // @ts-ignore
      enterRebus()(dispatch, getState, null)
      expect(openRebus).toHaveBeenCalledWith('thingOne')

      // @ts-ignore
      expect(trackModuleInteraction.mock.calls.length).toEqual(1)
    })

    it('does not open the rebus if the cell is locked', () => {
      const getState = () => {}
      // @ts-ignore
      getSelectedCell.mockImplementation(() => ({
        cell: { confirmed: true },
        guess: 'thingTwo',
      }))

      // @ts-ignore
      enterRebus()(dispatch, getState, null)
      expect(openRebus).toHaveBeenCalledWith('thingTwo')
    })
  })

  describe('exitRebus', () => {
    it('converts a rebus to a guess if it is accepted', () => {
      const getState = () => ({ toolbar: { rebusValue: 'test' } })

      // @ts-ignore
      exitRebus(true)(dispatch, getState, null)
      expect(convertRebusToGuess).toHaveBeenCalledWith('test')
    })

    it('closes the rebus if a guess is accepted', () => {
      const getState = () => ({ toolbar: { rebusValue: 'test' } })

      // @ts-ignore
      exitRebus(true)(dispatch, getState, null)
      expect(dispatch).toHaveBeenCalledWith({ type: EXIT_REBUS })
    })

    it('closes the rebus if a guess is not accepted', () => {
      const getState = () => ({ toolbar: { rebusValue: 'test' } })

      // @ts-ignore
      exitRebus(false)(dispatch, getState, null)
      expect(dispatch).toHaveBeenCalledTimes(1)
    })
  })
})
