import { getSelectedCell } from '../state/selection/selectionSelectors'
import {
  getInRebusMode,
  getRebusValue,
} from '../state/toolbar/toolbarSelectors'
import {
  getIsMini,
  getPuzzleId,
} from '../state/puzzle/puzzleSelectors'
import {
  openRebus,
  EXIT_REBUS,
} from '../state/toolbar/toolbarActions'
import { isLocked } from '../utils/cellUtils'
import { trackModuleInteraction } from '../utils/tracker'

import { convertRebusToGuess, CrosswordThunk } from './helpers'
import { guess } from './statusThunks'

export const enterRebus =
  (): CrosswordThunk => (dispatch, getState) => {
    const state = getState()
    const selectedCell = getSelectedCell(state)
    const isMini = getIsMini(state)

    if (!isLocked(selectedCell)) {
      const puzzleID = getPuzzleId(state)
      const action = isMini ? 'mini-page' : 'game-page'
      trackModuleInteraction('click', puzzleID, action, 'rebus')

      dispatch(openRebus(selectedCell?.guess || ''))
    }
  }

export const exitRebus =
  (accept: boolean): CrosswordThunk =>
  (dispatch, getState) => {
    const state = getState()
    const rebusValue = getRebusValue(state)

    if (accept) {
      const saveRebus = convertRebusToGuess(rebusValue)
      dispatch(guess(saveRebus, true))
    }

    dispatch({ type: EXIT_REBUS })
  }

export const toggleRebus =
  (): CrosswordThunk => (dispatch, getState) => {
    const state = getState()
    const inRebusMode = getInRebusMode(state)

    dispatch(inRebusMode ? exitRebus(true) : enterRebus())
  }
