import moment from 'moment'

import { isMobile } from 'responsive'
import { UserType } from 'foundation'

import { trackModuleInteraction } from '../utils/tracker'
import {
  PUZZLE_READY,
  setSynced,
} from '../state/transient/transientActions'
import { getCurrentUserSettings } from '../state/user/userSelectors'
import { getTotalElapsedTime } from '../state/timer/timerSelectors'
import {
  getPuzzleId,
  getPuzzlePublishStream,
} from '../state/puzzle/puzzleSelectors'

import { CrosswordThunk } from './helpers'

export const setReady =
  (user: UserType): CrosswordThunk =>
  (dispatch, getState) => {
    const state = getState()
    const publishStream = getPuzzlePublishStream(state)
    const puzzleId = getPuzzleId(state)
    const totalElapsedTime = getTotalElapsedTime(state)
    const startOfGame = totalElapsedTime === 0

    if (!puzzleId) {
      return
    }

    if (startOfGame) {
      const eventAction =
        publishStream === 'mini' ? 'mini-page' : 'game-page'
      trackModuleInteraction(
        'click',
        puzzleId,
        eventAction,
        'start-game',
      )
    }

    dispatch({
      type: PUZZLE_READY,
      payload: {
        now: moment().unix(),
        user,
      },
    })
  }

export const markSyncedAndStart =
  (user: UserType, lastCommitID?: string | null): CrosswordThunk =>
  (dispatch, getState) => {
    dispatch(setSynced(lastCommitID))

    const state = getState()
    const userSettings = getCurrentUserSettings(state)

    if (isMobile) return

    const { status } = state

    if (!userSettings.showTimer || status.isSolved) {
      dispatch(setReady(user))
    }
  }
