import { UserType } from 'foundation'

import { ANONYMOUS_ID } from '../../../../shared/hub/store/constants'
import logger from '../../../shared/utils/clientLogger'
import { getLocalUserPreferences } from '../utils/forageUtils'
import {
  LOAD_PRINT_PREFS,
  LOAD_SETTINGS,
} from '../state/user/userActions'
import {
  defaultPrintPrefs,
  desktopSettings,
  mobileSettings,
} from '../state/user/userTypes'

import { CrosswordThunk } from './helpers'

export const recallUserSettings =
  (isMobile: boolean, userType: UserType): CrosswordThunk =>
  (dispatch) => {
    const defaultSettings = isMobile
      ? mobileSettings
      : desktopSettings

    const userId = userType.regiId || ANONYMOUS_ID

    return getLocalUserPreferences(`${userId}`)
      .then((preferences) => {
        // if we have stored prefs we should use them
        // but if there is a new option key we should take it from defaults
        // so we merge the stored into the default
        const prefs = {
          ...defaultSettings,
          ...(preferences ? preferences.settings : {}),
        }

        dispatch({
          type: LOAD_SETTINGS,
          payload: prefs,
        })
      })
      .catch((err: string) => {
        logger.error(err)
        dispatch({
          type: LOAD_SETTINGS,
          payload: defaultSettings,
        })
      })
  }

export const recallPrintPrefs =
  (userType: UserType): CrosswordThunk =>
  (dispatch) => {
    getLocalUserPreferences(`${userType.regiId}`)
      .then((preferences) => {
        dispatch({
          type: LOAD_PRINT_PREFS,
          payload:
            (preferences && preferences.printPrefs) ||
            defaultPrintPrefs,
        })
      })
      .catch((err) => {
        logger.error(err)

        dispatch({
          type: LOAD_PRINT_PREFS,
          payload: defaultPrintPrefs,
        })
      })
  }
