import type { BoardState } from '../../state/puzzle/puzzleTypes'

import { RawSVG, RawSVGAttributes } from './types'

const camelize = (tag: string) =>
  tag.replace(/-([a-z])/, (_, p1) => p1.toUpperCase())

const combineAttrs = (attrs: RawSVGAttributes) =>
  attrs.reduce((obj, { name, value }) => {
    if (name === 'fill') return obj // Unused attribute; handled with CSS
    let tagName = name.startsWith('data') ? name : camelize(name)
    if (name === 'class') tagName = 'className'

    return {
      ...obj,
      [tagName]: value || null,
    }
  }, {})

const adaptElement = (obj: RawSVG, index?: number): BoardState => ({
  ...obj,
  attributes: combineAttrs(obj.attributes || []),
  children: obj.children ? obj.children.map(adaptElement) : [],
  index,
})

const adaptBoard = (svgObj: RawSVG) => adaptElement(svgObj)

export default adaptBoard
