import moment from 'moment'
import 'moment-timezone'

import { RawNote, RawPuzzleData } from './types'

const VALID_PUBLISH_DATE = /\d{4}-\d{2}-\d{2}/
const isValidPublishDate = (publishDate: string) =>
  typeof publishDate === 'string' &&
  VALID_PUBLISH_DATE.exec(publishDate)

const getGoldStarCutoff = (publishDate: string) =>
  isValidPublishDate(publishDate)
    ? moment
        .tz(publishDate, 'America/Los_Angeles')
        .endOf('day')
        .format()
    : moment({ year: 3000 }).format()

const reduceNotes = (acc: RawNote[], note: RawNote) => {
  if (note.platforms && !note.platforms.web) return acc
  const textWithLineBreaks = note.text.replace(/\n\n/g, '<br><br>')
  const webNote = { ...note, text: textWithLineBreaks }
  return acc.concat(webNote)
}

const adaptMeta = (
  metadata: Omit<RawPuzzleData, 'assets' | 'body'>,
  stream: string,
) => ({
  category: 0,
  ...metadata,
  goldStarCutoff: getGoldStarCutoff(metadata.publicationDate),
  notes: metadata.notes
    ? metadata.notes.reduce<RawNote[]>(reduceNotes, [])
    : metadata.notes,
  publishStream: stream,
})

export default adaptMeta
