export type RawAssets = Array<{ uri: string }>

export type RawDimensions = {
  height: number
  width: number
}

export type RawSVGAttributes = Array<{
  name: string
  value: string
}>

export type RawSVG = {
  name: string
  attributes: RawSVGAttributes
  styles?: Array<{ name: string; value: string }>
  content?: string
  children?: Array<RawSVG>
}

export type RawNote = {
  text: string
  spoiler: boolean
  platforms?: {
    web: boolean
  }
}

export type RawCell = {
  answer: string
  clues?: [number, number]
  label: string
  type?: number
}

export type RawClue = {
  cells?: number[]
  direction: string
  label: string
  text: Array<{
    formatted?: string
    plain: string
  }>
}

export type RawClueList = {
  clues: number[]
  name: string
}

export type RawOverlays = {
  beforeStart?: number
  afterSolve?: number
}

export type RawPuzzleBody = {
  board: string
  cells: RawCell[]
  clueLists: RawClueList[]
  clues: RawClue[]
  dimensions: RawDimensions
  overlays: RawOverlays
  SVG: RawSVG
}

export type RawPuzzleData = {
  freePuzzle: boolean
  assets: RawAssets
  body: [RawPuzzleBody]
  constructors: string[]
  copyright: string
  editor: string
  id: number
  lastUpdated: string
  notes?: RawNote[]
  publicationDate: string
  relatedContent: {
    text: string
    url: string
  }
  title?: string
  subcategory?: number
  stream?: string
  status: number
}
