import { defaultUserType } from '../../../../shared/user/userHelpers'

import getEditorialContent from './editorialContentApi'
import { apiCallWithUser } from './remoteUtils'

jest.mock('./remoteUtils', () => ({
  apiCallWithUser: jest.fn(),
  edgeHost: 'edgeHost',
}))

jest.mock('foundation', () => ({
  env: {
    name: 'dev',
  },
}))

describe('API: GET EDITORIAL CONTENT', () => {
  const date = '2018-08-07'
  const user = defaultUserType

  it('should fetch puzzles from service', () => {
    expect.assertions(2)

    const fakeArticles = {
      featuredArticle: {
        headline: 'a',
        byline: 'By B',
        url: 'c',
      },
      secondaryArticles: [
        {
          headline: 'd',
          byline: 'By E',
          url: 'f',
        },
        {
          headline: 'g',
          byline: 'By H',
          url: 'i',
        },
      ],
    }

    // @ts-ignore
    apiCallWithUser.mockReturnValue(Promise.resolve(fakeArticles))

    return getEditorialContent(date, user).then((articles) => {
      expect(apiCallWithUser).toHaveBeenCalledWith(
        {
          method: 'GET',
          url: `edgeHost/v6/editorial-content/puzzle/${date}.json`,
        },
        user,
      )

      expect(articles).toEqual(fakeArticles)
    })
  })

  it('should format bylines', () => {
    expect.assertions(3)

    const fakeArticles = {
      featuredArticle: { byline: 'deb amlen' },
      secondaryArticles: [
        { byline: 'by GRAHAM SHELBY' },
        { byline: 'andy bertrand and deb amlen' },
      ],
    }

    // @ts-ignore
    apiCallWithUser.mockReturnValue(Promise.resolve(fakeArticles))

    return getEditorialContent(date, user).then((articles) => {
      expect(articles.featuredArticle.byline).toEqual('By DEB AMLEN')
      expect(articles.secondaryArticles[0].byline).toEqual(
        'By GRAHAM SHELBY',
      )
      expect(articles.secondaryArticles[1].byline).toEqual(
        'By ANDY BERTRAND and DEB AMLEN',
      )
    })
  })
})
