import { UserType } from '../../../../shared/foundation'
import type {
  ArticleData,
  EditorialData,
} from '../../components/EditorialContent/EditorialContent'

import { edgeHost, apiCallWithUser } from './remoteUtils'

const formatByline = (string: string) => {
  const cleanedString = string
    .trim()
    .toUpperCase()
    .replace(' AND ', ' and ')

  return cleanedString.startsWith('BY ')
    ? cleanedString.replace('BY ', 'By ')
    : `By ${cleanedString}`
}

const formatObj = (obj: ArticleData) => {
  if (obj.byline) {
    return { ...obj, byline: formatByline(obj.byline) }
  }

  return { ...obj }
}

const getEditorialContent = (
  date: string,
  user: UserType,
): Promise<EditorialData> =>
  apiCallWithUser(
    {
      method: 'GET',
      url: `${edgeHost}/v6/editorial-content/puzzle/${date}.json`,
    },
    user,
  ).then((data) => {
    data.featuredArticle = formatObj(data.featuredArticle)
    data.secondaryArticles = data.secondaryArticles.map(
      (obj: ArticleData) => formatObj(obj),
    )
    return data
  })

export default getEditorialContent
