import {
  addRecentPuzzle,
  getLastPlayedTime,
  checkIfStoredPuzzleIsStale,
  manageXWDBrowserStorage,
} from './forageUtils'

describe('FORAGE UTILS: CROSSWORD BROSWER STORAGE MANAGEMENT', () => {
  // This is a crossword puzzle key locally
  const crosswordGameKey = '1234567@24096'
  const moogleGameKey = 'nyt-wordle-moogle/1234567'

  it('should set a #lastPlayed timestamp', async () => {
    const now = new Date().getTime()
    addRecentPuzzle(crosswordGameKey, now)
    const retrievedValue = await getLastPlayedTime(crosswordGameKey)
    expect(retrievedValue).toBe(now)
  })

  it('should delete puzzles older than one week', (done) => {
    const twoWeeksAgo = new Date().getTime() - 1209600000
    addRecentPuzzle(crosswordGameKey, twoWeeksAgo)

    checkIfStoredPuzzleIsStale(crosswordGameKey)

    // Delay to allow the asynchronous getLastPlayedTime to fetch updated data
    setTimeout(() => {
      getLastPlayedTime(crosswordGameKey).then((result) => {
        expect(result).toBe(null)
        done()
      })
    }, 0)
  })

  it('should keep puzzles not older than one week', (done) => {
    const twoDaysAgo = new Date().getTime() - 172800000
    addRecentPuzzle(crosswordGameKey, twoDaysAgo)

    checkIfStoredPuzzleIsStale(crosswordGameKey)

    // Delay to allow the asynchronous getLastPlayedTime to fetch updated data
    setTimeout(() => {
      getLastPlayedTime(crosswordGameKey).then((result) => {
        expect(result).toBe(twoDaysAgo)
        done() // Call done to indicate the test completion
      })
    }, 0)
  })

  it('should only delete local data that belongs to the crossword', (done) => {
    const twoWeeksAgo = new Date().getTime() - 1209600000
    addRecentPuzzle(moogleGameKey, twoWeeksAgo)

    manageXWDBrowserStorage()

    // Delay to allow the asynchronous getLastPlayedTime to fetch updated data
    setTimeout(() => {
      getLastPlayedTime(moogleGameKey).then((result) => {
        expect(result).toBe(twoWeeksAgo)
        done() // Call done to indicate the test completion
      })
    }, 0)
  })
})
