// NOTE: not a deep comparison, but avoids lodash. works for its current use case in cellsReducer
export const keysMatch = <T>(
  obj: T,
  other: T,
  keys: Array<keyof T>,
) => {
  return keys.every((key) => obj[key] === other[key])
}

export const pickShallow = <T extends {}, K extends keyof T>(
  obj: T,
  keys: readonly K[],
): Pick<T, K> =>
  keys.reduce(
    (acc, key) => ({ ...acc, [key]: obj[key] }),
    {} as Pick<T, K>,
  )

const convertSnakeToCamel = (snake: string) => {
  let camel = ''
  for (let i = 0; i < snake.length; i += 1) {
    camel +=
      snake[i] === '_' ? snake[(i += 1)].toUpperCase() : snake[i]
  }

  return camel
}

export const camelizeKeysDeep = (o: any): any => {
  switch (true) {
    case !o:
      return o
    case Array.isArray(o):
      return o.map(camelizeKeysDeep)
    case typeof o === 'object':
      return Object.entries(o).reduce(
        (final, [key, val]) =>
          Object.assign(final, {
            [convertSnakeToCamel(key)]: camelizeKeysDeep(val),
          }),
        {},
      )
    default:
      return o
  }
}

export const newID = () => Math.random().toString(36).slice(2, 8)
