import { track } from 'foundation'

export const trackModuleInteraction = (
  category: string,
  context: number | string | undefined,
  action: string,
  elementLabel: string,
  moduleLabel?: string,
  useBeacon?: boolean,
) => {
  const event = {
    module: {
      name: category,
      context,
      element: {
        name: action || '',
        label:
          typeof elementLabel === 'string'
            ? elementLabel
            : JSON.stringify(elementLabel),
      },
      ...(moduleLabel && { label: moduleLabel }),
    },
    eventData: {
      pageType: 'game',
      type: useBeacon ? 'ob_click' : 'click',
      trigger: 'module',
      // important to leave an empty string for `status`
      // for the event to pass correctly to google analytics
      // consult with someone from tracking team before removing
      // and confirm that the events are still availably in big query
      status: '',
    },
  }
  track('moduleInteraction', event)
}

export const trackImpression = (
  name: string,
  region: string,
  label?: string,
  context?: string,
) => {
  track('impression', {
    module: {
      name,
      context,
      region: region || '',
      label: label || undefined,
    },
  })
}
