import { backspace, clear } from '../store/thunks/cellThunks'
import { enterRebus } from '../store/thunks/toolbarThunks'
import { navigate } from '../store/state/selection/selectionActions'
import { spaceBar } from '../store/thunks/sharedThunks'
import { openModal } from '../store/state/modal/modalActions'
import { CrosswordModal } from '../store/state/modal/modalTypes'

const openPause = () => openModal(CrosswordModal.Pause)

type HandlerProps = {
  key: string
  shiftKey: string
}

type ActionCreator =
  | typeof navigate
  | typeof openPause
  | typeof enterRebus
  | typeof spaceBar
  | typeof backspace
  | typeof clear

type HandlerReturn = {
  action?: ActionCreator
  payload?: string
}

export default ({ key, shiftKey }: HandlerProps): HandlerReturn => {
  let action
  let payload

  switch (key) {
    case 'Escape':
      action = shiftKey ? openPause : enterRebus
      break
    case 'Insert':
      action = enterRebus
      break
    case 'Tab':
    case 'Enter':
    case 'NumpadEnter':
      action = navigate
      payload = shiftKey ? 'PreviousClue' : 'NextClue'
      break
    case ' ':
      action = spaceBar
      break
    case 'End':
      action = navigate
      payload = 'ClueEnd'
      break
    case 'Home':
      action = navigate
      payload = 'ClueStart'
      break
    case 'ArrowLeft':
    case 'ArrowRight':
    case 'ArrowUp':
    case 'ArrowDown':
      action = navigate
      payload = shiftKey ? `Shift${key}` : key
      break
    case 'Backspace':
      action = backspace
      break
    case 'Delete':
      action = clear
      payload = 'Cell'
      break
    default:
      return {}
  }

  return {
    action,
    payload,
  }
}
