import { guess } from '../store/thunks/statusThunks'

type KeyPressEvent = {
  altKey: boolean
  ctrlKey: boolean
  key: string
  metaKey: boolean
  preventDefault: Function
  shiftKey: boolean
  which: number
}

/*
 * For microsoft keyboards on IE
 * the numpad converts the key values to strings
 * such as 'multiply' and 'add' ☹
 * so we fall back to using event.which
 */
export const getKey = (key: string, keyCode: number) => {
  /**
   * UTF-16 key codes 0-32 and 127-160 do not correspond to readable text,
   * but return truthy strings, causing havoc
   */
  if (keyCode < 33 || (keyCode > 126 && keyCode < 161)) return null

  // If we receive a non-standard key, fall back to event.which keycodes
  return key.length > 1
    ? String.fromCharCode(keyCode).toUpperCase()
    : key.toUpperCase()
}

const isPartOfNativeKeyCombo = ({
  altKey,
  ctrlKey,
  metaKey,
}: KeyPressEvent) => altKey || ctrlKey || metaKey

export default (event: KeyPressEvent) => {
  const { key, which, shiftKey } = event

  /**
   * If a special modifier is pressed,
   * allow default action to bubble up and don't alter puzzle
   */
  if (isPartOfNativeKeyCombo(event)) return {}

  /**
   * Otherwise, prevent Firefox's auto-search
   * from triggering and guess with key's value
   */
  event.preventDefault()

  return {
    action: guess,
    payload: getKey(key, which),
    shiftKey,
  }
}
