import { formatDate } from './time'

const EASY_MODE_REGEX = /Easy\sMode\sNo.\s+[0-9]\d*$/

export const capitalize = (s: string) =>
  s && s.length > 1 ? s[0].toUpperCase() + s.slice(1) : ''

export const getCellDomId = (cellIdx: number) => `cell-id-${cellIdx}`

export const getPuzzleLabel = (
  pubDate: string,
  publishStream: string,
) => {
  const isLabeled = ['daily', 'mini', 'bonus'].includes(publishStream)

  if (!isLabeled) return ''

  return publishStream === 'daily'
    ? formatDate(pubDate, 'dddd')
    : capitalize(publishStream)
}

export const prettyJoin = <T extends object | string>(arr: T[]) => {
  if (!arr || arr.length === 0) return ''

  if (arr.length === 1) return arr[0].toString()

  return [arr.slice(0, -1).join(', ')]
    .concat(arr.slice(-1).map((el) => el.toString()))
    .join(' and ')
}

export const constructorPrefix = (title: string | undefined) => {
  const prefix = 'By'
  if (title === undefined) return prefix

  if (EASY_MODE_REGEX.test(title)) return 'Grid by'

  return prefix
}

export const editorPrefix = (title: string | undefined) => {
  const prefix = 'Edited by'
  if (title === undefined) return prefix

  if (EASY_MODE_REGEX.test(title)) return 'Clues by'

  return prefix
}

export const addMeta = () => {
  const isIOSNewsreaderXWD = window.newsreaderAppPlatform === 'ios'
  if (isIOSNewsreaderXWD) {
    const currentMeta = document
      .querySelector('meta[name="viewport"]')
      ?.getAttribute('content')
    const newMeta = `${currentMeta}, viewport-fit=cover, maximum-scale=1, user-scalable=no`
    document
      .querySelector('meta[name="viewport"]')
      ?.setAttribute('content', newMeta)
  }
}
