import moment from 'moment'

export const getElapsedTime = (
  totalElapsedTime: number,
  sessionStartTimestamp?: number,
) => {
  const timeDiff = sessionStartTimestamp
    ? moment().unix() - sessionStartTimestamp
    : 0

  return totalElapsedTime + timeDiff
}

export const formatTime = (seconds: number) => {
  const h = Math.floor(seconds / 3600)
  const m = Math.floor((seconds % 3600) / 60)
  const mm = m < 10 ? `0${m}` : m
  const s = Math.floor(seconds % 60)
  const ss = s < 10 ? `0${s}` : s
  if (h > 0) return [h, mm, ss].join(':')

  return `${m}:${ss}`
}

const NYT_TOKEN_RE = /(\w*)\{nyt-(\w+)\}(\w*)/g
const NYT_TIME_FORMATS: Record<string, (t: moment.Moment) => string> =
  {
    m: (timestamp) => {
      const fullMonth = timestamp.format('MMMM')
      const threeLetterMonth =
        fullMonth === 'September' ? 'Sept' : fullMonth.substring(0, 3)

      return fullMonth.length > 4 ? `${threeLetterMonth}.` : fullMonth
    },
  }

const getNYTTimeTokens = (timestamp: moment.Moment, fmt: string) =>
  fmt.replace(NYT_TOKEN_RE, (_, __, nytFormat: string) => {
    const formatter = NYT_TIME_FORMATS[nytFormat]
    if (!formatter) {
      throw new Error(`Unrecognized NYT time: "${nytFormat}"`)
    }

    return `[${formatter(timestamp)}]`
  })

export const formatDate = (date: string, fmt: string) => {
  if (!date) return ''
  const timestamp = moment(date)
  const specialFormat = getNYTTimeTokens(timestamp, fmt)
  return timestamp.format(specialFormat)
}
