import { constructorPrefix, editorPrefix, addMeta } from './misc'

describe('constructorPrefix()', () => {
  it('with undefined title, returns "By"', () => {
    expect(constructorPrefix(undefined)).toEqual('By')
  })

  it('with defined title, returns "By"', () => {
    expect(constructorPrefix('A Random Title')).toEqual('By')
  })

  it(`with defined title matching "Easy Mode No. <number>", returns "Grid by"`, () => {
    expect(constructorPrefix('Easy Mode No. 1')).toEqual('Grid by')
    expect(constructorPrefix('Easy Mode No. 932786231')).toEqual(
      'Grid by',
    )
  })
})

describe('editorPrefix()', () => {
  it('with undefined title, returns "Edited by"', () => {
    expect(editorPrefix(undefined)).toEqual('Edited by')
  })

  it('with defined title, returns "Edited by"', () => {
    expect(editorPrefix('A Random Title')).toEqual('Edited by')
  })

  it(`with defined title matching "Easy Mode No. <number>", returns "Clues by"`, () => {
    expect(editorPrefix('Easy Mode No. 1')).toEqual('Clues by')
    expect(editorPrefix('Easy Mode No. 932786231')).toEqual(
      'Clues by',
    )
  })
})

describe('addMeta()', () => {
  const updateWindowNewsPlatform = (appPlatform = '') => {
    return Object.defineProperty(
      global.window,
      'newsreaderAppPlatform',
      {
        writable: true,
        value: appPlatform,
      },
    )
  }
  beforeEach(() => {
    jest.clearAllMocks()
    jest
      .spyOn(document, 'querySelector')
      .mockImplementation((selector: string) => null)
  })
  it('should not try to update the meta tag if newsreaderAppPlatform is null', () => {
    updateWindowNewsPlatform()
    addMeta()
    expect(document.querySelector).toBeCalledTimes(0)
  })
  it('should not try to update the meta tag if newsreaderAppPlatform is android', () => {
    updateWindowNewsPlatform('android')
    addMeta()
    expect(document.querySelector).toBeCalledTimes(0)
  })
  it('should try to access the document if newsreaderAppPlatform is iOS', () => {
    updateWindowNewsPlatform('ios')
    addMeta()
    expect(document.querySelector).toBeCalledTimes(2)
  })
})
