import React, { useEffect, useState } from 'react'

import {
  getFeedbackLink,
  SEND_EMAIL_TYPE,
  UserType,
} from 'foundation'

import {
  getEnhancedHybridDebugInfo,
  getHybridDebugInfo,
} from './getHybridDebugInfo'

export function getSubject(subject: string) {
  if (window.newsreaderAppPlatform) {
    return `News App: ${subject}`
  }

  if (window.gamesAppPlatform === 'ios') {
    return `iOS ${subject}`
  }

  if (window.gamesAppPlatform === 'android') {
    return `Android ${subject}`
  }

  return `${subject}`
}

type FeedbackLinkProps = {
  subject?: string
  href?: string
  children?: string
  type?: SEND_EMAIL_TYPE
  user?: Partial<UserType>
  useEnhancedHybridDebugInfo?: boolean
}

const FeedbackLink = ({
  subject = '',
  href = '',
  children = '',
  type = SEND_EMAIL_TYPE.FEEDBACK,
  user = {},
  useEnhancedHybridDebugInfo = false,
}: FeedbackLinkProps) => {
  const [overrideLink, setOverrideLink] = useState(
    'mailto:nytgames@nytimes.com',
  )
  const isHybrid = window.isHybridWebView && window.NativeBridge
  const subjectWithPlatform = getSubject(subject)

  useEffect(() => {
    getFeedbackLink(subjectWithPlatform).then(setOverrideLink)
  }, [])

  const handleClick: React.MouseEventHandler<HTMLAnchorElement> = (
    event,
  ) => {
    if (isHybrid) {
      event.preventDefault()
      window.NativeBridge?.gamesSendEmail({
        type,
        debugInfo: useEnhancedHybridDebugInfo
          ? getEnhancedHybridDebugInfo(user)
          : getHybridDebugInfo(user),
      })
    }
  }

  const msgSubject = href && subject ? subjectWithPlatform : '' // sets query param for custom links

  const anchorLink = href
    ? `${href}?subject=${msgSubject}`
    : overrideLink // allow email override
  const feedbackLink = !isHybrid ? anchorLink : undefined

  return (
    <a
      aria-label="Send feedback to nytgames@nytimes.com"
      rel={!isHybrid ? 'noopener noreferrer' : undefined}
      target={!isHybrid ? '_blank' : undefined}
      href={feedbackLink}
      onClick={handleClick}
      title="nytgames@nytimes.com"
    >
      {children}
    </a>
  )
}

export default FeedbackLink
