import { track } from 'foundation'

import createGameTracker from '../createGameTracker'

jest.mock('../../../shared/foundation', () => ({
  track: jest.fn(),
}))

describe('HELPER: CREATE GAME TRACKER', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should attempt to track interactions', () => {
    createGameTracker('SET', '123').interaction.gameplay('foo', 'bar')
    expect(track).toHaveBeenCalledWith('moduleInteraction', {
      eventData: {
        pageType: 'game',
        status: '',
        trigger: 'module',
        type: 'click',
      },
      module: {
        context: 'SET-123',
        element: {
          label: 'bar',
          name: 'foo',
        },
        label: null,
        name: 'gameplay',
      },
    })
  })

  it('should attempt to track impressions', () => {
    createGameTracker('SET', '123').impression.gameplay('foo', 'bar')
    expect(track).toHaveBeenCalledWith('impression', {
      module: {
        context: 'SET-123',
        label: 'bar',
        name: 'gameplay',
        region: 'foo',
      },
    })
  })

  it('should parse events with empty eventAction values', () => {
    createGameTracker('SET', '123').interaction.gameplay(
      undefined,
      'bar',
    )
    createGameTracker('SET', '123').impression.gameplay(
      undefined,
      'bar',
    )
    expect(track).toHaveBeenCalledWith('moduleInteraction', {
      eventData: {
        pageType: 'game',
        status: '',
        trigger: 'module',
        type: 'click',
      },
      module: {
        context: 'SET-123',
        element: {
          label: 'bar',
          name: '',
        },
        label: null,
        name: 'gameplay',
      },
    })
    expect(track).toHaveBeenCalledWith('impression', {
      module: {
        context: 'SET-123',
        label: 'bar',
        name: 'gameplay',
        region: '',
      },
    })
  })

  it('should parse events with 3 event values', () => {
    createGameTracker('SET', '123').interaction.gameplay(
      undefined,
      'bar',
      'hello',
    )

    expect(track).toHaveBeenCalledWith('moduleInteraction', {
      eventData: {
        pageType: 'game',
        status: '',
        trigger: 'module',
        type: 'click',
      },
      module: {
        context: 'SET-123',
        element: {
          label: 'bar',
          name: '',
        },
        label: 'hello',
        name: 'gameplay',
      },
    })
  })

  it('should parse events with Object-type eventExtra values', () => {
    createGameTracker('SET', '123').interaction.gameplay('foo', {
      baz: 'bar',
    })
    createGameTracker('SET', '123').impression.gameplay('foo', {
      baz: 'bar',
    })
    expect(track).toHaveBeenCalledWith('moduleInteraction', {
      eventData: {
        pageType: 'game',
        status: '',
        trigger: 'module',
        type: 'click',
      },
      module: {
        context: 'SET-123',
        element: {
          label: '{"baz":"bar"}',
          name: 'foo',
        },
        label: null,
        name: 'gameplay',
      },
    })
    expect(track).toHaveBeenCalledWith('impression', {
      module: {
        context: 'SET-123',
        label: '{"baz":"bar"}',
        name: 'gameplay',
        region: 'foo',
      },
    })
  })
})
