import createModalSystem from '../createModalSystem'

import { pressEnter, pressEscape } from './keyboardEventHelpers'

const modals = [
  {
    closeByEx: true,
    closeByBgClick: true,
    Content: '',
    name: 'test',
  },
]

describe('accessible modal system', () => {
  let isOpen = false

  beforeEach(() => {
    isOpen = false
  })

  const modalSystem = createModalSystem({
    modals,
    onClose() {
      isOpen = false
    },
    onOpen() {
      isOpen = true
    },
    root: document.body,
  })

  it('opens programmatically', () => {
    modalSystem.open('test')
    expect(isOpen).toEqual(true)
  })

  it('closes by clicking X', () => {
    modalSystem.open('test')
    expect(isOpen).toEqual(true)
    document.querySelector('.pzm-modal-ex').click()
    expect(isOpen).toEqual(false)
  })

  it('closes by clicking on the background', () => {
    modalSystem.open('test')
    expect(isOpen).toEqual(true)
    document.querySelector('.pzm-modals-wrapper').click()
    expect(isOpen).toEqual(false)
  })

  it('closes by pressing the Escape key', () => {
    modalSystem.open('test')
    expect(isOpen).toEqual(true)
    document.body.dispatchEvent(pressEscape)
    expect(isOpen).toEqual(false)
  })

  it('closes by pressing the Enter key when the X is in focus', () => {
    const closeButton = document.querySelector('.pzm-modal-ex')
    modalSystem.open('test')
    expect(isOpen).toEqual(true)
    closeButton.focus()
    closeButton.dispatchEvent(pressEnter)
    expect(isOpen).toEqual(false)
  })
})
