import { areSetEqual, deepCloneSimple } from '../gameUtils'

describe('GAME UTILS', () => {
  it('determines if two arrays have the same elements', () => {
    const list1 = ['Harry', 'Hermione', 'Ron']
    const list2 = ['Ron', 'Harry', 'Hermione']
    const list3 = ['Harry', 'Hermione', 'Ron', 'Luna']
    expect(areSetEqual(list1, list2)).toBe(true)
    expect(areSetEqual(list1, list3)).toBe(false)
  })

  it('should deep clone an object', () => {
    const tile = {
      id: 0,
      zLayer: { id: 'Z1', hidden: false },
      aLayer: { id: 'A1', hidden: false },
      bLayer: { id: 'B2', hidden: false },
      cLayer: { id: 'C3', hidden: false },
      d: null,
      e: [{}],
    }

    const newTile = deepCloneSimple(tile)
    newTile.bLayer.hidden = true
    expect(tile.bLayer.hidden).toBe(false)
    expect(newTile.bLayer.hidden).toBe(true)
    expect(newTile.d).toBe(null)
    expect(newTile.e).toEqual([{}])
    expect(newTile.e === tile.e).toBe(false)
    expect(newTile.e[0] === tile.e[0]).toBe(false)

    // top level array
    const a = [1, 2, 3]
    const o = deepCloneSimple(a)
    expect(o).toEqual([1, 2, 3])
    expect(o === a).toBe(false)
  })
})
