import {
  handleUserInformationUpdate,
  isDeepLink,
  openDeepLink,
  stringifyQueryParams,
} from '../hybridLinkHelpers'

it('should turn object into query string', () => {
  const object = {
    redirect_uri: 'http%3A%2F%2Fwww.nytimes.com',
    keyTwo: 'valueTwo',
  }

  const queryString =
    'redirect_uri=http%3A%2F%2Fwww.nytimes.com&keyTwo=valueTwo'
  expect(stringifyQueryParams(object)).toBe(queryString)
})

describe('isDeepLink()', () => {
  it('should return false if provided nothing', () => {
    expect(isDeepLink()).toBe(false)
  })

  it('should return false if provided an empty string', () => {
    expect(isDeepLink('')).toBe(false)
  })

  it('should return false if we have a normal http link', () => {
    expect(isDeepLink('https://nytimes.com')).toBe(false)
  })

  it('should return true if we have a deep link for Newsreader', () => {
    expect(isDeepLink('nytimes://products')).toBe(true)
  })

  it('should return true if we have a deep link for the Games app', () => {
    expect(isDeepLink('nytxwd://login')).toBe(true)
  })
})

describe('openDeepLink()', () => {
  const deepLink = 'nytimes://products'
  const createElementMock = jest.fn()

  const mockDocument = {
    createElement: createElementMock,
  }

  it('should not call any functions if not provided a deep link', () => {
    openDeepLink('', mockDocument)
    expect(createElementMock).not.toHaveBeenCalled()
  })

  it('should call the relevant document functions', () => {
    const clickMock = jest.fn()
    createElementMock.mockImplementationOnce((href) => ({
      href,
      click: clickMock,
    }))

    openDeepLink(deepLink, mockDocument)
    expect(createElementMock).toHaveBeenCalled()
    expect(clickMock).toHaveBeenCalled()
  })
})

describe('handleUserInformationUpdate', () => {
  it('should call callback on successful authentication', () => {
    const data = {
      success: true,
      values: {
        gamesAuthenticateUser: {},
      },
    }
    const updateUserType = jest.fn()
    handleUserInformationUpdate(
      data.values.gamesAuthenticateUser,
      updateUserType,
    )
    expect(updateUserType).toHaveBeenCalled()
  })
})
