import handleLoginLinkClick from '../hybridLoginLinkClick'
import {
  isDeepLink,
  stringifyQueryParams,
  openDeepLink,
} from '../hybridLinkHelpers'

const mockResponse = jest.fn()
Object.defineProperty(window, 'location', {
  value: {
    hash: {
      endsWith: mockResponse,
      includes: mockResponse,
    },
    assign: mockResponse,
  },
  writable: true,
})

jest.mock('../subscribeLinks', () => ({
  handleSubscribe: jest.fn(),
}))

jest.mock('../hybridLinkHelpers', () => ({
  handleUserInformationUpdate: jest.fn(),
  openDeepLink: jest.fn(),
  isDeepLink: jest.fn((str) => {
    // mock deep link checking to call through
    if (str === 'nytimes://www.hi.com') {
      return true
    }
  }),
  stringifyQueryParams: jest.fn(() => 'redirect_uri=test'),
}))

jest.mock('foundation', () => ({
  env: { account: 'https://myaccount.nytimes.com' },
}))

describe('UTILS HYBRID LOGIN LINK', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it("should call gamesAuthenticateUser on 'login' link click for Native", () => {
    const gamesAuthenticateUser = jest.fn().mockImplementation(() =>
      Promise.resolve({
        success: true,
        values: {},
      }),
    )
    window.isHybridWebView = true
    window.NativeBridge = { gamesAuthenticateUser }

    const event = { preventDefault: jest.fn() }
    const userAuthCallback = jest.fn()

    handleLoginLinkClick(event, userAuthCallback)

    expect(gamesAuthenticateUser).toBeCalledWith('login')
  })

  it('should take user to correct login link in browser', () => {
    window.isHybridWebView = false
    window.navigationLinks = window.navigationLinks || {}
    window.navigationLinks.login = ''

    const event = { preventDefault: jest.fn() }
    const userAuthCallback = jest.fn()

    handleLoginLinkClick(event, userAuthCallback)

    // if login link on window isn't hybrid use the set login url with query param generated
    expect(window.location.assign).toBeCalledWith(
      'https://myaccount.nytimes.com/auth/enter-email?redirect_uri=test',
    )
  })

  it('should launch deep link if set on window', () => {
    window.isHybridWebView = false
    window.navigationLinks = window.navigationLinks || {}
    window.navigationLinks.login = 'nytimes://www.hi.com'

    const event = { preventDefault: jest.fn() }
    const userAuthCallback = jest.fn()

    handleLoginLinkClick(event, userAuthCallback)

    expect(isDeepLink).toBeCalledWith('nytimes://www.hi.com')
    expect(openDeepLink).toBeCalledWith('nytimes://www.hi.com')
  })
})
