import { getLoginLink } from '../loginLinks'
import { appendSupportedParams } from '../../../shared/foundation'

jest.mock('foundation', () => ({
  appendSupportedParams: jest.fn(),
  env: { account: 'https://myaccount.nytimes.com' },
}))

describe('HELPERS: LOGIN LINKS', () => {
  describe('getLoginLink()', () => {
    const mockWindowDeepLink = {
      navigationLinks: {
        login: 'nytimes://www.hi.com',
      },
    }

    it('should return deep link if provided deep link scheme on window', () => {
      const deepLink = 'nytimes://www.hi.com'
      expect(getLoginLink(mockWindowDeepLink)).toBe(deepLink)
    })

    it('should return deep link without additional params if provided deep link ', () => {
      const deepLink = 'nytimes://www.hi.com'
      expect(getLoginLink(mockWindowDeepLink, '&asset=test')).toBe(
        deepLink,
      )
    })

    it('should return additional params if provided and not deep link', () => {
      const testAssetParam = '&asset=test'
      appendSupportedParams.mockReturnValue(testAssetParam)
      expect(getLoginLink(undefined, testAssetParam)).toContain(
        '&asset=test',
      )
    })
    it('should return deep link if provided deep link scheme on window', () => {
      expect(getLoginLink()).toContain('https://myaccount')
      expect(getLoginLink()).toContain('enter-email')
      // note: loginLink creates url for redirect based on environment `window.location.pathname` in browser,
      // this is just a simple check to make sure it's set
      expect(getLoginLink()).toContain('redirect_uri')
    })
  })
})
