import { ModalSystem, ModalConfirmOptions } from './createModalSystem'

const addClass = (elm: HTMLElement, className: string) => {
  elm.classList.add(className)
  return elm
}

const createConfirmationModal = (modals: ModalSystem) => {
  let confirmMessage: HTMLElement
  let cancelButton: HTMLElement
  let confirmButton: HTMLElement
  let onCancel: () => void
  let onConfirm: () => void

  modals.add({
    name: 'confirm',
    create({ root }) {
      confirmMessage = addClass(
        document.createElement('div'),
        'pzm-modal__content',
      )
      cancelButton = addClass(
        document.createElement('button'),
        'pzm-modal__button',
      )
      confirmButton = addClass(
        document.createElement('button'),
        'pzm-modal__button',
      )

      const buttons = addClass(
        document.createElement('div'),
        'pzm-modal__buttons',
      )

      addClass(confirmButton, 'primary')

      cancelButton.addEventListener('click', () => {
        modals.close()
        if (onCancel) onCancel()
      })

      confirmButton.addEventListener('click', (e) => {
        modals.close()
        e.stopPropagation() // To prevent congrats modal from closing immediately after opening upon reveal
        if (onConfirm) onConfirm()
      })

      confirmMessage.innerHTML = 'Are you sure?'
      cancelButton.innerHTML = 'Never mind'
      confirmButton.innerHTML = 'OK'

      buttons.appendChild(cancelButton)
      buttons.appendChild(confirmButton)

      root.appendChild(confirmMessage)
      root.appendChild(buttons)
    },
  })

  const confirm = (
    options: ModalConfirmOptions,
    cbConfirm: () => void,
    cbCancel: () => void,
  ) => {
    const opts =
      typeof options === 'string' ? { message: options } : options

    if (opts.message) {
      confirmMessage.innerHTML = opts.message
    }

    if (opts.cancelText) {
      cancelButton.innerHTML = opts.cancelText
    }

    if (opts.confirmText) {
      confirmButton.innerHTML = opts.confirmText
    }

    onConfirm = cbConfirm
    onCancel = cbCancel

    modals.open('confirm')
  }

  modals.confirm = confirm
  return confirm
}

export default createConfirmationModal
