import { UserType } from 'foundation'

const yes = 'Yes'
const no = 'No'
const none = '[NONE]'
const na = '[N/A]'

const getHybridDebugInfoHelper = (
  user: Partial<UserType> = {},
  rootElm: HTMLElement = document.documentElement,
): string[] => {
  const abraTestsString = Object.entries(window.abra.tests)
    .map((t) => t.join('='))
    .join(',')
  const regi = user.regiId || none
  const webVersion = window.env.version || na

  return [
    `Hybrid summary:`,
    `Platform: ${
      window.newsreaderAppPlatform ? 'News App' : 'XW App'
    }`,
    `Viewport Size: ${rootElm.clientWidth} x ${rootElm.clientHeight}`,
    `Logged In: ${user.isLoggedIn ? yes : no}`,
    `Xwd: ${user.hasXwd ? yes : no}`,
    `Regi: ${regi}`,
    `Web Version: ${webVersion}`,
    `Flags: ${abraTestsString}`,
  ]
}

export const getHybridDebugInfo = (
  user: Partial<UserType> = {},
): string => {
  return getHybridDebugInfoHelper(user).join('\n')
}

export const getEnhancedHybridDebugInfo = (
  user: Partial<UserType> = {},
) => {
  const tz = new Date().getTimezoneOffset()
  const build = window.sentryConfig?.release || na
  const additionalInfo = [
    `Timezone: ${`UTC${tz > 0 ? '' : '+'}${tz / -60}`}`,
    `Build: ${build}`,
  ]

  return getHybridDebugInfoHelper(user)
    .concat(additionalInfo)
    .join('\n')
}
