import { UserType } from '../../shared/foundation/window'

export const stringifyQueryParams = (obj: {}) =>
  Object.entries(obj).reduce((queryString, [k, v], idx) => {
    const amp = Object.keys(obj).length - 1 === idx ? '' : '&'
    return `${queryString}${k}=${v}${amp}`
  }, '')

/**
 * Determine if a URL is a deep link or not
 * @param url A url
 * @returns True if the URL starts w/ nytimes:// or nytxwd://
 */
export const isDeepLink = (url = '') =>
  url.indexOf('nytimes://') === 0 || url.indexOf('nytxwd://') === 0

/**
 * A deep link looks something like nytimes://products. If we try to load
 * that URL via JavaScript a la window.location.href etc, a NYT web view
 * won't know how to handle it and route to the correct native view. To work
 * around this, we have this hacky hack, where we create an a tag and then
 * "click" on it.
 *
 * It works.
 *
 * @param url A deep link URL
 */
export const openDeepLink = (url = '', d = document) => {
  if (!url) {
    return null
  }

  const a = d.createElement('a')
  a.href = url
  a.click()
}

/**
 * Callback to pass along updated userData
 * @param userData
 * @param updateUserType
 */
export const handleUserInformationUpdate = (
  userData: {
    isUserLoggedIn: boolean
    isSubscribed: boolean
    regiID: string
    isFreeTrial?: boolean
  },
  updateUserType: (userData: Partial<UserType>) => void,
) => {
  updateUserType({
    isLoggedIn: userData.isUserLoggedIn,
    hasXwd: userData.isSubscribed,
    regiId: userData.regiID,
    isFreeTrial: userData.isFreeTrial,
  })
}
