import React from 'react'

import { UserType } from '../../shared/foundation/window'

import { getLoginLink } from './loginLinks'
import {
  isDeepLink,
  openDeepLink,
  handleUserInformationUpdate,
} from './hybridLinkHelpers'

export const handleNativeLogin = (
  updateUserTypeCallback: (val: Partial<UserType>) => void,
) => {
  if (window.isHybridWebView && window.NativeBridge) {
    window.NativeBridge.gamesAuthenticateUser('login')
      .then((data: any) => {
        if (!data.success) throw new Error(data.error)

        // TODO: remove dispatch in client side entitlements milestone 3
        window.dispatchEvent(
          new CustomEvent('gamesUserCredentialChanged', {
            detail: data,
          }),
        )
        handleUserInformationUpdate(
          data.values.gamesAuthenticateUser,
          updateUserTypeCallback,
        )
      })
      .catch((e) => {
        console.error('Failed to log in user', e)
      })
  }
}

const handleHybridLoginClick = (
  e:
    | React.MouseEvent<HTMLButtonElement>
    | React.MouseEvent<HTMLAnchorElement>
    | React.MouseEvent<Element, MouseEvent>
    | MouseEvent,
  updateUserTypeCallback: (val: Partial<UserType>) => void,
  additionalParams: string = '',
) => {
  if (window.isHybridWebView && window.NativeBridge) {
    e.preventDefault()
    // Requests the native bridge to login
    handleNativeLogin(updateUserTypeCallback)
  } else {
    const loginLink = getLoginLink(
      window || undefined,
      additionalParams,
    )
    const shouldUseDeeplink = isDeepLink(loginLink)

    if (shouldUseDeeplink) {
      // if deep link navigate to the appropriate deep link to the correct native view
      openDeepLink(loginLink)
    } else {
      // otherwise force the window to load and display login
      window.location.assign(loginLink)
    }
  }
}

export default handleHybridLoginClick
