/**
 * XWD-14390: Standardize congrats moment text
 */
export const CONGRATS_NAVIGATE_BACK_TEXT = 'View all games'

/**
 * A cross-platform function that navigates the user back to the Hub.
 * Compatible with web, hybrid, and play tab envionrments
 */
export const navigateBack = (variant?: string | null) => {
  const playTabNavTest =
    window.newsreaderAppPlatform === 'ios' &&
    variant === '1_BackToPlayTab'

  if (window.isHybridWebView && window.NativeBridge) {
    window.NativeBridge.gamesBackToHub()
  } else if (window.isPlayTab || playTabNavTest) {
    /**
     * Due to a quirk in how the Newsreader handles redirects, window.location.assign
     * does not work. You must create a detached anchor element and click()
     */
    const anchor = document.createElement('a')
    anchor.href = 'nytimes://play'
    anchor.click()
  } else {
    // note: /puzzles won't redirect properly within Newsreader
    // host name is optional, so we omit to allow flexiblity across envs
    window.location.href = '/crosswords'
  }

  return null
}
