const onExit = (fn: () => void) => {
  /**
   * Ensure the state is saved when the page refreshes
   * - https://philipwalton.com/articles/page-lifecycle-api/
   * - https://github.com/GoogleChromeLabs/page-lifecycle/issues/2
   */
  const isSafari = !!(
    typeof window.safari === 'object' && window.safari.pushNotification
  )

  window.addEventListener('visibilitychange', fn, true)

  if (isSafari) {
    window.addEventListener('beforeunload', fn, true)
  }

  return function unsubscribe() {
    window.removeEventListener('visibilitychange', fn, true)

    if (isSafari) {
      window.removeEventListener('beforeunload', fn, true)
    }
  }
}

export default onExit
