/**
 * Helper for handling touch/click buttons without ghost clicks
 */
// TODO: document this better and make sure it is a good api
// @from https://github.com/rafrex/detect-passive-events/blob/master/src/index.js

const win = window
const touchstart = 'touchstart'
const touchend = 'touchend'
// const touchmove = 'touchmove'
const mousedown = 'mousedown'
const mouseup = 'mouseup'
const mouseout = 'mouseout'
// const preventDefault = 'preventDefault'
const addEventListener = 'addEventListener'
const removeEventListener = 'removeEventListener'
const activeClass = 'push-active'

let supportsPassiveEvents = false
if (typeof win.addEventListener === 'function') {
  let passive = false
  const options = Object.defineProperty({}, 'passive', {
    get() {
      passive = true
      return passive
    },
  })

  const noop = () => {}
  win.addEventListener('testPassiveEventSupport', noop, options)
  win.removeEventListener('testPassiveEventSupport', noop, options)
  supportsPassiveEvents = passive
}

const passiveOptions: AddEventListenerOptions = { passive: true }

const onPush = (
  elm: Element,
  onDown: (e: Event) => void,
  onUp?: (e: Event) => void,
  supportBurst?: boolean,
) => {
  // ie11 does not have a classList api on svg tags :(
  const hasClassList = !!elm.classList

  let isBursting: ReturnType<typeof setInterval> | void
  let isBurstPending: ReturnType<typeof setTimeout> | void

  const wrappedDown = (e: Event) => {
    // for browsers that support passive events
    // we should only call preventDefault on touchend (https://mzl.la/2JoIcdg)
    if (!supportsPassiveEvents) e.preventDefault()

    if (hasClassList) elm.classList.add(activeClass)

    if (
      supportBurst &&
      !isBurstPending // prevent subsequent fingers from hiding original timer
    ) {
      isBurstPending = setTimeout(() => {
        isBursting = setInterval(() => {
          onDown(e)
        }, 90)
      }, 350)
    }
    onDown(e)
  }

  const wrappedUp = (e: Event) => {
    if (e.cancelable) e.preventDefault()

    if (hasClassList) elm.classList.remove(activeClass)

    if (isBursting) isBursting = clearInterval(isBursting)

    if (isBurstPending) {
      isBurstPending = clearTimeout(isBurstPending)
    }

    if (onUp) onUp(e)
  }

  elm[addEventListener](touchstart, wrappedDown, passiveOptions)
  elm[addEventListener](mousedown, wrappedDown)
  elm[addEventListener](touchend, wrappedUp)
  elm[addEventListener](mouseup, wrappedUp)
  elm[addEventListener](mouseout, wrappedUp)

  return function unbind() {
    if (isBursting) isBursting = clearInterval(isBursting)

    if (isBurstPending) {
      isBurstPending = clearTimeout(isBurstPending)
    }
    elm[removeEventListener](touchstart, wrappedDown, passiveOptions)
    elm[removeEventListener](mousedown, wrappedDown)
    elm[removeEventListener](touchend, wrappedUp)
    elm[removeEventListener](mouseup, wrappedUp)
    elm[removeEventListener](mouseout, wrappedUp)
  }
}

export default onPush
