/* eslint-disable no-param-reassign */
export const smoothScroll: {
  timer: ReturnType<typeof setTimeout> | undefined
  stop: () => void
  scrollTo: (id: string, e: Event) => void
} = {
  timer: undefined,

  stop() {
    if (this.timer) clearTimeout(this.timer)
  },

  scrollTo(id: string, e: Event) {
    e.preventDefault()
    const settings = {
      duration: window.innerHeight < 500 ? 1000 : 1500,
      easing: {
        // easing equations: http://gizma.com/easing/
        easeInOutCirc(t: number, b: number, c: number, d: number) {
          t /= d / 2
          if (t < 1) return (-c / 2) * (Math.sqrt(1 - t * t) - 1) + b
          t -= 2
          return (c / 2) * (Math.sqrt(1 - t * t) + 1) + b
        },
      },
    }
    let percentage
    const node = document.getElementById(id)
    if (!node) return // bail if element doesn't exist

    const nodeTop = node.offsetTop
    const nodeHeight = node.offsetHeight
    const { body } = document
    const html = document.documentElement
    const height = Math.max(
      body.scrollHeight,
      body.offsetHeight,
      html.clientHeight,
      html.scrollHeight,
      html.offsetHeight,
    )
    const windowHeight = window.innerHeight
    const offset = window.pageYOffset
    const delta = nodeTop - offset
    const bottomScrollableY = height - windowHeight
    const targetY =
      bottomScrollableY < delta
        ? bottomScrollableY - (height - nodeTop - nodeHeight + offset)
        : delta

    const startTime = Date.now()
    percentage = 0

    if (this.timer) {
      clearInterval(this.timer)
    }

    const step = () => {
      let yScroll
      const elapsed = Date.now() - startTime

      if (elapsed > settings.duration && this.timer) {
        clearTimeout(this.timer)
      }

      percentage = elapsed / settings.duration

      if (percentage > 1 && this.timer) {
        clearTimeout(this.timer)
        document.getElementById(id)?.focus()
        const loc = window.location.href
        window.history.replaceState(
          {},
          '',
          `${loc.substring(0, loc.indexOf('#'))}#submit-your-puzzle`,
        )
      } else {
        yScroll = settings.easing.easeInOutCirc(
          elapsed,
          offset,
          targetY,
          settings.duration,
        )
        window.scrollTo(0, yScroll)
        this.timer = setTimeout(step, 10)
      }
    }

    this.timer = setTimeout(step, 10)
  },
}
