import '../../shared/shared-styles'
import '../../shared/shared-scripts'

import React from 'react'
import ReactDOM from 'react-dom'
import { Provider } from 'react-redux'

import { getGameData } from 'foundation'
import { UserProvider } from 'user'
import AbraProviderWithUser from 'shared/abra/AbraProviderWithUser'
import { FeatureFlagProvider } from 'shared/abra/FeatureFlagProvider'

import ShortzMode from '../shared/ShortzMode'
import ClientSideScripts from '../../shared/components/ClientSideScripts'
import { setUpStore } from '../letter-boxed/js/store'
import PuzzleContainer from '../letter-boxed/js/containers/PuzzleContainer/index'
import { MeterProvider } from '../letter-boxed/js/meter/meterProvider'

import './index.scss'

const gameRoot = document.getElementById('pz-game-root')

const store = setUpStore(getGameData())

const gameBase = () => (
  <AbraProviderWithUser>
    <FeatureFlagProvider>
      <MeterProvider>
        <Provider store={store}>
          <PuzzleContainer />
        </Provider>
      </MeterProvider>
    </FeatureFlagProvider>
  </AbraProviderWithUser>
)

ReactDOM.render(
  <>
    <ClientSideScripts />
    <UserProvider>
      <ShortzMode>{gameBase()}</ShortzMode>
    </UserProvider>
  </>,
  gameRoot,
)
