import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import { isMobile } from 'responsive'

import { getResponsiveConfig } from './sharedUtils'
import { textfieldConfig } from './constants'

const scrollCursor = () => {
  const element = document.getElementsByClassName('lb-text-field')[0]

  element.scrollLeft += 9999
}

class TextField extends React.Component {
  constructor(props) {
    super(props)

    this.fontBreak = 15
    this.fontBreakMaxLength = 21
    this.scrollableBreak = 20

    this.fontSize = getResponsiveConfig(
      window.innerWidth,
      window.innerHeight,
      textfieldConfig,
    ).fontSize
  }

  componentDidMount() {
    const { action } = this.props

    scrollCursor()

    window.addEventListener(
      'keydown',
      (...event) => {
        action(...event)
        scrollCursor()
      },
      false,
    )
  }

  componentWillUnmount() {
    const { action } = this.props

    window.removeEventListener('keydown', action)
  }

  getFontSize = (length) => {
    const { fontBreak, fontSize, fontBreakMaxLength } = this

    if (length < fontBreak) {
      return fontSize
    }

    const factor = isMobile ? 0.5 : 1

    return (
      fontSize -
      (Math.min(length, fontBreakMaxLength) - fontBreak) * factor
    )
  }

  getLineHeightSize = (length) => {
    const { fontBreak, fontBreakMaxLength } = this

    const base = isMobile ? 34 : 38

    return (
      base +
      Math.max(
        (Math.min(length, fontBreakMaxLength) - fontBreak) / 4,
        0,
      )
    )
  }

  render() {
    const { value, children, submittedWords, par } = this.props

    return (
      <div className="lb-text-field-wrapper">
        <div className="lb-text-field-container">
          <div
            className={cn('lb-text-field', {
              'not-empty': !!value.length,
              scrollable: value.length > this.scrollableBreak,
            })}
            style={{
              fontSize: `${this.getFontSize(value.length)}px`,
              lineHeight: `${this.getLineHeightSize(value.length)}px`,
            }}
          >
            {value.split('').map((letter, idx) => (
              <span key={`${letter}-${idx}`}>{letter}</span>
            ))}
            <span className="lb-text-field__caret"> </span>
          </div>
        </div>
        <hr className="lb-text-field-underline" />
        {children}
        {submittedWords.length === 0 && (
          <div className="lb-par no-words">
            Try to solve in {par} {par > 1 ? 'words' : 'word'}
          </div>
        )}
      </div>
    )
  }
}

TextField.defaultProps = {
  children: undefined,
}

TextField.propTypes = {
  value: pt.string.isRequired,
  action: pt.func.isRequired,
  children: pt.node,
  submittedWords: pt.arrayOf(pt.string).isRequired,
  par: pt.number.isRequired,
}

export default TextField
