/* eslint-disable jsx-a11y/control-has-associated-label */
/* eslint-disable jsx-a11y/interactive-supports-focus */
/* eslint-disable jsx-a11y/click-events-have-key-events */
import React from 'react'
import ReactDOM from 'react-dom'
import pt from 'prop-types'
import cn from 'classnames'

import { isMobile } from 'responsive'
import { useUser } from 'user'

import track from './letterBoxedTracker'
import { toolBarShouldBeInteractive } from './util'
import HelpSelectMenu from './HelpSelectMenu'

const barRoot = document.getElementById(
  `${isMobile ? 'js-mobile' : 'portal-game'}-toolbar`,
)

const toolbarClasses = cn({
  'pz-flex-row': true,
  'pz-game-toolbar-content': true,
  'lb-toolbar': true,
})

const Toolbar = ({ actions, animating, printDate, meterResponse }) => {
  const { userType } = useUser()
  return ReactDOM.createPortal(
    <>
      <div className={toolbarClasses}>
        <div className="lb-toolbar__left" />
        <div className="lb-toolbar__right">
          <button
            type="button"
            aria-label="how to play"
            data-testid="how-to-play"
            className="pz-toolbar-button lb-app__howto"
            onClick={() => {
              if (
                !toolBarShouldBeInteractive(
                  printDate,
                  userType.hasXwd || meterResponse.granted,
                )
              ) {
                return
              }
              track.interaction.settings('how-to-play')
              actions.openModal('howToPlay')
            }}
          >
            <i className="lb-app__help-icon" />
          </button>
          <HelpSelectMenu animating={animating} actions={actions} />
        </div>
      </div>
    </>,
    barRoot,
  )
}

Toolbar.propTypes = {
  printDate: pt.string.isRequired,
  actions: pt.shape({
    openModal: pt.func.isRequired,
  }),
}

export default Toolbar
