import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'

import DropDown from '../../../shared/DropDown/DropDown'
import DropDownItem from '../../../shared/DropDown/DropDownItem'
import track from '../letterBoxedTracker'
import HelpSelectMenu from '../HelpSelectMenu'

jest.mock('foundation', () => ({
  getGameData: () => {
    return { id: 0 }
  },
}))

jest.mock('../util', () => ({
  toolBarShouldBeInteractive: jest.fn(),
}))

jest.mock('../letterBoxedTracker.js', () => ({
  interaction: {
    gameplay: jest.fn(),
    settings: jest.fn(),
  },
}))

let wrapper
let defaultProps
const makeStore = () => ({
  getState: () => ({}),
  subscribe: jest.fn(),
  dispatch: jest.fn(),
})

const store = makeStore()

beforeEach(async () => {
  defaultProps = {
    animating: false,
    actions: {
      openModal: jest.fn(),
    },
  }

  wrapper = await mount(
    <Provider store={store}>
      <HelpSelectMenu {...defaultProps} />
    </Provider>,
  )
})

afterEach(() => {
  jest.clearAllMocks()
})

it('renders help menu', () => {
  expect(wrapper.exists()).toBe(true)
})

it('help button exists', () => {
  const dropdown = wrapper.find(DropDown)

  expect(dropdown.props().ariaLabel).toBe('help')
})

it('dropdown item does not exist by default', () => {
  const dropdownitem = wrapper.find(DropDownItem)

  expect(dropdownitem.exists()).toBe(false)
})

it('dropdown item exists after clicking dropdown button', () => {
  const dropdown = wrapper.find(DropDown)
  dropdown.find('.pz-dropdown__button').simulate('click')
  const dropdownitem = wrapper.find(DropDownItem)

  expect(dropdownitem.exists()).toBe(true)
})

it('should fire the "yesterday-solution" analytics event when answers button is clicked', () => {
  const dropdown = wrapper.find(DropDown)
  dropdown.find('.pz-dropdown__button').simulate('click')
  const dropdownitem = wrapper.find(DropDownItem)

  dropdownitem.first().find('button').simulate('click')

  expect(track.interaction.settings).toHaveBeenCalledWith(
    'yesterday-solution',
  )
})
