import React from 'react'
import { shallow } from 'enzyme'

import Toolbar from '../Toolbar'
import track from '../letterBoxedTracker'
import { toolBarShouldBeInteractive } from '../util'
import HelpSelectMenu from '../HelpSelectMenu'

jest.mock('responsive', () => ({
  isMobile: false,
}))

jest.mock('react-dom', () => ({
  createPortal: (jsx) => jsx,
}))

jest.mock('../util', () => ({
  toolBarShouldBeInteractive: jest.fn(),
}))

jest.mock('foundation', () => ({}))

jest.mock('user', () => ({
  useUser: () => ({
    userType: {
      hasXwd: true,
      isLoggedIn: true,
    },
  }),
}))

jest.mock('../letterBoxedTracker.js', () => ({
  interaction: {
    gameplay: jest.fn(),
    settings: jest.fn(),
  },
}))

function wrapToolbar() {
  return shallow(
    <Toolbar
      actions={{ openModal: jest.fn() }}
      printDate="2021-06-23"
      animating={false}
    />,
  )
}

describe('LETTER BOXED: TOOLBAR', () => {
  afterEach(() => {
    jest.resetAllMocks()
  })

  describe('help button and dropdown exist', () => {
    it('should show help button', () => {
      const wrapper = wrapToolbar()
      expect(
        wrapper.find('.pz-toolbar-button.lb-app__howto').exists(),
      ).toBe(true)
    })

    it('should show dropdown button', () => {
      const wrapper = wrapToolbar()
      expect(wrapper.find(HelpSelectMenu).exists()).toBe(true)
    })
  })

  describe('when toolbar is active', () => {
    beforeEach(() => {
      toolBarShouldBeInteractive.mockReturnValue(true)
    })

    it('should fire the "how-to-play" analytics event when help button is clicked', () => {
      const wrapper = wrapToolbar()
      wrapper
        .find('.pz-toolbar-button.lb-app__howto')
        .simulate('click')
      expect(track.interaction.settings).toHaveBeenCalledWith(
        'how-to-play',
      )
    })
  })

  describe('when toolbar is inactive', () => {
    beforeEach(() => {
      toolBarShouldBeInteractive.mockReturnValue(false)
    })

    it('should not fire the "how-to-play" analytics event when help button is clicked', () => {
      const wrapper = wrapToolbar()
      wrapper
        .find('.pz-toolbar-button.lb-app__howto')
        .simulate('click')
      expect(track.interaction.settings).not.toHaveBeenCalled()
    })
  })
})
