import responsive from 'responsive'

import { getResponsiveConfig } from '../sharedUtils'
import { textfieldConfig, canvasConfig } from '../constants'

jest.mock('responsive', () => ({
  isMobile: false,
}))

const testWidths = [800, 445, 332, 1]

let testHeight = 1000

describe('SHARED UTILS: Desktop', () => {
  testWidths.forEach((testWidth, i) => {
    it(`should return the ${testWidth} desktop textfield config`, () => {
      const expected = textfieldConfig[i].desktop

      expect(
        getResponsiveConfig(testWidth, testHeight, textfieldConfig),
      ).toBe(expected)
      expect(expected).toBeDefined()
    })
  })
  testWidths.forEach((testWidth, i) => {
    it(`should return the ${testWidth} desktop canvas config`, () => {
      const expected = canvasConfig[i].desktop

      expect(
        getResponsiveConfig(testWidth, testHeight, canvasConfig),
      ).toBe(expected)
      expect(expected).toBeDefined()
    })
  })
})

describe('SHARED UTILS: Mobile', () => {
  beforeAll(() => {
    responsive.isMobile = true
  })

  testWidths.forEach((testWidth, i) => {
    it(`should return the ${testWidth} mobile textfield config`, () => {
      const expected = textfieldConfig[i].mobile

      expect(
        getResponsiveConfig(testWidth, testHeight, textfieldConfig),
      ).toBe(expected)
      expect(expected).toBeDefined()
    })
  })
  testWidths.forEach((testWidth, i) => {
    it(`should return the ${testWidth} desktop canvas config in landscape`, () => {
      const desktopConfig = canvasConfig[i].desktop

      testHeight = 0

      expect(
        getResponsiveConfig(testWidth, testHeight, canvasConfig),
      ).toBe(desktopConfig)
    })
  })

  it('should return the mobile canvas config', () => {
    const mobileConfig = canvasConfig[0].desktop

    expect(
      getResponsiveConfig(testWidths[0], testHeight, canvasConfig),
    ).toBe(mobileConfig)
  })
})
