import {
  nonSubCompletedGame,
  toolBarShouldBeInteractive,
  disableActionButtons,
} from '../util'
import { didCompleteGame } from '../handleCompletion'

jest.mock('../handleCompletion')

jest.mock('foundation', () => ({
  userType: {
    hasXwd: false,
  },
}))

describe('LETTER BOXED: UTILS', () => {
  describe('toolBarShouldBeInteractive()', () => {
    beforeAll(() => {
      didCompleteGame.mockReturnValue(false)
    })

    it('when user is a sub, returns true', () => {
      const hasXwd = true
      expect(toolBarShouldBeInteractive('foobar', hasXwd)).toBe(true)
    })

    it('when user is not a sub and user did not complete game yet, returns true', () => {
      const hasXwd = false
      expect(toolBarShouldBeInteractive('foobar', hasXwd)).toBe(true)
    })

    it('when user is not a sub and user did complete game, returns false', () => {
      didCompleteGame.mockReturnValue(true)
      const hasXwd = false
      expect(
        toolBarShouldBeInteractive('didCompleteThisDate', hasXwd),
      ).toBe(false)
    })
  })

  describe('nonSubCompletedGame()', () => {
    beforeAll(() => {
      didCompleteGame.mockReturnValue(false)
    })

    it('when user is a sub, returns false', () => {
      const hasXwd = true
      expect(nonSubCompletedGame('foobar', hasXwd)).toBe(false)
    })

    it('when user is not a sub and user did not complete game yet, returns false', () => {
      const hasXwd = false
      expect(nonSubCompletedGame('foobar', hasXwd)).toBe(false)
    })

    it('when user is not a sub and user did complete game, returns true', () => {
      didCompleteGame.mockReturnValue(true)
      const hasXwd = false
      expect(nonSubCompletedGame('foobar', hasXwd)).toBe(true)
    })
  })

  describe('disableActionButtons()', () => {
    const puzzleProps = {
      isCompleted: false,
      preventMoves: false,
      activeWord: 'a',
    }
    describe('as a sub', () => {
      const hasXwd = true
      it('when active word has no letters, returns true', () => {
        expect(
          disableActionButtons(
            { ...puzzleProps, activeWord: '' },
            hasXwd,
          ),
        ).toBe(true)
      })
      it('when active word present, returns false', () => {
        expect(disableActionButtons({ ...puzzleProps }, hasXwd)).toBe(
          false,
        )
      })
      it('when active word has no letters, and is completed, returns false', () => {
        expect(
          disableActionButtons(
            { ...puzzleProps, isCompleted: true },
            hasXwd,
          ),
        ).toBe(false)
      })
      it('when active word has no letters, and prevent moves is on, returns false', () => {
        expect(
          disableActionButtons(
            { ...puzzleProps, preventMoves: true },
            hasXwd,
          ),
        ).toBe(false)
      })
    })
    describe('as a non-sub', () => {
      const hasXwd = false
      it('when active word present, did not complete game, and prevent moves off, returns false', () => {
        expect(disableActionButtons({ ...puzzleProps }, hasXwd)).toBe(
          false,
        )
      })
      it('when active word has no letters, returns true', () => {
        expect(
          disableActionButtons(
            { ...puzzleProps, activeWord: '' },
            hasXwd,
          ),
        ).toBe(true)
      })
      it('when active word has no letters, and is completed, returns true', () => {
        expect(
          disableActionButtons(
            { ...puzzleProps, isCompleted: true },
            hasXwd,
          ),
        ).toBe(true)
      })
      it('when active word has no letters, and prevent moves is on, returns true', () => {
        expect(
          disableActionButtons(
            { ...puzzleProps, preventMoves: true },
            hasXwd,
          ),
        ).toBe(true)
      })
    })
  })
})
