import {
  validateWord,
  isPuzzleLocked,
  isPuzzleComplete,
  getUniqueValues,
  validateWordLength,
  getSuccessMessage,
} from '../utils'

describe('LETTER BOXED: PUZZLE CONTAINER UTILS', () => {
  it('should validate a word against the dictionary', () => {
    const state = {
      activeWord: 'RED',
      dictionary: ['RED'],
    }
    expect(validateWord(state)).toBe(true)
  })

  it('should determine whether the puzzle is locked', () => {
    const state = {
      isLocked: false,
      animating: false,
      preventMoves: false,
    }
    expect(isPuzzleLocked(state)).toBe(false)
    const state2 = {
      isLocked: true,
      animating: false,
      preventMoves: false,
    }
    expect(isPuzzleLocked(state2)).toBe(true)
    const state3 = {
      isLocked: false,
      animating: true,
      preventMoves: false,
    }
    expect(isPuzzleLocked(state3)).toBe(true)
    const state4 = {
      isLocked: false,
      animating: false,
      preventMoves: true,
    }
    expect(isPuzzleLocked(state4)).toBe(true)
  })

  it('should determine whether the puzzle is complete', () => {
    const state = {
      sides: ['ADR', 'MEO', 'BXU', 'ITS'],
      submittedWords: ['AMBIDEXTROUS'],
    }
    expect(isPuzzleComplete(state)).toBe(true)
    const state2 = {
      sides: ['ADR', 'MEO', 'BXU', 'ITS'],
      submittedWords: ['AMBIDEXTROU'],
    }
    expect(isPuzzleComplete(state2)).toBe(false)
    const state3 = {
      sides: ['ADR', 'MEO', 'BXU', 'ITS'],
      submittedWords: ['AMBIT', 'ADEXT', 'ROUS'],
    }
    expect(isPuzzleComplete(state3)).toBe(true)
    const state4 = {
      sides: ['ADR', 'MEO', 'BXU', 'ITS'],
      submittedWords: ['AMBIT', 'ADEXT', 'ROU'],
    }
    expect(isPuzzleComplete(state4)).toBe(false)
  })

  it('should return an array of unique values', () => {
    const expected = ['A', 'B', 'C']
    const actual = ['A', 'B', 'C', 'A']
    expect(getUniqueValues(actual)).toEqual(expected)
    const expected2 = ['A', 'B', 'C']
    const actual2 = ['A', 'B', 'C']
    expect(getUniqueValues(actual2)).toEqual(expected2)
  })

  it('should return the proper bool for word length', () => {
    expect(validateWordLength('ev')).toEqual(false)
    expect(validateWordLength('eva')).toEqual(true)
  })

  it('should return the respective encouragement words', () => {
    const awesomeWordConfig = {
      previousSuccess: false,
      submittedWords: ['AMBI'],
      activeWord: 'I',
    }
    expect(getSuccessMessage(awesomeWordConfig)).toEqual('Awesome!')
    const niceWordConfig = {
      previousSuccess: true,
      submittedWords: ['AMBI'],
      activeWord: 'I',
    }
    expect(getSuccessMessage(niceWordConfig)).toEqual('Nice!')
    const geniusWordConfig = {
      previousSuccess: true,
      submittedWords: ['AMBIDEXTROUS'],
      activeWord: 'S',
    }
    expect(getSuccessMessage(geniusWordConfig)).toEqual('Genius!')
    const oneWordSolutionConfig = {
      previousSuccess: true,
      submittedWords: ['AMBIDEXTROUS'],
      isCompleted: true,
      activeWord: 'S',
    }
    expect(getSuccessMessage(oneWordSolutionConfig)).toEqual(
      'Savant!',
    )
  })
})
