import React from 'react'
import pt from 'prop-types'
import { connect } from 'react-redux'

import Layout from '../../Layout'
import * as actions from '../../store/puzzleContainer/actions'
import {
  selectLetterData,
  selectPuzzleData,
} from '../../store/puzzleContainer/selectors'

class PuzzleContainer extends React.PureComponent {
  render() {
    const { puzzle } = this.props
    return <Layout actions={this.props} puzzle={{ ...puzzle }} />
  }
}

PuzzleContainer.defaultProps = {
  puzzle: {},
  abra: {},
}

PuzzleContainer.propTypes = {
  puzzle: pt.shape({
    id: pt.number.isRequired,
    printDate: pt.string.isRequired,
    sides: pt.arrayOf(pt.string).isRequired,
    dictionary: pt.arrayOf(pt.string).isRequired,
    activeWord: pt.string.isRequired,
    activeLetter: pt.string.isRequired,
    submittedWords: pt.arrayOf(pt.string).isRequired,
    ourSolution: pt.arrayOf(pt.string).isRequired,
    yesterdaysSolution: pt.arrayOf(pt.string).isRequired,
    par: pt.number.isRequired,
    letters: pt.arrayOf(
      pt.shape({
        isActiveLetter: pt.bool,
        isInActiveWord: pt.bool,
        isUsed: pt.bool,
      }),
    ),
  }),
  abra: pt.shape({
    getVariant: pt.func,
    tests: pt.shape({}),
  }),
}

const mapDispatchToProps = {
  ...actions,
}

const mapStateToProps = (state) => {
  return {
    puzzle: {
      ...selectPuzzleData(state),
      letters: selectLetterData(state),
    },
  }
}

export default connect(
  mapStateToProps,
  mapDispatchToProps,
)(PuzzleContainer)
