import {
  selectLetterData,
  selectPuzzleData,
} from '../../store/puzzleContainer/selectors'

export const isValidLetter = (letter) =>
  /[A-Z]{1}/.test(letter) && letter.length === 1

export const isLetterInPuzzle = (letters, letter) =>
  !!letters.find((letterObj) => letterObj.letter === letter)

export const areLettersOnSameSide = (letters, letter, prevLetter) => {
  const foundLetterObj = letters.find(
    (letterObj) => letterObj.letter === letter,
  )

  const prevLetterObj = letters.find(
    (letterObj) => letterObj.letter === prevLetter,
  )

  return (
    foundLetterObj &&
    prevLetterObj &&
    foundLetterObj.side === prevLetterObj.side
  )
}

export const validateLetter = (state, letter) => {
  const localState =
    state.puzzleContainer !== undefined
      ? state
      : { puzzleContainer: { ...state } }
  const letters = selectLetterData(localState)
  const prevLetter = selectPuzzleData(localState).activeLetter

  return (
    isValidLetter(letter) &&
    isLetterInPuzzle(letters, letter) &&
    !areLettersOnSameSide(letters, letter, prevLetter)
  )
}

export const validateWord = ({ dictionary, activeWord }) =>
  dictionary.includes(activeWord)

export const validateWordLength = (activeWord) =>
  activeWord.length && activeWord.length > 2

export const isPuzzleLocked = (state) => {
  const { animating, isLocked, preventMoves } =
    state.puzzleContainer !== undefined
      ? state.puzzleContainer
      : state

  return !!(animating || isLocked || preventMoves)
}

export const getUniqueValues = (arr) => {
  return arr.filter((value, idx, arr2) => arr2.indexOf(value) === idx)
}

export const isPuzzleComplete = ({ submittedWords, sides }) => {
  const submittedLetters = [].concat(
    ...submittedWords.map((word) => word.split('')),
  )

  const uniqueSubmittedLetters = getUniqueValues(submittedLetters)

  const puzzleLetters = [].concat(
    ...sides.map((side) => side.split('')),
  )

  return puzzleLetters.every((letter) =>
    uniqueSubmittedLetters.includes(letter),
  )
}

export const getSuccessMessage = ({
  previousSuccess,
  submittedWords = [],
  isCompleted,
  activeWord,
}) => {
  const lastWord = submittedWords.length
    ? submittedWords[submittedWords.length - 1]
    : activeWord

  if (lastWord.length < 7) {
    return previousSuccess ? 'Nice!' : 'Awesome!'
  }

  if (isCompleted) return 'Savant!'

  return 'Genius!'
}
