import React from 'react'

import Layout from './Layout'

const props = {
  puzzle: {
    editor: 'Jane Doe',
    animating: false,
    activeWord: '',
    activeLetter: '',
    printDate: '2022-12-31',
    submittedWords: [],
    par: 10,
    handleTextChange: () => {},
    letters: [
      {
        letter: 'K',
        isActiveLetter: false,
        isInActiveWord: false,
        isUsed: false,
        side: 'NORTH',
      },
      {
        letter: 'P',
        isActiveLetter: false,
        isInActiveWord: false,
        isUsed: false,
        side: 'NORTH',
      },
      {
        letter: 'R',
        isActiveLetter: false,
        isInActiveWord: false,
        isUsed: false,
        side: 'NORTH',
      },
      {
        letter: 'A',
        isActiveLetter: false,
        isInActiveWord: false,
        isUsed: false,
        side: 'EAST',
      },
      {
        letter: 'G',
        isActiveLetter: false,
        isInActiveWord: false,
        isUsed: false,
        side: 'EAST',
      },
      {
        letter: 'N',
        isActiveLetter: false,
        isInActiveWord: false,
        isUsed: false,
        side: 'EAST',
      },
      {
        letter: 'D',
        isActiveLetter: false,
        isInActiveWord: false,
        isUsed: false,
        side: 'SOUTH',
      },
      {
        letter: 'M',
        isActiveLetter: false,
        isInActiveWord: false,
        isUsed: false,
        side: 'SOUTH',
      },
      {
        letter: 'O',
        isActiveLetter: false,
        isInActiveWord: false,
        isUsed: false,
        side: 'SOUTH',
      },
      {
        letter: 'I',
        isActiveLetter: false,
        isInActiveWord: false,
        isUsed: false,
        side: 'WEST',
      },
      {
        letter: 'C',
        isActiveLetter: false,
        isInActiveWord: false,
        isUsed: false,
        side: 'WEST',
      },
      {
        letter: 'U',
        isActiveLetter: false,
        isInActiveWord: false,
        isUsed: false,
        side: 'WEST',
      },
    ],
    message: {},
  },
  actions: {
    handleTextChange: () => {},
    addLetter: () => {},
    removeLetter: () => {},
    submitWord: () => {},
    unlockAndResetGame: () => {},
    addWord: () => {},
    clearErrorMessage: () => {},
    endAnimation: () => {},
    showMessage: () => {},
  },
  momentSystem: { open: () => {} },
  modalSystem: {
    getAll: () => [],
  },
}

const largeWordList = [
  'ACARID',
  'DROID',
  'DIORAMA',
  'AOUDAD',
  'DRAMA',
  'AMINO',
  'ONROAD',
  'DAIMIO',
  'OINK',
  'KARMA',
  'AIRDROP',
  'PIAPIAC',
  'CAPO',
  'ONIGIRI',
]

const xlargeWordList = [
  'ACARID',
  'DROID',
  'DIORAMA',
  'AOUDAD',
  'DRAMA',
  'AMINO',
  'ONROAD',
  'DAIMIO',
  'OINK',
  'KARMA',
  'AIRDROP',
  'PIAPIAC',
  'CAPO',
  'ONIGIRI',
  'ACARID',
  'DROID',
  'DIORAMA',
  'AOUDAD',
  'DRAMA',
  'AMINO',
  'ONROAD',
  'DAIMIO',
  'OINK',
  'KARMA',
  'AIRDROP',
  'PIAPIAC',
  'CAPO',
  'ONIGIRI',
  'DROID',
  'DIORAMA',
  'AOUDAD',
  'DRAMA',
  'AMINO',
  'ONROAD',
  'DAIMIO',
  'OINK',
  'KARMA',
  'AIRDROP',
  'PIAPIAC',
  'CAPO',
  'ONIGIRI',
]

const errorMessage = {
  isError: true,
  value: 'Not a word',
}

const successMessage = {
  isError: false,
  value: 'Awesome!',
}

const Template = (args) => <Layout {...args} />

export const LongWordList = Template.bind({})
LongWordList.args = {
  ...props,
  puzzle: {
    ...props.puzzle,
    submittedWords: largeWordList,
  },
}

export const ExtraLongWordList = Template.bind({})
ExtraLongWordList.args = {
  ...props,
  puzzle: {
    ...props.puzzle,
    submittedWords: xlargeWordList,
  },
}

export const withErrorMessaging = Template.bind({})
withErrorMessaging.args = {
  ...props,
  puzzle: {
    ...props.puzzle,
    message: errorMessage,
  },
}

export const withSuccessMessaging = Template.bind({})
withSuccessMessaging.args = {
  ...props,
  puzzle: {
    ...props.puzzle,
    message: successMessage,
  },
}

export const LongWordListSuccess = Template.bind({})
LongWordListSuccess.args = {
  ...props,
  puzzle: {
    ...props.puzzle,
    submittedWords: largeWordList,
    message: successMessage,
  },
}

export const LongWordListError = Template.bind({})
LongWordListError.args = {
  ...props,
  puzzle: {
    ...props.puzzle,
    submittedWords: largeWordList,
    message: errorMessage,
  },
}

export const Tablet = Template.bind({})

Tablet.parameters = {
  viewport: {
    defaultViewport: 'ipad',
  },
}

export const Desktop = Template.bind({})

Desktop.parameters = {
  viewport: {
    defaultViewport: 'reset',
  },
}

export default {
  title: 'Letterboxed/Layout',
  component: Layout,
  args: props,
  parameters: {
    viewport: {
      defaultViewport: 'iphone5',
    },
  },
  decorators: [
    (Story) => (
      <>
        <div id="js-hook-game-wrapper" />
        <div id="js-hook-pz-moment__game" className="pzm-system" />
        <div
          className="pz-moment__frame on-stage"
          id="js-hook-pz-moment__loading"
          style={{ className: 'slide-up', textAlign: 'center' }}
        >
          <Story />
        </div>
      </>
    ),
  ],
}
