import React from 'react'
import { waitFor, render } from '@testing-library/react'

import { useUser } from 'user'
import { retrieveMeterValue, willUseMeterToGate } from 'shared/meter'

import { MeterProvider } from './meterProvider'

jest.mock('user', () => ({
  useUser: jest.fn(() => ({
    userType: { isLoggedIn: true, hasXwd: true },
  })),
}))

jest.mock('../../../../shared/meter', () => ({
  retrieveMeterValue: jest.fn(),
  willUseMeterToGate: jest.fn(),
}))

describe('MeterProvider', () => {
  beforeEach(jest.clearAllMocks)
  afterEach(jest.clearAllMocks)

  it('should not call Meter if user is subscribed and on web', () => {
    // @ts-ignore
    willUseMeterToGate.mockReturnValueOnce(true)
    render(
      <MeterProvider>
        <></>
      </MeterProvider>,
    )

    expect(retrieveMeterValue).not.toHaveBeenCalled()
  })

  it('should not call Meter if user is subscribed and on games app', () => {
    // @ts-ignore
    window.isHybridWebView = true
    window.newsreaderAppPlatform = ''
    render(
      <MeterProvider>
        <></>
      </MeterProvider>,
    )

    expect(retrieveMeterValue).not.toHaveBeenCalled()
  })

  it('should call Meter if user is anon and on web', () => {
    // @ts-ignore
    useUser.mockReturnValueOnce({
      userType: { isLoggedIn: false, hasXwd: false },
      hasLoaded: true,
    })

    window.isHybridWebView = false
    window.newsreaderAppPlatform = ''

    render(
      <MeterProvider>
        <></>
      </MeterProvider>,
    )

    expect(retrieveMeterValue).toHaveBeenCalled()
  })

  it('should not call Meter if user is anon and on games app', () => {
    // @ts-ignore
    useUser.mockReturnValueOnce({
      userType: { isLoggedIn: false, hasXwd: false },
    })

    window.isHybridWebView = true
    window.newsreaderAppPlatform = ''

    render(
      <MeterProvider>
        <></>
      </MeterProvider>,
    )

    expect(retrieveMeterValue).not.toHaveBeenCalled()
  })

  it('should call Meter if user is regi and on web', () => {
    // @ts-ignore
    useUser.mockReturnValueOnce({
      userType: { isLoggedIn: true, hasXwd: false },
      hasLoaded: true,
    })

    // @ts-ignore
    willUseMeterToGate.mockReturnValueOnce(true)

    render(
      <MeterProvider>
        <></>
      </MeterProvider>,
    )

    expect(retrieveMeterValue).toHaveBeenCalled()
  })

  it('should not call Meter if user is regi and on games app', () => {
    // @ts-ignore
    useUser.mockReturnValueOnce({
      userType: { isLoggedIn: true, hasXwd: false },
    })

    window.isHybridWebView = true
    window.newsreaderAppPlatform = ''

    render(
      <MeterProvider>
        <></>
      </MeterProvider>,
    )
    expect(retrieveMeterValue).not.toHaveBeenCalled()
  })
})
