import React, {
  createContext,
  useEffect,
  useState,
  ReactNode,
} from 'react'

import { useUser } from 'user'
import { retrieveMeterValue, willUseMeterToGate } from 'shared/meter'
import {
  MeterProperties,
  grantReasons,
} from 'shared/meter/MeterTypes'

const MeterContext = createContext({
  granted: false,
  grantReason: grantReasons.METER_LIMIT,
  isOffline: false,
  loggedIn: false,
})

interface MeterProviderProps {
  children: ReactNode
}

const MeterProvider = ({ children }: MeterProviderProps) => {
  const { userType, hasLoaded } = useUser()
  const [meterRes, setMeterRes] = useState({
    granted: false,
    grantReason: grantReasons.METER_LIMIT,
    isOffline: false,
    loggedIn: false,
  })

  const canMakeRequest =
    hasLoaded && !userType.hasXwd && willUseMeterToGate()

  useEffect(() => {
    const retrieveMeterValueAsync = async () => {
      try {
        const meterProperties: MeterProperties =
          await retrieveMeterValue({})
        setMeterRes(meterProperties)
      } catch (error) {
        console.error('Failed to retrieve meter response:', error)
      }
    }

    canMakeRequest && retrieveMeterValueAsync()
  }, [canMakeRequest])

  return (
    <MeterContext.Provider value={meterRes}>
      {children}
    </MeterContext.Provider>
  )
}

export { MeterContext, MeterProvider }
