import React from 'react'
import { useDispatch } from 'react-redux'

import type { ModalProps } from '../../../shared/ModalSystem/modalTypes'
import ModalWrapper from '../../../shared/ModalSystem/ModalWrapper'
import track from '../letterBoxedTracker'
import { saveConfirmReset } from '../store/settings'

type Props = ModalProps & {
  actions?: { unlockAndResetGame: () => void }
  data?: { par: number }
}

const DEFAULT_ACTIONS = {
  unlockAndResetGame: () => {},
}

const ConfirmReset = ({
  close,
  actions = DEFAULT_ACTIONS,
  isClosing,
  onRemove,
  data = { par: 0 },
}: Props) => {
  const { par } = data
  const { unlockAndResetGame } = actions
  const dispatch = useDispatch()

  return (
    <ModalWrapper
      bodyClassName="modal-pause-body su-modal-pause limit-height"
      close={close}
      keyConfig={{
        Escape: () => {},
        Enter: () => {},
      }}
      ignoreBackgroundClick
      isClosing={isClosing}
      onRemove={onRemove}
    >
      <div className="modal-rules-container">
        <p className="modal-system-body modal-message">
          Are you sure you want to start over?
        </p>
        <button
          className="pz-modal__button dark large"
          onClick={() => {
            track.interaction.gameplay(
              'letter-boxed',
              'reset-game',
              null,
            )
            unlockAndResetGame()
          }}
          type="button"
        >
          Start over
        </button>
        <label htmlFor="reset" className="pz-modal__checkbox">
          <input
            id="reset"
            type="checkbox"
            onChange={(evt) => {
              track.interaction.gameplay(
                'letter-boxed',
                'reset-game',
                'turn-on',
              )

              return dispatch(
                saveConfirmReset({
                  confirmReset: !evt.target.checked,
                }),
              )
            }}
          />
          <span>Do not ask me again</span>
        </label>
      </div>
    </ModalWrapper>
  )
}

export default ConfirmReset
