import React from 'react'

import { SEND_EMAIL_TYPE } from 'foundation'

import PreviewSquare from '../PreviewSquare'
import FeedbackLink from '../../../helpers/FeedbackLink'
import ModalWrapper from '../../../shared/ModalSystem/ModalWrapper'
import { ModalProps } from '../../../shared/ModalSystem/modalTypes'
import { helpSquareConfig } from '../previewSquareConfig'

export default ({ onRemove, isClosing, close }: ModalProps) => {
  const helpSolution = ['WORDS']
  const helpSides = ['WMY', 'TOI', 'HND', 'SLR']

  return (
    <ModalWrapper
      bodyClassName="modal-rules-body"
      close={close}
      isClosing={isClosing}
      onRemove={onRemove}
    >
      <div>
        <h1 className="modal-system-header">How to Play</h1>
        <p className="modal-system-description">
          Create words using letters round the square
        </p>
        <div className="modal-system-centered-content">
          <PreviewSquare
            solution={helpSolution}
            sides={helpSides}
            config={helpSquareConfig}
          />
        </div>
        <ul className="bullet-list">
          <li className="modal-system-body">
            Connect letters to spell words
          </li>
          <li className="modal-system-body">
            Words must be at least 3 letters long
          </li>
          <li className="modal-system-body">
            Consecutive letters cannot be from the same side
          </li>
          <li className="modal-system-body">
            The last letter of a word becomes the first letter of the
            next word eg. THY &gt; YES &gt; SINCE
          </li>
          <li className="modal-system-body">
            Words cannot be proper nouns or hyphenated
          </li>
          <li className="modal-system-body">
            No cussing either, sorry
          </li>
          <li className="modal-system-body">
            Use all letters to solve!
          </li>
        </ul>
        <p className="modal-system-body paragraph">
          New puzzles are released daily at 3 a.m. ET.
        </p>
        <p className="modal-system-body paragraph">
          Have feedback? Email us at{' '}
          <FeedbackLink
            subject="Letter Boxed Feedback"
            useEnhancedHybridDebugInfo
            type={SEND_EMAIL_TYPE.LETTERBOXED}
          >
            nytgames@nytimes.com
          </FeedbackLink>
          .
        </p>
      </div>
    </ModalWrapper>
  )
}
