import React from 'react'

import { isMobile } from 'responsive'

import PreviewSquare from '../PreviewSquare'
import {
  yesterdaysSquareConfig,
  yesterdaysSquareMobileConfig,
} from '../previewSquareConfig'
import { ModalProps } from '../../../shared/ModalSystem/modalTypes'
import ModalWrapper from '../../../shared/ModalSystem/ModalWrapper'

type Props = {
  data?: {
    yesterdaysSolution: string[]
    yesterdaysSides: string[]
  }
}

const DEFAULT_DATA = {
  yesterdaysSolution: [],
  yesterdaysSides: [],
}

const YesterdaysSolution = ({
  close,
  isClosing,
  onRemove,
  data = DEFAULT_DATA,
}: YesterdaysSolutionProps) => {
  const { yesterdaysSolution, yesterdaysSides } = data

  return (
    <ModalWrapper
      bodyClassName="modal-rules-body limit-height"
      close={close}
      isClosing={isClosing}
      onRemove={onRemove}
    >
      <h1 className="modal-system-header" data-testid="header">
        Our Solution to Yesterday’s Puzzle
      </h1>

      <div className="modal-system-centered-content">
        <div
          className="modal-system-limit-width"
          data-testid="wordlist"
        >
          {yesterdaysSolution.map((word, i) => (
            <div
              className="modal-wordlist"
              data-testid="yesterday-word"
              key={`yesterday-answer-${word}`}
            >
              {word}
            </div>
          ))}
        </div>
      </div>
      <div
        className="modal-system-centered-content"
        data-testid="yesterday-square"
      >
        <PreviewSquare
          solution={yesterdaysSolution}
          sides={yesterdaysSides}
          config={
            isMobile
              ? yesterdaysSquareMobileConfig
              : yesterdaysSquareConfig
          }
        />
      </div>
    </ModalWrapper>
  )
}

export type YesterdaysSolutionProps = Props & ModalProps

export default YesterdaysSolution
