import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'

import track from '../../letterBoxedTracker'
import { saveConfirmReset } from '../../store/settings'
import ConfirmReset from '../ConfirmReset'

jest.mock('../../letterBoxedTracker.js', () => ({
  interaction: {
    gameplay: jest.fn(),
  },
}))

jest.mock('../../store/settings', () => ({
  saveConfirmReset: jest.fn(),
}))

const unlockAndResetGame = jest.fn()
const closeMock = jest.fn()

const setup = () => {
  const makeStore = () => ({
    getState: () => ({}),
    subscribe: jest.fn(),
    dispatch: jest.fn(),
  })

  return mount(
    // @ts-ignore
    <Provider store={makeStore()}>
      <ConfirmReset
        data={{ par: 6 }}
        actions={{
          unlockAndResetGame,
        }}
        close={closeMock}
        isClosing={false}
        onRemove={() => {}}
      />
    </Provider>,
  )
}

describe(`LETTER BOXED: CONFIRM RESET MODAL`, () => {
  beforeEach(() => {
    jest.resetAllMocks()
  })

  it('calls unlockAndResetGame when "Start Over" is clicked', () => {
    const wrapper = setup()
    const resetBtn = wrapper.find('button')
    expect(resetBtn.text()).toEqual('Start over')

    resetBtn.simulate('click')
    expect(track.interaction.gameplay).toHaveBeenCalledWith(
      'letter-boxed',
      'reset-game',
      null,
    )
    expect(unlockAndResetGame).toHaveBeenCalled()
  })

  it('saves reset confirmation preferences on checkbox update', () => {
    const wrapper = setup()
    const checkbox = wrapper.find('input')

    expect(checkbox.props().id).toEqual('reset')

    checkbox.simulate('change')

    expect(saveConfirmReset).toHaveBeenCalled()
  })
})
