import React from 'react'
import { shallow } from 'enzyme'

import YesterdaysModal from '../YesterdaysSolution'

const injectedState = {
  yesterdaysSolution: [],
  yesterdaysSides: [],
}

const componentObject = {
  title: {
    dataTestid: 'header',
    text: 'Our Solution to Yesterday’s Puzzle',
  },
  wordList: {
    dataTestid: 'wordList',
  },
  word: {
    dataTestid: 'yesterday-word',
  },
  square: {
    dataTestid: 'yesterday-square',
  },
}

const wordList = ['HOME', 'EYES', 'SEWN']

jest.mock('responsive', () => ({
  isMobile: false,
}))

describe(`LETTER BOXED: YESTERDAY'S SOLUTION MODAL`, () => {
  it('should render a modal', () => {
    const wrapper = shallow(
      <YesterdaysModal
        close={() => {}}
        isClosing={false}
        onRemove={() => {}}
        data={injectedState}
      />,
    )
    expect(wrapper).toHaveLength(1)
  })

  it('should render a modal with respective H3 text', () => {
    const wrapper = shallow(
      <YesterdaysModal
        close={() => {}}
        isClosing={false}
        onRemove={() => {}}
        data={injectedState}
      />,
    )
    expect(
      wrapper
        .find(`h1[data-testid="${componentObject.title.dataTestid}"]`)
        .text(),
    ).toBe(componentObject.title.text)
  })

  it('should render a modal with 3 words', () => {
    const testData = {
      yesterdaysSolution: wordList,
      yesterdaysSides: [],
    }

    const wrapper = shallow(
      <YesterdaysModal
        close={() => {}}
        isClosing={false}
        onRemove={() => {}}
        data={testData}
      />,
    )

    const actual = wrapper.find(
      `[data-testid="${componentObject.word.dataTestid}"]`,
    )
    const expected = 3
    expect(actual).toHaveLength(expected)
  })

  it('should render a modal with a square canvas', () => {
    const wrapper = shallow(
      <YesterdaysModal
        close={() => {}}
        isClosing={false}
        onRemove={() => {}}
        data={injectedState}
      />,
    )

    const actual = wrapper.find(
      `[data-testid="${componentObject.square.dataTestid}"]`,
    )
    const expected = 1
    expect(actual).toHaveLength(expected)
  })
})
