import React from 'react'
import { Provider } from 'react-redux'
import { configureStore } from '@reduxjs/toolkit'
import { Story } from '@storybook/react'

import CongratsComponent from '../Congrats'
import {
  withProvider,
  withUserProvider,
} from '../../../../../shared/storybook/helpers'
import { initialState as storyState } from '../../store/puzzleContainer/reducer'

const store = configureStore({ reducer: () => storyState })

interface Props {
  perfectSolve: boolean
  hybrid: boolean
}

interface UserProps {
  hasXwd: boolean
  isLoggedIn: boolean
}
const CongratsTemplate: Story<Props & UserProps> = ({
  hybrid,
  perfectSolve,
}: Props) => {
  window.isHybridWebView = hybrid
  // @ts-ignore
  window.NativeBridge = hybrid
  return (
    <Provider store={store}>
      <CongratsComponent
        actions={{ unlockAndResetGame: () => {} }}
        close={() => {}}
        isClosing={false}
        onRemove={() => {}}
        data={{
          par: perfectSolve ? 5 : 4,
          submittedWords: [
            'ACAI',
            'INCH',
            'HOBNOB',
            'BIKINIS',
            'STRIM',
          ],
          sides: ['ASB', 'CTI', 'HNM', 'KOR'],
        }}
      />
    </Provider>
  )
}

export const Congrats = CongratsTemplate.bind({})
Congrats.args = {
  hasXwd: true,
  isLoggedIn: true,
  perfectSolve: false,
  hybrid: false,
}

export default {
  component: Congrats,
  title: 'Letterboxed/Modals/Congrats',
  argTypes: {
    hybrid: {
      control: {
        type: 'boolean',
      },
    },
    perfectSolve: {
      control: { type: 'boolean' },
    },
  },
  decorators: [
    (
      Story: Story,
      { args: { hasXwd, isLoggedIn } }: { args: UserProps },
    ) => {
      document.body.classList.add('pz-desktop')
      document.body.classList.add('pz-page')
      return (
        <div
          id="modal-system-portal"
          className="modal-system-container modal-system-active"
        >
          {withUserProvider(withProvider(<Story />, store), {
            hasXwd: hasXwd && isLoggedIn,
            isLoggedIn,
          })}
        </div>
      )
    },
  ],
}
