import React from 'react'
import { configureStore } from '@reduxjs/toolkit'

import useAnimation from '../../../shared/moments/components/stories/useAnimation'
import {
  withProvider,
  withUserProvider,
} from '../../../../shared/storybook/helpers'

import { storyState } from './stories/helpers'
import MomentWelcomeManager from './MomentWelcomeManager'

const store = configureStore({ reducer: () => storyState })
const puzzle = {
  ...storyState,
  printDate: '2022-12-31',
  editor: 'Sam Ezersky',
}

const StoryTemplate = ({ ...args }) => (
  <MomentWelcomeManager {...args} />
)

const defaultArgs = {
  puzzle,
  isCompleted: false,
}

export const Anon = StoryTemplate.bind({})
Anon.args = {
  ...defaultArgs,
  hasXwd: false,
  isLoggedIn: false,
}

export const Regi = StoryTemplate.bind({})
Regi.args = {
  ...defaultArgs,
  hasXwd: false,
  isLoggedIn: true,
}

export const Sub = StoryTemplate.bind({})
Sub.args = {
  ...defaultArgs,
  hasXwd: true,
  isLoggedIn: true,
}

const hideControl = { table: { disable: true } }

export default {
  title: 'Letterboxed/Moments/Welcome Moment',

  argTypes: {
    // These args are custom to each story, but we don't need to expose controls
    hasXwd: hideControl,
    isLoggedIn: hideControl,
    puzzle: hideControl,
  },
  decorators: [
    (Story, { args: { hasXwd, isLoggedIn } }) => {
      useAnimation('storybook-welcome')

      return withUserProvider(
        withProvider(
          <div id="storybook-welcome">
            <Story />
          </div>,
          store,
        ),
        { hasXwd, isLoggedIn },
      )
    },
  ],
}
