import React, { useEffect } from 'react'

import { trackImpression } from 'foundation'
import { useUser } from 'user'
import useCTA from 'shared/marketing/useCTA'
import { MeterProperties } from 'shared/meter/MeterTypes'

import useAbra from '../../../../shared/abra/useAbra'
import track from '../letterBoxedTracker'
import Welcome from '../../../shared/moments/components/Welcome'
import NonDismissalBanner from '../../../shared/Banner/NonDismissalBanner'
import { trackLBInteraction } from '../analytics'
import { shouldShowAppDownloadCTA } from '../../../shared/Banner/bannerHelpers'
import useSaleBannerHybridSubscribe from '../../../shared/hooks/use-sale-banner-hybrid-subscribe'

import { createButtons } from './CreateButtons'

export type PuzzleProps = {
  activeLetter?: string
  activeWord?: string
  animating?: boolean
  dictionary?: string[]
  editor: string
  editorImage?: string
  expiration?: number
  id?: number
  isCompleted?: boolean
  isFree?: boolean
  isLocked?: boolean
  letters?: object
  message?: object
  ourSolution?: string[]
  par: number
  previousSuccess?: boolean
  printDate: string
  sides?: string[]
  submittedWords?: string[]
  yesterdaysSides?: string[]
  yesterdaysSolution?: string[]
}

type MomentWelcomeManagerProps = {
  isCompleted: boolean
  puzzle: PuzzleProps
  meterResponse: MeterProperties
}

type Months = {
  [key: string]: string
}

const MomentWelcomeManager = ({
  puzzle,
  isCompleted,
  meterResponse,
}: MomentWelcomeManagerProps) => {
  const { userType, updateUserType, hasLoaded } = useUser()
  const { hasXwd, isLoggedIn } = userType
  const { getButtonText } = useCTA()
  const { getVariant, reportExposure } = useAbra()

  const downloadCTAVariant = getVariant(
    'GAMES_lbWelcomeAppDownloadCTA_0823',
  )

  const showAppDownloadCTA = React.useMemo(
    () =>
      shouldShowAppDownloadCTA(
        downloadCTAVariant,
        '0_control',
        window,
      ),
    [downloadCTAVariant],
  )

  React.useEffect(() => {
    if (downloadCTAVariant) {
      reportExposure('GAMES_lbWelcomeAppDownloadCTA_0823')
    }

    if (showAppDownloadCTA) {
      trackImpression(
        'welcome-modal',
        'letter-boxed',
        'download-app',
        '',
      )
    }
  }, [showAppDownloadCTA, downloadCTAVariant])

  useEffect(() => {
    if (!hasLoaded) return

    if (hasXwd) {
      track.impression.custom({
        // @ts-ignore
        module: {
          name: 'welcome-modal',
          region: 'letter-boxed',
        },
      })
    } else if (isLoggedIn) {
      trackImpression(
        'welcome-modal',
        'letter-boxed',
        'subscribe',
        isCompleted ? '0' : '1',
      )
    } else {
      trackImpression(
        'welcome-modal',
        'letter-boxed',
        ['log-in', 'subscribe'],
        isCompleted ? '0' : '1',
      )
    }
  }, [hasXwd, isLoggedIn, hasLoaded])

  const months: Months = {
    '01': 'January',
    '02': 'February',
    '03': 'March',
    '04': 'April',
    '05': 'May',
    '06': 'June',
    '07': 'July',
    '08': 'August',
    '09': 'September',
    '10': 'October',
    '11': 'November',
    '12': 'December',
  }
  const dateArray = puzzle.printDate.split('-')

  const momentWelcomeProps = {
    icon: 'letter-boxed',
    title: 'Letter Boxed',
    date: `${months[dateArray[1] as keyof Months]} ${dateArray[2]}, ${
      dateArray[0]
    }`,
    bgColor: '$letter-boxed-red',
    buttonGroups: createButtons(
      meterResponse,
      puzzle,
      isCompleted,
      hasXwd,
      isLoggedIn,
      updateUserType,
      getButtonText,
    ),
    description: {
      text: 'Create words using letters around the square.',
    },
    editor: puzzle.editor,
    promo: 'oxford',
  }

  return (
    <>
      <Welcome game={momentWelcomeProps} />
      {showAppDownloadCTA && (
        <NonDismissalBanner
          title="Play Letter Boxed and more in the NYT Games app."
          icon="crossword-app"
          position="fixed"
          ctaLink="https://fpx3r.app.goo.gl/app-store"
          onClickLink={() => {
            trackLBInteraction('APP_DOWNLOAD_CTA')
          }}
          showMultipleIconsBanner
        />
      )}
    </>
  )
}

export default MomentWelcomeManager
