import * as selectors from '../selectors'
import { initialState } from '../reducer'

const fullLetterArray = [
  {
    letter: 'U',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'NORTH',
  },
  {
    letter: 'N',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'NORTH',
  },
  {
    letter: 'S',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'NORTH',
  },
  {
    letter: 'H',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'EAST',
  },
  {
    letter: 'V',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'EAST',
  },
  {
    letter: 'I',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'EAST',
  },
  {
    letter: 'F',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'SOUTH',
  },
  {
    letter: 'O',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'SOUTH',
  },
  {
    letter: 'G',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'SOUTH',
  },
  {
    letter: 'A',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'WEST',
  },
  {
    letter: 'T',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'WEST',
  },
  {
    letter: 'R',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'WEST',
  },
]

const fullLetterArrayActive = [
  {
    letter: 'U',
    isActiveLetter: true,
    isInActiveWord: true,
    isUsed: false,
    side: 'NORTH',
  },
  {
    letter: 'N',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'NORTH',
  },
  {
    letter: 'S',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'NORTH',
  },
  {
    letter: 'H',
    isActiveLetter: false,
    isInActiveWord: true,
    isUsed: false,
    side: 'EAST',
  },
  {
    letter: 'V',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'EAST',
  },
  {
    letter: 'I',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'EAST',
  },
  {
    letter: 'F',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'SOUTH',
  },
  {
    letter: 'O',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'SOUTH',
  },
  {
    letter: 'G',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'SOUTH',
  },
  {
    letter: 'A',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'WEST',
  },
  {
    letter: 'T',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'WEST',
  },
  {
    letter: 'R',
    isActiveLetter: false,
    isInActiveWord: false,
    isUsed: false,
    side: 'WEST',
  },
]

describe('Puzzle Container Selector', () => {
  it('should return the initial puzzle container puzzle data', () => {
    expect(
      selectors.selectPuzzleData({
        puzzleContainer: initialState,
      }),
    ).toEqual(initialState)
  })

  it('should return an empty letters array', () => {
    const sides = ['', '', '', '']

    expect(
      selectors.selectLetterData({
        puzzleContainer: { ...initialState, sides },
      }),
    ).toEqual([])
  })

  it('should return an full letters array', () => {
    const sides = ['UNS', 'HVI', 'FOG', 'ATR']

    expect(
      selectors.selectLetterData({
        puzzleContainer: { ...initialState, sides },
      }),
    ).toEqual(fullLetterArray)
  })

  it('should return an full letters array with active values', () => {
    const sides = ['UNS', 'HVI', 'FOG', 'ATR']
    const activeWord = 'HU'

    expect(
      selectors.selectLetterData({
        puzzleContainer: {
          ...initialState,
          sides,
          activeLetter: activeWord.slice(-1),
          activeWord,
        },
      }),
    ).toEqual(fullLetterArrayActive)
  })
})
