import * as constants from '../../containers/PuzzleContainer/constants'

const resetState = {
  activeWord: '',
  activeLetter: '',
  submittedWords: [],
  isCompleted: false,
  message: {},
  preventMoves: false,
  isLocked: false,
  animating: false,
  previousSuccess: false,
  modalSystem: {
    isClosing: false,
    modal: null,
  },
}

export const initialState = {
  id: 0,
  expiration: 0,
  printDate: '',
  sides: ['ADR', 'MEO', 'BXU', 'ITS'],
  dictionary: [],
  par: 0,
  ourSolution: [],
  yesterdaysSides: [],
  yesterdaysSolution: [],
  editor: '',
  editorImage: '',
  preventMoves: false,
  isLocked: false,
  animating: false,
  modalSystem: {
    isClosing: false,
    modal: null,
  },
  ...resetState,
}

export const puzzleContainerReducer = (
  state = initialState,
  action,
) => {
  switch (action.type) {
    case constants.ADD_LETTER: {
      return {
        ...state,
        activeLetter: action.payload,
        activeWord: state.activeWord + action.payload,
      }
    }

    case constants.REMOVE_LETTER: {
      let { activeLetter, activeWord, submittedWords } = state

      if (
        state.activeWord.length === 1 &&
        state.submittedWords.length > 0
      ) {
        activeWord = state.submittedWords.slice(-1).pop()
        submittedWords = state.submittedWords.slice(0, -1)
      } else {
        activeLetter = state.activeWord.slice(-2, -1)
        activeWord = state.activeWord.slice(0, -1)
      }

      return {
        ...state,
        activeLetter,
        activeWord,
        submittedWords,
      }
    }

    case constants.ADD_WORD: {
      return {
        ...state,
        activeWord: state.activeLetter,
        submittedWords: [...state.submittedWords, state.activeWord],
      }
    }

    case constants.ANIMATE_START: {
      return {
        ...state,
        animating: true,
      }
    }

    case constants.ANIMATE_END: {
      return {
        ...state,
        animating: false,
      }
    }

    case constants.UNLOCK_AND_RESET_GAME: {
      return {
        ...state,
        ...resetState,
        isLocked: false,
      }
    }

    case constants.PREVENT_MOVES: {
      return {
        ...state,
        preventMoves: true,
      }
    }

    case constants.COMPLETE_GAME: {
      return {
        ...state,
        isCompleted: true,
      }
    }

    case constants.SHOW_ERROR_MESSAGE: {
      return {
        ...state,
        message: { isError: true, value: action.payload },
      }
    }

    case constants.SHOW_SUCCESS_MESSAGE: {
      return {
        ...state,
        message: { isError: false, value: action.payload },
        previousSuccess: !state.previousSuccess,
      }
    }

    case constants.CLEAR_MESSAGE: {
      return {
        ...state,
        message: {},
      }
    }

    case constants.OPEN_MODAL:
      return {
        ...state,
        modalSystem: {
          modal: action.modal,
          isClosing: false,
        },
        isLocked: true,
      }

    case constants.CLOSE_MODAL:
      return {
        ...state,
        modalSystem: {
          isClosing: true,
        },
        isLocked: false,
        isCompleted: false,
      }

    case constants.REMOVE_MODAL:
      return {
        ...state,
        modalSystem: {
          isClosing: false,
          modal: null,
        },
        isLocked: false,
      }

    default:
      return state
  }
}

export default puzzleContainerReducer
