import { createSelector } from 'reselect'

import * as constants from '../../containers/PuzzleContainer/constants'

export const selectPuzzleData = (state) => state.puzzleContainer

const sidesMap = (sideInt) => {
  switch (sideInt) {
    case 0:
      return constants.NORTH
    case 1:
      return constants.EAST
    case 2:
      return constants.SOUTH
    case 3:
      return constants.WEST
    default:
      throw new Error(`Unknown side number: ${sideInt}`)
  }
}

const updateLetters = (puzzle) => {
  const { activeWord, activeLetter, submittedWords, sides } = puzzle

  const lettersMetaData = []

  sides.map((letterSideArr, idx) =>
    letterSideArr.split('').map((letter) => {
      lettersMetaData.push({
        letter,
        isActiveLetter: activeLetter === letter,
        isInActiveWord: !!activeWord.includes(letter),
        isUsed: submittedWords.some((word) => word.includes(letter)),
        side: sidesMap(idx),
      })

      return ''
    }),
  )

  return lettersMetaData
}

export const selectLetterData = createSelector(
  selectPuzzleData,
  (puzzle) => updateLetters(puzzle),
)

export const getOpenModalName = (state) =>
  state.puzzleContainer.modalSystem.modal

export const getIsModalOpen = (state) => !!getOpenModalName(state)

export const getIsClosing = (state) =>
  state.puzzleContainer.modalSystem.isClosing
