import React, { useEffect } from 'react'
import cn from 'classnames'

import Icon from '../../../shared/components/Icon/Icon'

import styles from './LargeCTABanner.module.scss'

export const InlineGames = () => (
  <div className={styles.inlineGames} />
)

export const PlayButton = () => (
  <div className={styles.playButton}>
    <Icon icon="crossword-app" />
    <span>Play in the NYT Games App</span>
  </div>
)

export const IconAndButton = () => (
  <>
    <p className={styles.headline}>Play in the NYT Games App</p>
    <InlineGames />
    <PlayButton />
  </>
)

export const IconAndImage = () => (
  <>
    <div className={styles.ctaImage} />
    <div className={styles.imageOverlay}>
      <div className={styles.iconTextWrapper}>
        <InlineGames />
        <p className={styles.smallHeadline}>
          Play Wordle and more in the NYT Games app.
        </p>
      </div>
      <Icon icon="caret-right" />
    </div>
  </>
)

export const ButtonAndImage = () => (
  <>
    <div className={styles.ctaImage} />
    <div className={styles.imageOverlay}>
      <PlayButton />
    </div>
  </>
)

type LargeCTAProps = {
  variant: string | null
  ctaLink: string
  newTab: boolean
  onVisible?: () => void
  onClickLink?: () => void
  positionRelative?: boolean
}

const variantMap: Record<string, React.ReactNode> = {
  '1_iconButton': <IconAndButton />,
  '2_iconImage': <IconAndImage />,
  '3_buttonImage': <ButtonAndImage />,
}

const LargeCTAVariant = ({
  variant,
  ctaLink,
  newTab,
  onVisible,
  onClickLink,
  positionRelative,
}: LargeCTAProps) => {
  useEffect(() => {
    if (onVisible) onVisible()
  }, [onVisible])

  return (
    <a
      href={ctaLink}
      target={newTab ? '_blank' : '_self'}
      className={cn(styles.banner, {
        [styles.relative]: positionRelative,
      })}
      onClick={onClickLink}
      rel="noopener noreferrer"
      aria-live="polite"
      data-testid={variant}
    >
      {variant && variantMap[variant]}
    </a>
  )
}

export default LargeCTAVariant
