import React, { useEffect } from 'react'
import cn from 'classnames'

import Icon from '../../../shared/components/Icon/Icon'

import styles from './NonDismissalBanner.module.scss'

/**
 Displays a banner at the bottom of a page with an icon, title, and a ">", this banner is not able to be dismissed.
 Supports two different layouts one with
 and without an optional message.
 */

type BannerProps = {
  title: string | null
  message?: string | null
  icon: string | null
  ctaLink?: string | null
  newTab?: boolean
  showMultipleIconsBanner?: boolean
  onClickLink?: () => void
  onVisible?: () => void
  position?: 'fixed' | 'relative'
}

const NonDismissalBanner = ({
  title,
  icon,
  message,
  ctaLink,
  newTab,
  showMultipleIconsBanner,
  onClickLink,
  onVisible,
  position,
}: BannerProps) => {
  useEffect(() => {
    if (onVisible) onVisible()
  }, [onVisible])

  if (showMultipleIconsBanner) {
    return (
      <a
        href={ctaLink ?? ''}
        target={newTab ? '_blank' : '_self'}
        rel="noopener noreferrer"
        onClick={() => {
          if (onClickLink) {
            onClickLink()
          }
        }}
        style={{ position }}
        className={cn(styles.multiIconBannerTest)}
        aria-live="polite"
      >
        <div
          className={styles.bannerInformationTest}
          aria-label="Information"
        >
          <div className={styles.iconHolder} />
          <div className={styles.bannerBodyTest}>
            <h3>{title}</h3>
          </div>
        </div>
        <button className={styles.iconButtonTest} type="button">
          <Icon icon="caret-right" />
        </button>
      </a>
    )
  }

  return (
    <a
      href={ctaLink ?? ''}
      target={newTab ? '_blank' : '_self'}
      rel="noopener noreferrer"
      onClick={() => {
        if (onClickLink) {
          onClickLink()
        }
      }}
      className={cn(styles.banner)}
      style={{ position }}
      aria-live="polite"
    >
      <button className={styles.iconButton} type="button">
        <Icon icon="caret-right" />
      </button>
      <div
        className={cn(styles.bannerInformation, {
          [styles.bannerMessageIcon]: message,
        })}
        aria-label="Information"
      >
        <Icon icon={icon ?? ''} />
        <div
          className={cn(styles.bannerBody, {
            [styles.clickArea]: !message,
          })}
        >
          <h3 className={message ? styles.bannerMessageTitle : ''}>
            {title}
          </h3>
          {message && <p>{message}</p>}
        </div>
      </div>
    </a>
  )
}

export default NonDismissalBanner
