import React, { MouseEvent } from 'react'
import classNames from 'classnames'

import Icon from 'shared/components/Icon/Icon'

import Pill from '../Pill'

/**
 * A basic Button component to be used in Games app
 */
export type ButtonProps = {
  text: string
  type?: 'primary' | 'secondary' | 'card-primary' | 'card-secondary'
  disabled?: boolean
  className?: string
  onClick?: (e: MouseEvent<HTMLButtonElement>) => void
  isEmphasizedNew?: boolean
  iconLeft?: string
  iconRight?: string
}

const Button = ({
  text = 'Play',
  type = 'primary',
  disabled = false,
  className,
  onClick,
  isEmphasizedNew = false,
  iconLeft,
  iconRight,
}: ButtonProps) => {
  return (
    <button
      type="button"
      className={classNames(`button-${type}`, className, {
        disabled,
      })}
      disabled={disabled}
      onClick={(e) => {
        if (typeof onClick === 'function') {
          onClick(e)
        }
      }}
    >
      {iconLeft && <Icon icon={iconLeft} />}
      {isEmphasizedNew && (
        <Pill text="new" position="top-right-outside" />
      )}
      {text}
      {iconRight && (
        <Icon icon={iconRight} className="pz-icon-right" />
      )}
    </button>
  )
}

export default Button
