import React from 'react'
import pt from 'prop-types'

const ConversionBanner = ({
  fireInteractionEvent,
  handleClose,
  gameType,
  isGiftBanner,
  isSubscriber,
  bannerUrl,
}) => {
  return (
    <a
      href={bannerUrl}
      target="_blank"
      rel="noreferrer"
      id="conversion-banner"
      className={`conversion-banner ${
        gameType === 'tiles' ? 'tilesConversionBanner' : ''
      }`}
      onClick={fireInteractionEvent.bind('goto-subscribe')}
    >
      <div className="conversion-banner__leftpanel">
        <img
          className={
            isGiftBanner
              ? 'conversion-banner__gift-logo'
              : 'conversion-banner__sub-logo'
          }
          src={`https://mwcm.nyt.com/dam/LP/games/banner/${
            isGiftBanner ? 'gift-icon.svg' : `${gameType}-icon`
          }`}
          alt={`${gameType} Tiles game icon`}
        />
        {isGiftBanner ? (
          <span>
            Enjoy{' '}
            <span className="conversion-banner__bold">
              {gameType === 'spelling-bee' ? 'Spelling Bee' : 'Tiles'}
            </span>
            ? Share the love with a gift subscription.
          </span>
        ) : (
          <span>
            Love{' '}
            <span className="conversion-banner__bold">
              {gameType === 'spelling-bee' ? 'Spelling Bee' : 'Tiles'}
            </span>
            ? Subscribe to play the full game, plus The Crossword and
            more.
          </span>
        )}
      </div>
      {isSubscriber ? (
        <div role="button" onClick={handleClose}>
          <img
            className="conversion-banner__icon"
            src="https://mwcm.nyt.com/dam/LP/games/banner/close-icon"
            alt="close banner"
          />
        </div>
      ) : (
        <img
          className="conversion-banner__icon"
          src="https://mwcm.nyt.com/dam/LP/games/banner/chevron-right.svg"
          alt="open banner"
        />
      )}
    </a>
  )
}

ConversionBanner.propTypes = {
  gameType: pt.string.isRequired,
  isGiftBanner: pt.bool,
  fireInteractionEvent: pt.func.isRequired,
  handleClose: pt.func.isRequired,
  isSubscriber: pt.bool,
  bannerUrl: pt.string.isRequired,
}

export default ConversionBanner
