import React from 'react'
import { render, screen, act } from '@testing-library/react'

import CountdownTimer from './index'

jest.mock('foundation', () => ({
  env: { version: 'test' },
}))

describe('<CountdownTimer />', () => {
  beforeAll(() => jest.useFakeTimers('modern'))

  beforeEach(() =>
    jest.setSystemTime(new Date('April 20, 2022 23:59:00')),
  )

  afterAll(() => jest.useRealTimers())

  it('should display correct time at first', () => {
    render(<CountdownTimer />)
    const text = screen.getByTestId('timer').textContent
    expect(text).toEqual('00:01:00')
  })

  it('should display time until midnight', () => {
    render(<CountdownTimer />)
    act(() => {
      jest.advanceTimersByTime(250)
    })
    const text = screen.getByTestId('timer').textContent
    expect(text).toEqual('00:00:59')
  })

  it('should display 0s after midnight', () => {
    render(<CountdownTimer />)
    act(() => {
      jest.advanceTimersByTime(100000)
    })
    const text = screen.getByTestId('timer').textContent
    expect(text).toEqual('00:00:00')
  })
})
