import React, { useState, useEffect } from 'react'
import cn from 'classnames'

import styles from './CountdownTimer.module.scss'

const INTERVAL_MS = 200
const ONE_SECOND = 1000
const ONE_MINUTE = ONE_SECOND * 60
const ONE_HOUR = ONE_MINUTE * 60
const ONE_DAY = ONE_HOUR * 24

const padDigit = (digit: number) => {
  return digit.toString().padStart(2, '0')
}

const getTimeUntil = (targetEpochMS: number) => {
  const now = new Date().getTime()
  const msDiff = Math.floor(targetEpochMS - now)
  if (msDiff <= 0) {
    return '00:00:00'
  }
  const hours = Math.floor((msDiff % ONE_DAY) / ONE_HOUR)
  const minutes = Math.floor((msDiff % ONE_HOUR) / ONE_MINUTE)
  const seconds = Math.floor((msDiff % ONE_MINUTE) / ONE_SECOND)

  return `${padDigit(hours)}:${padDigit(minutes)}:${padDigit(
    seconds,
  )}`
}

export default () => {
  const [timer, setTimer] = useState('')

  useEffect(() => {
    const targetDate = new Date()
    // Set to tomorrow
    targetDate.setDate(targetDate.getDate() + 1)
    // Set to midnight
    targetDate.setHours(0, 0, 0, 0)
    const targetEpochMS = targetDate.getTime()
    const update = () => setTimer(getTimeUntil(targetEpochMS))

    const interval = setInterval(update, INTERVAL_MS)
    update()

    return () => clearInterval(interval)
  }, [])

  return (
    <div role="timer">
      <div className={cn(styles.statistic, styles.timer)}>
        <div
          id="timer"
          data-testid="timer"
          className={styles.testTimer}
        >
          {timer}
        </div>
      </div>
    </div>
  )
}
