import React from 'react'
import { render, screen, fireEvent } from '@testing-library/react'

import DismissableMessage from '.'

const title = 'New feature here!'
const text = 'Check this out.'

const renderMessage = () => {
  return render(
    <DismissableMessage
      title={title}
      text={text}
      localStorageKey="dismissable-msg-test"
      frequencyCap={1}
    />,
  )
}

const assertMessageExists = () => {
  expect(screen.queryByText(title)).toBeTruthy()
}

const assertMessageDoesNotExist = () => {
  expect(screen.queryByText(title)).toBeFalsy()
}

const dismissMessage = () => {
  const closeButton = screen.getByRole('button')
  fireEvent.click(closeButton)
}

describe('SHARED: Dismissable Message', () => {
  afterEach(() => {
    window.localStorage.clear()
  })

  test('message gets rendered with title and text', () => {
    renderMessage()
    const messageContent = screen.getByTestId(
      'dismissable-message',
    ).textContent

    expect(screen.getByRole('heading').textContent).toBe(title)
    expect(messageContent?.includes(text)).toBe(true)
  })

  test('should disappear when dismissed', () => {
    renderMessage()
    assertMessageExists()
    dismissMessage()
    assertMessageDoesNotExist()
  })

  test('should stay hidden if remounted after dismissed', () => {
    renderMessage()
    assertMessageExists()
    dismissMessage()
    assertMessageDoesNotExist()

    renderMessage()
    assertMessageDoesNotExist()
  })
})
