import React from 'react'

import Pill from '../Pill'
import { usePersistHide } from '../hooks/use-persist-hide'

import styles from './DismissableMessage.module.scss'

const DismissableMessage = ({
  title,
  text,
  localStorageKey,
  frequencyCap,
}: {
  title: string
  text: string
  localStorageKey: string
  frequencyCap?: number
}) => {
  const { isHidden, hide } = usePersistHide(
    localStorageKey,
    frequencyCap,
  )

  return isHidden ? null : (
    <div className={styles.message} data-testid="dismissable-message">
      <button
        type="button"
        onClick={hide}
        aria-label="close"
        className={styles.close}
      >
        ×
      </button>
      <Pill text="New" className={styles.pill} />
      <h4 className={styles.title}>{title}</h4>
      <p className={styles.text}>{text}</p>
    </div>
  )
}

export default DismissableMessage
