import React from 'react'
import { mount } from 'enzyme'

import DropDown from './DropDown'
import DropDownItem from './DropDownItem'

const someAction = jest.fn()

const props = {
  buttonLabel: 'Stuff',
  children: (
    <>
      <DropDownItem
        type="button"
        value="Do This"
        buttonAction={someAction}
      />
      <DropDownItem
        type="button"
        value="Try This"
        buttonAction={someAction}
      />
    </>
  ),
}

describe('DROPDOWN: DISPLAYS DROPDOWN OPTIONS', () => {
  let wrapper
  let dropDownButton

  beforeEach(() => {
    wrapper = mount(<DropDown {...props} />)
    dropDownButton = wrapper.find('.pz-dropdown__button')
  })

  it('should display dropdown button', () => {
    expect(dropDownButton.text()).toBe('Stuff')
  })

  it('should show correct arrow position by default and when clicked', () => {
    let arrow = wrapper.find('.pz-dropdown__arrow')
    expect.assertions(2)
    expect(arrow.hasClass('reverse')).toBe(false)
    dropDownButton.simulate('click')
    arrow = wrapper.find('.pz-dropdown__arrow')
    expect(arrow.hasClass('reverse')).toBe(true)
  })

  it('should display dropdown menu when clicked', () => {
    dropDownButton.simulate('click')
    const dropDownItems = wrapper.find('.pz-dropdown__list ul')
    const dropDownOne = dropDownItems.childAt(0).find('button')
    const dropDownTwo = dropDownItems.childAt(1).find('button')
    expect(dropDownOne.text()).toBe('Do This')
    expect(dropDownTwo.text()).toBe('Try This')
  })

  it('dropdown item should be clickable', () => {
    dropDownButton.simulate('click')
    const dropDownItems = wrapper.find('.pz-dropdown__list ul')
    const dropDownOne = dropDownItems.childAt(0).find('button')
    dropDownOne.simulate('click')
    expect(someAction).toHaveBeenCalled()
  })
})
