import React from 'react'
import propTypes from 'prop-types'

import ToolbarIcon from './ToolbarIcon'

const DropDownItem = ({
  type,
  value,
  buttonAction,
  url,
  icon,
  menuToggle,
}) => {
  const clickActions = () => {
    // perform action such as opening modal
    buttonAction && buttonAction()
    // close the dropdown in DropDown.js
    menuToggle && menuToggle()
  }

  return (
    <>
      <li key={value} className="pz-dropdown__menu-item">
        {/** List item that can handle opening a modal (help, rankings),
     or an action (check, reveal) */}
        {type === 'button' && (
          <button
            type="button"
            onClick={clickActions}
            className="pz-dropdown__button"
          >
            {value}
            {icon && <ToolbarIcon icon={icon} />}
          </button>
        )}

        {/* List item that opens an external link (today’s hints, community) */}
        {type === 'navigation' && (
          <a
            href={url}
            target={window.isHybridWebView ? '_self' : '_blank'}
            rel="noreferrer"
            onClick={clickActions}
            className="pz-dropdown__button"
          >
            {value}
            {icon && <ToolbarIcon icon={icon} />}
          </a>
        )}
      </li>
    </>
  )
}

DropDownItem.propTypes = {
  type: propTypes.oneOf(['button', 'navigation']).isRequired,
  value: propTypes.string.isRequired,
  buttonAction: propTypes.func,
  url: propTypes.string,
  icon: propTypes.string,
  menuToggle: propTypes.func,
}

export default DropDownItem
