import React from 'react'
import { shallow } from 'enzyme'

import DropDownItem from './DropDownItem'

const someAction = jest.fn()

describe('DROPDOWN ITEM', () => {
  describe('button type', () => {
    const buttonItemProps = {
      type: 'button',
      value: 'Do Things',
      buttonAction: someAction,
      icon: 'external',
    }

    let wrapper
    let dropDownItem

    beforeEach(() => {
      wrapper = shallow(<DropDownItem {...buttonItemProps} />)
      dropDownItem = wrapper.find('button')
    })

    it('displays a button', () => {
      expect(dropDownItem).toHaveLength(1)
    })

    it('calls whatever callback is passed into buttonAction on click', () => {
      dropDownItem.simulate('click')
      expect(someAction).toHaveBeenCalled()
    })

    it('displays an icon if an icon prop is passed', () => {
      expect(wrapper.find('ToolbarIcon')).toHaveLength(1)
    })
  })

  describe('navigation type', () => {
    const navigationItemProps = {
      type: 'navigation',
      value: 'Navigate to a page',
      url: '/path/to/something/cool',
      icon: 'external',
    }

    let wrapper
    let dropDownItem

    beforeEach(() => {
      wrapper = shallow(<DropDownItem {...navigationItemProps} />)
      dropDownItem = wrapper.find('a')
    })

    it('displays a link', () => {
      expect(dropDownItem).toHaveLength(1)
    })

    it('displays an icon if an icon prop is passed', () => {
      wrapper = shallow(<DropDownItem {...navigationItemProps} />)

      expect(wrapper.find('ToolbarIcon')).toHaveLength(1)
    })
  })
})
