import React from 'react'
import cn from 'classnames'

import { trackModuleInteraction } from 'foundation'

import styles from './BackButton.module.scss'

const BackButton = ({
  buttonStyle,
  textStyle,
  handler,
  trackData,
}: {
  buttonStyle?: string
  textStyle?: string
  handler?: Function
  trackData: {
    context?: string
    elementName: string
    moduleLabel: string
  }
}) => {
  return (
    <button
      type="button"
      data-testid="back-button"
      className={cn(styles.backButton, buttonStyle)}
      onClick={() => {
        const { elementName, context, moduleLabel } = trackData
        const elementLabel = 'back'
        trackModuleInteraction(
          'click',
          context,
          elementName,
          elementLabel,
          moduleLabel,
        )
        if (handler) handler()
        window.NativeBridge?.gamesBackToHub()
      }}
    >
      <span className={cn(styles.backButtonText, textStyle)}>
        Back
      </span>
    </button>
  )
}

export default BackButton
