import React from 'react'
import { shallow } from 'enzyme'

import { List, ListItem } from './List'

const props = {
  children: (
    <>
      <ListItem>
        <div>A List Item</div>
      </ListItem>
    </>
  ),
}

describe('LIST', () => {
  let wrapper
  let list

  beforeEach(() => {
    wrapper = shallow(<List {...props} />)
    list = wrapper.find('.pz-list')
  })

  it('it displays an unordered list', () => {
    expect(list.is('ul')).toBe(true)
  })

  it('displays an active state top border by default', () => {
    expect(list.hasClass('top-border--active')).toBe(true)
  })

  it('displays no bottom border by default', () => {
    expect(list.hasClass('bottom-border--none')).toBe(true)
  })

  it('top border can be toggled off ', () => {
    wrapper.setProps({ topBorder: 'none' })
    const updatedList = wrapper.find('.pz-list')
    expect(updatedList.hasClass('top-border--none')).toBe(true)
  })

  it('bottom border can be toggled to inactive state ', () => {
    wrapper.setProps({ bottomBorder: 'inActive' })
    const updatedList = wrapper.find('.pz-list')
    expect(updatedList.hasClass('bottom-border--inactive')).toBe(true)
  })
})
