import React from 'react'
import cn from 'classnames'

import ListItem from './ListItem'

/**
 * List to be used in tandem with ListItem Component.
 * The purpose of this component is to provide uniform
 * top/bottom borders (and border states) for the unordered list (<ul>)
 * when constructing a ruled/bordered list.
 *
 * While the default props, paired with ListItem Component, will
 * provide a ruled list with black borders, the props in this
 * component also provide flexibility to construct lists with no borders,
 * or delegate borders to the ListItem component.
 */

interface ListProps {
  children: React.ReactNode
  topBorder?: 'active' | 'inActive' | 'none'
  bottomBorder?: 'active' | 'inActive' | 'none'
}

const List = ({
  children,
  topBorder = 'active',
  bottomBorder = 'none',
}: ListProps) => {
  const borderClasses = cn('pz-list', {
    'top-border--active': topBorder === 'active',
    'top-border--inactive': topBorder === 'inActive',
    'top-border--none': topBorder === 'none',
    'bottom-border--active': bottomBorder === 'active',
    'bottom-border--inactive': bottomBorder === 'inActive',
    'bottom-border--none': bottomBorder === 'none',
  })

  return (
    <>
      <ul className={borderClasses}>{children}</ul>
    </>
  )
}

export { List, ListItem }
