import React from 'react'
import { shallow } from 'enzyme'

import ListItem from './ListItem'

const props = {
  children: (
    <>
      <div>Amazing content</div>
    </>
  ),
}

describe('LIST ITEM', () => {
  let wrapper
  let listItem

  beforeEach(() => {
    wrapper = shallow(<ListItem {...props} />)
    listItem = wrapper.find('.pz-list__item')
  })

  it('it displays a html list', () => {
    expect(listItem.is('li')).toBe(true)
  })

  it('displays no top border by default', () => {
    expect(listItem.hasClass('top-border--none')).toBe(true)
  })

  it('displays an active state bottom border by default', () => {
    expect(listItem.hasClass('bottom-border--active')).toBe(true)
  })

  it('displays small spacing by default', () => {
    expect(listItem.hasClass('top-bottom-padding--small')).toBe(true)
  })

  it('top border can be toggled off ', () => {
    wrapper.setProps({ topBorder: 'none' })
    const updatedListItem = wrapper.find('.pz-list__item')
    expect(updatedListItem.hasClass('top-border--none')).toBe(true)
  })

  it('bottom border can be toggled to inactive state ', () => {
    wrapper.setProps({ bottomBorder: 'inActive' })
    const updatedListItem = wrapper.find('.pz-list__item')
    expect(updatedListItem.hasClass('bottom-border--inactive')).toBe(
      true,
    )
  })

  it('spacing can be toggled to medium', () => {
    wrapper.setProps({ spacing: 'medium' })
    const updatedListItem = wrapper.find('.pz-list__item')
    expect(
      updatedListItem.hasClass('top-bottom-padding--medium'),
    ).toBe(true)
  })
})
