import React from 'react'
import propTypes from 'prop-types'
import cn from 'classnames'

/**
 * ListItem to be used in tandem with List Component.
 * Creates a ruled/bordered list with uniform borders and padding
 * when paired with List Component.
 *
 * While the default props, paired with List Component, will provide
 * a ruled list with black borders, the props in this component also
 * provide flexibility to construct lists with no borders, or construct
 * the list with just top borders on the ListItem, based on the engineer's
 * discretion.
 */

interface ListItemProps {
  children: React.ReactNode
  topBorder?: 'active' | 'inActive' | 'none'
  bottomBorder?: 'active' | 'inActive' | 'none'
  spacing?: 'small' | 'medium' | 'large' | 'none'
}

const ListItem = ({
  children,
  topBorder = 'none',
  bottomBorder = 'active',
  spacing = 'small',
}: ListItemProps) => {
  const listItemClasses = cn('pz-list__item', {
    'top-border--active': topBorder === 'active',
    'top-border--inactive': topBorder === 'inActive',
    'top-border--none': topBorder === 'none',

    'bottom-border--active': bottomBorder === 'active',
    'bottom-border--inactive': bottomBorder === 'inActive',
    'bottom-border--none': bottomBorder === 'none',

    'top-bottom-padding--small': spacing === 'small',
    'top-bottom-padding--medium': spacing === 'medium',
    'top-bottom-padding--large': spacing === 'large',
    'top-bottom-padding--none': spacing === 'none',
  })

  return <li className={listItemClasses}>{children}</li>
}

export default ListItem
