import React from 'react'
import { shallow } from 'enzyme'

import LoginBanner from './LoginBanner'

describe('SHARED: LOGIN BANNER', () => {
  it('should render text and no heading', () => {
    const props = { bannerText: 'click me', entitlement: 'anon' }
    const banner = shallow(<LoginBanner {...props} />)
    const bannerText = banner.find('.login-banner__text').text()
    expect(bannerText.includes('click me')).toBe(true)
  })

  it('should render text and heading', () => {
    const props = {
      bannerHeading: 'hello',
      bannerText: 'click me',
      entitlement: 'anon',
    }
    const banner = shallow(<LoginBanner {...props} />)
    const bannerHeading = banner.childAt(0).text()
    const bannerText = banner.childAt(1).text()
    expect(bannerHeading).toBe('hello')
    expect(bannerText.includes('click me')).toBe(true)
  })

  it('should not render if user is logged in', () => {
    const props = {
      bannerHeading: 'hello',
      bannerText: 'click me',
      entitlement: 'reg',
    }
    const banner = shallow(<LoginBanner {...props} />)
    expect(banner.html()).toBeFalsy()
  })

  it('should not render if user is subscriber', () => {
    const props = {
      bannerHeading: 'hello',
      bannerText: 'click me',
      entitlement: 'cr',
    }
    const banner = shallow(<LoginBanner {...props} />)
    expect(banner.html()).toBeFalsy()
  })
})
