import React from 'react'
import { createPortal } from 'react-dom'
import { useSelector, useDispatch } from 'react-redux'

import type { ModalManagerProps } from './modalTypes'

/*
  This ModalManager component is responsible for:

  1) Displaying the proper modal (which is in the redux store)
  2) Passing down a close function
  3) Mounted towards the top of the DOM tree
*/
export default function ModalManager({
  getIsClosing,
  getOpenModalName,
  modalMap,
  onClose,
  portalId,
  onRemove,
  ...otherProps
}: ModalManagerProps) {
  const portalRef = React.useRef(document.getElementById(portalId))
  const modalName = useSelector(getOpenModalName)
  const isClosing = useSelector(getIsClosing)
  const dispatch = useDispatch()

  const close = (isCancelled = false) =>
    dispatch(onClose(isCancelled))

  const remove = () => dispatch(onRemove())

  if (!modalName) {
    return null
  }

  const ModalComponent = modalMap[modalName]
  const modal = (
    <ModalComponent
      close={close}
      isClosing={isClosing}
      onRemove={remove}
      {...otherProps}
    />
  )

  if (!portalRef.current) {
    return modal
  }

  return createPortal(modal, portalRef.current)
}
