import React from 'react'
import { shallow } from 'enzyme'

import ModeToggle, { GRID_MODE, LIST_MODE } from './ModeToggle'

const buildSelector = (...classNames) => `.${classNames.join('.')}`
// const findListButton = toggle => toggle.find(buildSelector(styles.button, styles.toggle, styles.listView))
const findListButton = (toggle) =>
  toggle.find(
    buildSelector(
      'archive_button',
      'archive_toggle',
      'archive_list-view',
    ),
  )

const findGridButton = (toggle) =>
  toggle.find(
    buildSelector(
      'archive_button',
      'archive_toggle',
      'archive_grid-view',
    ),
  )

describe('ARCHIVE VIEWER / MODE TOGGLE', () => {
  let setMode

  beforeEach(() => {
    setMode = jest.fn()
  })

  test('active states', () => {
    const toggle = shallow(
      <ModeToggle mode={GRID_MODE} setMode={setMode} />,
    )

    expect(findListButton(toggle).hasClass('archive_active')).toBe(
      false,
    )
    expect(findGridButton(toggle).hasClass('archive_active')).toBe(
      true,
    )

    toggle.setProps({ mode: LIST_MODE })

    expect(findListButton(toggle).hasClass('archive_active')).toBe(
      true,
    )
    expect(findGridButton(toggle).hasClass('archive_active')).toBe(
      false,
    )
  })

  test('setting mode to list', () => {
    const toggle = shallow(
      <ModeToggle mode={GRID_MODE} setMode={setMode} />,
    )

    findListButton(toggle).simulate('click')

    expect(setMode).toHaveBeenCalledWith(LIST_MODE)
  })

  test('setting mode to grid', () => {
    const toggle = shallow(
      <ModeToggle mode={LIST_MODE} setMode={setMode} />,
    )

    findGridButton(toggle).simulate('click')

    expect(setMode).toHaveBeenCalledWith(GRID_MODE)
  })
})
