import React from 'react'
import cn from 'classnames'

type OfflineTickerProps = {
  dismissIcon?: React.ReactNode
}

const OfflineTicker = ({ dismissIcon }: OfflineTickerProps) => {
  const [isHidden, setHidden] = React.useState(
    window.navigator?.onLine || false,
  )

  React.useEffect(() => {
    const handleOnline = () => setHidden(true)
    const handleOffline = () => setHidden(false)

    window.addEventListener('online', handleOnline)
    window.addEventListener('offline', handleOffline)
    return () => {
      window.removeEventListener('online', handleOnline)
      window.removeEventListener('offline', handleOffline)
    }
  }, [])

  const className = cn('pz-offline-ticker', {
    'is-offline': !isHidden,
  })

  return (
    <div className={className} aria-hidden={isHidden}>
      You&apos;re offline! Progress may not be saved.
      {dismissIcon && (
        <span
          role="button"
          aria-label="Close"
          className="offline-ticker-dismiss"
          onClick={() => setHidden(true)}
        >
          {dismissIcon}
        </span>
      )}
    </div>
  )
}

export default OfflineTicker
