import React from 'react'
import { render, screen } from '@testing-library/react'

import { useUser } from 'user'

import ShortzMode from './index'

jest.mock('user', () => ({
  useUser: jest.fn(() => ({
    hasLoaded: false,
    shortzHasLoaded: false,
    userType: {
      isLoggedIn: false,
      inShortzMode: false,
    },
  })),
}))

describe('<ShortzMode />', () => {
  const renderComponent = () => {
    render(
      <ShortzMode loading={<p>page is loading</p>}>
        <p>shortz mode user</p>
      </ShortzMode>,
    )
  }

  it('renders a loading state if user data is not yet ready', () => {
    renderComponent()
    expect(screen.getByText(/page is loading/i)).toBeTruthy()
  })

  it('renders its children if user is a shortz mode user', () => {
    // @ts-ignore
    useUser.mockReturnValueOnce({
      hasLoaded: true,
      shortzHasLoaded: true,
      userType: {
        isLoggedIn: true,
        inShortzMode: true,
      },
    })

    renderComponent()
    expect(screen.getByText(/shortz mode user/i)).toBeTruthy()
  })

  it('renders the Error component if user is not a shortz mode user', () => {
    // mock navigationLinks for Error component
    window.navigationLinks = {
      login: '',
      subscribe: {
        key: '',
      },
    }

    // @ts-ignore
    useUser.mockReturnValueOnce({
      hasLoaded: true,
      shortzHasLoaded: true,
      userType: {
        isLoggedIn: true,
        inShortzMode: false,
      },
    })

    renderComponent()
    expect(
      screen.getByText(/this page no longer exists/i),
    ).toBeTruthy()
  })
})
