import React from 'react'

import { useUser } from 'user'

import Error from '../../../shared/components/Error/Error'

type Props = {
  children: React.ReactElement
  loading?: React.ReactElement
}

const ShortzMode = ({ children, loading = <></> }: Props) => {
  const user = useUser()

  const isLoading =
    !user.hasLoaded ||
    (user.userType.isLoggedIn && !user.shortzHasLoaded)

  if (isLoading) {
    return loading
  }

  if (user.userType.inShortzMode) {
    return children
  }

  return (
    <Error
      error={{ status: 404 }}
      navigationLinks={window.navigationLinks}
      documentTitle="Page Not Found - The New York Times"
    />
  )
}

export default ShortzMode
