import React from 'react'
import { render, screen } from '@testing-library/react'
import userEvent from '@testing-library/user-event'

import SkipNav from './index'

describe('SkipNav', () => {
  const renderSkipNav = () => {
    render(<SkipNav associatedSectionId="main" linkText="Skip ad" />)
  }

  it('should display skip nav in DOM', () => {
    renderSkipNav()
    expect(screen.getByText('Skip ad')).toBeTruthy()
  })

  it('should not be focused by default', () => {
    renderSkipNav()
    const skipAnchor = screen.getByText('Skip ad')
    expect(skipAnchor).not.toHaveFocus()
  })

  it('should gain focus with tab', async () => {
    renderSkipNav()
    const skipAnchor = screen.getByText('Skip ad')
    await userEvent.tab()
    expect(skipAnchor).toHaveFocus()
  })

  it('should jump to section id when selected', async () => {
    renderSkipNav()
    const skipAnchor = screen.getByText('Skip ad')

    await userEvent.click(skipAnchor)
    expect(window.location.hash).toEqual('#main')
  })
})
