import React from 'react'

import SkipNavComponent from './index'

const skipArgs = {
  associatedSectionId: 'main',
  linkText: 'Skip to content',
}

/**
 * The decorators added around the SkipNavTemplate
 * provide the context in which this component is
 * typically rendered at top level and pointing to a main content block
 */
const SkipNavTemplate = (args: {
  associatedSectionId: string
  linkText: string
}) => {
  const { associatedSectionId } = args

  return (
    <>
      <div
        style={{
          padding: '10px',
          position: 'relative',
        }}
      >
        <SkipNavComponent {...args} />
        <p>
          If you use the keyboard within this this area and tab to
          beginning, skip link navigation will show
        </p>
        <br />
        <p>
          Example Fake content with{' '}
          <a style={{ textDecoration: 'underline' }} href="blah">
            link outside of main content
          </a>
        </p>
        <div
          style={{
            backgroundColor: '#ccc',
            height: '200px',
            marginTop: '20px',
            padding: '20px',
          }}
          id={associatedSectionId}
        >
          <p>Main content here the skip link will jump to.</p>
          <p>
            Should focus next focusable element within this div when
            skip link is selected - which would be anchor below.
          </p>
          <p>
            <a style={{ textDecoration: 'underline' }} href="blah">
              I am a fake anchor.
            </a>
          </p>{' '}
        </div>
      </div>
    </>
  )
}

export const SkipNav = SkipNavTemplate.bind({})

export default {
  title: 'Design System / Skip Nav',
  component: SkipNav,
  args: skipArgs,
  parameters: {
    docs: {
      description: {
        component:
          'Please see component documentation in `<SkipNav>` for more context and background of full usage.',
      },
    },
  },
}
