import React from 'react'
import { ReactWrapper, mount } from 'enzyme'

import withToggle from '../Toggle'

describe('SHARED: TOGGLE', () => {
  let toggleAndDisplay: ReactWrapper
  let toggle: ReactWrapper

  beforeEach(() => {
    const Display = ({ isToggled }: { isToggled: boolean }) => (
      <div className="pz-display">
        {isToggled ? 'Selected Two' : 'Selected One'}
      </div>
    )
    const DisplayWithToggle = withToggle(Display, true)
    toggleAndDisplay = mount(
      <DisplayWithToggle labelA="One" labelB="Two" />,
    )
    toggle = toggleAndDisplay.find('.pz-toggle')
  })

  it('should mount', () => {
    expect(toggleAndDisplay.length).toBeTruthy()
  })

  it('should have default selection', () => {
    const options = toggle.find('.pz-toggle__option')
    const labelA = options.first()
    const labelB = options.last()
    expect(labelA.hasClass('selected')).toBe(false)
    expect(labelB.hasClass('selected')).toBe(true)
  })

  it('should display passed in component', () => {
    const display = toggleAndDisplay.find('.pz-display')
    expect(display.text()).toBe('Selected Two')
  })

  it('should toggle when unselected option is clicked', () => {
    const options = toggle.find('.pz-toggle__option')
    const labelA = options.first()
    const labelB = options.last()
    const display = toggleAndDisplay.find('.pz-display')
    const selectedClass = 'pz-toggle__option selected'
    labelB.simulate('click')
    expect(labelA.html().includes(selectedClass)).toBe(false)
    expect(labelB.html().includes(selectedClass)).toBe(true)
    expect(display.text()).toBe('Selected Two')
  })

  it('should not toggle when selected option is clicked', () => {
    const options = toggle.find('.pz-toggle__option')
    const labelA = options.first()
    const labelB = options.last()
    const display = toggleAndDisplay.find('.pz-display')
    const selectedClass = 'pz-toggle__option selected'
    labelA.simulate('click')
    expect(labelA.html().includes(selectedClass)).toBe(true)
    expect(labelB.html().includes(selectedClass)).toBe(false)
    expect(display.text()).toBe('Selected One')
  })
})
