import React, { useRef } from 'react'
import { createPortal } from 'react-dom'

import { isMobile } from 'responsive'
import {
  globalNavId,
  mobileToolbarId,
  showToolbarClass,
} from 'foundation'

type ToolbarAdapterProps = {
  children: React.ReactNode
  isHidden?: boolean
}

/**
 * A React-based alternative to mobileNavTools from foundation
 *
 * When on mobile, this will send your Toolbar through a portal
 * to the server-side-rendered Nav. You can trigger the animated
 * replacement of the Games logo via the isHidden prop.
 */
export default function ToolbarAdapter({
  children,
  isHidden,
}: ToolbarAdapterProps) {
  const mobilePortalRef = useRef(
    document.getElementById(mobileToolbarId),
  )

  const desktopPortalRef = useRef(
    document.getElementById('portal-game-toolbar'),
  )

  const globalNavRef = React.useRef(
    document.getElementById(globalNavId),
  )

  React.useEffect(() => {
    if (!isMobile) return

    // serves the same purpose as activate/deactivate in mobileNavTools
    if (isHidden) {
      globalNavRef.current?.classList.remove(showToolbarClass)
    } else {
      globalNavRef.current?.classList.add(showToolbarClass)
    }
  }, [isHidden])

  const portalElement = isMobile
    ? mobilePortalRef.current
    : desktopPortalRef.current

  if (!portalElement) {
    return <>{children}</>
  }

  return createPortal(children, portalElement)
}
