/* eslint-disable require-await, react/prop-types  */

import React from 'react'
import { mount } from 'enzyme'

import useAndroidBack from './use-android-back'

const AndroidBackComponent = () => {
  const callback = jest.fn()
  useAndroidBack(callback, [])
  return <h1>Foobar</h1>
}

describe('useAndroidBack hook', () => {
  let div
  const mockAddEventListener = jest.fn()
  const mockRemoveEventListener = jest.fn()

  function addDiv(
    isHybridWebView,
    gamesAppPlatformValue,
    addNativeBridge = true,
  ) {
    window.isHybridWebView = isHybridWebView
    window.gamesAppPlatform = gamesAppPlatformValue
    if (addNativeBridge) {
      window.NativeBridge = {
        addEventListener: mockAddEventListener,
        removeEventListener: mockRemoveEventListener,
      }
    }
    div = document.createElement('div')
    // prevents warnings about mounting component to the document element
    document.body.appendChild(div)
  }

  describe('in android hybrid', () => {
    beforeEach(() => {
      addDiv(true, 'android')
    })

    afterEach(() => {
      jest.clearAllMocks()
    })

    it('attaches event listener', async () => {
      mount(<AndroidBackComponent />, {
        attachTo: div,
      })
      expect(window.NativeBridge.addEventListener).toHaveBeenCalled()
    })
  })

  describe('in non-android hybrid', () => {
    beforeEach(() => {
      addDiv(true, 'foobar')
    })

    afterEach(() => {
      jest.clearAllMocks()
    })

    it('does not attach event listener', async () => {
      mount(<AndroidBackComponent />, {
        attachTo: div,
      })
      expect(
        window.NativeBridge.addEventListener,
      ).not.toHaveBeenCalled()
    })
  })

  describe('in non-hybrid webview', () => {
    beforeEach(() => {
      addDiv(false, 'android')
    })

    afterEach(() => {
      jest.clearAllMocks()
    })

    it('does not attach event listener', async () => {
      mount(<AndroidBackComponent />, {
        attachTo: div,
      })
      expect(
        window.NativeBridge.addEventListener,
      ).not.toHaveBeenCalled()
    })
  })

  describe('does not error in android hybrid webviews with un-initialized native bridge', () => {
    beforeEach(() => {
      addDiv(true, 'android', false)
    })

    afterEach(() => {
      jest.clearAllMocks()
    })

    it('does not try to attach event listener', async () => {
      expect(() => {
        mount(<AndroidBackComponent />, {
          attachTo: div,
        })
      }).not.toThrow(TypeError)
    })
  })
})
