import { useEffect } from 'react'

import {
  BridgeListener,
  BridgeListenerResponse,
  EVENT_GET_GAME_DATA,
} from '../../../shared/foundation/js/hybrid/commands'

type GameDataHybridEventProps = {
  analyticsPuzzleID: string
  game: 'spellingBee' | 'tiles' | 'wordle' | 'letterBoxed'
  puzzleID?: number | null
}

const useGameDataHybridEvent = ({
  analyticsPuzzleID,
  game,
  puzzleID,
}: GameDataHybridEventProps) => {
  useEffect(() => {
    if (window.isHybridWebView && window.NativeBridge) {
      const sendGameData: BridgeListener = (event) => {
        const gameResponse: BridgeListenerResponse = {}
        gameResponse[EVENT_GET_GAME_DATA] = {
          [game]: {
            analyticsPuzzleID,
            puzzleID,
          },
        }
        event.respondWith(gameResponse)
      }

      window.NativeBridge?.addEventListener(
        EVENT_GET_GAME_DATA,
        sendGameData,
      )

      return () => {
        window.NativeBridge?.removeEventListener(
          EVENT_GET_GAME_DATA,
          sendGameData,
        )
      }
    }
  }, [analyticsPuzzleID, puzzleID])
}

export default useGameDataHybridEvent
