import { useEffect } from 'react'

const HIDDEN_CLASS = 'xwd__hide-when-no-data'

const hideElement = (
  element: Element | undefined,
  hiddenClass: string,
) => {
  if (element) {
    element.classList.add(hiddenClass)
  }
}

const showElement = (
  element: Element | undefined,
  hiddenClass: string,
) => {
  if (element) {
    element.classList.remove(hiddenClass)
  }
}

const getByClass = (className: string): Element | undefined =>
  document.getElementsByClassName(className)[0]

// Calling this hook from a component will hide the Header and Toolbar
// while that component is mounted. Uses vanilla JS because the
// Header and Toolbar are outside the client-side React tree
export const useHiddenHeader = (hiddenClass = HIDDEN_CLASS) => {
  return useEffect(() => {
    const headerContainer = getByClass('pz-game-title-bar')
    const toolbarContainer = getByClass('pz-game-toolbar')

    hideElement(headerContainer, hiddenClass)
    hideElement(toolbarContainer, hiddenClass)

    return () => {
      showElement(headerContainer, hiddenClass)
      showElement(toolbarContainer, hiddenClass)
    }
  }, [])
}
