import { useEffect, useState } from 'react'

import LocalStore from '../LocalStore'

const useLocalStore = (key, initialValue) => {
  const [state, setState] = useState(null)

  useEffect(() => {
    let unmounted = false

    LocalStore.get(key).then((value) => {
      if (!unmounted) {
        if (value === null) {
          LocalStore.set(key, initialValue)
          setState(initialValue)
        } else {
          setState(value)
        }
      }
    })

    return () => {
      unmounted = true
    }
  }, [])

  return [
    state,
    (newValue) => {
      LocalStore.set(key, newValue)
      setState(newValue)
    },
  ]
}

export default useLocalStore
