import { useState } from 'react'

import {
  getFromLocalStorage,
  writeToLocalStorage,
} from '../../../shared/moogle/utils'

// When we want to persist to localStorage the fact that a user has
// hidden an element, like a banner or tooltip
export const usePersistHide = (
  localStorageKey: string,
  frequencyCap = 1,
) => {
  const initialValue = getFromLocalStorage<number>(localStorageKey, 0)
  const numTimesClosed = initialValue || 0
  const [isHidden, setHidden] = useState(
    numTimesClosed >= frequencyCap,
  )

  const hide = () => {
    if (!isHidden) {
      writeToLocalStorage(localStorageKey, numTimesClosed + 1)
    }
    setHidden(true)
  }

  return { isHidden, hide }
}
