import { useEffect } from 'react'

/**
 * Since the Games sale banner (GameSalesBanners.tsx) is rendered on the server, it cannot
 * access the hybrid subscribe command (window.NativeBridge.gamesAuthenticateUser('subscribe')).
 *
 * As a solution, `useSaleBannerHybridSubscribe` runs on the client and checks if the user is hybrid. If they are,
 * the preexisting `href` is replaced by `#` and the hybrid subscribe command is added as the banner's onClick handler.
 */

function setHybridAttributes(elem: HTMLElement | null) {
  elem?.setAttribute('href', '#')
  elem?.addEventListener('click', (e) => {
    e.preventDefault()
    window.NativeBridge?.gamesAuthenticateUser('subscribe')
  })
}

function useSaleBannerHybridSubscribe() {
  useEffect(() => {
    const bannerElem = document.getElementById('games-sale-banner-a')
    const cacheSafeBannerElem = document.getElementById(
      'cache-safe-games-sale-banner-a',
    )

    if (window.isHybridWebView && window.NativeBridge) {
      setHybridAttributes(bannerElem)
      setHybridAttributes(cacheSafeBannerElem)
    }
  }, [])
}

export default useSaleBannerHybridSubscribe
