import React from 'react'
import { mount } from 'enzyme'

import useScreenSizeWarning from './use-screen-size-warning'

jest.mock('./use-window-size', () => ({
  __esModule: true,
  default: jest.fn(() => ({
    winHeight: 900,
    winWidth: 600,
  })),
}))

// eslint-disable-next-line react/prop-types
const MockComponent = ({ mockChecker }) => {
  const showWarning = useScreenSizeWarning(mockChecker)

  if (showWarning) {
    return <div id="warning" />
  }

  return <div id="not-a-warning" />
}

describe('HOOK: useScreenSizeWarning', () => {
  it('uses a custom checker and returns true when a warning is needed', () => {
    const mockChecker = ({ winHeight }) => {
      if (winHeight > 600) {
        return true
      }

      return false
    }

    const wrapper = mount(<MockComponent mockChecker={mockChecker} />)

    expect(wrapper.find('#warning')).toHaveLength(1)
  })

  it('uses a custom checker and returns false when screen size is valid', () => {
    const mockChecker = ({ winWidth }) => {
      if (winWidth > 900) {
        return true
      }

      return false
    }

    const wrapper = mount(<MockComponent mockChecker={mockChecker} />)

    expect(wrapper.find('#warning')).toHaveLength(0)
  })
})
