import useWindowSize, { WindowSize } from './use-window-size'

/**
 * The checker should return whether or not to show the screen size warning
 * If the screen size is invalid and a warning is needed, return true.
 * If the screen size is valid, return false.
 */
export type CheckScreenSize = (arg: WindowSize) => boolean

/**
 * Pass in a custom checker to validate based on a user's screen size
 */
const useScreenSizeWarning = (checkDimensions: CheckScreenSize) => {
  const { winHeight, winWidth } = useWindowSize()

  return checkDimensions({
    winHeight,
    winWidth,
  })
}

export const checkScreenSize: CheckScreenSize = ({
  winHeight,
  winWidth,
}) => {
  const aspectRatio = winWidth / winHeight
  const flatTablet = winHeight <= 650 && aspectRatio > 1.8
  const tinyPhone = winHeight < 400 && aspectRatio > 1

  return flatTablet || tinyPhone
}

export default useScreenSizeWarning
