import { useEffect, useState } from 'react'

import { debounce } from '../../helpers/gameUtils'

export type WindowSize = {
  winHeight: number
  winWidth: number
}

const useWindowSize = (): WindowSize => {
  const [windowSize, setWindowSize] = useState({
    winHeight: window.innerHeight,
    winWidth: window.innerWidth,
  })

  useEffect(() => {
    const handleResize = debounce(() => {
      setWindowSize({
        winHeight: window.innerHeight,
        winWidth: window.innerWidth,
      })
    }, 50)

    window.addEventListener('resize', handleResize)

    return () => window.removeEventListener('resize', handleResize)
  }, [])

  return windowSize
}

export default useWindowSize
