import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import { isPlayTab } from '../../../shared/foundation/js/hybrid/detection'

export const sbProps = {
  header: 'Try A Different Game',
  title: 'Spelling Bee',
  text: 'Tackle <strong>today&apos;s puzzle.</strong>',
  containerClassNames: ['sb'],
  link: `/puzzles/spelling-bee${
    isPlayTab() ? '?embed=ios&entry=playTab' : ''
  }`,
}

const ModalCard = ({
  header,
  title,
  text,
  containerClassNames,
  link,
  clickHandler,
  fontColor,
}) => (
  <a
    href={link}
    onClick={clickHandler}
    className={cn('modal-card', containerClassNames)}
  >
    <div
      className="modal-card__header"
      style={{ color: fontColor || '#000' }}
    >
      {header}
    </div>
    <div className="modal-card__inset">
      <div className="modal-card__icon" />
      <div className="modal-card__info">
        <div className="modal-card__title">{title}</div>
        <div
          dangerouslySetInnerHTML={{ __html: text }}
          className="modal-card__text"
        />
      </div>
      <div className="modal-card__arrow" />
    </div>
  </a>
)

ModalCard.propTypes = {
  header: pt.string.isRequired,
  title: pt.string.isRequired,
  text: pt.string.isRequired,
  containerClassNames: pt.arrayOf(pt.string).isRequired,
  link: pt.string.isRequired,
  clickHandler: pt.func,
  fontColor: pt.string,
}

export default ModalCard
