# Modal System Docs

## Intro

### This modal system comprises code in 
  1. ../helpers/createModalSystem which is a vanilla JS system for managing opening and closing modals in a framework agnostic way.
  1. ./setupModals.js which provides default configurations and any other boilerplate to allow high level api calls to setup the above system
  1. ./index.js contains a thin react wrapper which renders the modals, attaches open/close handlers

## Setup
  1. Create modals folder your project with an index.js file as it's root
  1. In this folder, add React components that reflect your app's needs using the React.Fragment wrapper.  An example is included below.
   ```javascript
    import React from 'react'

    const ModalHelp = () => (
      <React.Fragment>
        <h3 className="pzm-modal__title">Temporary Placeholder</h3>
      </React.Fragment>
    )

    export default ModalHelp
  ```
  3. Import all misc. modals into the index.js file and add them to a models configuration object
   
   ```javascript
   
   export const modals = [
    { name: 'quit', meta: { Content: ModalQuit } },
    { name: 'help', meta: { Content: ModalHelp } },
  ]

  ```
  
  4. Create the modalSystem using the setupModal function included in the respective file in this folder and export it as well.
  5. In whatever file is rendering the modals, import the modalSystem created above as well as the modals component included in this folder. Add the modals component to the render function, passing the modalSystem as a modalSystem property

  ```javascript

    import { modalSystem } from './modals/index'
    import Modals from '../../shared/modals/index'

    const Layout = ({ ...props }) => {
      return (
          <Modals modalSystem={modalSystem} data={{ ... }} />
      );
    }

  ```