import React from 'react'
import { mount } from 'enzyme'

import createMomentSystem from '../index'
import { setUpMoments } from '../momentHelpers'

jest.mock('react-dom', () => ({
  createPortal: (component) => component,
}))

jest.mock('../momentHelpers', () => ({
  transition: () => {},
  reanimateMoment: jest.fn(),
  setUpMoments: jest.fn(),
  putOnStage: jest.fn(),
  CLASS_ANIMATION: 'animation-class',
}))

const WelcomeContent = () => <div className="welcome">Welcome</div>

const moments = [
  {
    name: 'welcome',
    Content: WelcomeContent,
  },
]

const momentObj = createMomentSystem(moments)
const { Moments, momentSystem } = momentObj

describe('MOMENTS: CREATE MOMENT SYSTEM', () => {
  it('should return Moments component and system object', () => {
    expect(momentObj.hasOwnProperty('Moments')).toBe(true)
    expect(momentObj.hasOwnProperty('momentSystem')).toBe(true)
  })

  it('should call setup moments post Moment load', () => {
    mount(<Moments />)
    expect(setUpMoments).toHaveBeenCalled()
  })

  it('Moments component should render passed in content in frame div', () => {
    const momentsEl = mount(<Moments />)

    // should render frame
    const frame = momentsEl.find('.pz-moment__frame')

    // should add hook to frame using name of moment
    expect(frame.prop('id')).toBe('js-hook-pz-moment__welcome')

    // should render passed in content as child of frame
    expect(frame.children()).toHaveLength(1)

    // should render expected content
    const welcome = momentsEl.find('.welcome')
    expect(welcome.prop('className')).toBe('welcome')
  })

  it('Moments component should provide contentProps to Content components in Moments', () => {
    const func = () => {}

    const momentsEl = mount(
      <Moments contentProps={{ b: true, s: 'apples', f: func }} />,
    )

    const welcome = momentsEl.find('WelcomeContent')
    expect(welcome.prop('b')).toBe(true)
    expect(welcome.prop('s')).toBe('apples')
    expect(welcome.prop('f')).toBe(func)
  })

  it('system object should have transition method and sequencing class', () => {
    expect(momentSystem.hasOwnProperty('transition')).toBe(true)
    expect(momentSystem.hasOwnProperty('sequencingClass')).toBe(true)
  })
})
