import React from 'react'
import propTypes from 'prop-types'
import classnames from 'classnames'

import {
  CloseButton,
  CloseButtonWithText,
  Icon,
  Title,
  Description,
  BodyText,
  Button,
  Wrapper,
} from './subcomponents'

const Congrats = ({ children, game }) => {
  let closeButton
  if (game.close) {
    closeButton = game.closeModalText ? (
      <CloseButtonWithText
        closeText={game.closeModalText}
        action={game.close.action}
      />
    ) : (
      <CloseButton action={game.close.action} />
    )
  }

  return (
    <Wrapper bgColor={game.bgColor}>
      <div className="pz-moment__container alternate shorten-top-whitespace">
        {closeButton}
        <div className="pz-moment__content sequence-animation">
          {children || <Icon icon={game.icon} size="large" />}
          <Title text={game.title} size={game.titleSize} />
          <Description {...game.description} />
          {game.celebrationMessage}
          <div
            className={classnames(
              'pz-moment__button-wrapper',
              game.desktopButtonOrder,
            )}
          >
            {(game.buttons || []).map((props, i) => (
              <Button {...props} key={i} />
            ))}
          </div>
          {game.bodyText && <BodyText>{game.bodyText}</BodyText>}
        </div>
      </div>
    </Wrapper>
  )
}

Congrats.propTypes = {
  children: propTypes.node,
  game: propTypes.shape({
    icon: propTypes.string,
    title: propTypes.string,
    titleSize: propTypes.string,
    screen: propTypes.oneOf(['welcome', 'congrats']),
    celebrationMessage: propTypes.node,
    closeModalText: propTypes.string,
    description: propTypes.shape({
      variant: propTypes.oneOf(['default', 'small']),
      text: propTypes.string,
    }),
    desktopButtonOrder: propTypes.oneOf(['default', null]),
    buttons: propTypes.arrayOf(
      propTypes.shape({
        color: propTypes.oneOf(['primary', 'secondary']),
        variant: propTypes.oneOf([
          'default',
          'wide',
          'extra-wide',
          'extra-extra-wide',
        ]),
        icon: propTypes.oneOf(['none', 'locked']),
        text: propTypes.node,
        action: propTypes.func,
        isEmphasizedNew: propTypes.bool,
      }),
    ),
    bodyText: propTypes.node,
    bgColor: propTypes.string,
    close: propTypes.shape({
      action: propTypes.func,
    }),
  }),
}

export default Congrats
