import React from 'react'
import pt from 'prop-types'

import colors from '../../colors/colors'

import LoadingBar from './LoadingBar'
import {
  HybridBackButton,
  Icon,
  Title,
  Description,
} from './subcomponents'

const Loader = (props) => {
  const {
    icon,
    title,
    bgColor = '$gray3',
    description,
    isActive,
    ...loadProps
  } = props

  React.useEffect(() => {
    /* set this so that it works like other moments */
    const loadingParent = document.getElementById(
      'js-hook-pz-moment__loading',
    )
    loadingParent.style['background-color'] = colors[bgColor]
  }, [])

  return (
    <div className="pz-loader-container">
      <HybridBackButton />
      <Icon icon={icon} size="large" />
      <Title text={title} size="large" />
      <Description text={description} />
      {isActive && <LoadingBar {...loadProps} />}
    </div>
  )
}

Loader.propTypes = {
  momentSystem: pt.shape({
    transition: pt.func,
    sequencingClass: pt.string,
  }),
  icon: pt.string,
  title: pt.string,
  bgColor: pt.oneOf(Object.keys(colors)),
  description: pt.string,
  isActive: pt.bool,
}

export default Loader
