import React, { useState, useEffect } from 'react'
import pt from 'prop-types'

const LoadingBar = ({
  momentSystem,
  transitionTo,
  barBgColor = 'rgba(0, 0, 0, 0.2)',
  barColor = '#FFF',
  hasLoaded = false,
}) => {
  const [fill, setFill] = useState(10)

  /* For "Can't perform a React state update on an unmounted component" error */
  const [stid, setStid] = useState(null)

  useEffect(() => {
    if (!hasLoaded) {
      if (fill <= 100) {
        const lastTimeout = setTimeout(() => {
          setFill(fill + Math.random() * 20)
        }, 30 + Math.random() * 150)
        setStid(lastTimeout)
      }
    } else {
      clearTimeout(stid)
      momentSystem.transition('loading', transitionTo)
    }
  }, [fill, hasLoaded])

  return (
    <div
      className="pz-loader"
      id="pz-loading-bar"
      style={{ background: barBgColor }}
    >
      <div
        className="pz-loader__fill"
        style={{
          background: barColor,
          right: `${Math.max(100 - fill, 0)}%`,
        }}
      />
    </div>
  )
}

LoadingBar.propTypes = {
  momentSystem: pt.shape({
    transition: pt.func,
    sequencingClass: pt.string,
  }),
  transitionTo: pt.string.isRequired,
  barBgColor: pt.string,
  barColor: pt.string,
  hasLoaded: pt.bool,
}

export default LoadingBar
