import React from 'react'

import {
  Icon,
  Title,
  Wrapper,
  CloseButton,
  Description,
  ButtonGroup,
  CloseButtonWithText,
} from './subcomponents'

export type RevealedProps = {
  title: string
  icon?: string | null
  intro?: {
    text: string
    variant?: string
  } | null
  description: {
    text: string
    variant?: string
  }
  buttons: {
    text: string
    action: () => void
    icon?: string
    color?: string
    variant?: string
    isEmphasizedNew?: boolean
  }[]
  bgColor: string
  close?: {
    action: () => void
    text?: string
  }
}

const Revealed = ({
  close,
  bgColor,
  title,
  intro,
  icon,
  description,
  buttons,
}: RevealedProps) => {
  let closeButton
  if (close) {
    closeButton = close.text ? (
      <CloseButtonWithText
        closeText={close.text}
        action={close.action}
      />
    ) : (
      <CloseButton action={close.action} />
    )
  }

  return (
    <Wrapper bgColor={bgColor}>
      <div className="pz-moment__container alternate">
        {closeButton}
        <div
          className="pz-moment__content sequence-animation"
          id="revealed"
        >
          {intro && <Description {...intro} />}
          {icon && <Icon icon={icon} />}
          <Title text={title} size="large" />
          <Description {...description} />
          <ButtonGroup buttons={buttons} />
        </div>
      </div>
    </Wrapper>
  )
}

export default Revealed
