import React from 'react'
import propTypes from 'prop-types'

import {
  HybridBackButton,
  Icon,
  Title,
  Description,
  Date,
  Editor,
  InfoText,
  Wrapper,
  Promo,
  Meta,
  ButtonGroup,
} from './subcomponents'

const Welcome = ({ game }) => (
  <Wrapper bgColor={game.bgColor}>
    <div className="pz-moment__container alternate">
      {/* Only pass tracking data if we have a game prop */}
      <HybridBackButton
        trackData={
          game.game
            ? {
                elementName: game.game,
                moduleLabel: 'welcome',
              }
            : undefined
        }
      />

      <div className="pz-moment__content sequence-animation">
        <Icon icon={game.icon} size="medium" />
        <Title text={game.title} size="large" />
        <Description {...game.description} />
        <Meta text={game.meta} />
        {(game.buttonGroups || []).map(
          ({ buttons, header, desktopButtonOrder }, i) => (
            <ButtonGroup
              key={i}
              buttons={buttons}
              header={header}
              order={desktopButtonOrder}
            />
          ),
        )}
        <p className="pz-moment__info">
          <Date date={game.date} />
          <Editor editor={game.editor} />
          {game.infoText && <InfoText>{game.infoText}</InfoText>}
        </p>
        <Promo promo={game.promo} />
      </div>
    </div>
  </Wrapper>
)

Welcome.propTypes = {
  game: propTypes.shape({
    game: propTypes.string,
    icon: propTypes.string,
    title: propTypes.string,
    description: propTypes.shape({
      text: propTypes.string,
    }),
    buttonGroups: propTypes.arrayOf(
      propTypes.shape({
        buttons: propTypes.arrayOf(
          propTypes.shape({
            text: propTypes.string,
            action: propTypes.func,
          }),
        ),
        header: propTypes.oneOfType([
          propTypes.node,
          propTypes.string,
        ]),
        desktopButtonOrder: propTypes.string || null,
      }),
    ),
    date: propTypes.string,
    editor: propTypes.string,
    infoText: propTypes.oneOfType([propTypes.string, propTypes.node]),
    bgColor: propTypes.string,
    promo: propTypes.string,
    meta: propTypes.string,
  }),
}

export default Welcome
