import React from 'react'
import propTypes from 'prop-types'

import {
  HybridBackButton,
  Icon,
  Title,
  Description,
  ButtonGroup,
  Date,
  Editor,
  Wrapper,
} from './subcomponents'

const WelcomeBack = ({ game }) => (
  <Wrapper bgColor={game.bgColor}>
    <div className="pz-moment__container alternate">
      <HybridBackButton />
      <div className="pz-moment__content sequence-animation">
        <Icon icon={game.icon} size="small" />
        <Title text={game.title} size="small" />
        <Title text="Welcome Back" size="large" />
        <Description {...game.description} />
        <div className="pz-moment__button-wrapper">
          {(game.buttonGroups || []).map((props, i) => (
            <ButtonGroup {...props} key={i} />
          ))}
        </div>
        <p className="pz-moment__info">
          <Date date={game.date} />
          <Editor editor={game.editor} />
        </p>
      </div>
    </div>
  </Wrapper>
)

WelcomeBack.propTypes = {
  game: propTypes.shape({
    icon: propTypes.string,
    title: propTypes.string,
    description: propTypes.shape({
      variant: propTypes.oneOf(['default', 'small']),
      text: propTypes.string,
    }),
    buttonGroups: propTypes.arrayOf(
      propTypes.shape({
        buttons: propTypes.arrayOf(
          propTypes.shape({
            color: propTypes.oneOf(['primary', 'secondary']),
            variant: propTypes.oneOf([
              'default',
              'wide',
              'extra-wide',
            ]),
            icon: propTypes.oneOf(['none', 'locked']),
            text: propTypes.node,
            action: propTypes.func,
          }),
        ),
      }),
    ),
    date: propTypes.string,
    editor: propTypes.string,
    bgColor: propTypes.string,
  }),
}

export default WelcomeBack
