import React from 'react'

import {
  HybridBackButton,
  Icon,
  Title,
  ButtonGroup,
  Description,
  Date,
  Editor,
  Wrapper,
} from './subcomponents'

export type WelcomePastProps = {
  bgColor: string
  icon: string
  subtitle: string
  title: string
  date: string
  editor?: string
  description: {
    text: string
    variant?: ['default', 'small', 'extra-small']
    font?: string
  }
  buttons: {
    text: string
    action: () => void
    icon?: string
    color?: string
    variant?: string
    isEmphasizedNew?: boolean
  }[]
  buttonsStyle?: string
}

const WelcomePast = ({
  bgColor,
  icon,
  subtitle,
  title,
  date,
  description,
  buttons,
  buttonsStyle,
  editor,
}: WelcomePastProps) => (
  <Wrapper bgColor={bgColor}>
    <div className="pz-moment__container alternate">
      <HybridBackButton />
      <div className="pz-moment__content sequence-animation">
        <Icon icon={icon} size="small" />
        <Title text={subtitle} font="franklin" size="extra-small" />
        <Title text={title} size="large" />
        <Date date={date} />
        <Description {...description} variant="extra-small" />
        <div className="pz-moment__button-wrapper">
          <ButtonGroup buttons={buttons} order={buttonsStyle} />
        </div>
        {editor && (
          <p className="pz-moment__info">
            <Editor editor={editor} />
          </p>
        )}
      </div>
    </div>
  </Wrapper>
)

export default WelcomePast
