import React from 'react'
import { mount, shallow } from 'enzyme'

import Loader from '../Loader'

jest.mock('../LoadingBar', () => () => (
  <div className="loading-bar" />
))

const props = {
  icon: 'spelling-bee',
  title: 'Spelling Bee',
  description: 'Play here',
  bgColor: '$spelling-bee-gold', // #f7da21
}

describe('MOMENTS: LOADER', () => {
  const { getElementById } = document

  beforeAll(() => {
    document.getElementById = jest.fn()
    document.getElementById.mockImplementation(() => ({ style: {} }))
  })

  afterAll(() => {
    document.getElementById = getElementById
  })

  it('should render', () => {
    const loader = shallow(<Loader {...props} />)
    const frame = loader.find('.pz-loader-container')
    expect(frame).toHaveLength(1)
  })

  it('should render icon', () => {
    const loader = mount(<Loader {...props} />)
    const icon = loader.find('.spelling-bee')
    expect(icon).toHaveLength(1)
  })

  it('should render title', () => {
    const loader = mount(<Loader {...props} />)
    const title = loader.find('.pz-moment__title')
    expect(title.text()).toBe('Spelling Bee')
  })

  it('should render description', () => {
    const loader = mount(<Loader {...props} />)
    const description = loader.find('.pz-moment__description')
    expect(description.text()).toBe('Play here')
  })

  it('should render LoadingBar if active', () => {
    const loader = mount(<Loader {...props} isActive />)
    const loadingBar = loader.find('.loading-bar')
    expect(loadingBar).toHaveLength(1)
  })

  it('should not render LoadingBar if not active', () => {
    const loader = mount(<Loader {...props} />)
    const loadingBar = loader.find('.loading-bar')
    expect(loadingBar).toHaveLength(0)
  })
})
