import React from 'react'

import WelcomeComponent from '../Welcome'

import useAnimation from './useAnimation'

const colorOptions = [
  '$sudoku-orange',
  '$vertex-turquoise',
  '$spelling-bee-gold',
  '$letter-boxed-red',
  '$tiles-green',
]

const iconOptions = [
  'spelling-bee',
  'spelling-bee-smarty',
  'spelling-bee-queen',
  'spelling-bee-loved',
  'letter-boxed',
  'tiles',
  'vertex',
  'sudoku',
]

const exampleButtonGroups = {
  oneGroup: [
    {
      header: 'A single group of buttons',
      buttons: [
        { text: 'Play' },
        { text: 'Login' },
        { text: 'Subscribe' },
      ],
    },
  ],
  twoGroups: [
    {
      header: 'A moment can have one button group',
      buttons: [{ text: 'One button' }],
    },
    {
      header: 'Or many groups',
      buttons: [
        { text: 'Two button' },
        { text: 'Three button' },
        { text: 'Ah ah ah 🧛' },
      ],
    },
  ],
  singleButton: [
    {
      header: 'A group with a single button',
      buttons: [{ text: 'Play' }],
    },
  ],
  manyButtons: [
    {
      header: 'A group with many buttons',
      buttons: [
        { text: 'One button' },
        { text: 'Two button' },
        { text: 'Three button' },
        { text: 'Ah ah ah 🧛' },
      ],
    },
  ],
  noHeader: [
    {
      buttons: [
        { text: 'Button groups' },
        { text: "don't necessarily" },
        { text: 'need a header' },
      ],
    },
  ],
}

export const Welcome = ({ promo, description, ...args }) => {
  const id = 'storybook-welcome'
  const { icon } = args
  const promoText = promo ? 'oxford' : ''
  const descriptionObj = { text: description }

  useAnimation(id, icon)

  return (
    <div className="pz-moment__frame on-stage" id={id}>
      <WelcomeComponent
        game={{
          promo: promoText,
          description: descriptionObj,
          ...args,
        }}
      />
    </div>
  )
}

export default {
  title: 'Design System/Moments/Welcome',
  argTypes: {
    bgColor: {
      options: colorOptions,
      control: { type: 'select' },
    },
    icon: {
      options: iconOptions,
      control: { type: 'select' },
    },
    buttonGroups: {
      options: Object.keys(exampleButtonGroups),
      mapping: exampleButtonGroups,
      control: {
        type: 'select',
        labels: {
          oneGroup: 'One Group',
          twoGroups: 'Two Groups',
          singleButton: 'Single Button',
          manyButtons: 'Many Buttons',
          noHeader: 'Buttons without Header',
        },
      },
    },
    promo: { control: 'boolean' },
    description: { control: 'text' },
  },
  args: {
    title: 'Test Game',
    bgColor: '$spelling-bee-gold',
    icon: 'tiles',
    description: "Describe the game you're about to play",
    meta: 'Some additional metadata about the game',
    buttonGroups: exampleButtonGroups.oneGroup,
    date: 'Thursday, February 31st',
    editor: 'Sam Ezersky',
    infoText:
      'Less structured info about the game, if we need something other than date and editor',
    promo: true,
  },
}
