import createHybridNewsLink from '../createHybridNewsLink'

describe('SHARED: CREATE HYBRID NEWS LINK', () => {
  beforeEach(() => {
    window.newsreaderAppPlatform = ''
    window.isHybridWebView = false
  })

  it('should return the link passed in if not in hybrid webview in news app', () => {
    const link = 'www.nytimes.com/puzzles/spelling-bee'
    const newLink = createHybridNewsLink(link)
    expect(newLink).toBe(link)
  })

  it('should return link with hybrid news param if in hybrid webview in news app ', () => {
    window.newsreaderAppPlatform = 'ios'
    window.isHybridWebView = true
    const link = 'www.nytimes.com/puzzles/spelling-bee'
    const newLink = createHybridNewsLink(link)
    expect(newLink).toBe(`${link}?hybrid=news`)
  })

  it('should return link with other params plus hybrid news param if link already has params and in hybrid webview in news app ', () => {
    window.newsreaderAppPlatform = 'ios'
    window.isHybridWebView = true
    const link = 'www.nytimes.com/puzzles/spelling-bee?ios=embed'
    const newLink = createHybridNewsLink(link)
    expect(newLink).toBe(`${link}&hybrid=news`)
  })
})
