/* eslint-disable no-console, max-len */

const noop = (...args) => {}

/* CLIENT-SIDE LOGGING */
const logger = {
  log: noop,
  info: noop,
  warn: noop,
  error: noop,
  dir: noop,
  time: noop,
  timeEnd: noop,
  trace: noop,
  assert: noop,
  debug: noop,
  table: noop,
  group: noop,
  groupCollapsed: noop,
  groupEnd: noop,
  clear: noop,
  count: noop,
  timeStamp: noop,
}

/**
 * Creates a logger for each console method
 * Allows us to suppress certain methods if we ever need
 */
Object.keys(logger).forEach((key) => {
  /**
   * A logger that runs a provided function or
   * runs the default console[key] (console.log, console.error, etc...)
   * function with the provided message
   * @param  {(Function|string)} out
   */
  const proxyLogger = (...out) => {
    const message = typeof out === 'function' ? out() : out
    console[key](...message)
  }

  const shouldSuppress = false

  if (!shouldSuppress) {
    logger[key] = proxyLogger
  }
})

export default logger
