export type DateString = `${number}-${number}-${number}`

export const toUTCDateStringYMD = (fullDate: Date) => {
  const splitDate = fullDate
    .toLocaleString('en-us', {
      timeZone: 'UTC',
      year: 'numeric',
      month: '2-digit',
      day: '2-digit',
    })
    .split('/')

  // return date range as YYYY-DD-MM
  return `${splitDate[2]}-${splitDate[0]}-${splitDate[1]}`
}

export const getUTCDateString = (
  dateToConvert?: string | undefined,
): string => {
  const date: Date = dateToConvert
    ? new Date(dateToConvert)
    : new Date()

  // returns string as example formatted:
  // Day, M/D/YYY, UTC
  return date.toLocaleDateString('en-US', {
    timeZone: 'UTC',
    timeZoneName: 'short',
    weekday: 'short',
    year: 'numeric',
    month: 'numeric',
    day: 'numeric',
  })
}

export const getUTCShortPuzzleDateString = (date = new Date()) => {
  // returns string as DD/YY
  return date.toLocaleDateString('en-US', {
    timeZone: 'UTC',
    month: 'numeric',
    day: 'numeric',
  })
}

// convert `-` formatted date to separator with `/` to ensure
// conversion is correct for getting full day
export const getSlashFormattedPrintDate = (printDate: DateString) => {
  return printDate.replace(/-/g, '/')
}
