import makeCancelable from './makeCancelable'

const goodPromise = (ms) => {
  return new Promise((resolve) => {
    setTimeout(() => resolve(ms), ms)
  })
}

const badPromise = () => {
  return new Promise((_, reject) => {
    reject(new Error('should reject'))
  })
}

describe('makeCancelable function', () => {
  jest.useFakeTimers()

  it('returns an object with promise and cancel properties', () => {
    const { promise, cancel } = makeCancelable(goodPromise(100))

    expect(promise).toBeInstanceOf(Promise)
    expect(cancel).toBeInstanceOf(Function)
  })

  it('resolves an uncancled promise with a value', async () => {
    const { promise } = makeCancelable(goodPromise(100))
    jest.runAllTimers()

    const value = await promise
    expect(value).toEqual(100)
  })

  it('rejects an uncanceled promise with an error', async () => {
    const { promise } = makeCancelable(badPromise())

    try {
      await promise
    } catch (err) {
      expect(err.message).toEqual('should reject')
    }
  })

  it('rejects a canceled promise with an isCanceled property', async () => {
    const { promise, cancel } = makeCancelable(goodPromise(100))
    cancel()
    jest.runAllTimers()

    try {
      await promise
    } catch (err) {
      expect(err).toMatchObject({ isCanceled: true })
    }
  })

  it('rejects an uncanceled promise with an isCanceled property', async () => {
    const { promise, cancel } = makeCancelable(badPromise())
    cancel()
    jest.runAllTimers()

    try {
      await promise
    } catch (err) {
      expect(err).toMatchObject({ isCanceled: true })
    }
  })
})
