import React from 'react'
import { render, screen, waitFor } from '@testing-library/react'

import { xhr, getGameData } from 'foundation'

import { mockLatestsState } from '../../spelling-bee/js/__tests__/mockLatestsState'

import Layout from './Layout'

jest.mock('foundation', () => ({
  env: { account: 'https://myaccount.nytimes.com' },
  getGameData: () => {
    // eslint-disable-next-line global-require
    return require('./mockGameData').mockGameData
  },
  xhr: {
    get: jest.fn(),
  },
}))

describe('Layout', () => {
  beforeEach(() => jest.resetAllMocks())

  it('renders a hero card', async () => {
    // @ts-ignore
    xhr.get.mockReturnValue({ states: mockLatestsState })

    const { pastPuzzles } = getGameData()
    render(<Layout pastPuzzles={pastPuzzles} />)

    await waitFor(() => {
      const heroCard = screen.getByText('Spelling Bee')
      const blurb = screen.getByText(
        'Make as many words as you can with 7 letters.',
      )
      expect(heroCard).toBeInTheDocument()
      expect(blurb).toBeInTheDocument()
    })
  })

  it('renders past puzzles cards', async () => {
    // @ts-ignore
    xhr.get.mockReturnValue({ states: mockLatestsState })

    const { pastPuzzles } = getGameData()
    render(<Layout pastPuzzles={pastPuzzles} />)

    await waitFor(async () => {
      // // given the mock data assert correct text is displayed
      const header = screen.getByText('Past Puzzles')
      const text = screen.getByText('June 11 - June 5')
      // screen.debug()
      const sundayPuzzle = await screen.findAllByText('Sunday')

      expect(header).toBeInTheDocument()
      expect(text).toBeInTheDocument()
      expect(sundayPuzzle).toHaveLength(1)
    })
  })
})
