import React, { useEffect, useState } from 'react'

import { useUser } from '../../../shared/user'
import type { SpellingBeeGameData } from '../../spelling-bee/js/store/game/game.state'
import {
  CardProgressMap,
  getProgressMap,
  getRankStats,
} from '../../spelling-bee/js/store/api/api.selectors'
import { fetchMultiStates } from '../../spelling-bee/js/store/api/api.utils'
import { getActivePuzzleIds } from '../../spelling-bee/js/store/utils'
import useSaleBannerHybridSubscribe from '../../shared/hooks/use-sale-banner-hybrid-subscribe'

import styles from './Layout.module.scss'
import TodayHero from './TodayHero'
import PastPuzzlesSections from './PastPuzzlesSections'

export default ({
  pastPuzzles,
}: {
  pastPuzzles: NonNullable<SpellingBeeGameData['pastPuzzles']>
}) => {
  const { userType, hasLoaded: hasUserLoaded } = useUser()
  const { hasXwd } = userType

  const { printDate, displayDate, editor, id } = pastPuzzles.today
  const todayIdString = id.toString()

  useSaleBannerHybridSubscribe()

  const [progressMap, setProgressMap] = useState<CardProgressMap>({})
  const [isProgressLoading, setProgressLoading] = useState(true)

  useEffect(() => {
    const getNewStats = async () => {
      try {
        const puzzleIds = getActivePuzzleIds(pastPuzzles)
        const states = await fetchMultiStates(puzzleIds)
        const rankStats = getRankStats(states, pastPuzzles)
        const map = getProgressMap(rankStats)
        setProgressMap(map)
      } catch (err) {
        console.warn('Error loading SB hub ranks', err)
      } finally {
        setProgressLoading(false)
      }
    }

    getNewStats()
  }, [])

  return (
    <>
      <div className={styles.outerWrapper}>
        <div className={styles.innerWrapper}>
          <TodayHero
            displayDate={displayDate}
            editor={editor}
            puzzleId={todayIdString}
            printDate={printDate}
          />
          <PastPuzzlesSections
            progressMap={progressMap}
            pastPuzzles={pastPuzzles}
            isProgressLoading={isProgressLoading}
            hasXwd={hasXwd}
            hasUserLoaded={hasUserLoaded}
          />
        </div>
      </div>
    </>
  )
}
