import React from 'react'
import { render, screen, waitFor } from '@testing-library/react'

import { getGameData, xhr } from 'foundation'

import { mockLatestsState } from '../../spelling-bee/js/__tests__/mockLatestsState'

import { SBHubErrorProvider } from './SBHubErrorProvider'

jest.mock('foundation', () => ({
  track: jest.fn(),
  trackClick: jest.fn(),
  getGameData: jest.fn(() => {
    // eslint-disable-next-line global-require
    return require('./mockGameData').mockGameData
  }),
  env: { account: 'https://myaccount.nytimes.com' },
  xhr: {
    get: jest.fn(),
  },
}))

describe('Hub Error Provider', () => {
  it('renders layout when there is past puzzle data', async () => {
    // @ts-ignore
    xhr.get.mockReturnValue({ states: mockLatestsState })
    render(<SBHubErrorProvider />)

    await waitFor(() => {
      const heroCard = screen.getByText('Spelling Bee')
      const blurb = screen.getByText(
        'Make as many words as you can with 7 letters.',
      )
      expect(heroCard).toBeInTheDocument()
      expect(blurb).toBeInTheDocument()
    })
  })

  it('renders error component when there is no past puzzle data', async () => {
    window.isHybridWebView = false
    window.navigationLinks = window.navigationLinks || {}
    window.navigationLinks.login = ''

    // @ts-ignore
    xhr.get.mockReturnValue({ states: mockLatestsState })
    // @ts-ignore
    getGameData.mockReturnValueOnce({
      pastPuzzles: null,
    })
    render(<SBHubErrorProvider />)

    await waitFor(() => {
      const errorText = screen.getByText(
        'This page no longer exists.',
      )

      expect(errorText).toBeInTheDocument()
    })
  })
})
