import React from 'react'
import { render, screen, waitFor } from '@testing-library/react'

import HeroCard from './HeroCard'

describe('HeroCard', () => {
  beforeEach(() => {
    window.newsreaderAppPlatform = ''
    window.isHybridWebView = false
  })

  it('renders a title', () => {
    render(
      <HeroCard
        displayDate="April 5, 2023"
        puzzleId="potato"
        printDate="2023-05-10"
      />,
    )
    const title = screen.queryByText('Spelling Bee')
    expect(title).toBeInTheDocument()
  })

  it('renders formatted date for today', () => {
    render(
      <HeroCard
        displayDate="April 5, 2023"
        puzzleId="potato"
        printDate="2023-05-10"
      />,
    )
    const heroCardDate = screen.queryByText('April 5, 2023')
    expect(heroCardDate).toBeInTheDocument()
  })

  it('renders link', () => {
    render(
      <HeroCard
        displayDate="April 5, 2023"
        puzzleId="potato"
        printDate="2023-05-10"
      />,
    )
    const link = screen.getByRole('link')
    expect(link).toHaveAttribute('href', '/puzzles/spelling-bee')
  })

  it('renders link with hybrid news query param when in newsreader and hybrid webview', () => {
    window.newsreaderAppPlatform = 'ios'
    window.isHybridWebView = true

    render(
      <HeroCard
        displayDate="April 5, 2023"
        puzzleId="potato"
        printDate="2023-05-10"
      />,
    )
    const link = screen.getByRole('link')
    expect(link).toHaveAttribute(
      'href',
      '/puzzles/spelling-bee?hybrid=news',
    )
  })
})
