import React from 'react'

import { trackInteraction } from '../../../../shared/foundation'
import { DateString } from '../../../shared/utils/dateUtils'
import createHybridNewsLink from '../../../shared/utils/createHybridNewsLink'

import styles from './HeroCard.module.scss'

const HeroCard = ({
  displayDate,
  puzzleId,
  printDate,
}: {
  displayDate: string
  puzzleId: string
  printDate: DateString
}) => {
  return (
    <a
      href={createHybridNewsLink('/puzzles/spelling-bee')}
      aria-label="Link to today’s Spelling Bee"
      onClick={() => {
        trackInteraction({
          element: {
            name: 'spelling-bee-hub',
            label: 'spelling-bee',
          },
          context: `SB-${puzzleId}`,
          name: {
            p: printDate,
            t: 'today',
          },
        })
      }}
    >
      <div className={styles.heroCard}>
        <div className={styles.heroCardContent}>
          <div className={styles.heroCardTextContainer}>
            <div className={styles.heroCardHeading}>Spelling Bee</div>
            <div className={styles.todayCardString}>
              <p>Make as many words as you can with 7 letters.</p>
            </div>
            <div className={styles.smallDateHeader}>
              {displayDate}
            </div>
          </div>
          <i
            className={styles.heroCardIcon}
            role="presentation"
            aria-label="Beatrice Bee"
            aria-hidden="true"
          />
        </div>
      </div>
    </a>
  )
}

export default HeroCard
