import { format, endOfWeek, startOfWeek } from 'date-fns'

/**
 * Helper function to return a string containing month and numbered date based on a provided start date,
 * returned string concanated for display, follows example format: March 16th - March 10, using date-fns helper library
 * note that this function returns a reverse chronological week range
 */
export const getFullWeekDateRangeFormattedForDisplay = (
  fullDate: Date = new Date(),
  // index to start week on: 0 === Sunday, 1 === Monday, etc
  dayOfWeekIndexToStartOn: 0 | 1 | 2 | 3 | 4 | 5 | 6 = 0,
): string => {
  const beginningOfWeek = startOfWeek(fullDate, {
    weekStartsOn: dayOfWeekIndexToStartOn,
  })

  const endingOfWeek = endOfWeek(fullDate, {
    weekStartsOn: dayOfWeekIndexToStartOn,
  })

  const beginningOfWeekFormatted = format(beginningOfWeek, 'MMMM d')
  const endingOfWeekFormatted = format(endingOfWeek, 'MMMM d')

  return `${endingOfWeekFormatted} - ${beginningOfWeekFormatted}`
}
