import { subDays } from 'date-fns'

import type { SpellingBeePuzzle } from '../../../spelling-bee/js/store/game/game.state'

import { getFullWeekDateRangeFormattedForDisplay } from './DaysOfWeek'

export const getWeekRangesToDisplay = (currentDate: string) => {
  // convert print date into JS date and get this week and last week's date range -
  // this is used simply to display the dates in UI and is not used for any puzzle related logic
  const currentPuzzleDate = new Date(currentDate)

  const thisWeekDateRange = getFullWeekDateRangeFormattedForDisplay(
    currentPuzzleDate,
    1,
  )

  // to get last weeks date range, subtract 7 days from date before getting full range
  const lastWeekDateRange = getFullWeekDateRangeFormattedForDisplay(
    subDays(currentPuzzleDate, 7),
    1,
  )

  return {
    thisWeekDateRange,
    lastWeekDateRange,
  }
}

export const getReversedWeekRanges = (
  thisWeek: SpellingBeePuzzle[],
  lastWeek: SpellingBeePuzzle[],
) => {
  // omit first day from this week of past and upcoming week date ranges
  const thisWeekWithoutTodayReversed = thisWeek.slice(0, -1).reverse()
  const lastWeekReversed = lastWeek.slice().reverse()

  return { thisWeekWithoutTodayReversed, lastWeekReversed }
}
