import React from 'react'
import ReactDOM from 'react-dom'
import { Provider } from 'react-redux'

import { UserProvider } from 'user'
import ClientSideScripts from 'shared/components/ClientSideScripts'

import '../../shared/shared-styles'
import '../../shared/shared-scripts'

import AbraProviderWithUser from '../../shared/abra/AbraProviderWithUser'
import { FeatureFlagProvider } from '../../shared/abra/FeatureFlagProvider'
import ClientSideHeader from '../shared/ClientSideHeader'
import ShortzMode from '../shared/ShortzMode'
import { setUpStore } from '../spelling-bee/js/store'
import Layout from '../spelling-bee/js/Layout'
import './index.scss'

const gameRoot = document.getElementById('pz-game-root')

const gameBase = () => (
  <>
    <ClientSideHeader>
      <h2>
        <em className="pz-game-title">Spelling Bee</em>
        <span className="pz-game-date">
          {window.gameData.today.displayDate}
        </span>
      </h2>
      <div className="pz-byline">
        <span className="pz-byline__text">
          Edited by
          {` `}
          {window.gameData.today.editor}
        </span>
      </div>
    </ClientSideHeader>
    <Provider store={setUpStore()}>
      <UserProvider>
        <AbraProviderWithUser>
          <FeatureFlagProvider>
            <Layout />
          </FeatureFlagProvider>
        </AbraProviderWithUser>
      </UserProvider>
    </Provider>
  </>
)

ReactDOM.render(
  <>
    <ClientSideScripts />
    <UserProvider>
      <ShortzMode>{gameBase()}</ShortzMode>
    </UserProvider>
  </>,
  gameRoot,
)
