import React, { useEffect, useRef } from 'react'
import cn from 'classnames'

import onPush from '../../helpers/onPush'

const SQRT_3 = 3 ** 0.5
const HEX_HEIGHT = SQRT_3 * 2
const HEX_WIDTH = 4

const points = [
  [0, SQRT_3],
  [1, 0],
  [3, 0],
  [HEX_WIDTH, SQRT_3],
  [3, HEX_HEIGHT],
  [1, HEX_HEIGHT],
]

// scale up all the numbers so they
// wont have such minimal fractions
const SCALE = 30

const noop = () => {}

const pointsString = points
  .map((p) => p.map((c) => c * SCALE).join())
  .join(' ')

type HiveCellProps = {
  letter: string
  activeKey: string | null
  type: 'center' | 'outer'
  onDown: () => void
  onUp: () => void
}

const HiveCell = ({
  activeKey = '',
  letter = '',
  type = 'center',
  onUp = noop,
  onDown = noop,
}: HiveCellProps) => {
  const polygonRef = useRef<SVGPolygonElement>(null)

  useEffect(() => {
    if (polygonRef.current) {
      return onPush(polygonRef.current, onDown, onUp)
    }
  }, [])

  return (
    <svg
      className={cn('hive-cell', type)}
      viewBox={`0 0 ${HEX_WIDTH * SCALE} ${HEX_HEIGHT * SCALE}`}
      data-testid="hive-cell"
    >
      <polygon
        ref={polygonRef}
        className={cn('cell-fill', {
          'push-active': letter === activeKey,
        })}
        points={pointsString}
        stroke="white"
        strokeWidth={0.25 * SCALE}
      />
      <text className="cell-letter" x="50%" y="50%" dy="0.35em">
        {letter}
      </text>
    </svg>
  )
}

export default HiveCell
