import React from 'react'
import cn from 'classnames'
import { useDispatch } from 'react-redux'

import { useUser } from 'user'

import OfflineTicker from '../../shared/OfflineTicker/OfflineTicker'
import ConversionBannerWrapper from '../../shared/ConversionBanner/ConversionBannerWrapper'
import useSaleBannerHybridSubscribe from '../../shared/hooks/use-sale-banner-hybrid-subscribe'

import Hive from './Hive'
import HiveInput from './HiveInput'
import Wordlist from './Wordlist'
import ListHeading from './ListHeading'
import Progress from './Progress'
import Message from './Message'
import Toolbar from './Toolbar'
import { updateCurrentMoment } from './store/game/game.actions'
import {
  selectIsLocked,
  selectMoment,
  selectWordlistExpanded,
} from './store/game/game.selectors'
import { Moments } from './moments/index'
import { SBModals, toggleModal } from './modals/index'
import { useProgress } from './hooks/useProgress'
import { useSbSelector } from './store/game/hooks'
import { useVh } from './hooks/useVh'
import { useSBHybridEffects } from './hooks/useSBHybridEffects'
import { useWordlistContracting } from './hooks/useWordlistContracting'

const Layout = () => {
  const isWordlistExpanded = useSbSelector(selectWordlistExpanded)
  const isLocked = useSbSelector(selectIsLocked)
  const currentMoment = useSbSelector(selectMoment)
  const dispatch = useDispatch()
  const { userType } = useUser()
  useProgress()
  useVh(currentMoment === 'game')
  useSBHybridEffects()
  const { isWordlistContracting, endWordlistContraction } =
    useWordlistContracting(isWordlistExpanded)
  useSaleBannerHybridSubscribe()

  React.useEffect(() => {
    if (currentMoment === 'game' && window.innerHeight < 550) {
      document.body.classList.add('enable-scrolling') // enable scrolling on short phones
    }
  }, [currentMoment])

  const controlsBoxRef = React.useRef(null)

  return (
    <>
      {window.isHybridWebView && <OfflineTicker />}
      <div
        className={cn('sb-content-box', {
          'sb-expanded': isWordlistExpanded,
          'sb-contracting': isWordlistContracting,
          'sb-game-locked': isLocked,
        })}
      >
        <Toolbar />
        <Moments
          onEnter={(m: string) => dispatch(updateCurrentMoment(m))}
          contentProps={{ toggleModal }}
        />
        <SBModals />
        <div className="sb-status-box">
          <div className="sb-progress-box">
            <Progress />
          </div>
          <div className="sb-wordlist-box">
            <div className="sb-wordlist-heading">
              <ListHeading />
            </div>
            <div
              className="sb-wordlist-drawer"
              onTransitionEnd={endWordlistContraction}
            >
              <div className="sb-wordlist-window">
                <Wordlist />
              </div>
            </div>
          </div>
        </div>
        <div className="sb-controls-box" ref={controlsBoxRef}>
          <div className="sb-controls">
            <Message />
            <HiveInput />
            <Hive boundingParentRef={controlsBoxRef} />
          </div>
        </div>
      </div>
      <ConversionBannerWrapper
        gameType="spelling-bee"
        subAbraTest="MKT_Spellingbee_banner_test_sub_0522"
        regiAbraTest="MKT_Spellingbee_banner_test_0522"
        userType={userType}
        isLocked={isLocked}
      />
    </>
  )
}

export default Layout
