import React from 'react'
import { Dispatch } from 'redux'
import cn from 'classnames'
import { connect } from 'react-redux'

import { toggleWordlist } from './store/game/game.actions'
import type { SpellingBeeState, SpellingBeeAction } from './store'
import Anagram from './Anagram'
import TouchButton from './TouchButton'
import { useSbSelector } from './store/game/hooks'
import { selectTodayPangramSet } from './store/game/game.selectors'

type ListHeadingProps = {
  wordCount: number
  recentWords: string[]
  isExpandedWordlist: boolean
  toggleWordlist: () => void
}

const ListHeading = ({
  wordCount,
  recentWords,
  isExpandedWordlist,
  toggleWordlist,
}: ListHeadingProps) => {
  const pangramSet = useSbSelector(selectTodayPangramSet)

  return (
    <TouchButton
      className="sb-wordlist-heading-wrap"
      onDown={toggleWordlist}
    >
      <div className="sb-wordlist-summary">
        You have found {wordCount}{' '}
        {wordCount === 1 ? 'word' : 'words'}
      </div>
      <div className="sb-recent-words-wrap">
        <ul
          className={cn('sb-recent-words', {
            'sb-has-words': recentWords.length > 0,
          })}
        >
          {recentWords.length ? (
            recentWords.map((w) => (
              <li key={w}>
                <Anagram value={w} isPangram={pangramSet.has(w)} />
              </li>
            ))
          ) : (
            <li key="none" className="sb-placeholder-text">
              Your words …
            </li>
          )}
        </ul>
      </div>
      <div className="sb-toggle-expand">
        <span
          className={cn('sb-toggle-icon', {
            'sb-toggle-icon-expanded': isExpandedWordlist,
          })}
        />
      </div>
    </TouchButton>
  )
}

const mapStateToProps = (state: SpellingBeeState) => ({
  wordCount: state.game.foundWords.length,
  recentWords: state.game.foundWords.slice().reverse(),
  isExpandedWordlist: state.game.isExpandedWordlist,
})

const mapDispatchToProps = (
  dispatch: Dispatch<SpellingBeeAction>,
) => ({
  toggleWordlist: () => dispatch(toggleWordlist()),
})

export default connect(
  mapStateToProps,
  mapDispatchToProps,
)(ListHeading)
