import React from 'react'
import cn from 'classnames'
import { connect } from 'react-redux'

import { ModalButton } from './modals/index'
import { SpellingBeeRank } from './store/utils'
import {
  selectCurrentScore,
  selectCurrentRank,
  selectRanks,
  selectCurrentRankIdx,
} from './store/game/game.selectors'
import type { SpellingBeeState } from './store'

type ProgressProps = {
  score: number
  rank: string
  rankIdx: number
  ranksUpToGenius: { title: SpellingBeeRank; minScore: number }[]
}

export const Progress = ({
  score,
  rank,
  rankIdx,
  ranksUpToGenius,
}: ProgressProps) => {
  const isQueenBeeRank = rankIdx === 9

  // The index of the final rank will differ between "Genius"
  // and "Queen Bee" i.e.
  // "Genius" - 8
  // "Queen Bee" - 9
  // (see RANKS array in src/games/spelling-bee/js/store/utils.ts)
  // This index is conditionally supplied to ensure that the "completed"
  // game state i.e. "Genius" and "Queen Bee" are styled the same
  const finalRankIndex = isQueenBeeRank ? 9 : 8

  return (
    <ModalButton modal="ranks" triggerName="in-game">
      <div className="sb-progress" title="Click to see today’s ranks">
        <h4 className="sb-progress-rank">{rank}</h4>
        <div className="sb-progress-bar">
          <div className="sb-progress-line">
            <div className="sb-progress-dots">
              {ranksUpToGenius.map((rank, i) => (
                <span
                  // eslint-disable-next-line react/no-array-index-key
                  key={i}
                  className={cn('sb-progress-dot', {
                    completed: i < rankIdx,
                  })}
                />
              ))}
            </div>
          </div>
          <div
            className={cn('sb-progress-marker', {
              final: rankIdx === finalRankIndex,
            })}
            style={{
              left: `${(rankIdx / finalRankIndex) * 100}%`,
            }}
          >
            <span className="sb-progress-value">{score}</span>
          </div>
        </div>
      </div>
    </ModalButton>
  )
}

const mapStateToProps = (state: SpellingBeeState) => {
  const ranks = selectRanks(state)
  // Creating an array here that omits the "Queen Bee" rank since
  // "Genius" is considered to be the completed state ("Queen Bee"
  // being a bonus state) in order to ensure the number of dots
  // do not exceed the "Genius" state
  const ranksUpToGenius = ranks.slice(0, 9)

  return {
    score: selectCurrentScore(state),
    ranksUpToGenius,
    rankIdx: selectCurrentRankIdx(state),
    rank: selectCurrentRank(state),
  }
}

export default connect(mapStateToProps)(Progress)
