import React, { Component, MutableRefObject, ReactNode } from 'react'
import cn from 'classnames'

import onPush from '../../helpers/onPush'

type TouchButtonProps = {
  className: string
  onDown: () => void
  onUp?: () => void
  allowBurst?: boolean
  children?: ReactNode | ReactNode[] | null
  outerRef?: MutableRefObject<HTMLElement | null> | null
}

class TouchButton extends Component<TouchButtonProps, any> {
  unbind: (() => void) | undefined

  button: HTMLElement | null | undefined

  componentDidMount() {
    const {
      onDown = () => {},
      onUp = () => {},
      allowBurst,
    } = this.props

    if (this.button) {
      this.unbind = onPush(this.button, onDown, onUp, allowBurst)
    }
  }

  componentDidUpdate(prevProps: TouchButtonProps) {
    const { onDown, onUp, allowBurst } = this.props
    if (
      prevProps.onDown !== onDown ||
      prevProps.onUp !== onUp ||
      prevProps.allowBurst !== allowBurst
    ) {
      this.unbind?.()
      if (this.button) {
        this.unbind = onPush(this.button, onDown, onUp, allowBurst)
      }
    }
  }

  componentWillUnmount() {
    this.unbind?.()
  }

  render() {
    const { className, children, outerRef } = this.props
    return (
      <div
        ref={(button) => {
          this.button = button
          if (outerRef && button) {
            outerRef.current = button
          }
        }}
        className={cn(className, 'sb-touch-button')}
        data-testid="touch-button"
      >
        {children}
      </div>
    )
  }
}

export default TouchButton
