import React from 'react'
import { mount } from 'enzyme'

import HiveCell from '../HiveCell'

jest.mock('responsive', () => ({
  isMobile: false,
}))

jest.mock('foundation', () => ({
  trackClick: jest.fn(),
  userType: {
    hasXwd: true,
  },
  getGameData: () => ({
    today: { id: 1 },
  }),
}))

const onUp = jest.fn()
const onDown = jest.fn()

const store = {
  onUp,
  onDown,
}

function makeHiveCellProps(letter, activeKey, type) {
  return {
    letter,
    activeKey,
    type,
    onUp,
    onDown,
  }
}

describe('HIVECELL: HAS PROPER TAGS', () => {
  it('should have center tag for center letter', () => {
    const hiveCellProps = makeHiveCellProps('C', '', 'center')
    const wrapper = mount(
      <HiveCell {...hiveCellProps} store={store} />,
    )

    expect(wrapper.find('.cell-letter')).toHaveLength(1)
    expect(wrapper.find('.hive-cell')).toHaveLength(1)
    expect(wrapper.find('.center')).toHaveLength(1)
    expect(wrapper.find('.center').text()).toEqual('C')
  })

  it('should have outer tag for outer letters', () => {
    const hiveCellProps = makeHiveCellProps('V', '', 'outer')
    const wrapper = mount(
      <HiveCell {...hiveCellProps} store={store} />,
    )
    expect(wrapper.find('.cell-letter')).toHaveLength(1)
    expect(wrapper.find('.hive-cell')).toHaveLength(1)
    expect(wrapper.find('.outer')).toHaveLength(1)
    expect(wrapper.find('.outer').text()).toEqual('V')
  })

  it('should have active letter tag if letter is active', () => {
    const hiveCellProps = makeHiveCellProps('C', 'C', 'center')
    const wrapper = mount(
      <HiveCell {...hiveCellProps} store={store} />,
    )
    expect(wrapper.find('.cell-letter')).toHaveLength(1)
    expect(wrapper.find('.hive-cell')).toHaveLength(1)
    expect(wrapper.find('.push-active')).toHaveLength(1)
  })

  it('should not have active letter tag if letter is not active', () => {
    const hiveCellProps = makeHiveCellProps('C', '', 'center')
    const wrapper = mount(
      <HiveCell {...hiveCellProps} store={store} />,
    )
    expect(wrapper.find('.cell-letter')).toHaveLength(1)
    expect(wrapper.find('.hive-cell')).toHaveLength(1)
    expect(wrapper.find('.push-active')).toHaveLength(0)
  })
})
