import React from 'react'
import { mount } from 'enzyme'

import { useSbSelector } from '../store/game/hooks'
import Message from '../Message'

const dispatch = jest.fn()
const subscribe = jest.fn()

jest.mock('../store/game/hooks', () => ({
  useSbSelector: jest.fn(),
}))

function makeStore(isError, isPangram, value, points) {
  useSbSelector.mockReset()
  useSbSelector.mockReturnValue({
    isError,
    isPangram,
    value,
    points,
  })
  return {
    getState: () => ({
      message: {
        isError,
        isPangram,
        value,
        points,
      },
    }),
    subscribe,
    dispatch,
  }
}

describe('MESSAGE: HAS PROPER ERROR/SUCCESS MESSAGES', () => {
  it('should show error message for error', () => {
    const store = makeStore(true, false, 'Error message', 'No points')

    const wrapper = mount(<Message store={store} />)

    expect(wrapper.find('.error-message')).toHaveLength(1)
    expect(wrapper.find('.sb-message-box')).toHaveLength(1)
    expect(wrapper.find('.sb-message')).toHaveLength(1)
    expect(wrapper.find('.sb-message').text()).toEqual(
      'Error message',
    )
    expect(wrapper.find('.sb-message-points')).toHaveLength(1)
    expect(wrapper.find('.sb-message-points').text()).toEqual(
      '+No points',
    )
  })

  it('should show success message for success', () => {
    const store = makeStore(false, false, 'Valid Word', '5')
    const wrapper = mount(<Message store={store} />)

    expect(wrapper.find('.success-message')).toHaveLength(1)
    expect(wrapper.find('.sb-message-box')).toHaveLength(1)
    expect(wrapper.find('.sb-message')).toHaveLength(1)
    expect(wrapper.find('.sb-message').text()).toEqual('Valid Word')
    expect(wrapper.find('.sb-message-points')).toHaveLength(1)
    expect(wrapper.find('.sb-message-points').text()).toEqual('+5')
  })

  it('should show panagram message for panagram', () => {
    const store = makeStore(false, true, 'Panagram!', '50')
    const wrapper = mount(<Message store={store} />)

    expect(wrapper.find('.pangram-message')).toHaveLength(1)
    expect(wrapper.find('.sb-message-box')).toHaveLength(1)
    expect(wrapper.find('.sb-message')).toHaveLength(1)
    expect(wrapper.find('.sb-message').text()).toEqual('Panagram!')
    expect(wrapper.find('.sb-message-points')).toHaveLength(1)
    expect(wrapper.find('.sb-message-points').text()).toEqual('+50')
  })
})
