import React from 'react'
import { render, screen } from '@testing-library/react'
import { Provider } from 'react-redux'

import { ToolbarTooltip } from '../ToolbarTooltip'
import { setUpStore } from '../store'
import {
  updateCurrentMoment,
  updateModalRedux,
} from '../store/game/game.actions'

jest.mock('foundation', () => ({
  ...jest.requireActual('foundation'),
  userType: { hasXwd: false, regiId: 2222 },
  trackImpression: jest.fn(),
  getGameData: () => {
    return require('./mockGameData').mockGameData
  },
}))

const title = 'More Stats'

describe('<ToolbarTooltip />', () => {
  const persistHide = jest.fn()

  const renderTooltip = () => {
    const store = setUpStore()
    const target = document.createElement('div')

    const component = render(
      <Provider store={store}>
        <div id="portal-sb-tooltip" />
        <ToolbarTooltip
          isHidden={false}
          persistHide={persistHide}
          targetRef={{ current: target }}
        />
      </Provider>,
    )

    return { component, store }
  }

  beforeAll(() => {
    jest.useFakeTimers()
  })

  afterAll(() => {
    jest.useRealTimers()
  })

  it('should be hidden by default', () => {
    renderTooltip()
    expect(screen.queryByText(title)).toBeFalsy()
  })

  it('should show up on transition to game', () => {
    const { store } = renderTooltip()
    store.dispatch(updateCurrentMoment('game'))
    jest.advanceTimersByTime(2000)
    expect(screen.queryByText(title)).toBeTruthy()
  })

  it('should disappear when a modal is opened', () => {
    const { store } = renderTooltip()
    store.dispatch(updateCurrentMoment('game'))
    jest.advanceTimersByTime(2000)

    store.dispatch(updateModalRedux(true))
    jest.advanceTimersByTime(500)
    expect(screen.queryByText(title)).toBeFalsy()
  })
})
