import React, { useRef } from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import Wordlist from '../Wordlist'

jest.mock('responsive', () => ({
  isMobile: false,
}))

jest.mock('foundation', () => ({
  trackClick: jest.fn(),
  getGameData: () => ({
    today: { id: 1 },
  }),
}))

jest.mock('react', () => ({
  ...jest.requireActual('react'),
  useRef: jest.fn(),
}))

const dispatch = jest.fn()
const subscribe = jest.fn()

function makeStore() {
  return {
    getState: () => ({
      game: {
        foundWords: ['millionfold'],
        centerLetter: 'i',
      },
    }),
    subscribe,
    dispatch,
  }
}

describe('WORDLIST: HAS PROPER HTML', () => {
  afterEach(jest.clearAllMocks)

  it('should have correct styling with 1 page', () => {
    const store = makeStore()

    useRef.mockReturnValue({ current: null })

    const wrapper = mount(
      <Provider store={store}>
        <Wordlist />
      </Provider>,
    )

    expect(wrapper.find('.sb-wordlist-items-pag')).toHaveLength(1)
    expect(wrapper.find('.sb-kebob')).toHaveLength(1)
    expect(wrapper.find('.sb-bob')).toHaveLength(0)
    expect(wrapper.find('.sb-bob.active')).toHaveLength(0)
    expect(wrapper.find('.sb-bob-prev')).toHaveLength(0)
    expect(wrapper.find('.sb-bob-next')).toHaveLength(0)
    expect(wrapper.find('.sb-wordlist-scroll-anchor')).toHaveLength(1)
  })

  it('should have correct styling with 2 pages', () => {
    const store = makeStore()

    const scrollTo = jest.fn()

    // some hackery around mocking refs
    // create an object that will not be modified when passed into a <div ref={myRef}>
    const getRefMock = (value) => {
      const mock = {}
      Object.defineProperty(mock, 'current', {
        get: () => value,
        set: () => null,
      })
      return mock
    }

    const containerValue = {
      scrollLeft: 0,
      offsetWidth: 300,
      scrollTo,
      getBoundingClientRect: () => ({ left: 0 }),
    }

    const lastItemValue = {
      getBoundingClientRect: () => ({ right: 500 }),
    }

    // must mock 8 times because guts of component run 4 times,
    // and useRef is called twice each time
    useRef
      .mockReturnValueOnce(getRefMock(containerValue))
      .mockReturnValueOnce(getRefMock(lastItemValue))
      .mockReturnValueOnce(getRefMock(containerValue))
      .mockReturnValueOnce(getRefMock(lastItemValue))
      .mockReturnValueOnce(getRefMock(containerValue))
      .mockReturnValueOnce(getRefMock(lastItemValue))
      .mockReturnValueOnce(getRefMock(containerValue))
      .mockReturnValueOnce(getRefMock(lastItemValue))

    const wrapper = mount(
      <Provider store={store}>
        <Wordlist />
      </Provider>,
    )

    expect(wrapper.find('.sb-wordlist-items-pag')).toHaveLength(1)
    expect(wrapper.find('.sb-kebob')).toHaveLength(1)
    expect(wrapper.find('.sb-bob')).toHaveLength(2)
    expect(wrapper.find('.sb-bob.active')).toHaveLength(1)
    expect(wrapper.find('.sb-bob-prev')).toHaveLength(1)
    expect(wrapper.find('.sb-bob-prev.active')).toHaveLength(0)
    expect(wrapper.find('.sb-bob-next')).toHaveLength(1)
    expect(wrapper.find('.sb-bob-next.active')).toHaveLength(1)
    expect(wrapper.find('.sb-wordlist-scroll-anchor')).toHaveLength(2)
  })
})
