import { useEffect } from 'react'

import { captureSentryError, setSentryData } from 'foundation'
import { useUser } from 'user'

import { useSbSelector } from '../store/game/hooks'
import { checkVersion } from '../../../../shared/abra/usePastPuzzles'

export const useSBoSLogging = () => {
  const hasLoaded = useSbSelector((state) => state.game.hasLoaded)
  const {
    userType: { regiId },
  } = useUser()

  const moogleRegi = useSbSelector(
    (state) => state.moogle.getRequest.regiId,
  )

  useEffect(() => {
    if (!hasLoaded) {
      return
    }

    const isOldIosGamesApp =
      window.gamesAppPlatform === 'ios' &&
      !checkVersion(window.gamesAppVersion, 4, 45)

    if (
      !isOldIosGamesApp &&
      regiId &&
      regiId.toString() !== moogleRegi?.toString() &&
      Math.random() < 0.01
    ) {
      setSentryData('sbos wrong regi', {
        moogleRegi: moogleRegi?.toString() || '',
        userRegi: regiId,
      })
      captureSentryError(new Error('SBOS wrong regi'))
    }
  }, [hasLoaded, regiId, moogleRegi])
}
