import { useEffect } from 'react'

import { debounce } from '../../../helpers/gameUtils'

// to account for discrepancies on mobile, see https://css-tricks.com/the-trick-to-viewport-units-on-mobile/
const setVh = () => {
  const vh = window.innerHeight * 0.01
  document.documentElement.style.setProperty('--vh', `${vh}px`)
}

const debouncedVh = debounce(setVh, 100)

export const useVh = (isGameVisible: boolean) => {
  useEffect(() => {
    setVh()

    window.addEventListener('resize', debouncedVh)
    return () => {
      window.removeEventListener('resize', debouncedVh)
    }
  }, [])

  // https://jira.nyt.net/browse/XWD-18026
  useEffect(() => {
    if (isGameVisible && window.gamesAppPlatform === 'ios') {
      setVh()
    }
  }, [isGameVisible])
}
