import React from 'react'
import { useDispatch } from 'react-redux'
import cn from 'classnames'

import Anagram from '../Anagram'
import Button from '../../../shared/Button'
import { useSbSelector } from '../store/game/hooks'
import { revealAnswers } from '../store/game/game.actions'
import { selectTodayPangramSet } from '../store/game/game.selectors'

import { ModalHeader, ModalBody } from './ModalComponents'

const ModalAnswers = ({
  toggleModal,
}: {
  toggleModal: (modalName: string, trigger: string) => void
}) => {
  const dispatch = useDispatch()
  const {
    displayDate,
    validLetters,
    answers,
    foundWords,
    isRevealed,
  } = useSbSelector((state) => state.game)

  const foundWordSet = new Set(foundWords)
  const pangramSet = useSbSelector(selectTodayPangramSet)

  const Confirm = (
    <>
      <p className="sb-modal-message">
        Do you want to reveal this puzzle’s answers? If you do you
        will no longer be able to enter words.
      </p>
      <p className="sb-modal-buttons-container">
        <Button
          text="Reveal"
          onClick={() => {
            dispatch(revealAnswers())
          }}
        />
        <Button
          text="Keep Playing"
          type="secondary"
          onClick={() => {
            toggleModal('answers', 'keep-playing')
          }}
        />
      </p>
    </>
  )

  const Answers = (
    <>
      <div className="sb-modal-letters">{validLetters}</div>
      <ul className="sb-modal-wordlist-items">
        {answers.map((w) => (
          <li key={w} data-testid="answers-word">
            <span
              className={cn('check', {
                checked: foundWordSet.has(w),
              })}
            />
            <Anagram value={w} isPangram={pangramSet.has(w)} />
          </li>
        ))}
      </ul>
    </>
  )

  return (
    <>
      <ModalHeader>
        <h3 className="sb-modal-title">Answers</h3>
        <div className="sb-modal-date__answers">{displayDate}</div>
      </ModalHeader>
      <ModalBody>{isRevealed ? Answers : Confirm}</ModalBody>
    </>
  )
}

export default ModalAnswers
