import React from 'react'

import { useUser } from 'user'
import { SEND_EMAIL_TYPE } from 'foundation'

import FeedbackLink from '../../../helpers/FeedbackLink'
import { useTracking } from '../store/game/hooks'

import { ModalBody, ModalHeader } from './ModalComponents'

const ModalHelp = () => {
  const trackSB = useTracking()
  const { userType } = useUser()

  return (
    <>
      <ModalHeader>
        <h3 className="sb-modal-title">How to Play Spelling Bee</h3>
        <h4 className="sb-modal-subtitle">
          Create words using letters from the hive.
        </h4>
      </ModalHeader>
      <ModalBody>
        <ul className="sb-modal-list">
          <li>Words must contain at least 4 letters.</li>
          <li>Words must include the center letter.</li>
          <li>
            Our word list does not include words that are obscure,
            hyphenated, or proper nouns.
          </li>
          <li>No cussing either, sorry.</li>
          <li>Letters can be used more than once.</li>
        </ul>
        <h4 className="sb-modal-heading">
          Score points to increase your rating.
        </h4>
        <ul className="sb-modal-list">
          <li>4-letter words are worth 1 point each.</li>
          <li>Longer words earn 1 point per letter.</li>
          <li>
            Each puzzle includes at least one “pangram” which uses
            every letter. These are worth 7 extra points!
          </li>
        </ul>
        <p className="sb-modal-message">
          Need more solving tips?{' '}
          <a
            href="https://www.nytimes.com/2021/12/09/crosswords/spellingbee-tips.html"
            target={window.isHybridWebView ? '_self' : '_blank'}
            rel="noreferrer"
            onClick={() => trackSB('tips-and-tricks', 'help')}
          >
            This article can help.
          </a>
        </p>
        <p className="sb-modal-message">
          New puzzles are released daily at 3 a.m. ET.
        </p>
        <p className="sb-modal-message">
          Think we missed a word? Email us at{' '}
          <FeedbackLink
            subject="Spelling Bee Word Suggestion"
            href="mailto:buzzwords@nytimes.com"
            type={SEND_EMAIL_TYPE.SUGGESTION}
            user={userType}
          >
            buzzwords@nytimes.com
          </FeedbackLink>
          .
        </p>
        <p className="sb-modal-message">
          Have feedback? Email us at&ensp;
          <FeedbackLink
            subject="Spelling Bee Feedback"
            type={SEND_EMAIL_TYPE.FEEDBACK}
            user={userType}
          >
            nytgames@nytimes.com
          </FeedbackLink>
          .
        </p>
      </ModalBody>
    </>
  )
}

export default ModalHelp
