import React, { useEffect } from 'react'
import { useDispatch } from 'react-redux'
import cn from 'classnames'

import { useSbSelector } from '../store/game/hooks'
import {
  selectYesterdayFoundWords,
  selectYesterdayFoundWordSet,
  selectYesterdayPangramSet,
} from '../store/game/game.selectors'
import Anagram from '../Anagram'
import RankRecap from '../recaps'

import { ModalHeader, ModalBody } from './ModalComponents'

const ModalYesterday = () => {
  const yesterday = useSbSelector((state) => state.game.yesterday)
  const foundWords = useSbSelector(selectYesterdayFoundWords)
  const foundWordSet = useSbSelector(selectYesterdayFoundWordSet)
  const pangramSet = useSbSelector(selectYesterdayPangramSet)

  // Only show rank if we have a list of found words (which indicates
  // yesterdays progress) and if there is one word or more in list
  const showYesterdaysRank = foundWords && foundWords.length >= 1

  if (!yesterday) {
    return null
  }

  const { displayDate, answers, validLetters } = yesterday

  return (
    <>
      <ModalHeader>
        <h3 className="sb-modal-title">Yesterday’s Answers</h3>
        <div className="sb-modal-date__yesterday">{displayDate}</div>
      </ModalHeader>
      <ModalBody>
        {showYesterdaysRank && <RankRecap messageType="yesterday" />}
        <div className="sb-modal-letters">{validLetters}</div>
        <ul className="sb-modal-wordlist-items">
          {answers.map((w) => (
            <li key={w} data-testid="yesterdays-answer-word">
              <span
                className={cn('check', {
                  checked: foundWordSet.has(w),
                })}
              />
              <Anagram value={w} isPangram={pangramSet.has(w)} />
            </li>
          ))}
        </ul>
      </ModalBody>
    </>
  )
}

export default ModalYesterday
