import React from 'react'
import cn from 'classnames'
import { useDispatch } from 'react-redux'

import { useTracking, useSbSelector } from '../store/game/hooks'
import { revealYesterdaysAnswers } from '../store/game/game.actions'
import {
  selectYesterdayFoundWords,
  selectYesterdayFoundWordSet,
  selectYesterdayPangramSet,
} from '../store/game/game.selectors'
import Anagram from '../Anagram'
import RankRecap from '../recaps'
import Button from '../../../shared/Button'
import createHybridNewsLink from '../../../shared/utils/createHybridNewsLink'

import { ModalHeader, ModalBody } from './ModalComponents'

const ModalYesterdayNew = () => {
  const trackSB = useTracking()
  const dispatch = useDispatch()
  const yesterday = useSbSelector((state) => state.game.yesterday)
  const foundWords = useSbSelector(selectYesterdayFoundWords)
  const foundWordSet = useSbSelector(selectYesterdayFoundWordSet)
  const pangramSet = useSbSelector(selectYesterdayPangramSet)

  if (!yesterday) {
    return null
  }

  // Only show rank if we have a list of found words (which indicates
  // yesterdays progress) and if there is one word or more in list
  const showYesterdaysRank = foundWords && foundWords.length >= 1

  const {
    answers,
    printDate,
    isRevealed,
    displayDate,
    validLetters,
  } = yesterday

  const Confirm = (
    <>
      <p className="sb-modal-message">
        Do you want to reveal yesterday’s answers? If you do you
        will&nbsp;
        <em>
          no longer be able to enter words and continue to play that
          puzzle.
        </em>
      </p>
      <p className="sb-modal-buttons-container">
        <Button
          text="Reveal"
          onClick={() => {
            dispatch(revealYesterdaysAnswers())
          }}
        />
        <Button
          text="Play instead"
          type="secondary"
          onClick={() => {
            trackSB('play-yesterday', 'answers')
            window.location.href = createHybridNewsLink(
              `/puzzles/spelling-bee/${printDate}`,
            )
          }}
        />
      </p>
    </>
  )

  const Answers = (
    <>
      {showYesterdaysRank && <RankRecap messageType="yesterday" />}
      <div className="sb-modal-letters">{validLetters}</div>
      <ul className="sb-modal-wordlist-items">
        {answers.map((w) => (
          <li key={w} data-testid="yesterdays-answer-word">
            <span
              className={cn('check', {
                checked: foundWordSet.has(w),
              })}
            />
            <Anagram value={w} isPangram={pangramSet.has(w)} />
          </li>
        ))}
      </ul>
    </>
  )

  return (
    <>
      <ModalHeader>
        <h3 className="sb-modal-title">Yesterday’s Answers</h3>
        <div className="sb-modal-date__yesterday">{displayDate}</div>
      </ModalHeader>
      <ModalBody>{isRevealed ? Answers : Confirm}</ModalBody>
    </>
  )
}

export default ModalYesterdayNew
