import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import ModalShare from '../ModalShare'

jest.mock('responsive', () => ({
  isMobile: true,
}))

describe('SPELLING BEE: MODAL SHARE', () => {
  let connectModal
  const store = {
    getState: () => ({
      game: {
        printDate: '2022-11-15',
        validLetters: ['f', 'l', 'o', 'd', 'i', 'g', 'n'],
        pangrams: ['folding', 'flooding'],
        foundWords: ['folding', 'flooding', 'fooling'], // 75%
        answers: ['folding', 'flooding', 'fooling', 'fiddling'],
      },
    }),
    subscribe: jest.fn(),
    dispatch: jest.fn(),
  }

  beforeAll(() => {
    connectModal = () =>
      mount(
        <Provider store={store}>
          <ModalShare />
        </Provider>,
      )
  })

  it('should render title', () => {
    const component = connectModal()
    const title = component.find('.sb-modal-title')

    expect(title.text()).toEqual('Share Your Achievement')
  })

  it('should render image', () => {
    const component = connectModal()
    const img = component
      .find('.sb-share__tout-image-wrapper')
      .children()
    const imgSrc = img.prop('src')
    const baseUrl = 'https://www.nytimes.com/badges/games/v1/bee.png'
    const date = 'd=2022-11-15'
    const letters = 'l=flodign'
    const rank = 'r=Genius'

    expect.assertions(4)
    expect(imgSrc.includes(baseUrl)).toBe(true)
    expect(imgSrc.includes(date)).toBe(true)
    expect(imgSrc.includes(letters)).toBe(true)
    expect(imgSrc.includes(rank)).toBe(true)
  })

  it('should render correct download attribute name for downloading image', () => {
    const component = connectModal()
    const downloadAttribute = component
      .find('[aria-label="Download image"]')
      .prop('download')

    expect(downloadAttribute).toBe('spelling-bee-genius-2022-11-15')
  })

  it('should show Download image and Share buttons when native share is available', () => {
    navigator.canShare = () => true
    const component = connectModal()
    const list = component.find('.sb-share__share-networks')

    expect.assertions(3)
    expect(list.children()).toHaveLength(2)
    expect(list.childAt(0).text()).toBe('Share')
    expect(list.childAt(1).text()).toBe('Download image')
  })

  it('should show all share options when native share is not available', () => {
    navigator.canShare = () => false
    const component = connectModal()
    const list = component.find('.sb-share__share-networks')

    expect.assertions(6)
    expect(list.children()).toHaveLength(5)
    expect(list.childAt(0).text()).toBe('Download image')
    expect(list.childAt(1).text()).toBe('Copy link')
    expect(list.childAt(2).text()).toBe('Facebook')
    expect(list.childAt(3).text()).toBe('Twitter')
    expect(list.childAt(4).text()).toBe('WhatsApp')
  })
})
