import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import ModalYesterday from '../ModalYesterday'

jest.mock('foundation', () => ({
  track: jest.fn(),
  trackClick: jest.fn(),
  getGameData: () => ({
    today: { id: 1 },
  }),
  env: { account: 'https://myaccount.nytimes.com' },
}))

const mockDispatch = jest.fn()

const mockStore = (state) => {
  return {
    default: jest.fn(),
    subscribe: jest.fn(),
    dispatch: mockDispatch,
    getState: () => state,
  }
}

describe('ModalYesterday', () => {
  let component

  const puzzleData = {
    displayDate: '01-01-2020',
    centerLetter: 'A',
    validLetters: ['B', 'C', 'D', 'E', 'F', 'G'],
    answers: ['ACE', 'BAG', 'DEF'],
    foundWords: ['ACE'],
    pangrams: ['ACE'],
  }

  const createComponent = (puzzleData) => {
    const store = mockStore({
      game: {
        yesterday: puzzleData,
      },
    })

    const wrapper = mount(
      <Provider store={store}>
        <ModalYesterday />
      </Provider>,
    )

    return wrapper.find(ModalYesterday)
  }

  beforeEach(() => {
    jest.resetAllMocks()
  })

  it('should render without crashing', () => {
    component = createComponent(puzzleData)
    expect(component.length).toBeTruthy()
  })

  it('should show checkmark only next to found words', () => {
    component = createComponent(puzzleData)
    const answers = component.find(
      'li[data-testid="yesterdays-answer-word"]',
    )
    expect(answers).toHaveLength(3)
    expect(answers.at(0).find('span.check')).toHaveLength(1)
    expect(answers.at(0).find('span.checked')).toHaveLength(1)

    expect(answers.at(1).find('span.check')).toHaveLength(1)
    expect(answers.at(1).find('span.checked')).toHaveLength(0)

    expect(answers.at(2).find('span.check')).toHaveLength(1)
    expect(answers.at(1).find('span.checked')).toHaveLength(0)
  })

  it('should not fetch remote progress when in hybrid and found words is not null', () => {
    window.isHybridWebView = true
    component = createComponent({
      ...puzzleData,
      foundWords: [],
    })

    expect(mockDispatch).not.toHaveBeenCalled()
  })

  it('should not fetch remote progress when not in hybrid', () => {
    window.isHybridWebView = false
    component = createComponent({
      ...puzzleData,
      foundWords: null,
    })

    expect(mockDispatch).not.toHaveBeenCalled()
  })

  it('should show yesterdays rank if found words is not empty or null', () => {
    component = createComponent(puzzleData)
    const rank = component.find('.sb-modal-yesterday-rank')
    expect(rank.length).toBeTruthy()
  })

  it('should not show yesterdays rank if found words is empty or null', () => {
    component = createComponent({
      ...puzzleData,
      foundWords: null,
    })
    const rank = component.find('.sb-modal-yesterday-rank')
    expect(rank.length).toBeFalsy()
  })
})
