import md5 from 'blueimp-md5'

import { SMID, encodeUrlWithSMID, getShareInfo } from '../shareUtils'

describe('SPELLING BEE: SHARE UTILS', () => {
  it('should return spelling bee link nothing is passed in', () => {
    const defaultUrl = encodeURIComponent(
      'https://www.nytimes.com/puzzles/spelling-bee?smid=share',
    )

    expect(encodeUrlWithSMID('', '')).toBe(defaultUrl)
  })

  it('should return default smid if nothing is passed in', () => {
    const url = 'www.nytimes.com/games'
    const newUrl = encodeURIComponent(
      'www.nytimes.com/games?smid=share',
    )

    expect(encodeUrlWithSMID(url, '')).toBe(newUrl)
  })

  it('should append smid to url', () => {
    const url = 'www.nytimes.com/games'
    const newUrl = encodeURIComponent(
      'www.nytimes.com/games?smid=tw-share',
    )

    expect(encodeUrlWithSMID(url, SMID.twitter)).toBe(newUrl)
  })

  it('should append smid to url if there are already other query params in url', () => {
    const url = 'www.nytimes.com/games?some=stuff'
    const newUrl = encodeURIComponent(
      'www.nytimes.com/games?some=stuff&smid=tw-share',
    )

    expect(encodeUrlWithSMID(url, SMID.twitter)).toBe(newUrl)
  })

  it('should return share url with proper params', () => {
    const date = '2022-11-15'
    const letters = 'abcedfg'
    const points = 100
    const rank = 'Genius'

    const { shareUrl } = getShareInfo(date, letters, points, rank)

    expect.assertions(5)
    expect(shareUrl.includes('.html')).toBe(true)
    expect(shareUrl.includes('d=2022-11-15')).toBe(true)
    expect(shareUrl.includes('l=abcedfg')).toBe(true)
    expect(shareUrl.includes('p=100')).toBe(true)
    expect(shareUrl.includes('r=Genius')).toBe(true)
  })

  it('should return share image url with proper params', () => {
    const date = '2022-11-15'
    const letters = 'abcedfg'
    const points = 100
    const rank = 'Genius'

    const { shareImageSrc } = getShareInfo(
      date,
      letters,
      points,
      rank,
    )

    expect.assertions(5)
    expect(shareImageSrc.includes('.png')).toBe(true)
    expect(shareImageSrc.includes('d=2022-11-15')).toBe(true)
    expect(shareImageSrc.includes('l=abcedfg')).toBe(true)
    expect(shareImageSrc.includes('p=100')).toBe(true)
    expect(shareImageSrc.includes('r=Genius')).toBe(true)
  })
})
