import React from 'react'
import cn from 'classnames'

import { useSbSelector } from '../../store/game/hooks'
import { selectCurrentScore } from '../../store/game/game.selectors'

import {
  selectRanksForModal,
  selectRanksForCutoff,
  selectPointsForGenius,
} from './ranksSelectors'
import RankModalRow from './RankModalRow'

type ModalRankTableProps = {
  isCutoff?: boolean
}

const ModalRankTable: React.FC<ModalRankTableProps> = ({
  isCutoff,
}: ModalRankTableProps) => {
  const allRanks = useSbSelector(selectRanksForModal)
  const cutoffRanks = useSbSelector(selectRanksForCutoff)

  const ranks = isCutoff ? cutoffRanks : allRanks

  const pointsForGenius = useSbSelector(selectPointsForGenius)
  const score = useSbSelector(selectCurrentScore)

  return (
    <table
      className={cn('sb-modal-ranks__list', {
        'sb-modal-ranks__cutoff-scoreboard-table': isCutoff,
      })}
    >
      {isCutoff ? null : (
        <thead>
          <tr className="sb-modal-ranks__col-headers">
            <th className="sb-modal-ranks__rank-marker" />
            <th className="sb-modal-ranks__rank-title">Rank</th>
            <th className="sb-modal-ranks__spacer" />
            <th className="sb-modal-ranks__rank-points">
              Minimum score
            </th>
          </tr>
        </thead>
      )}
      <tbody>
        {ranks.map((rankItem, index) => (
          <RankModalRow
            key={rankItem.title}
            rankItem={rankItem}
            index={index}
            pointsForGenius={pointsForGenius}
            score={score}
            isBottom={index === allRanks.length - 1}
          />
        ))}
      </tbody>
    </table>
  )
}

export default ModalRankTable
