import { Middleware } from 'redux'
import { screen } from '@testing-library/react'

import { SpellingBeeState } from '../../store'
import { ACCEPT_WORD } from '../../store/game/game.actions'
import renderWithRankUp from '../../__tests__/renderWithRankUp'

import ModalRanks from './ModalRanks'

jest.mock('../../store/middleware/analytics', () => {
  const middlewareNoop: Middleware<{}, SpellingBeeState> =
    () => (next) => (action) =>
      next(action)

  return {
    analyticsMiddleware: middlewareNoop,
    trackGameStateMiddleware: middlewareNoop,
    trackUserStateMiddleware: middlewareNoop,
  }
})

jest.mock('foundation', () => ({
  ...jest.requireActual('foundation'),
  getGameData: () => {
    return require('../../__tests__/mockGameData').mockGameData
  },
}))

describe('SPELLING BEE: MODAL RANKS', () => {
  const renderModal = () => renderWithRankUp(ModalRanks)

  it('should have headings for Rank and Minimum score', () => {
    renderModal()
    expect(screen.queryByText('Rank')).toBeTruthy()
    expect(screen.queryByText('Minimum score')).toBeTruthy()
  })

  it('should only include Queen Bee once Queen Bee is reached', () => {
    const { rankUp } = renderModal()
    expect(screen.queryByText('Queen Bee')).toBeFalsy()
    rankUp(9)
    expect(screen.queryByText('Queen Bee')).toBeTruthy()
  })

  it('should have 1 highlighted row', () => {
    const { component: modal } = renderModal()
    expect(
      modal.container.querySelectorAll('.sb-modal-ranks__current'),
    ).toHaveLength(1)
  })

  it('should highlight Genius with subtext', () => {
    const { component: modal, rankUp } = renderModal()
    rankUp(8)
    expect(
      modal.container.querySelectorAll('.sb-modal-ranks__current'),
    ).toHaveLength(1)
    expect(
      screen.queryByText('Congrats!', { exact: false }),
    ).toBeTruthy()
  })

  it('should display score, rank, and helper text on highlighted row', () => {
    const { store, component: modal } = renderModal()
    store.dispatch({ type: ACCEPT_WORD, payload: 'illegality' })
    const currentRow = modal.container.querySelector(
      '.sb-modal-ranks__current',
    )

    const getValue = (className: string) =>
      currentRow?.querySelector(`.${className}`)?.textContent

    const score = getValue('current-score')
    const rankTitle = getValue('current-rank')
    const subText = getValue('sub-text')

    expect(score).toEqual('10')
    expect(rankTitle).toEqual('Moving Up')
    expect(subText).toEqual('5 points to next rank, 117 to Genius')
  })

  it('should not be redundant at Amazing', () => {
    const { component: modal, rankUp } = renderModal()
    rankUp(7)
    const currentRow = modal.container.querySelector(
      '.sb-modal-ranks__current',
    )

    const getValue = (className: string) =>
      currentRow?.querySelector(`.${className}`)?.textContent

    const subText = getValue('sub-text')
    expect(subText).toEqual('35 points to Genius')
  })
})
