import React from 'react'
import cn from 'classnames'

import { RankItem } from './ranksSelectors'

type RankModalRowProps = {
  rankItem: RankItem
  index: number
  pointsForGenius?: number
  score: number
  isBottom: boolean
}

const RankModalRow = ({
  rankItem,
  index,
  pointsForGenius,
  score,
  isBottom,
}: RankModalRowProps) => {
  const { title, minScore, achieved, isCurrent, nextRankMinScore } =
    rankItem

  const isGenius = title === 'Genius'
  const isQueenBee = title === 'Queen Bee'

  const getCurrentRankSubText = () => {
    if (isGenius) {
      return 'Congrats! Can you spell even more words?'
    }

    if (isQueenBee) {
      return 'Congrats! You’ve found every single word!'
    }

    if (pointsForGenius && nextRankMinScore) {
      const toNext = nextRankMinScore - score
      const toGenius = pointsForGenius - score

      const points = `point${toNext <= 1 ? '' : 's'}`

      // remove redundancy at Amazing (the rank before Genius)
      if (toNext === toGenius) {
        return `${toNext} ${points} to Genius`
      }

      return `${toNext} ${points} to next rank, ${toGenius} to Genius`
    }
  }

  const progressMarkerElement = (
    <td className="sb-modal-ranks__rank-marker">
      <div
        className={cn({
          dot: index > 0,
          square: index === 0,
          achieved,
        })}
      />
      <div
        className={cn('line', {
          achieved,
          top: index === 0,
          bottom: isBottom,
        })}
      />
      {isCurrent && <span className="current-score">{score}</span>}
    </td>
  )

  const rankElement = isCurrent ? (
    <td className="sb-modal-ranks__rank-title">
      <span className="current-rank">
        {title}
        <div
          className={cn('rank-icon', {
            genius: isGenius,
            qb: isQueenBee,
          })}
        />
      </span>
      <span
        className={cn('sub-text', {
          points: !isGenius && !isQueenBee,
        })}
      >
        {getCurrentRankSubText()}
      </span>
    </td>
  ) : (
    <td className="sb-modal-ranks__rank-title">{title}</td>
  )

  return (
    <tr
      className={cn({
        'sb-modal-ranks__current': isCurrent,
        'sb-modal-ranks__achieved': achieved && !isCurrent,
      })}
    >
      {progressMarkerElement}
      {rankElement}
      <td
        className={cn('sb-modal-ranks__spacer', { hr: !isCurrent })}
      />
      <td className="sb-modal-ranks__rank-points">{minScore}</td>
    </tr>
  )
}

export default RankModalRow
