import { createSelector } from 'reselect'

import {
  selectCurrentRank,
  selectCurrentRankIdx,
  selectRanks,
} from '../../store/game/game.selectors'
import { SpellingBeeRank } from '../../store/utils'

export type RankItem = {
  title: SpellingBeeRank
  minScore: number
  achieved: boolean
  isCurrent: boolean
  nextRankMinScore?: number
  index: number
}

export const selectRanksForModal = createSelector(
  [selectRanks, selectCurrentRank, selectCurrentRankIdx],
  (ranks, currentRank, currentRankIdx): RankItem[] => {
    return (
      ranks
        .map(({ title, minScore }, index) => {
          return {
            title,
            minScore,
            isCurrent: title === currentRank,
            achieved: currentRankIdx >= index,
            nextRankMinScore: ranks[index + 1]?.minScore,
            index,
          }
        })
        // hide queen bee from the list unless the user is already there
        .filter(
          (rank) => rank.title !== 'Queen Bee' || rank.isCurrent,
        )
        .reverse()
    )
  },
)

export const selectRanksForCutoff = createSelector(
  [selectRanksForModal, selectCurrentRankIdx],
  (modalRanks, currRank) => {
    const cutoffTop = 5
    const cutoffBottom = 5

    // For cutoff, only display ranks within X ranks of current rank
    return modalRanks.filter((rank) => {
      return !(
        rank.index >= currRank + cutoffTop ||
        rank.index <= currRank - cutoffBottom
      )
    })
  },
)

export const selectPointsForGenius = createSelector(
  selectRanks,
  (ranks) => {
    const geniusRank = ranks.find((rank) => rank.title === 'Genius')
    return geniusRank?.minScore
  },
)
