import md5 from 'blueimp-md5'

const SHARE_URL_BASE =
  'https://www.nytimes.com/badges/games/v1/bee.html'

const IMAGE_URL_BASE =
  'https://www.nytimes.com/badges/games/v1/bee.png'

export const SMID = {
  facebook: 'fb-share',
  twitter: 'tw-share',
  whatsapp: 'wa-share',
  link: 'url-share',
}

// Generates a URL suitable for sharing containing the tracking param (smid)
export const encodeUrlWithSMID = (url: string, smid: string) => {
  if (!url) {
    return encodeURIComponent(
      'https://www.nytimes.com/puzzles/spelling-bee?smid=share',
    )
  }

  if (!smid) smid = 'share' // eslint-disable-line

  const sep = url.indexOf('?') === -1 ? '?' : '&'
  return encodeURIComponent(`${url}${sep}smid=${smid}`)
}

export const getShareInfo = (
  date: string,
  letters: string,
  points: number,
  rank: string,
) => {
  const baseParams = `d=${date}&l=${letters}&p=${points.toString()}&r=${rank}`
  const checksum = md5(baseParams)

  const shareUrl = encodeURI(
    `${SHARE_URL_BASE}?${baseParams}&c=${checksum}`,
  )
  const shareImageSrc = `${IMAGE_URL_BASE}?${baseParams}&c=${checksum}`

  return {
    shareUrl,
    shareImageSrc,
  }
}
