import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import { setUpStore } from '../../store'
import {
  LOAD_MULTI_STATES,
  MULTI_STATES_SUCCESS,
} from '../../../../../shared/moogle/moogleActions'
import { mockLatestsState } from '../../__tests__/mockLatestsState'

import RankList from './RankList'

jest.mock('foundation', () => ({
  ...jest.requireActual('foundation'),
  userType: { hasXwd: false, regiId: 2222 },
  trackInteraction: jest.fn(),
  getGameData: () => {
    return require('../../__tests__/mockGameData').mockGameData
  },
}))

describe('SPELLING BEE: RANK LIST', () => {
  beforeEach(() => {
    jest.resetAllMocks()
  })

  const toggleModal = jest.fn()

  const renderRankList = (stateError = false) => {
    const store = setUpStore()

    store.dispatch({ type: LOAD_MULTI_STATES })

    if (!stateError) {
      store.dispatch({
        type: MULTI_STATES_SUCCESS,
        payload: { data: mockLatestsState },
      })
    }

    return mount(
      <Provider store={store}>
        <RankList isToggled={false} toggleModal={toggleModal} />
      </Provider>,
    )
  }

  it('should show stats for this week by default', () => {
    const component = renderRankList()

    // find the text within the first list item
    const thisWeekListItem = component
      .find('DailyRecapBar')
      .find('.sb-stats-bar-rank')
      .first()

    // it displays the date for this week (as defined by data passed in)
    expect(thisWeekListItem.text()).toBe('Amazing')
  })

  it('renders current gameplay data (instead of backend data) for today', () => {
    const component = renderRankList()
    // find the 2rd node (in the mocked data, 2nd object
    // in thisWeek matches printDate, indicating today)
    const todaysListItem = component
      .find('DailyRecapBar')
      .find('.sb-stats-bar-rank')
      .at(1)

    // it displays the current gameplay data (computed by redux)
    // rather than the backend data
    expect(todaysListItem.text()).toBe('Nice')
  })

  it('should show stats in modal body for last week when toggled', () => {
    const component = renderRankList()

    // toggle the list
    const statsListComponent = component.setProps({
      children: <RankList isToggled toggleModal={toggleModal} />,
    })

    // find the text within the first list item
    const nextWeekListItem = statsListComponent
      .find('DailyRecapBar')
      .find('.sb-stats-bar-rank')
      .first()

    // it displays the date for last week (as defined by data passed in)
    expect(nextWeekListItem.text()).toEqual('Genius')
  })

  it('should render nothing if states arent loaded', () => {
    const component = renderRankList(true)
    expect(component.isEmptyRender()).toBe(true)
  })
})
