import React from 'react'

import { trackInteraction } from 'foundation'

import { useSbSelector } from '../../store/game/hooks'
import { List, ListItem } from '../../../../shared/Lists/List'
import { selectRankStats } from '../../store/api/api.selectors'

import DailyRecapBar from './DailyRecapBar'

/**
 * The prop isToggled is provided by the HOC `withToggle`
 * found in src/games/shared/Toggle/Toggle.tsx. RankList
 * is wrapped in `withToggle` in ModalStats component.
 */
const RankList = ({
  isToggled,
  toggleModal,
}: {
  isToggled: boolean
  toggleModal: (modalName?: string, trigger?: string) => void
}) => {
  const showLastWeek = isToggled
  const {
    printDate: currentPuzzlePrintDate,
    isPastPuzzle,
    id,
  } = useSbSelector((state) => state.game)

  trackInteraction({
    element: {
      name: 'spelling-bee',
      label: 'stats',
    },
    context: showLastWeek ? 'last-week' : 'this-week',
    name: {
      p: currentPuzzlePrintDate,
      t: isPastPuzzle ? 'archive' : 'today',
    },
  })

  const createTracking = (barPuzzleDate: string) => () => {
    trackInteraction({
      element: {
        name: 'spelling-bee',
        label: 'play-archive',
      },
      context: `SB-${id}`,
      region: 'stats',
      name: {
        p: currentPuzzlePrintDate,
        t: isPastPuzzle ? 'archive' : 'today',
      },
      label: barPuzzleDate,
    })
  }

  const statsFromState = useSbSelector(selectRankStats)

  if (!statsFromState) {
    return null
  }

  const weekOfStats = showLastWeek
    ? statsFromState.lastWeek
    : statsFromState.thisWeek

  return (
    <div>
      <List>
        {weekOfStats.map((item) => {
          return (
            <ListItem key={item.printDate} spacing="none">
              <DailyRecapBar
                publishedDate={item.printDate}
                rank={item.rank}
                wordsFound={item.wordsFound}
                totalWords={item.totalWords}
                trackClick={createTracking(item.printDate)}
                toggleModal={toggleModal}
                isCurrentPuzzle={
                  item.printDate === currentPuzzlePrintDate
                }
              />
            </ListItem>
          )
        })}
      </List>
    </div>
  )
}

export default RankList
