import React from 'react'
import cn from 'classnames'

import { useUser } from 'user'
import useFeatureFlag from 'shared/abra/useFeatureFlag'

import { trackImpression } from '../../../../helpers/tracking'
import { useSbSelector, useTracking } from '../../store/game/hooks'
import handleLoginButtonClick from '../../../../helpers/hybridLoginLinkClick'
import { List, ListItem } from '../../../../shared/Lists/List'
import Button from '../../../../shared/Button'

import DailyRecapBar from './DailyRecapBar'
import { Row, Stat } from './LifetimeStats'

// fake rank data for use in visual demonstration of what
// a users stats might look like
// dates are arbitrary but fall on the right days of the week we want to display
const fakeRankData = [
  {
    publishedDate: '2022-06-13',
    rank: 'Genius',
    wordsFound: 80,
    totalWords: 100,
  },
  {
    publishedDate: '2022-06-14',
    rank: 'Solid',
    wordsFound: 40,
    totalWords: 100,
  },
  {
    publishedDate: '2022-06-15',
    rank: 'Great',
    wordsFound: 70,
    totalWords: 100,
  },
  {
    publishedDate: '2022-06-16',
    rank: '',
    wordsFound: 0,
    totalWords: 0,
  },
]

const StatsAnonMessaging = () => {
  const trackSB = useTracking()
  const { updateUserType } = useUser()
  const { id } = useSbSelector((state) => state.game)
  const showLifetimeStats = useFeatureFlag('sbLifetimeStats')

  trackImpression(
    'softregiwall',
    'spelling-bee-weekly-recap',
    '',
    `SB-${id}`,
  )

  return (
    <div
      className={cn('sb-modal-message-container', {
        'lifetime-stats': showLifetimeStats,
      })}
    >
      <div className="sb-modal-overflow-fade">
        {showLifetimeStats && (
          <Row>
            <Stat id="puzzles" label="Puzzles">
              134
            </Stat>
            <Stat id="words" label="Words">
              4,602
            </Stat>
            <Stat id="pangrams" label="Pangrams">
              103
            </Stat>
          </Row>
        )}
        <List>
          {fakeRankData.map((item) => {
            return (
              <ListItem
                spacing="none"
                key={`list-${item.publishedDate}`}
              >
                <DailyRecapBar
                  key={item.publishedDate}
                  publishedDate={item.publishedDate}
                  rank={item.rank}
                  wordsFound={item.wordsFound}
                  totalWords={item.totalWords}
                  disableLink
                />
              </ListItem>
            )
          })}
        </List>
      </div>
      <div className="sb-regiwall-message">
        <h3>Your Spelling Bee stats, revealed.</h3>
        {showLifetimeStats ? (
          <p>
            Track weekly ranks and totals over time with a free New
            York Times account.
          </p>
        ) : (
          <p>
            Check out your ranks over time with a free <br />
            New York Times account.
          </p>
        )}
        <Button
          className="sb-anon-login"
          text={showLifetimeStats ? 'Create free account' : 'Log in'}
          onClick={(event) => {
            trackSB('log-in-weekly-recap')
            handleLoginButtonClick(
              event,
              updateUserType,
              '&asset=spelling-bee-stats',
            )
          }}
        />
      </div>
    </div>
  )
}

export default StatsAnonMessaging
