import React from 'react'

import { CONGRATS_NAVIGATE_BACK_TEXT } from '../../../helpers/navigateBack'
import RankRecap from '../recaps/index'
import Congrats from '../../../shared/moments/components/Congrats'

export const MomentCongrats = ({
  wordCount,
  score,
  isActive,
  trackInteraction,
  navigateBack,
  beatriceHatIcon,
  openShare,
  showRevealedCongrats,
  ...props
}: {
  navigateBack: () => void
  trackInteraction: (cause: string, label: string) => void
  beatriceHatIcon?: string
  wordCount?: number
  score?: number
  isActive?: boolean
  desktopButtonOrder?: 'default' | null
  openShare: () => void
  showRevealedCongrats?: boolean
}) => {
  const shareButton = {
    text: 'Share your achievement',
    variant: 'extra-extra-wide',
    action: () => {
      openShare()
    },
  }

  const backToHubButton = {
    text: CONGRATS_NAVIGATE_BACK_TEXT,
    color: 'secondary',
    variant: 'extra-extra-wide',
    action: () => {
      navigateBack()
      trackInteraction('back-to-hub', 'genius-modal')
    },
  }

  const momentCongratsProps = {
    ...props,
    icon: beatriceHatIcon,
    title: 'Genius',
    closeModalText: showRevealedCongrats
      ? 'Admire this puzzle'
      : 'Keep Playing',
    celebrationMessage: (
      <RankRecap messageType="today" isDisplayed={isActive} />
    ),
    desktopButtonOrder: 'default',
    buttons: showRevealedCongrats
      ? [shareButton]
      : [shareButton, backToHubButton],
    description: {
      text: `You reached the highest rank, with <em>${wordCount}\u00A0words</em> and <em>${score}\u00A0points</em>.`,
    },
  }

  return <Congrats game={momentCongratsProps} />
}

export default MomentCongrats
