import React from 'react'

import { CONGRATS_NAVIGATE_BACK_TEXT } from '../../../helpers/navigateBack'
import Congrats from '../../../shared/moments/components/Congrats'

export const MomentCongratsCompleted = ({
  wordCount,
  score,
  trackInteraction,
  navigateBack,
  openShare,
  showRevealedCongrats,
  ...props
}: {
  wordCount?: number
  score?: number
  trackInteraction: (cause: string, label: string) => void
  navigateBack: () => void
  desktopButtonOrder?: 'default' | null
  openShare: () => void
  showRevealedCongrats?: boolean
}) => {
  const shareButton = {
    text: 'Share your achievement',
    variant: 'extra-extra-wide',
    action: () => {
      openShare()
    },
  }

  const backToHubButton = {
    text: CONGRATS_NAVIGATE_BACK_TEXT,
    color: 'secondary',
    variant: 'extra-extra-wide',
    action: () => {
      navigateBack()
      trackInteraction('back-to-hub', 'completed-modal')
    },
  }

  const momentCongratsProps = {
    ...props,
    icon: 'spelling-bee-queen',
    title: 'Queen Bee',
    closeModalText: showRevealedCongrats ? 'Admire this puzzle' : '',
    desktopButtonOrder: 'default',
    buttons: showRevealedCongrats
      ? [shareButton]
      : [shareButton, backToHubButton],
    description: {
      text: `You found everything! All <em>${wordCount}\u00A0words</em> worth <em>${score}\u00A0points</em>.`,
    },
  }

  return <Congrats game={momentCongratsProps} />
}

export default MomentCongratsCompleted
