import React from 'react'
import cn from 'classnames'

import { useUser } from 'user'
import useCTA from 'shared/marketing/useCTA'

import {
  selectCurrentScore,
  selectRanks,
  selectCurrentRankIdx,
} from '../store/game/game.selectors'
import { trackImpression } from '../../../helpers/tracking'
import { handleSubscribe } from '../../../helpers/subscribeLinks'
import { getLoginLink } from '../../../helpers/loginLinks'
import { handleNativeLogin } from '../../../helpers/hybridLoginLinkClick'
import {
  navigateBack,
  CONGRATS_NAVIGATE_BACK_TEXT,
} from '../../../helpers/navigateBack'
import Congrats from '../../../shared/moments/components/Congrats'
import ModalRankTable from '../modals/ranks/ModalRankTable'
import { useSbSelector, useTracking } from '../store/game/hooks'

export const MomentCongratsCutoff = ({
  isActive,
}: {
  isActive: boolean
}) => {
  const trackSB = useTracking()
  const { updateUserType } = useUser()
  const { id } = useSbSelector((state) => state.game)

  const handleLoginLinkClick = (e: React.SyntheticEvent) => {
    trackSB('login')

    if (window.isHybridWebView && window.NativeBridge) {
      e.preventDefault()
      handleNativeLogin(updateUserType)
    }
  }

  const { getButtonText } = useCTA()

  const score = useSbSelector(selectCurrentScore)
  const ranks = useSbSelector(selectRanks)
  const rankIdx = useSbSelector(selectCurrentRankIdx)
  const pointsToNext = ranks[rankIdx + 1]?.minScore - score

  const momentCongratsCutoffProps = {
    bgColor: '$white',
    icon: 'spelling-bee-loved',
    title: `You’re ${pointsToNext} points away from the next rank in today’s puzzle.`,
    titleSize: 'med-large',
    buttons: [
      {
        variant: 'default',
        text: getButtonText(),
        action: () => {
          handleSubscribe('spellingBeeCutoffStop', updateUserType)
          trackSB('subscribe-congrats')
        },
      },
      {
        variant: 'default',
        text: CONGRATS_NAVIGATE_BACK_TEXT,
        color: 'secondary',
        action: () => {
          navigateBack()
          trackSB('back-to-hub', 'cutoff-modal')
        },
      },
    ],
    bodyText: (
      <>
        Have a Games subscription?{' '}
        <a
          href={getLoginLink(
            window || undefined,
            '&asset=spelling-bee-paywall',
          )}
          onClick={handleLoginLinkClick}
        >
          Log in
        </a>
        .
      </>
    ),
    description: {
      text: 'Subscribe to keep playing.',
      variant: 'small',
    },
    screen: 'congrats',
  }

  if (isActive) {
    trackImpression(
      'hardpaywall',
      'spelling-bee-cutoff',
      '',
      `SB-${id}`,
    )
  }

  return (
    <Congrats game={momentCongratsCutoffProps}>
      <div
        className={cn(
          'sb-modal-overflow-fade',
          'sb-modal-overflow-fade-top',
          'sb-modal-ranks__cutoff-scoreboard',
        )}
      >
        <ModalRankTable isCutoff />
      </div>
    </Congrats>
  )
}

export default MomentCongratsCutoff
