import React from 'react'

import { trackInteraction } from 'foundation'

import {
  selectHasWon,
  selectWordCount,
  selectIsRevealed,
  selectBeatriceHat,
  selectCurrentScore,
} from '../store/game/game.selectors'
import { useSbSelector } from '../store/game/hooks'
import { trackImpression } from '../../../helpers/tracking'
import { navigateBack } from '../../../helpers/navigateBack'
import { usePastPuzzles } from '../../../../shared/abra/usePastPuzzles'

import MomentCongrats from './MomentCongrats'
import { MomentCongratsProps } from './constants'
import MomentCongratsCompleted from './MomentCongratsCompleted'

type MomentCongratsManagerProps = {
  isActive: boolean
  toggleModal: (m?: string, origin?: string) => {}
  momentSystem: {
    transition: (from: string, to: string) => Promise<void>
  }
}

export const MomentCongratsManager = ({
  isActive,
  toggleModal,
  momentSystem,
}: MomentCongratsManagerProps) => {
  const bgColor = '$white'
  const gotGenius = useSbSelector(selectHasWon)
  const score = useSbSelector(selectCurrentScore)
  const wordCount = useSbSelector(selectWordCount)
  const isRevealed = useSbSelector(selectIsRevealed)
  const beatriceHatIcon = useSbSelector(selectBeatriceHat)
  const { id, printDate, isPastPuzzle } = useSbSelector(
    (state) => state.game,
  )

  const isPastPuzzlesActive = usePastPuzzles()

  const showRevealedCongrats = isPastPuzzlesActive && isRevealed

  const trackSB = (
    elementLabel: string,
    label?: string,
    elementName?: string,
  ) => {
    trackInteraction({
      element: {
        name: elementName || 'spelling-bee',
        label: elementLabel,
      },
      context: `SB-${id}`,
      name: {
        p: printDate,
        t: isPastPuzzle ? 'archive' : 'today',
      },
      label,
    })
  }

  const transitionToGame = () => {
    momentSystem.transition('congrats', 'game')
  }

  const openShare = () => {
    toggleModal('share')
  }

  const congratsProps: MomentCongratsProps = {
    score,
    bgColor,
    isActive,
    openShare,
    wordCount,
    navigateBack,
    momentSystem,
    trackImpression,
    beatriceHatIcon,
    transitionToGame,
    trackInteraction: trackSB,
    screen: 'congrats' as const,
    close: {
      action: transitionToGame,
    },
    showRevealedCongrats,
  }

  if (gotGenius) {
    return <MomentCongrats {...congratsProps} />
  }

  return <MomentCongratsCompleted {...congratsProps} />
}

export default MomentCongratsManager
