import React from 'react'

import { useUser } from 'user'

import colors from '../../../shared/colors/colors'
import { useSbSelector } from '../store/game/hooks'
import Loader from '../../../shared/moments/components/Loader'
import { willUseMeterToGate } from '../../../../shared/meter'

type LoaderConfig = {
  bgColor: keyof typeof colors
  barBgColor: string
  barColor: string
  transitionTo: string
}

const config: LoaderConfig = {
  bgColor: '$spelling-bee-gold',
  barBgColor: 'rgba(255, 255, 255, 0.6)',
  barColor: 'black',
  transitionTo: 'welcome',
}

type MomentLoaderProps = {
  momentSystem: {
    transition: () => {}
    sequencingClass: string
  }
  icon: string
  title: string
  bgColor: LoaderConfig['bgColor']
  description: string
  isActive: boolean
}

const MomentLoader = (props: MomentLoaderProps) => {
  const { hasLoaded: hasUserLoaded, userType } = useUser()
  const hasProgressLoaded = useSbSelector(
    (state) => state.game.hasLoaded,
  )

  const { hash: meterHash } = useSbSelector((state) => state.meter)

  const hasLoaded = hasUserLoaded && hasProgressLoaded
  const loaderProps = { ...props, ...config, hasLoaded }

  return <Loader {...loaderProps} />
}

export default MomentLoader
