import React from 'react'

import { usePastPuzzles } from '../../../../shared/abra/usePastPuzzles'
import Welcome from '../../../shared/moments/components/Welcome'

import {
  MomentWelcomeProps,
  WelcomeProps,
  MomentButton,
} from './constants'

export const MomentWelcome = ({
  transitionToGame,
  handleSubscribe,
  trackInteraction,
  isSubscribed,
  isGamesSale,
  gamesSaleText,
  isInGamesApp,
  openPastPuzzleHub,
  ...props
}: MomentWelcomeProps) => {
  const isPastPuzzlesActive = usePastPuzzles()
  const buttons: MomentButton[] = [
    {
      text: 'Play',
      action: () => {
        transitionToGame()
        trackInteraction('start-game')
      },
    },
  ]

  if (!isSubscribed) {
    buttons.push({
      text: isGamesSale ? gamesSaleText : 'Subscribe',
      color: 'secondary',
      action: () => {
        handleSubscribe('spellingBeeCutoffStart')
        trackInteraction('subscribe-welcome')
      },
    })
  }

  // If past puzzles is active, and user is a sub
  // in games app, show Past Puzzles button
  if (isPastPuzzlesActive && isInGamesApp && isSubscribed) {
    buttons.push({
      text: 'Past Puzzles',
      color: 'secondary',
      action: () => {
        trackInteraction('spelling-bee-hub', 'welcome')
        openPastPuzzleHub()
      },
    })
  }

  const welcomeProps: WelcomeProps = {
    ...props,
    description: {
      text: 'How many words can you make with&nbsp;7&nbsp;letters?',
    },
    buttonGroups: [{ buttons }],
  }

  return <Welcome game={welcomeProps} />
}

export default MomentWelcome
