import React from 'react'

import { usePastPuzzles } from '../../../../shared/abra/usePastPuzzles'
import WelcomeBack from '../../../shared/moments/components/WelcomeBack'

import {
  MomentWelcomeProps,
  WelcomeProps,
  MomentButton,
} from './constants'

export const MomentWelcomeBack = ({
  wordCount,
  transitionToGame,
  handleSubscribe,
  trackInteraction,
  isSubscribed,
  isGamesSale,
  gamesSaleText,
  isInGamesApp,
  openPastPuzzleHub,
  ...props
}: MomentWelcomeProps) => {
  const isPastPuzzlesActive = usePastPuzzles()
  const buttons: MomentButton[] = [
    {
      text: 'Continue',
      action: () => {
        transitionToGame()
        trackInteraction('continue')
      },
    },
  ]

  if (!isSubscribed) {
    buttons.push({
      text: isGamesSale ? gamesSaleText : 'Subscribe',
      color: 'secondary',
      action: () => {
        handleSubscribe('spellingBeeCutoffWelcomeBack')
        trackInteraction('subscribe-welcome-back')
      },
    })
  }

  // If past puzzles is active, and user is a sub
  // in games app, show Past Puzzles button
  if (isPastPuzzlesActive && isInGamesApp && isSubscribed) {
    buttons.push({
      text: 'Past Puzzles',
      color: 'secondary',
      action: () => {
        trackInteraction('spelling-bee-hub', 'welcome-back')
        openPastPuzzleHub()
      },
    })
  }

  const welcomeBackProps: WelcomeProps = {
    ...props,
    description: {
      text: `You’ve found ${wordCount}&nbsp;word${
        wordCount > 1 ? 's' : ''
      }.`,
    },
    buttonGroups: [{ buttons }],
  }

  return <WelcomeBack game={welcomeBackProps} />
}

export default MomentWelcomeBack
