import React from 'react'

import { useSbSelector } from '../store/game/hooks'
import { trackImpression } from '../../../helpers/tracking'
import WelcomeBack from '../../../shared/moments/components/WelcomeBack'

type MomentWelcomeBackCutoffProps = {
  handleSubscribe: (tag: string) => void
  trackInteraction: (label: string) => void
  isActive: boolean
  isGamesSale: boolean
  gamesSaleText: string
}

export const MomentWelcomeBackCutoff = ({
  handleSubscribe,
  trackInteraction,
  isActive,
  isGamesSale,
  gamesSaleText,
  ...props
}: MomentWelcomeBackCutoffProps) => {
  const { id } = useSbSelector((state) => state.game)
  // please note that the shared Welcome Moment has a bevy of props you can provide,
  // the shared Moment code is not in TS so below types are scoped to this file for sake of berevity
  // see file: /shared/moments/components/Welcome.js for other types
  // ticket: https://jira.nyt.net/browse/XWD-18466
  const momentWelcomeBackProps: {
    buttonGroups: {
      buttons: {
        text: string
        variant?: string
        action: () => void
        color?: string
        icon?: string
      }[]
    }[]
    description: {
      text: string
      variant?: string
    }
  } = {
    ...props,
    buttonGroups: [
      {
        buttons: [
          {
            color: 'secondary',
            variant: 'wide',
            text: 'Today’s Puzzle',
            action: () => {
              handleSubscribe('spellingBeeCutoffWelcomeBack')
              trackInteraction('play-subscribe')
            },
            icon: 'locked',
          },
          {
            color: 'primary',
            variant: 'wide',
            text: isGamesSale ? gamesSaleText : 'Subscribe',
            action: () => {
              handleSubscribe('spellingBeeCutoffWelcomeBack')
              trackInteraction('subscribe-welcome-back')
            },
          },
        ],
      },
    ],
    description: {
      text: 'Subscribe to continue playing or come back tomorrow.',
      variant: 'small',
    },
  }

  if (isActive) {
    trackImpression(
      'hardpaywall',
      'spelling-bee-cutoff-welcome',
      '',
      `SB-${id}`,
    )
  }

  return <WelcomeBack game={momentWelcomeBackProps} />
}

export default MomentWelcomeBackCutoff
