import React, { useEffect } from 'react'

import { trackImpression } from 'foundation'
import useCTA from 'shared/marketing/useCTA'

import WelcomePast, {
  WelcomePastProps,
} from '../../../shared/moments/components/WelcomePast'
import { useSbSelector } from '../store/game/hooks'
import { selectCurrentScore } from '../store/game/game.selectors'
import { selectPointsForGenius } from '../modals/ranks/ranksSelectors'

import { MomentWelcomeProps } from './constants'

export const MomentWelcomeBackPast = ({
  icon,
  date,
  editor,
  bgColor,
  usingMeter,
  isSubscribed,
  shouldCutOff,
  isInGamesApp,
  handleSubscribe,
  transitionToGame,
  trackInteraction,
  openPastPuzzleHub,
}: MomentWelcomeProps) => {
  const { getButtonText } = useCTA()
  const isGated = usingMeter ? shouldCutOff : !isSubscribed
  const currentScore = useSbSelector(selectCurrentScore)
  const genius = useSbSelector(selectPointsForGenius) || 0
  const pointsToGenius = genius - currentScore
  const pointsToGeniusMessage = `You’re ${pointsToGenius} points away from Genius!`
  const dayOfWeek = useSbSelector(
    (state) => state.game.displayWeekday,
  )

  // Impression
  const id = useSbSelector((state) => state.game.id)
  const currentMoment = useSbSelector(
    (state) => state.game.currentMoment,
  )

  useEffect(() => {
    if (isGated && currentMoment === 'welcome') {
      trackImpression(
        'hardpaywall',
        'spelling-bee-archive',
        null,
        `SB-${id}`,
      )
    }
  }, [currentMoment, isGated])

  // Buttons
  const playButton = {
    text: currentScore < genius ? 'Continue' : 'Play',
    action: () => {
      transitionToGame()
      trackInteraction('continue')
    },
  }

  const subscribeButton = {
    text: getButtonText(),
    action: () => {
      handleSubscribe('spellingBeeWelcomePastPuzzles')
      trackInteraction('subscribe-welcome-back')
    },
  }

  const pastPuzzlesButton = {
    text: 'Past Puzzles',
    color: 'secondary',
    action: () => {
      trackInteraction('spelling-bee-hub', 'welcome-back')
      openPastPuzzleHub()
    },
  }

  const buttons = isGated ? [subscribeButton] : [playButton]

  // Only show Past Puzzles button in Games App
  if (!isGated && isInGamesApp) buttons.push(pastPuzzlesButton)

  // Description
  const pointsRecap = `You have ${currentScore} point${
    currentScore === 1 ? '' : 's'
  }.`
  const subscribeMessage = `${pointsRecap} <br /> Want to continue this puzzle?`
  const playMessage =
    currentScore < genius
      ? `${pointsRecap}<br />${pointsToGeniusMessage}`
      : pointsRecap

  // Welcome Past Props
  const welcomePastProps: WelcomePastProps = {
    icon,
    subtitle: 'PAST PUZZLES',
    title: dayOfWeek,
    editor,
    date,
    bgColor,
    buttons,
    description: {
      text: isGated ? subscribeMessage : playMessage,
      font: 'karnak',
    },
  }

  return <WelcomePast {...welcomePastProps} />
}

export default MomentWelcomeBackPast
