import React, { useEffect } from 'react'

import { trackImpression } from 'foundation'
import useCTA from 'shared/marketing/useCTA'

import WelcomePast, {
  WelcomePastProps,
} from '../../../shared/moments/components/WelcomePast'
import { useSbSelector } from '../store/game/hooks'

import { MomentWelcomeProps } from './constants'

export const MomentWelcomePast = ({
  icon,
  date,
  editor,
  bgColor,
  usingMeter,
  shouldCutOff,
  isSubscribed,
  isInGamesApp,
  handleSubscribe,
  transitionToGame,
  trackInteraction,
  openPastPuzzleHub,
}: MomentWelcomeProps) => {
  const { getButtonText } = useCTA()
  const isGated = usingMeter ? shouldCutOff : !isSubscribed
  const dayOfWeek = useSbSelector(
    (state) => state.game.displayWeekday,
  )

  const id = useSbSelector((state) => state.game.id)
  const currentMoment = useSbSelector(
    (state) => state.game.currentMoment,
  )

  useEffect(() => {
    if (isGated && currentMoment === 'welcome') {
      trackImpression(
        'hardpaywall',
        'spelling-bee-archive',
        null,
        `SB-${id}`,
      )
    }
  }, [currentMoment])

  const playButton = {
    text: 'Play',
    action: () => {
      transitionToGame()
      trackInteraction('start-game')
    },
  }

  const subscribeButton = {
    text: getButtonText(),
    action: () => {
      handleSubscribe('spellingBeeWelcomePastPuzzles')
      trackInteraction('subscribe-welcome')
    },
  }

  const pastPuzzlesButton = {
    text: 'Past Puzzles',
    color: 'secondary',
    action: () => {
      trackInteraction('spelling-bee-hub', 'welcome')
      openPastPuzzleHub()
    },
  }

  const buttons = isGated ? [subscribeButton] : [playButton]

  // Only show Past Puzzles button in Games App
  if (!isGated && isInGamesApp) buttons.push(pastPuzzlesButton)

  const welcomePastProps: WelcomePastProps = {
    icon,
    subtitle: 'PAST PUZZLES',
    title: dayOfWeek,
    editor,
    date,
    bgColor,
    buttons,
    description: {
      text: isGated
        ? 'Want to play past puzzles?'
        : 'You haven’t started this puzzle yet.<br />Can you get to Genius?',
      font: isGated ? 'franklin' : 'karnak',
    },
  }

  return <WelcomePast {...welcomePastProps} />
}

export default MomentWelcomePast
