import React from 'react'

import { trackInteraction } from 'foundation'

import WelcomePast, {
  WelcomePastProps,
} from '../../../shared/moments/components/WelcomePast'
import { useSbSelector } from '../store/game/hooks'
import { selectCurrentRank } from '../store/game/game.selectors'
import useFeatureFlag from '../../../../shared/abra/useFeatureFlag'

import { MomentWelcomeProps } from './constants'

export const MomentWelcomeRevealed = ({
  icon,
  date,
  bgColor,
  transitionToGame,
  openPastPuzzleHub,
}: MomentWelcomeProps) => {
  const {
    id,
    printDate,
    isPastPuzzle,
    displayWeekday: dayOfWeek,
  } = useSbSelector((state) => state.game)
  const rank = useSbSelector(selectCurrentRank)
  const showOldIcons = useFeatureFlag('sbHubIconsOld')

  const pastPuzzlesButton = {
    text: 'All Past Puzzles',
    color: 'secondary',
    action: () => {
      trackInteraction({
        element: {
          name: 'spelling-bee',
          label: 'spelling-bee-hub',
        },
        context: `SB-${id}`,
        name: {
          p: printDate,
          t: isPastPuzzle ? 'archive' : 'today',
        },
        region: 'revealed-welcome',
      })
      openPastPuzzleHub()
    },
  }

  const admireButton = {
    text: 'Admire this puzzle >',
    color: 'secondary',
    variant: 'link',
    action: () => {
      trackInteraction({
        element: {
          name: 'spelling-bee',
          label: 'close-reveal',
        },
        context: `SB-${id}`,
        name: {
          p: printDate,
          t: isPastPuzzle ? 'archive' : 'today',
        },
        region: 'revealed-welcome',
      })
      transitionToGame()
    },
  }

  const welcomeRevealedProps: WelcomePastProps = {
    icon: showOldIcons
      ? 'old-spelling-bee-gold-star'
      : 'spelling-bee-gold-star',
    subtitle: 'PAST PUZZLES',
    title: dayOfWeek,
    date,
    description: {
      text: `You got <span class=${
        showOldIcons ? 'sb-moment__rank-old' : 'sb-moment__rank'
      }>${rank}</span>on
      this puzzle! After revealing, you can no longer
      <br />
      enter words.`,
    },
    bgColor,
    buttons: [pastPuzzlesButton, admireButton],
    buttonsStyle: 'vertical',
  }

  return <WelcomePast {...welcomeRevealedProps} />
}

export default MomentWelcomeRevealed
