import React from 'react'
import { mount } from 'enzyme'

import { CONGRATS_NAVIGATE_BACK_TEXT } from '../../../../helpers/navigateBack'
import { MomentCongrats } from '../MomentCongrats'
import RankRecap from '../../recaps/index'

jest.mock('responsive', () => ({
  isMobile: false,
}))

// mock Recap component
jest.mock('../../recaps/index', () => {
  return {
    __esModule: true,
    default: () => {
      return <div />
    },
  }
})

const trackInteraction = jest.fn()
const navigateBack = jest.fn()
const wordCount = 2
const score = 2
const props = {
  trackInteraction,
  navigateBack,
  wordCount,
  score,
}

describe('MOMENT CONGRATS', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })
  it('should render proper text', () => {
    const wrapper = mount(<MomentCongrats {...props} />)
    expect(wrapper.text()).toContain(
      'You reached the highest rank, with 2\u00A0words and 2\u00A0points.',
    )
  })

  it("should render a 'More puzzles' button", () => {
    const wrapper = mount(<MomentCongrats {...props} />)

    expect(
      wrapper.find('.pz-moment__button').last().text(),
    ).toContain(CONGRATS_NAVIGATE_BACK_TEXT)
  })

  it("should call navigateBack + trackInteraction on 'More puzzles' button click", () => {
    const wrapper = mount(<MomentCongrats {...props} />)

    wrapper.find('.pz-moment__button').last().simulate('click')
    expect(navigateBack).toBeCalled()
    expect(trackInteraction).toBeCalledWith(
      'back-to-hub',
      'genius-modal',
    )
  })

  it('should show rank recap message', () => {
    const wrapper = mount(<MomentCongrats {...props} isActive />)
    const rankMessage = wrapper.find(RankRecap)

    expect(rankMessage.props().messageType).toBe('today')
  })

  it("should render a 'Share' button", () => {
    const wrapper = mount(<MomentCongrats {...props} />)

    expect(
      wrapper.find('.pz-moment__button').first().text(),
    ).toContain('Share your achievement')
  })

  it('should call share callback on Share your Achievement button click', () => {
    const shareCallback = jest.fn()
    const wrapper = mount(
      <MomentCongrats
        {...props}
        isActive
        closeModalText="Keep Playing"
        openShare={shareCallback}
        close={{ action: () => {} }}
      />,
    )

    wrapper.find('.pz-moment__button').first().simulate('click')
    expect(shareCallback).toHaveBeenCalledTimes(1)
  })

  it('should show close button with text if in props', () => {
    const wrapper = mount(
      <MomentCongrats
        {...props}
        isActive
        closeModalText="Keep Playing"
        close={{ action: () => {} }}
      />,
    )
    expect(wrapper.find('.pz-moment__close_text').text()).toBe(
      'Keep Playing',
    )
  })

  it('should show close button with different text if puzzle is revealed', () => {
    const wrapper = mount(
      <MomentCongrats
        {...props}
        showRevealedCongrats
        close={{ action: () => {} }}
      />,
    )
    expect(wrapper.find('.pz-moment__close_text').text()).toBe(
      'Admire this puzzle',
    )
  })

  it('should only show share button if puzzle is revealed', () => {
    const wrapper = mount(
      <MomentCongrats {...props} showRevealedCongrats />,
    )

    const button = wrapper.find('.pz-moment__button')
    expect(button.length).toBe(1)
    expect(button.text()).toBe('Share your achievement')
  })
})
