import React from 'react'
import { mount } from 'enzyme'

import { MomentCongratsCompleted } from '../MomentCongratsCompleted'

jest.mock('responsive', () => ({
  isMobile: false,
}))

jest.mock('foundation', () => ({
  getGameData: () => ({
    today: { id: 1 },
  }),
}))

jest.mock('../../store/game/hooks', () => ({
  useSbSelector: () => {},
}))

const trackInteraction = jest.fn()
const transitionToGame = jest.fn()
const navigateBack = jest.fn()
const wordCount = 2
const score = 2

const props = {
  wordCount,
  score,
  trackInteraction,
  transitionToGame,
  navigateBack,
}

describe('MOMENT CONGRATS COMPLETED', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should render proper text', () => {
    const wrapper = mount(<MomentCongratsCompleted {...props} />)

    expect(wrapper.text()).toContain(
      `You found everything! All ${wordCount}\u00A0words worth ${score}\u00A0points.`,
    )
  })

  it("should render a 'Share Puzzle' button", () => {
    const wrapper = mount(<MomentCongratsCompleted {...props} />)

    expect(
      wrapper.find('.pz-moment__button').first().text(),
    ).toContain('Share your achievement')
  })

  it('should call share callback on Share your Achievement button click', () => {
    const shareCallback = jest.fn()
    const wrapper = mount(
      <MomentCongratsCompleted
        {...props}
        isActive
        closeModalText="Keep Playing"
        openShare={shareCallback}
        close={{ action: () => {} }}
      />,
    )

    wrapper.find('.pz-moment__button').first().simulate('click')
    expect(shareCallback).toHaveBeenCalledTimes(1)
  })

  it('should show close button with different text if puzzle is revealed', () => {
    const wrapper = mount(
      <MomentCongratsCompleted
        {...props}
        showRevealedCongrats
        close={{ action: () => {} }}
      />,
    )
    expect(wrapper.find('.pz-moment__close_text').text()).toBe(
      'Admire this puzzle',
    )
  })

  it('should only show share button if puzzle is revealed', () => {
    const wrapper = mount(
      <MomentCongratsCompleted {...props} showRevealedCongrats />,
    )

    const button = wrapper.find('.pz-moment__button')
    expect(button.length).toBe(1)
    expect(button.text()).toBe('Share your achievement')
  })
})
