import React from 'react'
import { mount } from 'enzyme'

import {
  navigateBack,
  CONGRATS_NAVIGATE_BACK_TEXT,
} from '../../../../helpers/navigateBack'
import { getLoginLink } from '../../../../helpers/loginLinks'
import { MomentCongratsCutoff } from '../MomentCongratsCutoff'
import { trackImpression } from '../../../../helpers/tracking'
import { handleSubscribe } from '../../../../helpers/subscribeLinks'

const mockTrack = jest.fn()

jest.mock('responsive', () => ({
  isMobile: false,
}))

jest.mock('../../store/game/hooks', () => ({
  useTracking: () => mockTrack,
  useSbSelector: () => [],
}))

jest.mock('../../../../helpers/tracking', () => ({
  trackImpression: jest.fn(),
}))

jest.mock('../../../../helpers/loginLinks', () => ({
  getLoginLink: jest.fn(),
}))

jest.mock('../../../../helpers/subscribeLinks', () => ({
  handleSubscribe: jest.fn(),
}))

jest.mock('../../../../helpers/navigateBack', () => ({
  navigateBack: jest.fn(),
  CONGRATS_NAVIGATE_BACK_TEXT: 'View all games',
}))

describe('MOMENT CONGRATS CUTOFF', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should render proper text', () => {
    const wrapper = mount(<MomentCongratsCutoff />)

    expect(wrapper.text()).toContain('Subscribe to keep playing')
  })

  it('should render a Subscribe and View all puzzles button', () => {
    const wrapper = mount(<MomentCongratsCutoff />)

    expect(
      wrapper.find('.pz-moment__button').first().text(),
    ).toContain('Subscribe')
    expect(
      wrapper.find('.pz-moment__button').last().text(),
    ).toContain(CONGRATS_NAVIGATE_BACK_TEXT)
  })

  it("should call subscribe + trackInteraction on 'subscribe' button click", () => {
    const wrapper = mount(<MomentCongratsCutoff />)

    wrapper.find('.pz-moment__button').first().simulate('click')
    expect(handleSubscribe).toBeCalled()
    expect(mockTrack).toBeCalledWith('subscribe-congrats')
  })

  it("should call navigateBack + trackInteraction on 'View all puzzles' button click", () => {
    const wrapper = mount(<MomentCongratsCutoff />)

    wrapper.find('.pz-moment__button').last().simulate('click')
    expect(navigateBack).toBeCalled()
    expect(mockTrack).toBeCalledWith('back-to-hub', 'cutoff-modal')
  })

  it("should call login + trackInteraction + gamesAuthenticateUser on 'login' link click", () => {
    const gamesAuthenticateUser = jest
      .fn()
      .mockImplementation(() =>
        Promise.resolve({ success: true, values: {} }),
      )
    window.isHybridWebView = true
    window.NativeBridge = { gamesAuthenticateUser }

    const wrapper = mount(<MomentCongratsCutoff />)

    wrapper.find('.pz-moment__body a').simulate('click')
    expect(getLoginLink).toBeCalled()
    expect(mockTrack).toBeCalledWith('login')
    expect(gamesAuthenticateUser).toBeCalledWith('login')
  })

  it('should not fire trackImpression on initial render', () => {
    mount(<MomentCongratsCutoff />)

    expect(trackImpression).toHaveBeenCalledTimes(0)
  })

  it('should fire trackImpression once active', () => {
    mount(<MomentCongratsCutoff isActive />)

    expect(trackImpression).toHaveBeenCalledTimes(1)
  })
})
