import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import MomentCongrats from '../MomentCongrats'
import MomentCongratsManager from '../MomentCongratsManager'
import MomentCongratsCompleted from '../MomentCongratsCompleted'

jest.mock('responsive', () => ({
  isMobile: false,
}))

jest.mock('foundation', () => ({
  trackClick: jest.fn(),
  getGameData: () => ({
    today: { id: 1 },
  }),
  mobileNavTools: {
    activate: jest.fn(),
    deactivate: jest.fn(),
  },
  track: jest.fn(),
}))

jest.mock('../../../../helpers/navigateBack', () => ({
  navigateBack: jest.fn(),
}))

const props = {
  isActive: false,
  toggleModal: jest.fn(),
  momentSystem: {
    transition: jest.fn().mockReturnValue(Promise.resolve()),
  },
}

const mockStore = (state) => {
  return {
    default: jest.fn(),
    subscribe: jest.fn(),
    dispatch: jest.fn(),
    getState: () => state,
  }
}

const gameState = {
  displayDate: 'March 5, 2021',
  editor: 'Sam Ezersky',
  foundWords: [
    'clickable',
    'aback',
    'babka',
    'bake',
    'balk',
    'cackle',
    'cake',
    'kebab',
  ],
  outerLetters: ['b', 'c', 'i', 'e', 'l', 'a'],
  centerLetter: 'k',
  pangrams: ['clickable'],
  answers: [
    'clickable',
    'aback',
    'babka',
    'bake',
    'balk',
    'cackle',
    'cake',
    'kebab',
    'kickball',
    'likeable',
  ],
  isPastPuzzle: false,
  userType: {
    hasXwd: true,
  },
  isRevealed: false,
}

const createComponent = (gameState) => {
  const store = mockStore({
    game: gameState,
    meter: {
      granted: true,
    },
  })

  const wrapper = mount(
    <Provider store={store}>
      <MomentCongratsManager {...props} />
    </Provider>,
  )

  return wrapper
}

describe('MOMENT CONGRATS MANAGER: MANAGEMENT', () => {
  it('should go to MomentCongrats if the user is subscribed and reached congrats', () => {
    const wrapper = createComponent(gameState)
    expect(wrapper.find(MomentCongrats)).toHaveLength(1)
  })

  it('should go to MomentCongratsCompleted if the user is subscribed and got all words', () => {
    const queenBeeGameState = {
      ...gameState,
      foundWords: gameState.answers,
    }

    const wrapper = createComponent(queenBeeGameState)
    expect(wrapper.find(MomentCongratsCompleted)).toHaveLength(1)
  })

  it('should show revealed congrats', () => {
    const revealedGameState = {
      ...gameState,
      isRevealed: true,
    }

    const wrapper = createComponent(revealedGameState)
    const congrats = wrapper.find(MomentCongrats)
    expect(congrats.props().showRevealedCongrats).toBe(true)
  })
})
