import React from 'react'
import { mount } from 'enzyme'

import { MomentWelcome } from '../MomentWelcome'

jest.mock('responsive', () => ({
  isMobile: false,
}))

jest.mock('foundation', () => ({
  trackClick: jest.fn(),
  getGameData: () => ({
    today: { id: 1 },
  }),
}))

const handleSubscribe = jest.fn()
const transitionToGame = jest.fn()
const trackInteraction = jest.fn()
const openPastPuzzleHub = jest.fn()

describe('MOMENT WELCOME: SUBSCRIBE', () => {
  it('should render a Subscribe button if the user is not logged in', () => {
    const props = {
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      isSubscribed: false,
    }

    const wrapper = mount(<MomentWelcome {...props} />)

    expect(wrapper.text()).toContain('Subscribe')
  })

  it('should call trackInteraction and transitionToGame on Play button click', () => {
    const props = {
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      isSubscribed: false,
    }

    const wrapper = mount(<MomentWelcome {...props} />)

    wrapper.find('.pz-moment__button').first().simulate('click')
    expect(trackInteraction).toBeCalledWith('start-game')
    expect(transitionToGame).toBeCalled()
  })

  it('should call handleSubscribe + trackInteraction on Subscribe button click', () => {
    const props = {
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      isSubscribed: false,
    }

    const wrapper = mount(<MomentWelcome {...props} />)

    wrapper.find('.pz-moment__button').last().simulate('click')
    expect(handleSubscribe).toBeCalledWith('spellingBeeCutoffStart')
    expect(trackInteraction).toBeCalledWith('subscribe-welcome')
  })

  it('should render Play button if the user is logged in', () => {
    const props = {
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      isSubscribed: true,
    }

    const wrapper = mount(<MomentWelcome {...props} />)
    const button = wrapper.find('.pz-moment__button')

    expect(button.length).toBe(1)
    expect(button.text()).toBe('Play')
  })

  it('should render the past puzzle hub button if user is a sub in games app', () => {
    const props = {
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      openPastPuzzleHub,
      isInGamesApp: true,
      isSubscribed: true,
    }

    const wrapper = mount(<MomentWelcome {...props} />)
    const button = wrapper.find('.pz-moment__button').last()

    expect(button.text()).toContain('Past Puzzles')
  })

  it('clicking on past puzzles button should open hub', () => {
    const props = {
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      openPastPuzzleHub,
      isInGamesApp: true,
      isSubscribed: true,
    }

    const wrapper = mount(<MomentWelcome {...props} />)
    const button = wrapper.find('.pz-moment__button').last()
    button.simulate('click')

    expect(openPastPuzzleHub).toHaveBeenCalledTimes(1)
  })
})
