import React from 'react'
import { mount } from 'enzyme'

import { MomentWelcomeBack } from '../MomentWelcomeBack'

jest.mock('responsive', () => ({
  isMobile: false,
}))

jest.mock('foundation', () => ({
  trackClick: jest.fn(),
  getGameData: () => ({
    today: { id: 1 },
  }),
}))

const editor = 'Sam Ezersky'
const date = 'March 5, 2021'
const handleSubscribe = jest.fn()
const transitionToGame = jest.fn()
const trackInteraction = jest.fn()
const openPastPuzzleHub = jest.fn()

describe('MOMENT WELCOME BACK: WORDS', () => {
  it("should be 'words' if wordCount is greater than 1", () => {
    const wordCount = 2
    const props = {
      wordCount,
      editor,
      date,
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      isSubscribed: false,
    }

    const wrapper = mount(<MomentWelcomeBack {...props} />)

    expect(wrapper.text()).toContain('You’ve found 2 words')
  })

  it("should be 'word' if wordCount is equal to 1", () => {
    const wordCount = 1
    const props = {
      wordCount,
      editor,
      date,
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      isSubscribed: false,
    }

    const wrapper = mount(<MomentWelcomeBack {...props} />)

    expect(wrapper.text()).toContain('You’ve found 1 word')
  })
})

describe('MOMENT WELCOME BACK: SUBSCRIBE', () => {
  it('should render a Subscribe button if the user is not logged in', () => {
    const wordCount = 1
    const props = {
      wordCount,
      editor,
      date,
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      isSubscribed: false,
    }

    const wrapper = mount(<MomentWelcomeBack {...props} />)

    expect(wrapper.text()).toContain('Subscribe')
  })

  it('should call trackInteraction and transitionToGame on Continue button click', () => {
    const wordCount = 1
    const props = {
      wordCount,
      editor,
      date,
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      isSubscribed: false,
    }

    const wrapper = mount(<MomentWelcomeBack {...props} />)

    wrapper.find('.pz-moment__button').first().simulate('click')
    expect(trackInteraction).toBeCalledWith('continue')
    expect(transitionToGame).toBeCalled()
  })

  it('should call handleSubscribe + trackInteraction on Subscribe button click', () => {
    const wordCount = 1
    const props = {
      wordCount,
      editor,
      date,
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      isSubscribed: false,
    }

    const wrapper = mount(<MomentWelcomeBack {...props} />)

    wrapper.find('.pz-moment__button').last().simulate('click')
    expect(handleSubscribe).toBeCalledWith(
      'spellingBeeCutoffWelcomeBack',
    )
    expect(trackInteraction).toBeCalledWith('subscribe-welcome-back')
  })

  it('should render a Continue button if the user is logged in', () => {
    const props = {
      wordCount: 1,
      editor,
      date,
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      isSubscribed: true,
    }

    const wrapper = mount(<MomentWelcomeBack {...props} />)
    const button = wrapper.find('.pz-moment__button')

    expect(button.length).toBe(1)
    expect(button.text()).toBe('Continue')
  })

  it('should render the past puzzle hub button if user is a sub in games app', () => {
    const props = {
      wordCount: 1,
      editor,
      date,
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      openPastPuzzleHub,
      isSubscribed: true,
      isInGamesApp: true,
    }

    const wrapper = mount(<MomentWelcomeBack {...props} />)
    const button = wrapper.find('.pz-moment__button').last()

    expect(button.text()).toContain('Past Puzzles')
  })

  it('clicking on past puzzles button should open hub', () => {
    const props = {
      wordCount: 1,
      editor,
      date,
      handleSubscribe,
      transitionToGame,
      trackInteraction,
      openPastPuzzleHub,
      isSubscribed: true,
      isInGamesApp: true,
    }

    const wrapper = mount(<MomentWelcomeBack {...props} />)
    const button = wrapper.find('.pz-moment__button').last()
    button.simulate('click')

    expect(openPastPuzzleHub).toHaveBeenCalledTimes(1)
  })
})
