import React from 'react'
import { mount } from 'enzyme'

import { trackImpression } from '../../../../helpers/tracking'
import { MomentWelcomeBackCutoff } from '../MomentWelcomeBackCutoff'

jest.mock('responsive', () => ({
  isMobile: false,
}))

jest.mock('foundation', () => ({
  trackClick: jest.fn(),
  getGameData: () => ({
    today: { id: 1 },
  }),
}))

jest.mock('../../../../helpers/tracking', () => ({
  trackImpression: jest.fn(),
}))

jest.mock('../../store/game/hooks', () => ({
  useSbSelector: () => 123,
}))

const handleSubscribe = jest.fn()
const trackInteraction = jest.fn()

const props = {
  handleSubscribe,
  trackInteraction,
}

describe('MOMENT WELCOME BACK CUTOFF', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should render proper text', () => {
    const wrapper = mount(<MomentWelcomeBackCutoff {...props} />)

    expect(wrapper.text()).toContain('Subscribe to continue playing')
  })

  it('should render a Today’s Puzzle and Subscribe button', () => {
    const wrapper = mount(<MomentWelcomeBackCutoff {...props} />)

    expect(
      wrapper.find('.pz-moment__button').first().text(),
    ).toContain('Today’s Puzzle')
    expect(
      wrapper.find('.pz-moment__button').last().text(),
    ).toContain('Subscribe')
  })

  it("should call handleSubscribe + trackInteraction on Today's Puzzle button click", () => {
    const wrapper = mount(<MomentWelcomeBackCutoff {...props} />)

    wrapper.find('.pz-moment__button').first().simulate('click')
    expect(handleSubscribe).toBeCalledWith(
      'spellingBeeCutoffWelcomeBack',
    )
    expect(trackInteraction).toBeCalledWith('play-subscribe')
  })

  it('should call handleSubscribe + trackInteraction on Subscribe button click', () => {
    const wrapper = mount(<MomentWelcomeBackCutoff {...props} />)

    wrapper.find('.pz-moment__button').last().simulate('click')
    expect(handleSubscribe).toBeCalledWith(
      'spellingBeeCutoffWelcomeBack',
    )
    expect(trackInteraction).toBeCalledWith('subscribe-welcome-back')
  })

  it('should not fire trackImpression on initial render', () => {
    mount(<MomentWelcomeBackCutoff {...props} />)

    expect(trackImpression).toHaveBeenCalledTimes(0)
  })

  it('should fire trackImpression once active', () => {
    mount(<MomentWelcomeBackCutoff {...props} isActive />)

    expect(trackImpression).toHaveBeenCalledTimes(1)
  })
})
