import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import RankRecap from '../index'
import { improvementMessages } from '../messaging'
import { trackImpression } from '../../../../helpers/tracking'

const mockStore = (state: {}) => {
  return {
    default: jest.fn(),
    subscribe: jest.fn(),
    dispatch: jest.fn(),
    getState: () => state,
  }
}
jest.mock('../../../../helpers/tracking', () => ({
  trackImpression: jest.fn(),
}))

describe('SPELLING BEE: YESTERDAYS RANK', () => {
  let component

  const puzzleData = {
    displayDate: '01-01-2020',
    centerLetter: 'A',
    validLetters: ['B', 'C', 'D', 'E', 'F', 'G'],
    answers: [
      'ACE',
      'BAG',
      'DEF',
      'FED',
      'ABC',
      'BAC',
      'GAG',
      'BAD',
      'FAD',
      'DAG',
      'GAD',
      'DAD',
      'DADA',
      'CAD',
      'GAB',
      'BAB',
      'DAB',
      'CAB',
      'FAB',
      'FADE',
    ],
    foundWords: ['ACE'],
    pangrams: ['ACE'],
  }

  const createComponent = (
    puzzleData: {
      displayDate: string
      centerLetter: string
      validLetters: string[]
      answers: string[]
      foundWords: string[]
      pangrams: string[]
    },
    messageType: 'yesterday' | 'today' = 'yesterday',
    isDisplayed: boolean = true,
  ) => {
    const store = mockStore({
      game: {
        id: 20,
        yesterday: puzzleData,
        isPastPuzzle: false,
      },
    })

    const wrapper = mount(
      <>
        {/* @ts-ignore */}
        <Provider store={store}>
          <RankRecap
            messageType={messageType}
            isDisplayed={isDisplayed}
          />
        </Provider>
      </>,
    )

    return wrapper.find(RankRecap)
  }

  beforeEach(() => {
    jest.resetAllMocks()
  })

  it('should mount', () => {
    component = createComponent(puzzleData)
    expect(component.length).toBeTruthy()
  })

  describe('YESTERDAY RANK RECAP', () => {
    it('should show Queen Bee message', () => {
      component = createComponent({
        ...puzzleData,
        foundWords: [
          'ACE',
          'BAG',
          'DEF',
          'FED',
          'ABC',
          'BAC',
          'GAG',
          'BAD',
          'FAD',
          'DAG',
          'GAD',
          'DAD',
          'DADA',
          'CAD',
          'GAB',
          'BAB',
          'DAB',
          'CAB',
          'FAB',
          'FADE',
        ],
      })
      const icon = component.find('.sb-modal-rank__icon')
      const text = component.find('p')

      expect(icon.hasClass('queen-bee')).toBe(true)
      expect(text.html().includes('Queen Bee')).toBe(true)
    })

    it('should show Genius message', () => {
      component = createComponent({
        ...puzzleData,
        foundWords: [
          'ACE',
          'BAG',
          'DEF',
          'FED',
          'ABC',
          'BAC',
          'GAG',
          'BAD',
          'FAD',
          'DAG',
          'GAD',
          'DAD',
          'DADA',
          'CAD',
          'GAB',
          'BAB',
          'DAB',
          'CAB',
          'FAB',
        ],
      })
      const icon = component.find('.sb-modal-rank__icon')
      const text = component.find('p')

      expect(icon.hasClass('genius')).toBe(true)
      expect(text.html().includes('Genius')).toBe(true)
    })

    it('should show Amazing message', () => {
      component = createComponent({
        ...puzzleData,
        foundWords: [
          'ACE',
          'BAG',
          'DEF',
          'FED',
          'ABC',
          'BAC',
          'GAG',
          'BAD',
          'FAD',
          'DAG',
          'GAD',
          'DAD',
        ],
      })
      const icon = component.find('.sb-modal-rank__icon')
      const text = component.find('p')

      expect(icon.hasClass('genius')).toBe(false)
      expect(icon.hasClass('queen-bee')).toBe(false)
      expect(text.html().includes('Amazing')).toBe(true)
    })

    it('should show Great message', () => {
      component = createComponent({
        ...puzzleData,
        foundWords: [
          'ACE',
          'BAG',
          'DEF',
          'FED',
          'ABC',
          'BAC',
          'GAG',
          'BAD',
          'FAD',
        ],
      })
      const icon = component.find('.sb-modal-rank__icon')
      const text = component.find('p')

      expect(icon.hasClass('genius')).toBe(false)
      expect(icon.hasClass('queen-bee')).toBe(false)
      expect(text.html().includes('Great')).toBe(true)
    })

    it('should show Nice message', () => {
      component = createComponent({
        ...puzzleData,
        foundWords: ['ACE', 'BAG', 'DEF', 'FED', 'ABC'],
      })
      const icon = component.find('.sb-modal-rank__icon')
      const text = component.find('p')

      expect(icon.hasClass('genius')).toBe(false)
      expect(icon.hasClass('queen-bee')).toBe(false)
      expect(text.html().includes('Nice')).toBe(true)
    })

    it('should show Solid message', () => {
      component = createComponent({
        ...puzzleData,
        foundWords: ['ACE', 'BAG', 'DEF', 'FED'],
      })
      const icon = component.find('.sb-modal-rank__icon')
      const text = component.find('p')

      expect(icon.hasClass('genius')).toBe(false)
      expect(icon.hasClass('queen-bee')).toBe(false)
      expect(text.html().includes('Solid')).toBe(true)
    })

    it('should show Good message', () => {
      component = createComponent({
        ...puzzleData,
        foundWords: ['ACE', 'BAG'],
      })
      const icon = component.find('.sb-modal-rank__icon')
      const text = component.find('p')

      expect(icon.hasClass('genius')).toBe(false)
      expect(icon.hasClass('queen-bee')).toBe(false)
      expect(text.html().includes('Good')).toBe(true)
    })

    it('should show Moving Up message', () => {
      component = createComponent({
        ...puzzleData,
        foundWords: ['ACE'],
      })
      const icon = component.find('.sb-modal-rank__icon')
      const text = component.find('p')

      expect(icon.hasClass('genius')).toBe(false)
      expect(icon.hasClass('queen-bee')).toBe(false)
      expect(text.html().includes('Moving Up')).toBe(true)
    })

    it('should fire tracking function', () => {
      component = createComponent({
        ...puzzleData,
        foundWords: ['ACE'],
      })

      expect(trackImpression).toHaveBeenCalledWith(
        'stats',
        'spelling-bee-yesterday',
        '2-moving-up',
        'SB-20',
      )
    })

    it('should not fire tracking function if isDisplayed is false', () => {
      component = createComponent(
        {
          ...puzzleData,
          foundWords: ['ACE'],
        },
        'yesterday',
        false,
      )

      expect(trackImpression).not.toHaveBeenCalled()
    })
  })

  describe('SPELLING BEE: TODAYS RANK', () => {
    it('should show Genius repeat message', () => {
      component = createComponent(
        {
          ...puzzleData,
          foundWords: [
            'ACE',
            'BAG',
            'DEF',
            'FED',
            'ABC',
            'BAC',
            'GAG',
            'BAD',
            'FAD',
            'DAG',
            'GAD',
            'DAD',
            'DADA',
            'CAD',
            'GAB',
            'BAB',
            'DAB',
            'CAB',
            'FAB',
          ],
        },
        'today',
      )
      const icon = component.find('.sb-modal-rank__icon')
      const text = component.find('p').text()
      // all possible genius repeat messages
      const todayMessages = improvementMessages.geniusRepeat

      expect(icon.hasClass('genius')).toBe(true)

      expect(trackImpression).toHaveBeenCalledWith(
        'congrats-modal',
        'spelling-bee',
        'genius',
        'SB-20',
      )

      // expect message modal text to include at least one genius message
      expect(todayMessages.includes(text)).toBe(true)
    })

    it('should show Genius improvement message', () => {
      component = createComponent(
        {
          ...puzzleData,
          foundWords: [
            'ACE',
            'BAG',
            'DAD',
            'CAD',
            'GAB',
            'BAB',
            'DAB',
            'CAB',
          ],
        },
        'today',
      )
      const icon = component.find('.sb-modal-rank__icon')
      const text = component.find('p').text()
      // all possible genius improvement messages
      const todayMessages = improvementMessages.rankImprovement

      expect(icon.hasClass('genius')).toBe(false)
      expect(icon.hasClass('sb-stats-arrow')).toBe(false)

      expect(trackImpression).toHaveBeenCalledWith(
        'congrats-modal',
        'spelling-bee',
        'higher',
        'SB-20',
      )

      // expect message modal text to include at least one genius message
      expect(todayMessages.includes(text)).toBe(true)
    })

    it('should not show message if rank not forced and no answers yesterday', () => {
      // forcing beginner rank as prop
      component = createComponent(
        {
          ...puzzleData,
          foundWords: [],
          pangrams: [],
        },
        'today',
      )

      expect(trackImpression).toHaveBeenCalledWith(
        'congrats-modal',
        'spelling-bee',
        '',
        'SB-20',
      )
      expect(component.html()).toBeNull()
    })
  })
})
