import React, { ReactElement } from 'react'

import { useSbSelector } from '../store/game/hooks'
import {
  selectYesterdaysRank,
  selectYesterdaysScore,
  selectCompletedYesterday,
  selectIsPastPuzzle,
} from '../store/game/game.selectors'
import { getRankIdxFromRank } from '../store/utils'
import { trackImpression } from '../../../helpers/tracking'

import {
  getEncouragementMessage,
  getYesterdayMessage,
  getRandomImprovementMessage,
  RANK_MESSAGE,
} from './messaging'
import RankMessage from './RankMessage'

const RankRecap = ({
  messageType,
  isDisplayed = true,
}: {
  messageType: 'yesterday' | 'today' | null
  isDisplayed?: boolean
}): ReactElement | null => {
  // this component should not render if it's a past puzzle
  const isPastPuzzle = useSbSelector(selectIsPastPuzzle)

  const completedYesterday = useSbSelector(selectCompletedYesterday)
  const yesterdaysScore = useSbSelector(selectYesterdaysScore)
  const gameId = useSbSelector((state) => state.game.id)
  const yesterdaysRank = useSbSelector(selectYesterdaysRank)
  const rank = completedYesterday ? 'Queen Bee' : yesterdaysRank
  const rankIdx = getRankIdxFromRank(rank)

  if (isPastPuzzle) {
    return null
  }

  const trackingId = `SB-${gameId}`

  if (messageType === 'today' && yesterdaysScore === 0) {
    trackImpression('congrats-modal', 'spelling-bee', '', trackingId)

    if (yesterdaysScore === 0 || rank === 'Beginner') return null
  }

  const showYesterdaysRecapMessage = (
    yesterdaysRank: string,
    messageType: 'yesterday' | 'today' | null,
  ): ReactElement => {
    const { encouragement, icon } =
      getEncouragementMessage(yesterdaysRank)

    const yesterdayMessage = getYesterdayMessage(
      yesterdaysRank,
      encouragement,
    )

    const trackingRank =
      rank === 'Queen Bee'
        ? 'completed'
        : rank.toLowerCase().split(' ').join('-')

    const trackingLabel = `${rankIdx}-${trackingRank}`

    const track = () =>
      trackImpression(
        'stats',
        'spelling-bee-yesterday',
        trackingLabel,
        trackingId,
      )

    return (
      <RankMessage
        icon={icon}
        message={yesterdayMessage}
        messageType={messageType}
        track={track}
        isDisplayed={isDisplayed}
      />
    )
  }

  const showTodaysImprovementMessage = (
    yesterdaysRank: string,
    messageType: 'yesterday' | 'today' | null,
  ): ReactElement | null => {
    let improvementType: RANK_MESSAGE

    // get message by improvement type since yesterday
    if (
      yesterdaysRank === 'Genius' ||
      yesterdaysRank === 'Queen Bee'
    ) {
      improvementType = 'geniusRepeat'
    } else if (yesterdaysRank !== 'Genius') {
      improvementType = 'rankImprovement'
    } else {
      return null
    }

    const trackingLabel =
      improvementType === 'rankImprovement' ? 'higher' : 'genius'

    const track = () =>
      trackImpression(
        'congrats-modal',
        'spelling-bee',
        trackingLabel,
        trackingId,
      )

    const { message, icon } =
      getRandomImprovementMessage(improvementType)

    return (
      <RankMessage
        icon={icon}
        message={message}
        messageType={messageType}
        track={track}
        isDisplayed={isDisplayed}
      />
    )
  }

  if (messageType === 'yesterday') {
    return showYesterdaysRecapMessage(rank, messageType)
  }

  if (messageType === 'today') {
    return showTodaysImprovementMessage(rank, messageType)
  }

  return null
}

export default RankRecap
