/* eslint-disable react/jsx-one-expression-per-line */
import React, { ReactElement } from 'react'

export type RANK_MESSAGE = 'geniusRepeat' | 'rankImprovement'

const getRandomArrayIndex = (arr: string[]): number =>
  Math.floor(Math.random() * arr.length)

export const improvementMessages = {
  rankImprovement: [
    'You’re on the up and up! You ranked higher than yesterday.',
    'You ranked higher than yesterday. Congrats!',
  ],
  geniusRepeat: [
    'Genius again! You’re on a roll.',
    'Genius, yet again! Well done.',
    'Still a Genius! Excellent work.',
    'Genius again! No surprise here.',
    'Genius ... again?! You’re great at this.',
  ],
}

export const getRankIcon = (rankClass: string = '') => {
  const icon = {
    class: rankClass,
  }

  return icon
}

export const getEncouragementMessage = (rank: string) => {
  let iconClass

  let encouragement: string = 'Keep it up!'
  switch (rank) {
    case 'Good Start':
      encouragement = 'Keep it up!'
      break
    case 'Moving Up':
      encouragement = 'The elevator is all yours.'
      break
    case 'Good':
      encouragement = 'And it looks great on you.'
      break
    case 'Solid':
      encouragement = 'You rock.'
      break
    case 'Nice':
      encouragement = 'And nice people clearly finish first.'
      break
    case 'Great':
      encouragement = 'We knew you were one of the Greats.'
      break
    case 'Amazing':
      encouragement = 'Bet you can do it again. Or maybe even better.'
      break
    case 'Genius':
      iconClass = 'genius'
      break
    case 'Queen Bee':
      iconClass = 'queen-bee'
      break
    default:
      iconClass = ''
      break
  }

  return {
    encouragement,
    icon: getRankIcon(iconClass),
  }
}

export const getRandomImprovementMessage = (
  messageType: RANK_MESSAGE,
) => {
  let icon = getRankIcon()

  const messageList = improvementMessages[messageType]
  const randomMessageIndex = getRandomArrayIndex(messageList)
  const message = <p>{messageList[randomMessageIndex]}</p>

  if (messageType === 'geniusRepeat') {
    icon = getRankIcon('genius')
  }

  return { message, icon }
}

export const getYesterdayMessage = (
  rank: string,
  encouragement: string,
) => {
  let message: ReactElement
  if (rank === 'Queen Bee') {
    message = (
      <p>
        May your reign last forever, <em>{rank}</em>!
      </p>
    )
  } else if (rank === 'Genius') {
    message = (
      <p>
        You had a stroke of <em>{rank}</em> yesterday.
      </p>
    )
  } else {
    message = (
      <p>
        <em>Rank: {rank}.</em> {encouragement}
      </p>
    )
  }

  return message
}
