import { UserType } from 'foundation'

import { SpellingBeeMessage } from './game.state'

export const SHUFFLE = 'SHUFFLE'
export const INPUT_LETTER = 'INPUT_LETTER'
export const DELETE_LETTER = 'DELETE_LETTER'
export const CLEAR_INPUT = 'CLEAR_INPUT'
export const ACCEPT_WORD = 'ACCEPT_WORD'
export const SHOW_MESSAGE = 'SHOW_MESSAGE'
export const CLEAR_MESSAGE = 'CLEAR_MESSAGE'
export const CLEAR_MESSAGE_AND_INPUT = 'CLEAR_MESSAGE_AND_INPUT'
export const TOGGLE_WORDLIST = 'TOGGLE_WORDLIST'
export const RESET_GAME = 'RESET_GAME'
export const INSERT_FOUND_WORDS = 'INSERT_FOUND_WORDS'
export const SET_YESTERDAYS_FOUND_WORDS = 'SET_YESTERDAYS_FOUND_WORDS'
export const SET_YESTERDAYS_PROGRESS = 'SET_YESTERDAYS_PROGRESS'
export const UPDATE_USER = 'UPDATE_USER'
export const UPDATE_CURRENT_MOMENT = 'UPDATE_CURRENT_MOMENT'
export const UPDATE_MODAL = 'UPDATE_MODAL'
export const SET_HAS_LOADED = 'SET_HAS_LOADED'
export const REVEAL = 'REVEAL'
export const REVEAL_YESTERDAY = 'REVEAL_YESTERDAY'

type ShuffleAction = { type: typeof SHUFFLE }
type InputLetterAction = {
  type: typeof INPUT_LETTER
  payload: string
}
type DeleteLetterAction = { type: typeof DELETE_LETTER }
type ClearInputAction = { type: typeof CLEAR_INPUT }
type AcceptWordAction = { type: typeof ACCEPT_WORD; payload: string }
type ShowMessageAction = {
  type: typeof SHOW_MESSAGE
  payload: SpellingBeeMessage
}
type ClearMessageAction = { type: typeof CLEAR_MESSAGE }
type ClearMessageAndInputAction = {
  type: typeof CLEAR_MESSAGE_AND_INPUT
}
type ToggleWordlistAction = { type: typeof TOGGLE_WORDLIST }
type ResetGameAction = { type: typeof RESET_GAME }
type InsertFoundWordsAction = {
  type: typeof INSERT_FOUND_WORDS
  payload: string[]
}
type SetYesterdaysProgressAction = {
  type: typeof SET_YESTERDAYS_PROGRESS
  payload?: {
    foundWords: string[]
    isRevealed: boolean
  }
}
type UpdateUserAction = {
  type: typeof UPDATE_USER
  payload: Partial<UserType>
}
type UpdateCurrentMomentAction = {
  type: typeof UPDATE_CURRENT_MOMENT
  payload: string
}
type UpdateModalAction = {
  type: typeof UPDATE_MODAL
  payload: {
    isOpen: boolean
  }
}
type SetHasLoadedAction = { type: typeof SET_HAS_LOADED }
type RevealAction = { type: typeof REVEAL }

type RevealYesterdayAction = { type: typeof REVEAL_YESTERDAY }

export type SpellingBeeGameAction =
  | ShuffleAction
  | InputLetterAction
  | DeleteLetterAction
  | ClearInputAction
  | AcceptWordAction
  | ShowMessageAction
  | ClearMessageAction
  | ClearMessageAndInputAction
  | ToggleWordlistAction
  | ResetGameAction
  | InsertFoundWordsAction
  | SetYesterdaysProgressAction
  | UpdateUserAction
  | UpdateCurrentMomentAction
  | UpdateModalAction
  | SetHasLoadedAction
  | RevealAction
  | RevealYesterdayAction

export const shuffleLetters = (): ShuffleAction => ({ type: SHUFFLE })

export const toggleWordlist = (): ToggleWordlistAction => ({
  type: TOGGLE_WORDLIST,
})

export const insertFoundWords = (
  words: string[],
): InsertFoundWordsAction => ({
  type: INSERT_FOUND_WORDS,
  payload: words,
})

export const setYesterdaysProgress = (
  foundWords: string[],
  isRevealed: boolean,
): SetYesterdaysProgressAction => ({
  type: SET_YESTERDAYS_PROGRESS,
  payload: { foundWords, isRevealed },
})

export const updateUser = (userInfo: UserType): UpdateUserAction => ({
  type: UPDATE_USER,
  payload: userInfo,
})

export const updateCurrentMoment = (
  currentMoment: string,
): UpdateCurrentMomentAction => ({
  type: UPDATE_CURRENT_MOMENT,
  payload: currentMoment,
})

export const updateModalRedux = (
  isOpen: boolean,
): UpdateModalAction => ({ type: UPDATE_MODAL, payload: { isOpen } })

export const setHasLoaded = (): SetHasLoadedAction => ({
  type: SET_HAS_LOADED,
})

export const resetGame = (): ResetGameAction => ({
  type: RESET_GAME,
})

export const revealAnswers = (): RevealAction => ({ type: REVEAL })

export const revealYesterdaysAnswers = (): RevealYesterdayAction => ({
  type: REVEAL_YESTERDAY,
})
