import { getGameData } from 'foundation'

import { shuffle } from '../../../../helpers/gameUtils'
import type { SpellingBeeAction } from '..'

import {
  SpellingBeeGameData,
  SpellingBeeGameState,
} from './game.state'
import {
  ACCEPT_WORD,
  CLEAR_INPUT,
  CLEAR_MESSAGE,
  CLEAR_MESSAGE_AND_INPUT,
  DELETE_LETTER,
  INPUT_LETTER,
  INSERT_FOUND_WORDS,
  RESET_GAME,
  SET_HAS_LOADED,
  SET_YESTERDAYS_PROGRESS,
  SHOW_MESSAGE,
  SHUFFLE,
  TOGGLE_WORDLIST,
  UPDATE_CURRENT_MOMENT,
  UPDATE_USER,
  UPDATE_MODAL,
  REVEAL,
  REVEAL_YESTERDAY,
} from './game.actions'

const createInitialState = (
  data: SpellingBeeGameData = getGameData(),
): SpellingBeeGameState => {
  return {
    ...data.today,
    input: [],
    foundWords: [],
    isExpandedWordlist: false,
    message: null,
    yesterday: data.yesterday
      ? {
          ...data.yesterday,
          foundWords: null,
          isRevealed: false,
        }
      : null,
    userType: {},
    hasLoaded: false,
    currentMoment: '',
    isModalOpen: false,
    isRevealed: false,
    isPastPuzzle: data.isPastPuzzle || false,
    pastPuzzlesData: data.pastPuzzles || null,
  }
}

export default (
  state: SpellingBeeGameState = createInitialState(),
  action: SpellingBeeAction,
): SpellingBeeGameState => {
  switch (action.type) {
    case INPUT_LETTER:
      return { ...state, input: [...state.input, action.payload] }
    case DELETE_LETTER:
      return { ...state, input: state.input.slice(0, -1) }
    case SHUFFLE:
      return {
        ...state,
        outerLetters: shuffle(state.outerLetters, true),
      }
    case CLEAR_INPUT:
      return { ...state, input: [] }
    case ACCEPT_WORD:
      return {
        ...state,
        foundWords: [...state.foundWords, action.payload],
      }
    case TOGGLE_WORDLIST:
      return {
        ...state,
        isExpandedWordlist: !state.isExpandedWordlist,
      }
    case SHOW_MESSAGE:
      return { ...state, message: action.payload }
    case CLEAR_MESSAGE:
      return { ...state, message: null }
    case CLEAR_MESSAGE_AND_INPUT:
      return { ...state, input: [], message: null }
    case INSERT_FOUND_WORDS:
      return {
        ...state,
        foundWords: [
          ...state.foundWords,
          ...action.payload.filter(
            (w) =>
              state.answers.includes(w) &&
              !state.foundWords.includes(w),
          ),
        ],
      }
    case SET_YESTERDAYS_PROGRESS:
      if (!state.yesterday) {
        return state
      }

      return {
        ...state,
        yesterday: {
          ...state.yesterday,
          foundWords: [...(action.payload?.foundWords || [])],
          isRevealed: action.payload?.isRevealed || false,
          fetched: true,
        },
      }
    case RESET_GAME:
      return { ...state, foundWords: [] }
    case UPDATE_USER:
      return {
        ...state,
        userType: {
          ...state.userType,
          ...action.payload,
        },
      }
    case UPDATE_CURRENT_MOMENT:
      return {
        ...state,
        currentMoment: action.payload,
      }
    case UPDATE_MODAL: {
      return {
        ...state,
        isModalOpen: action.payload.isOpen,
      }
    }
    case SET_HAS_LOADED:
      return { ...state, hasLoaded: true }
    case REVEAL:
      return {
        ...state,
        isRevealed: true,
        input: [],
      }
    case REVEAL_YESTERDAY:
      if (!state.yesterday) {
        return state
      }

      return {
        ...state,
        yesterday: {
          ...state.yesterday,
          isRevealed: true,
        },
      }
    default:
      return state
  }
}
