import thunk from 'redux-thunk'
import {
  createStore,
  applyMiddleware,
  compose,
  combineReducers,
} from 'redux'

import { moogleReducer } from 'shared/moogle/moogleReducer'

import {
  resetGame,
  shuffleLetters,
  SpellingBeeGameAction,
} from './game/game.actions'
import {
  analyticsMiddleware,
  trackGameStateMiddleware,
  trackUserStateMiddleware,
} from './middleware/analytics'
import game from './game/game.reducer'
import meter from './meter/meter.reducer'
import { SpellingBeeMeterAction } from './meter/meter.actions'
import { meterMiddleware } from './middleware/meter'
import {
  saveSpellingBee,
  saveYesterdaysSpellingBee,
} from './spellingBeeMoogleConfig'

const rootReducer = combineReducers({
  game,
  meter,
  moogle: moogleReducer,
})

export type SpellingBeeState = ReturnType<typeof rootReducer>
export type SpellingBeeAction =
  | SpellingBeeGameAction
  | SpellingBeeMeterAction

export const setUpStore = () => {
  // assemble all the middleware
  const middleware = [
    applyMiddleware(
      thunk,
      trackGameStateMiddleware,
      trackUserStateMiddleware,
      meterMiddleware,
      analyticsMiddleware,
      saveSpellingBee,
      saveYesterdaysSpellingBee,
    ),
  ]

  if (window.__REDUX_DEVTOOLS_EXTENSION__) {
    middleware.push(window.__REDUX_DEVTOOLS_EXTENSION__())
  }

  // create the store with the initial state
  const store = createStore(rootReducer, compose(...middleware))

  // shuffle initial letters
  store.dispatch(shuffleLetters())

  // For e2e tests
  window.reset = () => {
    store.dispatch(resetGame())
  }

  // return the store for the provider (or unit test)
  return store
}
