import { createSelector } from 'reselect'

import { shouldFailOpen } from '../../../../../shared/meter'
import type { SpellingBeeState } from '..'
import {
  selectCurrentRankIdx,
  selectUserType,
} from '../game/game.selectors'
import { CUTOFF_RANK_IDX } from '../../gating'

export const selectMeter = (state: SpellingBeeState) => state.meter

export const selectHasReachedCutoff = createSelector(
  [selectMeter, selectUserType, selectCurrentRankIdx],
  (meter, user, level) => {
    // if the meter is online, use the meter response
    if (meter.isOffline === false) {
      return !meter.granted
    }

    // if the meter is offline, verify if the last response should fail open
    if (shouldFailOpen(meter)) {
      return !meter.granted
    }

    // if they can't fail open, fall back to a user type
    if (user.hasXwd) {
      return false
    }

    // when all else fails, cut off at the hard-coded rank
    return level >= CUTOFF_RANK_IDX
  },
)
