import { SET_HAS_LOADED, ACCEPT_WORD } from '../game/game.actions'
import { grantReasons } from '../../../../../shared/meter/MeterTypes'
import {
  retrieveMeterValue,
  willUseMeterToGate,
} from '../../../../../shared/meter'
import { selectCurrentRankIdx } from '../game/game.selectors'
import { selectHasReachedCutoff } from '../meter/meter.selector'

import { meterMiddleware } from './meter'

jest.mock('../game/game.selectors', () => ({
  selectCurrentRankIdx: jest.fn(),
  selectUserType: jest.fn(),
}))

jest.mock('../../../../../shared/meter', () => ({
  retrieveMeterValue: jest.fn(),
  willUseMeterToGate: () => true,
}))

describe('middleware: spelling bee meter', () => {
  let next
  let getState
  let store
  let middleware
  let dispatch

  beforeEach(() => {
    jest.resetAllMocks()
    next = jest.fn()
    getState = jest.fn()
    dispatch = jest.fn()
    store = { getState, dispatch }
    retrieveMeterValue.mockReturnValue(Promise.resolve())
    middleware = meterMiddleware(store)(next)
    getState.mockReturnValue({
      meter: {
        loggedIn: false,
        grantReason: grantReasons.METER_LIMIT,
        granted: false,
        isOffline: false,
      },
    })
    selectCurrentRankIdx
      .mockReturnValueOnce(1)
      .mockReturnValueOnce(2)
      .mockReturnValueOnce(5)
  })

  it('calls next with the appropriate action', () => {
    const action = { type: ACCEPT_WORD }
    middleware(action)
    expect(next).toHaveBeenCalledWith(action)
  })

  it('will call the meter service on load of spelling bee data', () => {
    window.isHybridWebView = false
    window.newsreaderAppPlatform = ''
    const action = { type: SET_HAS_LOADED }
    middleware(action)
    expect(retrieveMeterValue).toHaveBeenCalled()
  })

  it('will not continue calling the meter service if the first meter call responds that the user is a subscriber', () => {
    window.isHybridWebView = true
    getState.mockReturnValue({
      meter: {
        loggedIn: true,
        grantReason: grantReasons.SUBSCRIBER,
        granted: true,
        isOffline: false,
      },
    })
    const action = { type: ACCEPT_WORD }
    middleware(action)
    expect(retrieveMeterValue).not.toHaveBeenCalled()
  })

  it('will continue calling the meter service if the user is being metered and they leveled up', () => {
    window.isHybridWebView = false
    window.newsreaderAppPlatform = ''

    getState.mockReturnValue({
      meter: {
        loggedIn: false,
        grantReason: grantReasons.METERING,
        granted: true,
        isOffline: false,
      },
    })
    const action = { type: ACCEPT_WORD }
    middleware(action)
    expect(retrieveMeterValue).toBeCalledTimes(1)
  })
})
