import { Middleware } from 'redux'

import {
  retrieveMeterValue,
  setDebugResponse,
  willUseMeterToGate,
} from '../../../../../shared/meter'
import {
  MeterProperties,
  grantReasons,
} from '../../../../../shared/meter/MeterTypes'
import type { SpellingBeeState } from '..'
import {
  ACCEPT_WORD,
  SET_HAS_LOADED,
  UPDATE_USER,
} from '../game/game.actions'
import { setMeter } from '../meter/meter.actions'
import {
  selectCurrentRankIdx,
  selectUserType,
} from '../game/game.selectors'
import { selectMeter } from '../meter/meter.selector'

type SbMiddleware = Middleware<{}, SpellingBeeState>

export const meterMiddleware: SbMiddleware = (store) => {
  const setMeterState = (meterResponse: MeterProperties) => {
    store.dispatch(setMeter(meterResponse))
  }

  return (next) => (action) => {
    const prevState = store.getState()
    const result = next(action)
    const state = store.getState()

    const { grantReason } = selectMeter(prevState)
    // If the user has previously been granted as a sub, make no more meter calls
    if (grantReason === grantReasons.SUBSCRIBER) {
      return result
    }

    const prevLevel = selectCurrentRankIdx(prevState)
    const level = selectCurrentRankIdx(state)

    if (action.type === SET_HAS_LOADED) {
      // Request a meter reading once we know the level has been fetched from progress
      const level = selectCurrentRankIdx(store.getState())
      if (willUseMeterToGate()) {
        retrieveMeterValue({ level }).then(setMeterState)
      }
    }

    if (action.type === ACCEPT_WORD) {
      // See if the user leveled up
      if (willUseMeterToGate() && level > prevLevel) {
        retrieveMeterValue({ level }).then(setMeterState)
      }
    }

    /**
     * Tooling to debug the Spelling Bee Meter
     *
     * Allows players in Shortz mode to toggle meter in and out of debug mode and
     * provide a mocked response when the meter is called
     */
    if (action.type === UPDATE_USER) {
      const { inShortzMode } = selectUserType(state)
      // @ts-ignore
      if (__DEV__ || inShortzMode) {
        // @ts-ignore
        window.setMeter = setDebugResponse
      }
    }

    return result
  }
}
