import React from 'react'
import pt from 'prop-types'
import { Provider } from 'react-redux'
import { createStore } from 'redux'

import DailyRecapBar from '../modals/stats/DailyRecapBar'

const getContainerStyles = (width, height) => ({
  width: `${width}px`,
  height: `${height}px`,
  position: 'relative',
  margin: '20px',
})

const state = {
  printDate: '2022-02-10',
  game: { pastPuzzlesData: { today: { printDate: '2022-12-31' } } },
}
const store = createStore(() => state)

const PastDidntPlay = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar publishedDate="2022-02-08" />
    </div>
  </Provider>
)

const Beginner = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-08"
        rank="Beginner"
        wordsFound={1}
        totalWords={100}
      />
    </div>
  </Provider>
)

const GoodStart = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-08"
        rank="Good Start"
        wordsFound={2}
        totalWords={100}
      />
    </div>
  </Provider>
)

const MovingUp = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-08"
        rank="Moving Up"
        wordsFound={5}
        totalWords={100}
      />
    </div>
  </Provider>
)

const Good = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-08"
        rank="Good"
        wordsFound={8}
        totalWords={100}
      />
    </div>
  </Provider>
)

const Solid = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-08"
        rank="Solid"
        wordsFound={15}
        totalWords={100}
      />
    </div>
  </Provider>
)

const Nice = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-08"
        rank="Nice"
        wordsFound={25}
        totalWords={100}
      />
    </div>
  </Provider>
)

const Great = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-08"
        rank="Great"
        wordsFound={40}
        totalWords={100}
      />
    </div>
  </Provider>
)

const Amazing = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-08"
        rank="Amazing"
        wordsFound={50}
        totalWords={100}
      />
    </div>
  </Provider>
)

const Genius = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-08"
        rank="Genius"
        wordsFound={70}
        totalWords={100}
      />
    </div>
  </Provider>
)

const QueenBee = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-08"
        rank="Queen Bee"
        wordsFound={100}
        totalWords={100}
      />
    </div>
  </Provider>
)

const NoProgressToday = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-08"
        rank=""
        wordsFound={0}
        totalWords={0}
        isToday
      />
    </div>
  </Provider>
)

const ProgressToday = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-08"
        rank="Nice"
        wordsFound={25}
        totalWords={100}
        isToday
      />
    </div>
  </Provider>
)

const FuturePuzzle = ({ containerWidth, containerHeight }) => (
  <Provider store={store}>
    <div style={getContainerStyles(containerWidth, containerHeight)}>
      <DailyRecapBar
        publishedDate="2022-02-12"
        rank=""
        wordsFound={0}
        totalWords={0}
      />
    </div>
  </Provider>
)

const templatePropTypes = {
  containerWidth: pt.number,
  containerHeight: pt.number,
}

PastDidntPlay.propTypes = templatePropTypes
Beginner.propTypes = templatePropTypes
GoodStart.propTypes = templatePropTypes
MovingUp.propTypes = templatePropTypes
Good.propTypes = templatePropTypes
Solid.propTypes = templatePropTypes
Nice.propTypes = templatePropTypes
Great.propTypes = templatePropTypes
Amazing.propTypes = templatePropTypes
Genius.propTypes = templatePropTypes
QueenBee.propTypes = templatePropTypes
NoProgressToday.propTypes = templatePropTypes
ProgressToday.propTypes = templatePropTypes
FuturePuzzle.propTypes = templatePropTypes

export const DailyRecapPastDidntPlay = PastDidntPlay.bind({})
export const DailyRecapBeginner = Beginner.bind({})
export const DailyRecapGoodStart = GoodStart.bind({})
export const DailyRecapMovingUp = MovingUp.bind({})
export const DailyRecapGood = Good.bind({})
export const DailyRecapSolid = Solid.bind({})
export const DailyRecapNice = Nice.bind({})
export const DailyRecapGreat = Great.bind({})
export const DailyRecapAmazing = Amazing.bind({})
export const DailyRecapGenius = Genius.bind({})
export const DailyRecapQueenBee = QueenBee.bind({})
export const DailyRecapNoProgressToday = NoProgressToday.bind({})
export const DailyRecapProgressToday = ProgressToday.bind({})
export const DailyRecapFuturePuzzle = FuturePuzzle.bind({})

DailyRecapBar.args = {
  containerWidth: 500,
  containerHeight: 400,
}

export default {
  title: 'Spelling Bee/Daily Recap Bar',
  component: DailyRecapBar,
  argTypes: {
    containerWidth: {
      control: {
        type: 'range',
        min: 320,
        max: 1000,
      },
    },
    containerHeight: {
      control: {
        type: 'range',
        min: 50,
        max: 150,
      },
    },
  },
}
