import React from 'react'
import pt from 'prop-types'
import { Provider } from 'react-redux'
import { createStore } from 'redux'

import ModalStats from '../modals/stats/ModalStats'

export const sbStoryState = {
  meter: { loggedIn: true },
  game: {
    stats: {
      scores: {
        thisWeek: [
          {
            score: 22,
            label: 'Amazing',
            userId: 11111,
            updatedAt: '2022-01-30T23:15:02Z',
            puzzleId: '22',
          },
          {
            score: 102,
            label: 'Genius',
            userId: 11111,
            updatedAt: '2022-01-30T23:15:02Z',
            puzzleId: '22',
          },
          {
            score: 22,
            label: 'Amazing',
            userId: 11111,
            updatedAt: '2022-01-30T23:15:02Z',
            puzzleId: '22',
          },
          {
            score: 22,
            label: 'Amazing',
            userId: 11111,
            updatedAt: '2022-01-30T23:15:02Z',
            puzzleId: '22',
          },
          {
            score: 22,
            label: 'Amazing',
            userId: 11111,
            updatedAt: '2022-01-30T23:15:02Z',
            puzzleId: '22',
          },
        ],
        lastWeek: [
          {
            score: 103,
            label: 'Genius',
            userId: 11111,
            updatedAt: '2022-01-30T23:15:02Z',
            puzzleId: '22',
          },
        ],
      },
    },
  },
}

const store = createStore(() => sbStoryState)

const getContainerStyles = (width, height) => ({
  width: `${width}px`,
  height: `${height}px`,
})

const Template = ({ containerWidth, containerHeight }) => (
  <div style={getContainerStyles(containerWidth, containerHeight)}>
    {/* Note below is a representation of modal system wrapping stats, not trying to recereate Modal system in Storybook */}
    <div className="sb-modal-system sb-modal-open">
      <div role="presentation" className="sb-modal-scrim">
        <div className="sb-modal-wrapper">
          <div role="button" className="sb-modal-frame stats">
            <div className="sb-modal-top">
              <div role="button" className="sb-modal-close">
                ×
              </div>
            </div>
            <div className="sb-modal-content has-overflow">
              <div className="sb-modal-body">
                <Provider store={store}>
                  <ModalStats />
                </Provider>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
)

Template.propTypes = {
  containerWidth: pt.number,
  containerHeight: pt.number,
}

export const Stats = Template.bind({})

Stats.args = {
  containerWidth: 600,
  containerHeight: 600,
}

export default {
  title: 'Spelling Bee/Stats',
  component: Stats,
  includeStories: ['Stats'],
  argTypes: {
    containerWidth: {
      control: {
        type: 'range',
        min: 200,
        max: 1000,
      },
    },
    containerHeight: {
      control: {
        type: 'range',
        min: 100,
        max: 1000,
      },
    },
  },
}
