import React from 'react'
import pt from 'prop-types'
import shuffle from 'lodash/shuffle'
import { Provider } from 'react-redux'
import { createStore } from 'redux'

import { WordlistBase } from '../Wordlist'

import { sbStoryState } from './ModalStats.stories'

// https://randomwordgenerator.com/ to the rescue
const words = [
  'winner',
  'governor',
  'exchange',
  'argument',
  'flawed',
  'discreet',
  'fluctuation',
  'relevance',
  'horoscope',
  'integrity',
  'route',
  'different',
  'nightmare',
  'disgrace',
  'paint',
  'racism',
  'depressed',
  'classify',
  'sail',
  'escape',
  'impound',
  'firsthand',
  'classroom',
  'waterfall',
  'transform',
  'please',
  'allowance',
  'rung',
  'overeat',
  'unlawful',
  'particular',
  'echo',
  'sharp',
  'flatware',
  'satisfied',
  'inspire',
  'machinery',
  'reduce',
  'functional',
  'brake',
  'process',
  'youth',
  'legislation',
  'predict',
  'swarm',
  'retailer',
  'bride',
  'heat',
  'driver',
  'flesh',
  'distant',
  'relaxation',
  'loan',
  'forbid',
  'achievement',
  'flexible',
  'vessel',
  'embrace',
  'immune',
  'misplace',
  'capture',
  'communication',
  'plaster',
  'monarch',
  'flaw',
  'attitude',
  'burial',
  'peak',
  'digital',
  'formal',
  'fragment',
  'display',
  'production',
  'expose',
  'soap',
  'writer',
  'inappropriate',
  'reflection',
  'root',
  'commitment',
  'jelly',
  'forward',
  'crystal',
  'braid',
  'cane',
  'patch',
  'candle',
  'pure',
  'good',
  'xray',
  'shower',
  'ecstasy',
  'headquarters',
  'wording',
  'climb',
  'presidency',
  'flourish',
  'scandal',
  'perform',
  'sense',
]

const getWords = (amount) => shuffle(words.slice()).slice(0, amount)

const getContainerStyles = (width, height) => ({
  width: `${width}px`,
  height: `${height}px`,
  position: 'relative',
  margin: '20px',
})

const Template = ({ containerWidth, containerHeight, numWords }) => (
  <div style={getContainerStyles(containerWidth, containerHeight)}>
    <WordlistBase words={getWords(numWords)} />
  </div>
)

Template.propTypes = {
  containerWidth: pt.number,
  containerHeight: pt.number,
  numWords: pt.number,
}

export const PaginatedWordlist = Template.bind({})

PaginatedWordlist.args = {
  containerWidth: 500,
  containerHeight: 400,
  numWords: 50,
}
const store = createStore(() => sbStoryState)

export default {
  title: 'Spelling Bee/Paginated Wordlist',
  component: PaginatedWordlist,
  decorators: [
    (Story) => (
      <Provider store={store}>
        <Story />
      </Provider>
    ),
  ],
  argTypes: {
    containerWidth: {
      control: {
        type: 'range',
        min: 200,
        max: 1000,
      },
    },
    containerHeight: {
      control: {
        type: 'range',
        min: 100,
        max: 1000,
      },
    },
    numWords: {
      control: {
        type: 'range',
        min: 0,
        max: 100,
      },
    },
  },
}
