import React from 'react'
import pt from 'prop-types'

import Cell from '../Cell/Cell'
import Candidate from '../Candidates/Candidates'
import { Welcome } from '../../constants/constants'

const Board = ({ act, view, shapes, level }) => {
  const cellElements = []
  const candidateElements = []

  view.cells.forEach((cell) => {
    const top = shapes.getOffset(cell.row)
    const left = shapes.getOffset(cell.column)

    const cellProps = {
      ...cell,
      top,
      left,
      size: shapes.cell,
      key: cell.id,
    }

    cellElements.push(React.createElement(Cell, cellProps))

    if (!cell.value) {
      candidateElements.push(
        React.createElement(Candidate, {
          ...view.candidates[cell.id],
          top,
          left,
          size: shapes.candidate,
          selected: cell.selected,
          key: cell.id,
        }),
      )
    }
  })

  return level === Welcome ? null : (
    <div
      role="grid"
      className="su-board"
      style={{
        top: shapes.gutter,
        width: shapes.board,
        height: shapes.board,
      }}
      onClick={(event) => {
        const cell = event.target.getAttribute('data-cell')
        const cellFromParent =
          event.target.parentNode?.getAttribute('data-cell')

        if (cell) {
          act('select', parseInt(cell))
        } else if (cellFromParent) {
          act('select', parseInt(cellFromParent))
        }

        const candidate = event.target.getAttribute('data-candidate')

        if (candidate) {
          act('toggleCandidate', parseInt(candidate))
        }
      }}
    >
      <>{cellElements}</>
      <>{candidateElements}</>
      <div
        style={{ outlineWidth: shapes.gutter }}
        className="su-board__frame"
      />
    </div>
  )
}

Board.propTypes = {
  act: pt.func,
  view: pt.shape({
    cells: pt.arrayOf(pt.shape({})),
    candidates: pt.arrayOf(pt.shape({})),
  }),
  level: pt.string,
  shapes: pt.shape({
    board: pt.oneOfType([pt.string, pt.number]),
    getOffset: pt.func,
    cell: pt.oneOfType([pt.string, pt.number]),
    candidate: pt.oneOfType([pt.string, pt.number]),
    gutter: pt.oneOfType([pt.number, pt.string]),
  }),
}

export default Board
