import React from 'react'
import { mount, shallow } from 'enzyme'

import Cell from '../Cell/Cell'
import Candidates from '../Candidates/Candidates'

import Board from './Board'

/* eslint-disable */
jest.mock('../Cell/Cell', () => () => <div />)
jest.mock('../Candidates/Candidates', () => () => <div />)
/* eslint-enable */
jest.mock('../../constants/constants', () => ({
  Welcome: 'welcome',
}))

describe('SUDOKU: BOARD', () => {
  let act
  let view
  let shapes

  beforeEach(() => {
    act = jest.fn()

    view = {
      candidates: {
        1: { 3: true },
        2: {},
        3: {},
        4: {},
      },
      cells: [
        { id: 1, row: 0, column: 0, value: 1 },
        { id: 2, row: 0, column: 1 },
        { id: 3, row: 1, column: 1 },
        { id: 4, row: 1, column: 1, selected: true },
      ],
    }

    shapes = {
      cell: 9,
      candidate: 3,
      getOffset: jest.fn(),
    }

    shapes.getOffset.mockImplementation((_) => _)
  })

  test('renders cells', () => {
    const board = shallow(
      <Board act={act} view={view} shapes={shapes} />,
    )
    const cells = board.find(Cell)

    expect(cells).toHaveLength(4)
    expect(cells.at(0).props()).toEqual({
      id: 1,
      row: 0,
      column: 0,
      top: 0,
      left: 0,
      size: 9,
      value: 1,
    })
    expect(cells.at(3).props()).toEqual({
      id: 4,
      row: 1,
      column: 1,
      top: 1,
      left: 1,
      size: 9,
      selected: true,
    })
  })

  test('renders candidates', () => {
    const board = shallow(
      <Board act={act} view={view} shapes={shapes} />,
    )
    const candidates = board.find(Candidates)

    expect(candidates).toHaveLength(3)
    expect(candidates.at(0).props()).toEqual({
      top: 0,
      left: 1,
      size: 3,
    })
    expect(candidates.at(2).props()).toEqual({
      top: 1,
      left: 1,
      size: 3,
      selected: true,
    })
  })

  test('handles cell clicks', () => {
    const board = mount(
      <Board act={act} view={view} shapes={shapes} />,
    ).find('.su-board')
    board.simulate('click', {
      target: {
        getAttribute: (attr) =>
          attr === 'data-cell' ? '1' : undefined,
      },
    })
    expect(act).toHaveBeenCalledWith('select', 1)
  })

  test('handles candidate clicks', () => {
    const board = mount(
      <Board act={act} view={view} shapes={shapes} />,
    ).find('.su-board')
    board.simulate('click', {
      target: {
        getAttribute: (attr) =>
          attr === 'data-candidate' ? '3' : undefined,
      },
    })
    expect(act).toHaveBeenCalledWith('toggleCandidate', 3)
  })

  test('handles non-cell clicks', () => {
    const board = mount(
      <Board act={act} view={view} shapes={shapes} />,
    ).find('.su-board')
    board.simulate('click', {
      target: { getAttribute: () => {} },
    })
    expect(act).not.toHaveBeenCalled()
  })
})
