import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import Number from '../Number/Number'
import hasTouch from '../../../helpers/hasTouch' // NOTE: this only works if this is not rendered on the server

/* eslint-disable react/destructuring-assignment */
const Candidates = (props) => {
  const { selected } = props

  const candidates = []
  const isClickable = !hasTouch() && selected

  for (let i = 0; i < 9; i += 1) {
    const n = i + 1
    const r = (i / 3) >> 0
    const c = i % 3
    const active = props[n]
    const style = {
      top: props.top + r * props.size,
      left: props.left + c * props.size,
      width: props.size,
      height: props.size,
    }

    if (active) {
      candidates.push(
        <Number
          key={`${n}c`}
          number={n}
          style={style}
          weight="light"
          className={cn('su-candidate')}
        />,
      )
    }

    /**
     * For the clickable hover effect,
     * a second set of candidates is rendered.
     * This is so the clicking and auto changes can not have any animation
     * while the hover effect animates independent
     */
    if (isClickable) {
      candidates.push(
        <Number
          key={n}
          number={n}
          style={style}
          data-candidate={n}
          weight="light"
          className={cn('su-candidate-button')}
        />,
      )
    }
  }

  return (
    <div
      style={{
        pointerEvents: selected && isClickable ? 'all' : 'none',
      }}
      className={cn('su-candidates', {
        selected,
      })}
    >
      {candidates}
    </div>
  )
}

Candidates.propTypes = {
  top: pt.number,
  left: pt.number,
  size: pt.number,
  selected: pt.bool,
}

export default React.memo(Candidates)
