import React from 'react'
import { shallow } from 'enzyme'

import Number from '../Number/Number'
import hasTouch from '../../../helpers/hasTouch' // NOTE: this only works if this is not rendered on the server

import Candidates from './Candidates'

jest.mock('../Number/Number', () => () => '')
jest.mock('../../../helpers/hasTouch', () => jest.fn())

describe('SUDOKU: CANDIDATES', () => {
  beforeEach(() => {
    hasTouch.mockReset()
  })

  test('Renders active numbers', () => {
    const candidates = shallow(
      React.createElement(Candidates, {
        top: 10,
        left: 20,
        size: 2,
        selected: false,
        1: true,
        9: true,
      }),
    )

    const numbers = candidates.find(Number)

    expect(numbers).toHaveLength(2)

    expect(numbers.at(0).props()).toMatchObject({
      number: 1,
      className: 'su-candidate',
      style: {
        top: 10,
        left: 20,
        width: 2,
        height: 2,
      },
    })

    expect(numbers.at(1).props()).toMatchObject({
      number: 9,
      className: 'su-candidate',
      style: {
        top: 14,
        left: 24,
        width: 2,
        height: 2,
      },
    })
  })

  test('renders numbers buttons for inactive candidates when selected', () => {
    const candidates = shallow(
      React.createElement(Candidates, {
        top: 10,
        left: 20,
        size: 2,
        selected: true,
        1: true,
        9: true,
      }),
    )

    const wrapper = candidates.find('.su-candidates')
    const active = candidates
      .find(Number)
      .filterWhere((n) => n.prop('className') === 'su-candidate')

    const inactive = candidates
      .find(Number)
      .filterWhere(
        (n) => n.prop('className') === 'su-candidate-button',
      )

    expect(active.at(0).prop('style')).toEqual(
      inactive.at(0).prop('style'),
    )
    expect(inactive).toHaveLength(9)
    expect(inactive.at(0).prop('number')).toBe(1)
    expect(inactive.at(8).prop('number')).toBe(9)
    expect(wrapper.prop('style').pointerEvents).toBe('all')
  })

  test('handles pointer events', () => {
    const selected = shallow(
      React.createElement(Candidates, {
        selected: true,
        top: 0,
        left: 0,
        size: 2,
      }),
    )

    const notSelected = shallow(
      React.createElement(Candidates, {
        selected: false,
        top: 0,
        left: 0,
        size: 2,
      }),
    )

    expect(
      selected.find('.su-candidates').prop('style').pointerEvents,
    ).toBe('all')
    expect(
      notSelected.find('.su-candidates').prop('style').pointerEvents,
    ).toBe('none')
  })

  test('having touch disables buttons', () => {
    hasTouch.mockReturnValue(true)
    const selected = shallow(
      React.createElement(Candidates, {
        selected: true,
        top: 0,
        left: 0,
        size: 2,
      }),
    )

    const inactive = selected
      .find(Number)
      .filterWhere(
        (n) => n.prop('className') === 'su-candidate-button',
      )

    expect(
      selected.find('.su-candidates').prop('style').pointerEvents,
    ).toBe('none')
    expect(inactive).toHaveLength(0)
  })
})
