import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import Number from '../Number/Number'

const Cell = (props) => {
  const {
    id,
    top,
    left,
    size,
    selected,
    prefilled,
    conflicted,
    value,
    state,
  } = props

  const dotSpace = ((size / 13) >> 0) + 1
  const dotSize = dotSpace * 2

  return (
    <div
      data-cell={id}
      aria-label={value || 'empty'}
      style={{
        top,
        left,
        width: size,
        height: size,
      }}
      className={cn('su-cell', state, {
        selected,
        prefilled,
        conflicted,
      })}
    >
      {value && (
        <Number
          className="su-cell__value su-stretch"
          number={value}
        />
      )}
      {state === 'rejected' && (
        <div className="su-cell__correction su-stretch" />
      )}
      <div
        className="su-cell__conflict"
        style={{
          width: dotSize,
          height: dotSize,
          bottom: dotSpace,
          right: dotSpace,
        }}
      />
    </div>
  )
}

Cell.propTypes = {
  id: pt.number,
  top: pt.number,
  left: pt.number,
  size: pt.number,
  state: pt.string,
  value: pt.number,
  selected: pt.bool,
  prefilled: pt.bool,
  conflicted: pt.bool,
}

export default React.memo(Cell)
