import React from 'react'
import { shallow } from 'enzyme'

import Number from '../Number/Number'

import Cell from './Cell'

jest.mock('../Number/Number', () => () => '')

describe('SUDOKU: CELL', () => {
  test('renders cell id', () => {
    const cell = shallow(<Cell id={3} />)
    expect(cell.prop('data-cell')).toBe(3)
  })

  test('renders cell value', () => {
    const cell = shallow(<Cell id={3} value={9} />)
    const number = cell.find(Number)
    expect(number.prop('number')).toBe(9)
  })

  const states = ['selected', 'prefilled', 'conflicted']

  states.forEach((state) => {
    test(`renders cell type: ${state}`, () => {
      const cell = shallow(
        React.createElement(Cell, { [state]: true }),
      )
      expect(cell.hasClass(state)).toBe(true)
    })
  })

  test(`renders cell state`, () => {
    const cell = shallow(React.createElement(Cell, { state: 'foo' }))
    expect(cell.hasClass('foo')).toBe(true)
  })

  test('does not render correction when state is not rejected', () => {
    const cell = shallow(
      React.createElement(Cell, { state: 'confirmed' }),
    )
    expect(cell.find('.su-cell__correction').exists()).toBe(false)
  })

  test('renders correction', () => {
    const cell = shallow(
      React.createElement(Cell, { state: 'rejected' }),
    )
    expect(cell.find('.su-cell__correction').exists()).toBe(true)
  })
})
