import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import Number from '../Number/Number'
import { trackEvent } from '../../helpers/sudokuTracker'

const Keyboard = ({ act, view }) => {
  const toggleAutoMode = () => {
    act('toggle', 'auto')
    trackEvent(
      view.difficulty,
      'auto-candidate-mode',
      view.auto ? 'turn-off' : 'turn-on',
    )
  }

  return (
    <div className="su-keyboard">
      <div className="su-keyboard__split">
        <button
          type="button"
          className={cn('su-keyboard__mode', {
            normal: true,
            normalMode: !view.candidateMode,
          })}
          onClick={() => {
            act('disable', 'candidateMode')
            trackEvent(view.difficulty, 'normal-mode')
          }}
        >
          Normal
        </button>
        <button
          type="button"
          className={cn('su-keyboard__mode', {
            candidate: true,
            candidateMode: view.candidateMode,
          })}
          onClick={() => {
            act('enable', 'candidateMode')
            trackEvent(view.difficulty, 'candidate-mode')
          }}
        >
          Candidate
        </button>
      </div>
      <div className="su-keyboard__container">
        {Array.from(new Array(9)).map((_, i) => (
          <div
            role="gridcell"
            key={i}
            onClick={() => act('guess', i + 1)}
            className="su-keyboard__number"
          >
            <div className="su-keyboard__svg-container">
              <Number
                className={cn(
                  'su-keyboard__svg',
                  { candidate: view.candidateMode },
                  {
                    completed: view.completed[i + 1] >= 9,
                  },
                  `row-${(i / 3) >> 0}`,
                  `col-${i % 3}`,
                )}
                number={i + 1}
                weight={view.completed[i + 1] >= 9 ? 'light' : 'bold'}
              />
            </div>
          </div>
        ))}
        <div
          role="button"
          onClick={() => {
            act('guess', undefined)
            trackEvent(view.difficulty, 'clear-square')
          }}
          className="su-keyboard__delete"
        />
        <div
          role="button"
          className="su-keyboard__auto"
          onClick={toggleAutoMode}
        >
          <input
            className="su-keyboard__checkbox"
            type="checkbox"
            name="lightenComplete"
            checked={!!view.auto}
            onChange={toggleAutoMode}
          />
          <div>Auto Candidate Mode</div>
        </div>
      </div>
    </div>
  )
}

Keyboard.propTypes = {
  act: pt.func,
  view: pt.shape({
    auto: pt.bool,
    difficulty: pt.string,
    candidateMode: pt.bool,
    completed: pt.shape({}),
  }),
}

export default Keyboard
