import React from 'react'

import ModalCongratsShared from '../../../shared/ModalSystem/ModalCongrats'
import type { ModalProps } from '../../../shared/ModalSystem/modalTypes'
import {
  trackEvent,
  trackSudokuImpressionEvent,
} from '../../helpers/sudokuTracker'
import {
  CONGRATS_NAVIGATE_BACK_TEXT,
  navigateBack,
} from '../../../helpers/navigateBack'
import { getCTA } from '../../../shared/ModalSystem/helpers'

import { ORIGIN, SudokuLevel } from './modalTypes'

const nextLevels = {
  [SudokuLevel.EASY]: SudokuLevel.MEDIUM,
  [SudokuLevel.MEDIUM]: SudokuLevel.HARD,
  [SudokuLevel.HARD]: null,
}

type ModalCongratsProps = {
  level: {
    current: SudokuLevel
    set: (nextLevel: string, origin?: { origin: string }) => void
  }
  timer: { timeFormatted: string }
}

const ModalCongrats = ({
  level,
  timer,
  close,
  isClosing,
  onRemove,
}: ModalCongratsWrapperProps) => {
  trackSudokuImpressionEvent(
    level.current,
    'congrats-modal',
    timer.timeFormatted,
  )
  trackSudokuImpressionEvent(
    level.current,
    'next-game',
    'spelling-bee',
  )

  const nextLevel = nextLevels[level.current]

  const subheading: JSX.Element = (
    <span>
      You finished {level.current === SudokuLevel.EASY ? 'an' : 'a'}{' '}
      <em>{level.current}</em> puzzle in
      {` `}
      {timer.timeFormatted}.
    </span>
  )

  const btnOnClick = () => {
    if (nextLevel) {
      level.set(nextLevel, {
        origin: ORIGIN.CONGRATS_MODAL,
      })
      return close()
    }
    trackEvent(SudokuLevel.HARD, 'back-to-hub')
    navigateBack()
  }

  const btnText = nextLevel
    ? 'Play another Sudoku'
    : CONGRATS_NAVIGATE_BACK_TEXT

  return (
    <ModalCongratsShared
      close={close}
      onRemove={onRemove}
      isClosing={isClosing}
      showStar
      heading="Congrats!"
      subheading={subheading}
      buttons={[
        {
          onClick: btnOnClick,
          text: btnText,
          filled: true,
          size: 'large',
          key: `${
            nextLevel
              ? 'play-again-btn-congrats'
              : 'nav-back-btn-congrats'
          }`,
        },
      ]}
      cta={{
        game: getCTA('spelling-bee'),
      }}
      currentGame={{ name: 'sudoku' }}
    />
  )
}

type ModalCongratsWrapperProps = ModalCongratsProps & ModalProps

export default ModalCongrats
