import React, { useEffect } from 'react'

import type { ModalProps } from '../../../shared/ModalSystem/modalTypes'
import ModalWrapper from '../../../shared/ModalSystem/ModalWrapper'

import type { GameProp } from './modalTypes'

type Props = ModalProps & {
  game: Pick<GameProp, 'timer' | 'view'>
}

const ModalPause = ({ close, game, isClosing, onRemove }: Props) => {
  useEffect(() => {
    return () => {
      if (!game.view.solved) game.timer.resume()
    }
  }, [])

  return (
    <ModalWrapper
      bodyClassName="modal-pause-body su-modal-pause limit-height"
      close={close}
      hideCloseX
      keyConfig={{
        Escape: () => {},
        Enter: () => {},
      }}
      ignoreBackgroundClick
      isClosing={isClosing}
      onRemove={onRemove}
    >
      <div className="modal-rules-container">
        <p className="modal-system-body modal-message">
          Your game has been paused
        </p>
        <button
          className="pz-modal__button dark large"
          onClick={() => {
            if (!game.view.solved) {
              game.timer.toggle()
            }
          }}
          type="button"
        >
          Resume
        </button>
      </div>
    </ModalWrapper>
  )
}

export default ModalPause
