import React, { useEffect } from 'react'

import { SEND_EMAIL_TYPE } from 'foundation'

import FeedbackLink from '../../../helpers/FeedbackLink'
import ModalWrapper from '../../../shared/ModalSystem/ModalWrapper'
import type { ModalProps } from '../../../shared/ModalSystem/modalTypes'

import { GameProp } from './modalTypes'

type Props = ModalProps & {
  game: GameProp
}

const ModalRules = ({ close, game, isClosing, onRemove }: Props) => {
  useEffect(() => {
    return () => {
      if (!game.view.solved) game.timer.resume()
    }
  }, [])

  return (
    <ModalWrapper
      bodyClassName="modal-rules-body"
      close={close}
      isClosing={isClosing}
      onRemove={onRemove}
    >
      <div>
        <h1
          data-testid="su-modal__title"
          className="modal-system-header"
        >
          How to play Sudoku
        </h1>
        <p className="modal-system-description">
          Fill each 3 x 3 set with numbers 1–9.
        </p>
        <ul className="bullet-list">
          <li className="modal-system-body">
            Tap a cell in any set, then select a number.
          </li>
          <li className="modal-system-body">
            Fill cells until the board is complete. Numbers in sets,
            rows or columns cannot repeat.
          </li>
          <li className="modal-system-body">
            Note: Each number can only appear on the board 9 times.
          </li>
        </ul>
        <h1 className="modal-system-header">Play modes and tips</h1>
        <ul className="bullet-list">
          <li className="modal-system-body">
            Normal mode: Add 1 number to a cell.
          </li>
          <li className="modal-system-body">
            Candidate mode: Add several numbers to a cell (for
            multiple options).
          </li>
          <li className="modal-system-body">
            Need a clue? Tap <i className="kebab-icon inline-icon" />
            -&gt; &quot;Hint&quot; to see the next logical cell to
            solve.
          </li>
          <>
            {window.isHybridWebView ||
            !!window.newsreaderAppPlatform ? (
              <li className="modal-system-body">
                Choose from 3 levels — easy, medium and hard. To
                change levels, tap &lt; in the toolbar.
              </li>
            ) : (
              <li className="modal-system-body">
                Choose from 3 levels — easy, medium and hard. To
                change levels, tap &quot;Back&quot; in the toolbar.
              </li>
            )}
          </>
          <li className="modal-system-body">
            New puzzles for each level are released daily:
            Sunday–Thursday at 10 p.m. E.T.; Friday–Saturday at 6 p.m.
            E.T.
          </li>
        </ul>
        <p className="modal-system-body paragraph">
          Have feedback?&ensp;
          <FeedbackLink
            subject="Sudoku Feedback"
            useEnhancedHybridDebugInfo
            type={SEND_EMAIL_TYPE.SUDOKU}
          >
            Email us
          </FeedbackLink>
          .
        </p>
      </div>
    </ModalWrapper>
  )
}

export default ModalRules
