import React, { useEffect } from 'react'

import { LEVELS } from '../../constants/constants'
import ModalWrapper from '../../../shared/ModalSystem/ModalWrapper'
import type { ModalProps } from '../../../shared/ModalSystem/modalTypes'

import type { GameProp, Settings } from './modalTypes'

type Props = ModalProps & {
  game: GameProp
  settings: Settings
}

const ModalSettings = ({
  close,
  game,
  settings,
  isClosing,
  onRemove,
}: Props) => {
  useEffect(() => {
    return () => {
      if (!game.view.solved) game.timer.resume()
    }
  }, [])

  const toggles = [
    {
      label: 'Check guesses when entered',
      checked: settings.get('autoCheck'),
      onChange: () => {
        if (!settings.get('autoCheck')) {
          game.act('check', 'puzzle')
        }

        settings.toggle('autoCheck')
      },
    },
    {
      label: 'Start in automatic mode',
      checked: settings.get('autoCandidateMode'),
      onChange: () => {
        if (!settings.get('autoCandidateMode')) {
          game.act('enable', 'auto')
        }

        settings.toggle('autoCandidateMode')
      },
    },
    {
      label: 'Highlight conflicts',
      checked: settings.get('highlightConflicts'),
      onChange: () => settings.toggle('highlightConflicts'),
    },
    {
      label: 'Play sound on solve',
      checked: settings.get('sound'),
      onChange: () => settings.toggle('sound'),
    },
    {
      label: 'Show clock',
      checked: settings.get('clock'),
      onChange: () => settings.toggle('clock'),
    },
  ]

  return (
    <ModalWrapper
      bodyClassName="modal-settings-body su-modal-settings"
      close={close}
      isClosing={isClosing}
      onRemove={onRemove}
    >
      <div>
        <div className="modal-system-header">Settings</div>
        <div>
          <form className="modal-settings-form">
            {toggles.map((toggle, i) => (
              <label
                htmlFor={`toggle-${toggle.label}`}
                key={i}
                className="su-modal-system-label"
              >
                <input
                  id={`toggle-${toggle.label}`}
                  type="checkbox"
                  checked={!!toggle.checked}
                  onChange={toggle.onChange}
                  className=""
                />
                {toggle.label}
              </label>
            ))}
          </form>
        </div>
      </div>
    </ModalWrapper>
  )
}

export default ModalSettings
