import React from 'react'
import { mount } from 'enzyme'

import ModalCongratsWrapper from '../ModalCongrats'
import { trackSudokuImpressionEvent } from '../../../helpers/sudokuTracker'
import { navigateBack } from '../../../../helpers/navigateBack'
import { ORIGIN } from '../modalTypes'

jest.mock('../../../../helpers/navigateBack', () => ({
  navigateBack: jest.fn(),
  CONGRATS_NAVIGATE_BACK_TEXT: 'View all games',
}))

jest.mock('../../../helpers/sudokuTracker', () => ({
  trackSudokuImpressionEvent: jest.fn(),
  trackEvent: jest.fn(),
}))

describe('SUDOKU: MODAL CONGRATS', () => {
  beforeEach(() => {})
  const levels = [
    {
      key: 'easy',
      time: '6:20',
      message: 'You finished an easy puzzle in 6:20.',
      next: 'medium',
    },
    {
      key: 'medium',
      time: '7:10',
      message: 'You finished a medium puzzle in 7:10.',
      next: 'hard',
    },
    {
      key: 'hard',
      time: '8:40',
      message: 'You finished a hard puzzle in 8:40.',
    },
  ]

  levels.forEach((level) => {
    const props = {
      level: { current: level.key, set: jest.fn() },
      timer: { timeFormatted: level.time },
      close: jest.fn(),
    }

    const modal = mount(<ModalCongratsWrapper {...props} />)

    test(`${level.key} - success message`, () => {
      const msg = modal.find('.modal-system-subheader')
      expect(msg.text()).toEqual(level.message)
    })

    test(`${level.key} - next level`, () => {
      const buttons = modal.find('.pz-modal__button')
      if (level.next) {
        const nextLevel = buttons.at(0)

        expect(nextLevel.text()).toEqual('Play another Sudoku')
        nextLevel.simulate('click')
        expect(props.level.set).toHaveBeenCalledWith(level.next, {
          origin: ORIGIN.CONGRATS_MODAL,
        })
        expect(props.close).toHaveBeenCalled()
      } else {
        const quit = buttons.at(0)

        expect(quit.text()).toEqual('View all games')
        expect(navigateBack).not.toHaveBeenCalled()

        quit.simulate('click')
        expect(navigateBack).toHaveBeenCalled()
      }
    })

    expect(trackSudokuImpressionEvent).nthCalledWith(
      1,
      'easy',
      'congrats-modal',
      '6:20',
    )

    expect(trackSudokuImpressionEvent).nthCalledWith(
      2,
      'easy',
      'next-game',
      'spelling-bee',
    )
  })
})
