import React from 'react'
import { shallow } from 'enzyme'

import ModalPause from '../ModalPause'

describe('SUDOKU: MODAL PAUSE', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })

  const props = {
    close: jest.fn(),
    game: {
      view: {
        solved: false,
      },
      timer: { toggle: jest.fn() },
    },
  }

  const modal = shallow(<ModalPause {...props} />)
  const btn = modal.find('.pz-modal__button.dark')

  it('should render text', () => {
    const msg = modal.find('.modal-message')
    expect(msg.text()).toEqual('Your game has been paused')
    expect(props.close).not.toHaveBeenCalled()
    expect(props.game.timer.toggle).not.toHaveBeenCalled()
  })

  describe('when game is complete', () => {
    it('does not call timer toggle when game is complete', () => {
      const propsSolved = {
        close: jest.fn(),
        game: {
          view: {
            solved: true,
          },
          timer: { toggle: jest.fn() },
        },
      }

      const modalSolved = shallow(<ModalPause {...propsSolved} />)
      const resumeButton = modalSolved.find('.pz-modal__button.dark')

      resumeButton.simulate('click')
      expect(propsSolved.game.timer.toggle).not.toHaveBeenCalled()
    })
  })

  it('should toggle timer and close modal on click', () => {
    btn.simulate('click')
    expect(props.game.timer.toggle).toHaveBeenCalled()
  })

  it('should not toggle timer on enter key press', () => {
    btn.simulate('keyDown', { key: 'Enter' })
    expect(props.game.timer.toggle).not.toHaveBeenCalled()
  })

  it('should not toggle timer on escape key press', () => {
    btn.simulate('keyDown', { key: 'Escape' })
    expect(props.game.timer.toggle).not.toHaveBeenCalled()
  })
})
