import React, { useEffect } from 'react'
import { useDispatch } from 'react-redux'

import { useUser } from 'user'

import { loadDifficulties } from '../../helpers/persist'
import Loader from '../../../shared/moments/components/Loader'
import { addToCompletedDifficulties } from '../../store/slices/gameStatus'

const config = {
  bgColor: '$sudoku-orange',
  barBgColor: 'rgba(255, 255, 255, 0.6)',
  barColor: 'black',
  transitionTo: 'welcome',
}

const MomentLoader = ({
  puzzleDate,
  ...props
}: {
  puzzleDate: string
}) => {
  const value = loadDifficulties(puzzleDate, 'completedDifficulties')

  const dispatch = useDispatch()

  const utilizeDispatch = (
    difficulty: 'easy' | 'medium' | 'hard',
  ) => {
    dispatch(addToCompletedDifficulties(difficulty))
  }

  useEffect(() => {
    if (value) {
      value.forEach(utilizeDispatch)
    }
  }, [])

  const { hasLoaded } = useUser()
  const loaderProps = { ...props, ...config, hasLoaded }

  return <Loader {...loaderProps} />
}

export default MomentLoader
