import React from 'react'
import { Provider } from 'react-redux'
import { render, screen } from '@testing-library/react'

import { trackImpression } from 'foundation'

import { store } from '../../store'
import * as useAbra from '../../../../shared/abra/useAbra'

import MomentWelcome from './MomentWelcome'

jest.mock('foundation', () => ({
  env: { version: 'test' },
  trackImpression: jest.fn(),
  trackClick: jest.fn(),
  abra: {
    getVariant: jest.fn(),
  },
}))

jest.mock('user', () => ({
  useUser: () => ({ hasLoaded: true, userType: {} }),
}))

jest.mock('../../../../shared/responsive/hybrid', () => ({
  setHybridWindowProperties: () => {},
  setHybridBodyClasses: () => {},
}))

jest.mock('responsive', () => ({
  isMobile: true,
}))

const momentWelcomeProps = {
  displayDate: 'September 8, 2023',
  startGame: jest.fn(),
  level: {
    current: 'welcome' as const,
  },
  setLevel: jest.fn(),
  puzzleDate: '2023-09-08',
}

describe('Welcome', () => {
  const testVariant = '1_icon'

  const renderWelcome = () => {
    render(
      <Provider store={store}>
        <MomentWelcome {...momentWelcomeProps} />
      </Provider>,
    )

    return { store }
  }

  beforeEach(() => {
    jest.resetAllMocks()
  })

  it('renders Welcome text and actions', () => {
    renderWelcome()
    const easyButton = screen.getByText('Easy', {
      selector: 'button',
    })

    const mediumButton = screen.getByText('Medium', {
      selector: 'button',
    })

    const hardButton = screen.getByText('Hard', {
      selector: 'button',
    })

    const description = screen.getByText(
      'Try this numbers game, minus the math.',
    )
    expect(easyButton).toBeTruthy()
    expect(mediumButton).toBeTruthy()
    expect(hardButton).toBeTruthy()
    expect(description).toBeTruthy()
    expect(trackImpression).toHaveBeenCalledWith(
      'welcome-modal',
      'sudoku',
      'log-in',
      '[]',
    )
  })

  it('shows app banner on mobile web', () => {
    window.isHybridWebView = false

    // @ts-ignore
    jest.spyOn(useAbra, 'default').mockImplementationOnce(() => ({
      getVariant: () => testVariant,
      reportExposure: jest.fn(),
    }))

    renderWelcome()
    expect(
      screen.queryByText('Play Sudoku and more', { exact: false }),
    ).toBeTruthy()
  })

  it('hides app banner on hybrid', () => {
    window.isHybridWebView = true

    // @ts-ignore
    jest.spyOn(useAbra, 'default').mockImplementationOnce(() => ({
      getVariant: () => testVariant,
      reportExposure: jest.fn(),
    }))

    renderWelcome()

    expect(
      screen.queryByText('Play Sudoku and more', { exact: false }),
    ).toBeFalsy()
  })

  it('hides app banner on newsreader: ios', () => {
    window.newsreaderAppPlatform = 'ios'
    // @ts-ignore
    jest.spyOn(useAbra, 'default').mockImplementationOnce(() => ({
      getVariant: () => testVariant,
      reportExposure: jest.fn(),
    }))

    renderWelcome()
    expect(
      screen.queryByText('Play Sudoku and more', { exact: false }),
    ).toBeFalsy()
  })
})
