import React from 'react'
import { shallow } from 'enzyme'

import { trackEvent } from '../../helpers/sudokuTracker'

import Timer from './Timer'

jest.mock('../../helpers/sudokuTracker', () => ({
  trackEvent: jest.fn(),
}))

jest.mock('../../store/slices/modalSystem', () => ({
  open: jest.fn(),
  selectOpenModal: jest.fn(),
}))

jest.mock('../../store/index', () => ({
  useAppDispatch: jest.fn(),
  useAppSelector: jest.fn(),
}))

jest.mock('../../constants/constants', () => ({
  Welcome: 'welcome',
}))

describe('SUDOKU - TIMER', () => {
  let tick
  let timer
  let view
  let level

  beforeEach(() => {
    tick = {
      timeFormatted: 'timeBefore',
      isPaused: true,
    }

    level = 'easy'

    timer = {
      toggle: jest.fn(),
      useTick: () => tick,
      pause: jest.fn(),
    }

    view = {
      solved: false,
    }
  })

  test('renders timer and pause buttons', () => {
    const myComponent = shallow(<Timer game={{ timer, view }} />)
    expect(myComponent.find('.su-timer__value')).toBeTruthy()
    expect(myComponent.find('.su-timer__pause')).toBeTruthy()
  })

  test('toggles timer on click', () => {
    const myComponent = shallow(
      <Timer game={{ timer, view }} level={level} />,
    )
    const timerBox = myComponent.find('.su-timer')

    timerBox.simulate('click')
    expect(timer.toggle).toHaveBeenCalledTimes(1)
    expect(trackEvent).toHaveBeenCalledWith('easy', 'pause')

    timerBox.simulate('click')
    expect(timer.toggle).toHaveBeenCalledTimes(2)
  })

  test('formatted time updates with tick', () => {
    const before = shallow(<Timer game={{ timer, view }} />)
    expect(before.find('.su-timer__value').text()).toBe('timeBefore')

    tick.timeFormatted = 'timeAfter'

    const after = shallow(<Timer game={{ timer, view }} />)
    expect(after.find('.su-timer__value').text()).toBe('timeAfter')
  })

  test('deactivated when solved', () => {
    view.solved = true
    const myComponent = shallow(<Timer game={{ timer, view }} />)
    const timerBox = myComponent.find('.su-timer')

    expect(myComponent.find('.su-timer__pause').exists()).toBe(false)

    timerBox.simulate('click')

    expect(timer.toggle).not.toHaveBeenCalled()
  })
})
