import React from 'react'
import pt from 'prop-types'

import DropDownComponent from '../../../../shared/DropDown/DropDown'
import DropDownItem from '../../../../shared/DropDown/DropDownItem'
import * as toolbarHelpers from '../../../helpers/toolbar'
import { trackEvent, gameIdMap } from '../../../helpers/sudokuTracker'
import { saveDifficulty } from '../../../helpers/persist'
import { removeFromCompletedDifficulties } from '../../../store/slices/gameStatus'
import { useAppDispatch, useAppSelector } from '../../../store'
import { selectOpenModal } from '../../../store/slices/modalSystem'
import DropDownCloseHook from '../../../../shared/DropDown/DropDownCloseHook'

const HelpSelectMenu = ({ game, level }) => {
  const dispatch = useAppDispatch()
  const isModalOpen = useAppSelector(selectOpenModal)
  const { difficulty } = game.state

  const handleMenuItemClick = (cb) => {
    if (typeof cb === 'string' && toolbarHelpers[cb]) {
      const eventHandler = toolbarHelpers[cb]
      eventHandler(game)
    }
  }

  return (
    <DropDownComponent
      buttonLabel={<i className="su-app__kebab-icon" />}
      removeArrow
      customLabelClass="su-app__help-label"
      ariaLabel="help"
      trackData={{
        context: `${difficulty[0]}-${gameIdMap[difficulty]}`,
        elementName: 'sudoku',
        elementLabel: 'help',
      }}
    >
      {!game.view.solved && [
        <DropDownItem
          type="button"
          key="hint"
          value="Hint"
          buttonAction={() => {
            handleMenuItemClick('onShowHint')
            trackEvent(difficulty, 'hint')
          }}
        />,
        <DropDownItem
          type="button"
          key="check-cell"
          value="Check Cell"
          buttonAction={() => {
            handleMenuItemClick('onCheckCell')
            trackEvent(difficulty, 'check-cell')
          }}
        />,
        <DropDownItem
          type="button"
          key="check-puzzle"
          value="Check Puzzle"
          buttonAction={() => {
            handleMenuItemClick('onCheckBoard')
            trackEvent(difficulty, 'check-puzzle')
          }}
        />,

        <DropDownItem
          type="button"
          key="reveal-cell"
          value="Reveal Cell"
          buttonAction={() => {
            handleMenuItemClick('onRevealCell')
            trackEvent(difficulty, 'reveal-cell')
          }}
        />,

        <DropDownItem
          type="button"
          key="reveal-puzzle"
          value="Reveal Puzzle"
          buttonAction={() => {
            handleMenuItemClick('onRevealBoard')
            trackEvent(difficulty, 'reveal-puzzle')
          }}
        />,
      ]}
      <DropDownItem
        type="button"
        key="reset-puzzle"
        value="Reset Puzzle"
        buttonAction={() => {
          handleMenuItemClick('onGameReset')
          trackEvent(difficulty, 'reset-puzzle')
          saveDifficulty(
            'completedDifficulties',
            difficulty,
            false,
            false,
          )
          dispatch(removeFromCompletedDifficulties(difficulty))
        }}
      />
      <DropDownCloseHook
        shouldClose={() => {
          return isModalOpen || level.current === 'welcome'
        }}
      />
    </DropDownComponent>
  )
}

HelpSelectMenu.propTypes = {
  game: pt.shape({
    act: pt.func,
    view: pt.shape({ solved: pt.bool }),
    state: pt.shape({ difficulty: pt.string }),
    timer: pt.shape({
      pause: pt.func,
    }),
  }),
  level: pt.shape({
    current: pt.string,
    set: pt.func,
  }),
}

export default HelpSelectMenu

/*
// DEBUG MENU
<button onClick={onDebugFill}>Debug Fill!</button>
<button onClick={onToggleAuto}>
{game.view.auto ? 'Disable Auto' : 'Enable Auto'}
</button>
<p className='temp-text'>{game.view.filled ? 'Filled!' : 'Not Filled'}</p>
<p className='temp-text'>{game.view.solved ? 'Solved!' : 'Not Solved'}</p>
*/
