import React from 'react'
import { createStore } from 'redux'
import { Provider } from 'react-redux'

import { UserProvider } from 'user'

import useAnimation from '../../../shared/moments/components/stories/useAnimation'
import WelcomeComponent from '../Moments/MomentWelcome'

import defaultProps from './mocks/store'

const WelcomeTemplate = ({
  date,
  completedDifficulties,
  isLoggedIn,
}) => {
  const state = {
    gameStatus: {
      completedDifficulties,
    },
    userType: {
      isLoggedIn,
    },
  }
  const store = createStore(() => state)

  const formattedDate = new Date(date).toLocaleDateString('en-us', {
    year: 'numeric',
    month: 'long',
    day: 'numeric',
  })

  return (
    <Provider store={store}>
      <WelcomeComponent
        displayDate={formattedDate}
        startGame={() => {}}
        level={defaultProps.level.current}
        setLevel={defaultProps.level.set}
      />
    </Provider>
  )
}

export const Welcome = WelcomeTemplate.bind({})
Welcome.args = {
  date: new Date(),
  completedDifficulties: [],
  isLoggedIn: true,
}

export default {
  component: WelcomeTemplate,
  title: 'Sudoku/Moments/Welcome',
  argTypes: {
    date: {
      control: {
        type: 'date',
      },
    },
    completedDifficulties: {
      control: 'check',
      options: ['easy', 'medium', 'hard'],
    },
    isLoggedIn: {
      control: 'boolean',
    },
  },
  decorators: [
    (Story, { args: { isLoggedIn } }) => {
      const id = 'storybook-welcome'
      useAnimation(id, '')

      const withUserProvider = (children, isLoggedIn) => {
        return (
          <UserProvider hasLoaded userType={{ isLoggedIn }}>
            {children}
          </UserProvider>
        )
      }

      return withUserProvider(
        <div
          className="pz-moment__frame on-stage"
          id="storybook-welcome"
        >
          <Story />
        </div>,
        isLoggedIn,
      )
    },
  ],
}
