import {
  STATE_GUESSED,
  STATE_REJECTED,
  STATE_CONFIRMED,
} from '../hooks/useGame/actions'

import { trackEvent } from './sudokuTracker'

export const trackPercentageComplete = (
  difficulty: 'easy' | 'medium' | 'hard',
  userCompletedCellCount: number,
  editableCellCount: number,
) => {
  // calculate 20% of all editable cells
  const twentyPercentOfCells: number = Math.round(
    editableCellCount / 5,
  )

  // map percentage to what value we send to tracking,
  // easier than dealing with finicky rounding for displayed string
  const percentMap: { [key: number]: string } = {
    [twentyPercentOfCells]: '20',
    [twentyPercentOfCells * 2]: '40',
    [twentyPercentOfCells * 3]: '60',
    [twentyPercentOfCells * 4]: '80',
    [editableCellCount]: '100',
  }

  // fire tracking if user is at mapped completion level
  if (percentMap[userCompletedCellCount]) {
    trackEvent(
      difficulty,
      `${percentMap[userCompletedCellCount]}%-complete`,
    )
  }
}

export const trackPuzzleCompletionProgress = (
  difficulty: 'easy' | 'medium' | 'hard',
  currentCells: {
    [key: string]: {
      id: number
      prefilled: boolean
      state:
        | typeof STATE_GUESSED
        | typeof STATE_REJECTED
        | typeof STATE_CONFIRMED
      value: string | undefined
    }
  },
  selectedCellId: string,
) => {
  // get count of all user editable cells, can change between levels
  const editableCellCount = Object.values(currentCells).filter(
    (cell) => !cell.prefilled,
  ).length

  // Check cells to track user progress toward completion of full puzzle -
  // item 'state' in this sense means the state of cell in UI
  const userCompletedCells = Object.values(currentCells).filter(
    (cell) => cell.state && cell.value,
  ).length

  if (userCompletedCells && editableCellCount) {
    trackPercentageComplete(
      difficulty,
      userCompletedCells,
      editableCellCount,
    )
  }
}
