import { yearsToMonths } from 'date-fns/fp'

import whenIdle from '../../helpers/whenIdle'

const memory = {}
const storage = window.localStorage
const makeKey = (k) => `xwd-sudoku-${k}`

const read = (key) => {
  try {
    return JSON.parse(storage.getItem(key))
  } catch (e) {
    console.error(e)
  }
}

const write = (key) => {
  try {
    storage.setItem(key, JSON.stringify(memory[key]))
  } catch (e) {
    console.error(e)
  }
}

const writeDifficulty = (key, data, add) => {
  try {
    let value = read(key)

    if (add) {
      if (value) {
        value = value.includes(key) ? value : [value, data].flat()
      } else {
        value = [data]
      }
    } else if (value) {
      value = value.filter((difficulty) => difficulty !== data)
    } else {
      value = []
    }

    memory[key] = value
    storage.setItem(key, JSON.stringify(value))
  } catch (e) {
    console.error(e)
  }
}

export const saveDifficulty = (inKey, data, isUrgent, add) => {
  const key = makeKey(inKey)

  if (isUrgent) {
    writeDifficulty(key, data, add)
  } else {
    whenIdle(key, () => {
      writeDifficulty(key, data, add)
    })
  }
}

export const save = (inKey, data, isUrgent) => {
  const key = makeKey(inKey)
  memory[key] = data

  if (isUrgent) {
    write(key)
  } else {
    whenIdle(key, () => {
      write(key)
    })
  }
}

export const load = (inKey) => {
  const key = makeKey(inKey)

  if (!memory.hasOwnProperty(key)) memory[key] = read(key)

  return memory[key]
}

// IDs are unique to each level, so indexing on them in local storage would be messier
export const loadDifficulties = (printDate, inKey) => {
  const key = makeKey(inKey)

  if (!memory.hasOwnProperty(key)) memory[key] = read(key)

  if (!load('easy') || printDate !== load('easy').id) {
    if (memory[key]) {
      memory[key] = memory[key].filter(
        (difficulty) => difficulty !== 'easy',
      )
    }
    saveDifficulty('completedDifficulties', 'easy', true, false)
  }

  if (!load('medium') || printDate !== load('medium').id) {
    if (memory[key]) {
      memory[key] = memory[key].filter(
        (difficulty) => difficulty !== 'medium',
      )
    }
    saveDifficulty('completedDifficulties', 'medium', true, false)
  }

  if (!load('hard') || printDate !== load('hard').id) {
    if (memory[key]) {
      memory[key] = memory[key].filter(
        (difficulty) => difficulty !== 'hard',
      )
    }
    saveDifficulty('completedDifficulties', 'hard', true, false)
  }

  return memory[key]
}

export const puzzleInfo = (data, level) => {
  return level.current !== 'welcome' ? data[level.current] : {}
}

export const puzzleAnalyticsId = (data, level) => {
  const info = puzzleInfo(data, level)
  if (!info.difficulty) return ''
  const prefix = info.difficulty[0].toLowerCase()
  return `${prefix}-${info.puzzle_id}`
}
