import { track, getGameData } from 'foundation'

import { trackImpression } from '../../helpers/tracking'

export const EVENT_TYPE = 'type'
export const WHERE_IT_HAPPENED = 'where'
export const WHAT_IT_DOES = 'what'
export const GAME_ID = 'id'
export const ADDITIONAL_INFO = 'extra'

/**
 * For event specs
 * @see https://docs.google.com/spreadsheets/d/1jrAEkH50Dt1xvpe_pELlAgXkqHPf2hh7vHmwu3OE4Tk/edit#gid=420489817
 */

const gameData = getGameData()

export const gameIdMap = {
  easy: gameData.easy.puzzle_id,
  medium: gameData.medium.puzzle_id,
  hard: gameData.hard.puzzle_id,
  welcome: {},
}

type TrackingEvent = {
  [GAME_ID]: string
  [WHAT_IT_DOES]: string
  [ADDITIONAL_INFO]: string
}

export const trackModuleInteraction = (evt: TrackingEvent) => {
  const moduleObj = {
    module: {
      name: '',
      context: evt[GAME_ID],
      label: evt[ADDITIONAL_INFO],
      element: {
        name: 'sudoku',
        label: evt[WHAT_IT_DOES],
      },
    },
    eventData: {
      pageType: 'game',
      type: '',
      trigger: 'module',
      // important to leave an empty string for `status`
      // for the event to pass correctly to google analytics
      // consult with someone from tracking team before removing
      // and confirm that the events are still available in big query
      status: '',
    },
  }

  track('moduleInteraction', moduleObj)
}

export const trackEvent = (
  difficulty: 'easy' | 'medium' | 'hard' | 'welcome',
  name: string,
  extra: string = '',
) => {
  const event = {
    [GAME_ID]: `${difficulty[0]}-${gameIdMap[difficulty]}`,
    [WHAT_IT_DOES]: name,
    [ADDITIONAL_INFO]: extra,
  }

  trackModuleInteraction(event)
}

/**
 * Aside from tracking module interaction, Sudoku also handles impressiom events which are implemented via a helper
 * and are less complex
 * @param difficulty
 * @param name
 * @param label
 * @param context
 */
export const trackSudokuImpressionEvent = (
  difficulty: 'easy' | 'medium' | 'hard',
  name: string = '',
  label: string = '',
) => {
  trackImpression(
    name,
    'sudoku',
    label,
    `${difficulty[0]}-${gameIdMap[difficulty]}`,
  )
}
