import createInitialState from './createInitialState'

describe('SUDOKU / USE GAME / CREATE INITIAL STATE', () => {
  test('Selected cell is set to corner cell', () => {
    const data = {
      puzzle: [0, 1],
      solution: [1, 1],
    }

    const final = createInitialState({
      puzzle_data: data,
      difficulty: 'Easy',
    })
    expect(final.selected).toEqual(0)
  })

  test('Selected cell is set to non-corner cell', () => {
    const data = {
      puzzle: [1, 1, 0, 1],
      solution: [1, 1, 1, 1],
    }

    const final = createInitialState({
      puzzle_data: data,
      difficulty: 'Easy',
    })
    expect(final.selected).toEqual(2)
  })

  test('creates cell states', () => {
    const data = {
      puzzle: [1, 1, 0, 1],
      solution: [1, 1, 1, 1],
    }

    const final = createInitialState({
      puzzle_data: data,
      difficulty: 'Easy',
    })

    expect(final.cells[1]).toEqual({
      id: 1,
      prefilled: true,
      value: 1,
      answer: 1,
    })

    expect(final.cells[2]).toEqual({
      id: 2,
      prefilled: false,
      answer: 1,
    })
  })

  test('creates manual and auto candidates', () => {
    const data = {
      puzzle: [1, 1, 0, 1],
      solution: [1, 1, 1, 1],
    }

    const final = createInitialState({
      puzzle_data: data,
      difficulty: 'Easy',
    })
    expect(final.manualCandidates).toEqual({})
    expect(final.autoCandidates).toEqual({})
  })

  test('mixes in puzzle metadata', () => {
    const final = createInitialState({
      puzzle_data: {
        puzzle: [1, 1, 0, 1],
        solution: [1, 1, 1, 1],
      },
      print_date: '0-0-0',
      difficulty: 'Easy',
      initialTime: 0,
    })

    expect(final.id).toBe('0-0-0')
    expect(final.difficulty).toBe('easy')
  })
})
