import reduce from './reducer'

describe('SUDOKU: USE GAME / REDUCER', () => {
  test('updates top level properties', () => {
    const initial = { foo: 0, bar: 0, baz: 0 }
    const change = { foo: 1, baz: 1 }
    const final = reduce(initial, change)

    expect(final).toEqual({ foo: 1, bar: 0, baz: 1 })
    expect(final).not.toBe(initial) // if we mutate initial state, reducer hook will fail
  })

  test('supports non-existent changes', () => {
    const initial = { foo: 0 }
    const final = reduce(initial, undefined)

    expect(final).toBe(initial)
  })

  test('suports updating cells', () => {
    const initial = {
      foo: 1,
      cells: {
        0: { foo: 0, bar: 0 },
        1: { foo: 0, bar: 0 },
        2: {},
      },
    }

    const change = {
      foo: 2,
      cells: {
        0: { bar: 1 },
        2: { foo: 1 },
        3: { foo: 1, bar: 1 },
      },
    }
    const final = reduce(initial, change)

    expect(final).toEqual({
      foo: 2,
      cells: {
        0: { foo: 0, bar: 1 },
        1: { foo: 0, bar: 0 },
        2: { foo: 1 },
        3: { foo: 1, bar: 1 },
      },
    })
    expect(initial.cells[0].bar).not.toEqual(final.cells[0].bar)
  })

  test('supports updating candidates', () => {
    const initial = {
      foo: 1,
      manualCandidates: { 0: { 1: true, 2: false } },
      autoCandidates: {},
    }

    const change = {
      manualCandidates: { 0: { 2: true, 3: false } },
      autoCandidates: { 10: { 1: true } },
    }

    const final = reduce(initial, change)

    expect(final).toEqual({
      foo: 1,
      manualCandidates: {
        0: { 1: true, 2: true, 3: false },
      },
      autoCandidates: { 10: { 1: true } },
    })
  })

  test('supports reset', () => {
    const initial = { cells: { 1: { value: 4 } } }
    const change = {
      reset: {
        cells: { 1: { value: undefined } },
      },
    }
    const final = reduce(initial, change)
    expect(final).toBe(change.reset)
  })
})
