const updateConflicts = (group, idx, cell, settings) => {
  if (!group[idx]) group[idx] = {}

  if (!cell.value) return

  if (!group[idx][cell.value]) {
    group[idx][cell.value] = cell
  } else if (settings.get('highlightConflicts')) {
    cell.conflicted = true
    group[idx][cell.value].conflicted = true
  }
}

const createView = (state, settings, wasSolved) => {
  const regions = {}
  const columns = {}
  const rows = {}

  const view = {
    ...state,
    cells: [],
    filled: true,
    solved: true,
    justSolved: !wasSolved,
    candidates: {},
    pendingAutoChanges: {},
    completed: {},
  }

  for (let i = 0; i < state.size; i += 1) {
    const cell = state.cells[i]

    if (!cell.prefilled) {
      if (view.filled && !cell.value) view.filled = false

      if (view.solved && cell.value !== cell.answer) {
        view.solved = false
        view.justSolved = false
      }
    }

    if (cell.value) {
      view.completed[cell.value] =
        (view.completed[cell.value] || 0) + 1
    }

    const row = (i / 9) >> 0
    const column = i % 9
    const region = ((row / 3) >> 0) * 3 + ((column / 3) >> 0)

    const viewCell = {
      row,
      column,
      region,
      selected: i === state.selected,
      ...cell,
    }

    updateConflicts(regions, region, viewCell, settings)
    updateConflicts(columns, column, viewCell, settings)
    updateConflicts(rows, row, viewCell, settings)

    view.cells.push(viewCell)

    /**
     * Getters are used here as a way to reduce code and run-time looping.
     * Since each view loops over the cells any way, we can take advantage of that loop
     * when looking up possibile candidates
     */
    Object.defineProperty(view.candidates, i, {
      get() {
        if (!state.auto) {
          return state.manualCandidates[i] || {}
        }

        const values = {}

        for (let v = 1; v <= 9; v += 1) {
          if (
            state.autoCandidates[i] &&
            typeof state.autoCandidates[i][v] !== 'undefined'
          ) {
            values[v] = state.autoCandidates[i][v]
            /**
             * In auto mode, the user can add candidates that are not possible,
             * but on the next guess action, those impossibilities are cleared
             *
             * To do this we rremove any truthy candidate notes on each guess
             * and this branch is the clearest place to identify and build that change
             */
            if (values[v]) {
              view.pendingAutoChanges[i] = {
                [v]: undefined,
                ...view.pendingAutoChanges[i],
              }
            }
          } else {
            values[v] =
              !rows[row][v] &&
              !columns[column][v] &&
              !regions[region][v]
          }
        }

        return values
      },
    })
  }

  return view
}

export default createView
