import { useEffect } from 'react'

import { trackEvent } from '../../helpers/sudokuTracker'

const KEY_SPACE = 32
const KEY_SHIFT = 16
const KEY_ALT = 18
const KEY_LEFT = 37
const KEY_UP = 38
const KEY_RIGHT = 39
const KEY_DOWN = 40
const KEY_DELETE = 46
const KEY_BACKSPACE = 8

const DIRECTIONS = {
  [KEY_UP]: 'up',
  [KEY_DOWN]: 'down',
  [KEY_LEFT]: 'left',
  [KEY_RIGHT]: 'right',
}

const getNumber = (keyCode) => {
  // main keys
  if (keyCode >= 48 && keyCode <= 57) return keyCode - 48

  // num pad keys
  if (keyCode >= 96 && keyCode <= 105) return keyCode - 96
}

const createKeydownHandler = (act, state) => (evt) => {
  const { difficulty, candidateMode } = state
  const { keyCode, repeat } = evt
  const number = getNumber(keyCode)

  if (number) {
    return act('guess', number)
  }

  let prevent

  switch (keyCode) {
    case KEY_DELETE:
    case KEY_BACKSPACE:
      act('guess', undefined)
      trackEvent(difficulty, 'clear-square')
      prevent = true
      break
    case KEY_UP:
    case KEY_DOWN:
    case KEY_LEFT:
    case KEY_RIGHT:
      act('move', DIRECTIONS[keyCode])
      prevent = true
      break
    case KEY_ALT:
    case KEY_SPACE:
    case KEY_SHIFT:
      if (!repeat) {
        act('toggle', 'candidateMode')
        trackEvent(
          difficulty,
          candidateMode ? 'normal-mode' : 'candidate-mode',
        )
      }
      prevent = true
      break
    default:
  }

  if (prevent) evt.preventDefault()
}

const createKeyupHandler = (act, state) => (evt) => {
  const { difficulty, candidateMode } = state
  const { keyCode } = evt

  if (keyCode === KEY_ALT || keyCode === KEY_SHIFT) {
    act('toggle', 'candidateMode')
    trackEvent(
      difficulty,
      candidateMode ? 'normal-mode' : 'candidate-mode',
    )
    evt.preventDefault()
  }
}

const useKeyboard = (act, state) => {
  const { difficulty, candidateMode } = state
  useEffect(() => {
    const handleKeydown = createKeydownHandler(act, state)
    const handleKeyup = createKeyupHandler(act, state)
    document.addEventListener('keydown', handleKeydown)
    document.addEventListener('keyup', handleKeyup)
    return () => {
      document.removeEventListener('keydown', handleKeydown)
      document.removeEventListener('keyup', handleKeyup)
    }
  }, [act, difficulty, candidateMode])
}

export default useKeyboard
