import { useState, useEffect, useRef } from 'react'

import { refreshAds } from 'foundation'

import { trackEvent } from '../../helpers/sudokuTracker'
import { Welcome } from '../../constants/constants'
import {
  ORIGIN,
  SudokuLevel,
} from '../../components/Modals/modalTypes'
import { load } from '../../helpers/persist'

import getInitalLevel from './getInitialLevel'
import getQueryString from './getQueryString'

// TODO - There is an argument to change level to phase with the addition of the "welcome" level
// but that would involve a large amount of changes in files, and might be better to
// do at a different time.

const previousLevel = {
  [SudokuLevel.EASY]: '',
  [SudokuLevel.MEDIUM]: SudokuLevel.EASY,
  [SudokuLevel.HARD]: SudokuLevel.MEDIUM,
}

const useLevel = () => {
  const [levelState, setLevelState] = useState({
    method: 'replaceState',
    level: getInitalLevel() || 'welcome',
  })

  const { level, method } = levelState

  useEffect(() => {
    if (method) {
      if (level !== Welcome) {
        window.history[method](
          { level },
          `Sudoku - ${level}`,
          `/puzzles/sudoku/${level}${getQueryString()}`,
        )
      } else {
        window.history[method](
          { level },
          `Sudoku - ${level}`,
          `/puzzles/sudoku${getQueryString()}`,
        )
      }
    }
  }, [levelState])

  useEffect(() => {
    window.onpopstate = (event) => {
      if (event.state && event.state.level) {
        setLevelState(event.state)
        if (event.state.level !== Welcome) {
          refreshAds()
        }
      }
    }
  }, [level, method])

  const setLevel = useRef((level, options) => {
    const newLevelorNewGame =
      level !== Welcome &&
      (load(level) === null ||
        load(level).initialTime === 0 ||
        (options &&
          options.puzzleDate &&
          load(level).id !== options.puzzleDate))

    setLevelState({ level, method: 'pushState' })

    if (options && options.origin === ORIGIN.CONGRATS_MODAL) {
      trackEvent(previousLevel[level], 'play-again', 'level-changed')
      trackEvent(level, 'start-game', 'level-changed')
    } else if (newLevelorNewGame) {
      trackEvent(level, 'start-game')
    }

    if (level !== Welcome) {
      refreshAds()
    }
  })

  return {
    current: level,
    set: setLevel.current,
  }
}

export default useLevel
