import React from 'react'
import ReactDOM from 'react-dom'
import { act } from 'react-dom/test-utils'

import { refreshAds } from 'foundation'

import { trackEvent } from '../../helpers/sudokuTracker'

import useLevel from './useLevel'
import getInitialLevel from './getInitialLevel'
import getQueryString from './getQueryString'

jest.mock('./getInitialLevel', () => jest.fn())
jest.mock('./getQueryString', () => jest.fn())
jest.mock('foundation', () => ({
  refreshAds: jest.fn(),
}))
jest.mock('../../helpers/sudokuTracker', () => ({
  trackEvent: jest.fn(),
}))

describe('SUDOKU: USE LEVEL', () => {
  let container
  let MyComponent

  function setUp() {
    /* eslint-disable */
    MyComponent = () => {
      const level = useLevel()
      return (
        <div>
          <span className="level">{level.current}</span>
          <button
            className="easy"
            onClick={() => level.set('easy')}
          />
          <button
            className="medium"
            onClick={() => level.set('medium')}
          />
          <button
            className="hard"
            onClick={() => level.set('hard')}
          />
        </div>
      )
    }
    /* eslint-enable */

    getInitialLevel.mockReset()
    getQueryString.mockReset()

    getQueryString.mockReturnValue('')

    container = document.createElement('div')
    document.body.appendChild(container)
  }

  beforeEach(() => {
    setUp()
  })

  afterEach(() => {
    document.body.removeChild(container)
    container = null
  })

  test('respects router "Welcome" level', () => {
    getInitialLevel.mockReturnValue(undefined)

    ReactDOM.render(<MyComponent />, container)

    const level = container.querySelector('.level')
    expect(level.innerHTML).toBe('welcome')
  })

  test('respects router level', () => {
    getInitialLevel.mockReturnValue('hard')

    ReactDOM.render(<MyComponent />, container)

    const level = container.querySelector('.level')
    expect(level.innerHTML).toBe('hard')
  })

  test('should keep query string', () => {
    const replaceState = jest.spyOn(window.history, 'replaceState')

    getQueryString.mockReturnValue('?foo=true')

    act(() => {
      ReactDOM.render(<MyComponent />, container)
    })

    const hard = container.querySelector('.hard')

    act(() => {
      hard.dispatchEvent(
        new window.MouseEvent('click', { bubbles: true }),
      )
    })

    expect(replaceState.mock.calls[0][2]).toBe(
      '/puzzles/sudoku/hard?foo=true',
    )

    expect(replaceState.mock.calls[1][2]).toBe(
      '/puzzles/sudoku?foo=true',
    )

    replaceState.mockClear()
  })
})
