import React from 'react'

import onExit from '../../../helpers/onExit'
import { save } from '../../helpers/persist'

const createSave = (game) => ({
  ...game.state,
  initialTime: game.timer.time,
})

const useSave = (game) => {
  const { difficulty } = game.state
  const stateRef = React.useRef()
  stateRef.current = game

  React.useEffect(() => {
    save(difficulty, createSave(stateRef.current))
  }, [game.state])

  React.useEffect(() => {
    const unSubscribeFromTimer = game.timer.subscribe((evt) => {
      if (evt === 'pause') {
        save(difficulty, createSave(stateRef.current))
      }
    })

    const unSubscribeFromExit = onExit(() => {
      const isUrgent = true
      save(difficulty, createSave(stateRef.current), isUrgent)
    })

    return () => {
      unSubscribeFromExit()
      unSubscribeFromTimer()
    }
  }, [difficulty])
}

export default useSave
