import React from 'react'

import { save, load } from '../../helpers/persist'

const defaultSettings = {
  autoCheck: false,
  autoCandidateMode: false,
  highlightConflicts: true,
  sound: true,
  clock: true,
}

const useSettings = () => {
  const apiRef = React.useRef()
  const settingsRef = React.useRef()
  const [settings, updateSettings] = React.useState(
    load('settings') || defaultSettings,
  )

  settingsRef.current = settings

  if (!apiRef.current) {
    apiRef.current = {
      set: (key, value) => {
        updateSettings({
          ...settingsRef.current,
          ...{ [key]: value },
        })
      },

      toggle: (key) => {
        updateSettings({
          ...settingsRef.current,
          ...{ [key]: !settingsRef.current[key] },
        })
      },

      get: (key) => settingsRef.current[key],
    }
  }

  React.useEffect(() => {
    save('settings', settings)
  }, [settings])

  return apiRef.current
}

export default useSettings
