import { useRef, useEffect, useState } from 'react'

const useSizer = () => {
  const ref = useRef()
  const shapeRef = useRef()
  const [shapes, setShapes] = useState({})
  shapeRef.current = shapes

  const scrollToTop = () => {
    if (window.scrollY > 0) window.scrollTo(0, 0)
  }

  const handleResize = () => {
    const total = ref.current.offsetWidth
    const gutter = total < 400 ? 3 : 5
    const candidate = ((total - 6 - 4 * gutter) / 27) >> 0

    if (candidate !== shapeRef.current.candidate) {
      const cell = candidate * 3
      const region = cell * 3 + 2
      const board = region * 3 + 2 * gutter
      setShapes({
        cell,
        board,
        region,
        gutter,
        candidate,
        getOffset: (i) => {
          const g = (i / 3) >> 0
          return i - g + g * gutter + i * cell
        },
      })
    }

    scrollToTop()
  }

  useEffect(() => {
    handleResize()
    window.addEventListener('resize', handleResize)

    return () => {
      window.removeEventListener('resize', handleResize)
    }
  }, [])

  return {
    ref,
    shapes,
    resize: handleResize,
  }
}

export default useSizer
