import React from 'react'
import ReactDOM from 'react-dom'
import { act } from 'react-dom/test-utils'

import useSizer from './useSizer'

describe('SUDOKU: USE SIZER', () => {
  let MyComponent
  let board
  let container
  let shapes

  beforeEach(() => {
    container = document.createElement('div')
    board = document.createElement('div')

    Object.defineProperty(board, 'offsetWidth', {
      get() {
        return this._width
      },
      set(v) {
        this._width = v
      },
    })

    document.body.appendChild(container)
    document.body.appendChild(board)

    MyComponent = () => {
      const sizer = useSizer()

      sizer.ref.current = board
      shapes = sizer.shapes

      return null
    }
  })

  afterEach(() => {
    ReactDOM.unmountComponentAtNode(container)
    document.body.removeChild(container)
    document.body.removeChild(board)
    board = null
    container = null
  })

  test('rounds values down to nearest whole numbers', () => {
    board.offsetWidth = 401

    act(() => {
      ReactDOM.render(<MyComponent />, container)
    })

    expect(shapes).toMatchObject({
      cell: 39,
      board: 367,
      region: 119,
      gutter: 5,
      candidate: 13,
    })
  })

  test('makes small gutters for small sizes', () => {
    board.offsetWidth = 366

    act(() => {
      ReactDOM.render(<MyComponent />, container)
    })

    expect(shapes).toMatchObject({
      cell: 36,
      board: 336,
      region: 110,
      gutter: 3,
      candidate: 12,
    })
  })

  test('helps compute offset positions', () => {
    board.offsetWidth = 300

    act(() => {
      ReactDOM.render(<MyComponent />, container)
    })

    expect(shapes.getOffset(0)).toBe(0)
    expect(shapes.getOffset(1)).toBe(shapes.cell * 1 + 1)
    expect(shapes.getOffset(2)).toBe(shapes.cell * 2 + 2)
    expect(shapes.getOffset(3)).toBe(
      shapes.cell * 3 + 2 + shapes.gutter,
    )
    expect(shapes.getOffset(8)).toBe(
      shapes.cell * 8 + 6 + shapes.gutter * 2,
    )
  })

  test('updates on resize', () => {
    board.offsetWidth = 401

    jest.spyOn(window, 'addEventListener')
    jest.spyOn(window, 'removeEventListener')

    act(() => {
      ReactDOM.render(<MyComponent />, container)
    })

    const resizeListeners = window.addEventListener.mock.calls.filter(
      ([e]) => e === 'resize',
    )
    const onResize = resizeListeners[0][1]

    expect(shapes.gutter).toBe(5)
    expect(resizeListeners).toHaveLength(1)

    // window resizes
    act(() => {
      board.offsetWidth = 366
      onResize()
    })

    expect(shapes.gutter).toBe(3)

    ReactDOM.unmountComponentAtNode(container)

    expect(window.removeEventListener).toHaveBeenCalledWith(
      'resize',
      onResize,
    )
  })
})
