import { trackEvent } from '../../helpers/sudokuTracker'
import { close, open } from '../../store/slices/modalSystem'
import { Welcome } from '../../constants/constants'

import formatTime from './formatTime'
import useTick from './useTick'

const createTimer = (initialTime = 0, difficulty, dispatch) => {
  const listeners = []

  let time = initialTime
  let isPaused = true
  let lastStart
  let interval

  const notify = (evt, time) => {
    listeners.forEach((cb) => {
      cb(evt, time)
    })
  }

  const getTime = () => {
    return isPaused ? time : time + Date.now() - lastStart
  }

  const pause = () => {
    time = getTime()
    interval = clearInterval(interval)
    isPaused = true
    notify('pause', getTime())
  }

  const resume = () => {
    dispatch(close())
    if (!isPaused) return
    interval = setInterval(() => {
      notify('tick', getTime())
    }, 1000)
    lastStart = Date.now()
    isPaused = false
    notify('resume', getTime())
  }

  const toggle = () => {
    if (isPaused) {
      resume()
      if (difficulty !== Welcome) {
        trackEvent(difficulty, 'start-timer')
      }
    } else {
      pause()
      dispatch(open('Pause'))

      if (difficulty !== Welcome) {
        trackEvent(difficulty, 'stop-timer')
      }
    }
  }

  const reset = () => {
    time = 0
    interval = clearInterval(interval)
    isPaused = true
    resume()
  }

  const subscribe = (cb) => {
    listeners.push(cb)
    if (listeners.length > 10) {
      console.warn('POSSIBLE GAME TIMER SUBSCRIPTION LEAK') // eslint-disable-line
    }

    return function unsubscribe() {
      const idx = listeners.findIndex((l) => l === cb)
      if (idx > -1) listeners.splice(idx, 1)
    }
  }

  return Object.create(
    {
      reset,
      pause,
      resume,
      toggle,
      subscribe,
    },
    {
      time: {
        get: () => getTime(),
      },
      timeFormatted: {
        get: () => formatTime(getTime() / 1000),
      },
      isPaused: {
        get: () => isPaused,
      },
      useTick: {
        value() {
          /* eslint-disable-next-line */
          return useTick(this)
        },
      },
    },
  )
}

export default createTimer
