import React from 'react'
import ReactDOM from 'react-dom'
import { act } from 'react-dom/test-utils'

import useTick from './useTick'

describe('SUDOKU - USE TIMER TICK', () => {
  let MyComponent
  let container
  let timer
  let listener
  let unsubscribe
  let rendered

  beforeEach(() => {
    container = document.createElement('div')
    unsubscribe = jest.fn()

    timer = {
      isPaused: false,
      time: 0,
      timeFormatted: '0:00',
      subscribe: (fn) => {
        listener = fn
        return unsubscribe
      },
    }

    /* eslint-disable */
    MyComponent = () => {
      rendered = { ...useTick(timer) }
      return null
    }
    /* eslint-enable */

    document.body.appendChild(container)
  })

  afterEach(() => {
    ReactDOM.unmountComponentAtNode(container)
    document.body.removeChild(container)
    container = null
  })

  test('component will update on tick', () => {
    act(() => {
      ReactDOM.render(<MyComponent />, container)
    })

    expect(rendered.time).toBe(0)
    expect(rendered.timeFormatted).toBe('0:00')
    expect(rendered.isPaused).toBe(false)

    timer.time = 1
    timer.timeFormatted = '1:00'
    timer.isPaused = true

    act(() => {
      listener()
    })

    expect(rendered.time).toBe(1)
    expect(rendered.timeFormatted).toBe('1:00')
    expect(rendered.isPaused).toBe(true)

    expect(unsubscribe).not.toHaveBeenCalled()
    ReactDOM.unmountComponentAtNode(container)
    expect(unsubscribe).toHaveBeenCalled()
  })
})
