import { createSlice, PayloadAction } from '@reduxjs/toolkit'

import type { RootState } from '..'

interface GameStatus {
  completedDifficulties: String[]
}

const initialState = {
  completedDifficulties: [],
} as GameStatus

const gameStatus = createSlice({
  initialState,
  name: 'gameStatus',
  reducers: {
    addToCompletedDifficulties: (
      state,
      action: PayloadAction<string>,
    ) => {
      state.completedDifficulties =
        state.completedDifficulties.indexOf(action.payload) === -1
          ? [...state.completedDifficulties, action.payload]
          : [...state.completedDifficulties]
    },
    removeFromCompletedDifficulties: (
      state,
      action: PayloadAction<string>,
    ) => {
      state.completedDifficulties =
        state.completedDifficulties.filter(
          (difficulty) => difficulty !== action.payload,
        )
    },
  },
})

export const {
  addToCompletedDifficulties,
  removeFromCompletedDifficulties,
} = gameStatus.actions

export const selectCompletedDifficulties = (state: RootState) =>
  state.gameStatus.completedDifficulties

export default gameStatus.reducer
