import { createSlice, PayloadAction } from '@reduxjs/toolkit'

import type { RootState } from '..'
import type { SudokuModal } from '../../components/Modals/modalTypes'

type InitialState = {
  isClosing: boolean
  name: SudokuModal | null
}

const initialState: InitialState = {
  isClosing: false,
  name: null,
}

const modalSystem = createSlice({
  initialState,
  name: 'modalSystem',
  reducers: {
    open: (state, action: PayloadAction<SudokuModal>) => {
      state.name = action.payload
      state.isClosing = false
    },
    close: (state) => {
      state.isClosing = true
    },
    remove: (state) => {
      state.name = null
      state.isClosing = false
    },
  },
})

export const { open, close, remove } = modalSystem.actions

export const selectOpenModal = (state: RootState) =>
  state.modalSystem.name

export const selectIsClosing = (state: RootState) =>
  state.modalSystem.isClosing

export default modalSystem.reducer
