import { isPaletteNew } from "./utils";

describe('isPaletteNew function', () => {
  it('returns false if palette has no highlightAsNew property', () => {
    const date = new Date()

    const palette = {
      displayName: 'testing',
      filename: 'testing.ts',
    }

    expect(isPaletteNew(palette, date)).toBe(false)
  })

  it('returns false if given date is not in the highlightAsNew range', () => {
    const date = new Date(2023, 0, 1) // Jan 1st 2023

    const palette = {
      displayName: 'testing',
      filename: 'testing.ts',
      highlightAsNew: {
        startDate: '2020-01-01',
        endDate: '2020-12-31',
      },
    }

    expect(isPaletteNew(palette, date)).toBe(false)
  })

  it('returns true if given date is in the highlightAsNew range', () => {
    const date = new Date(2022, 6, 6) // July 6th, 2022

    const palette = {
      displayName: 'testing',
      filename: 'testing.ts',
      highlightAsNew: {
        startDate: '2022-01-01',
        endDate: '2022-12-31',
      },
    }

    expect(isPaletteNew(palette, date)).toBe(true)
  })

  it('returns true if given date falls on the startDate', () => {
    const date = new Date(2022, 6, 6) // July 6th, 2022

    const palette = {
      displayName: 'testing',
      filename: 'testing.ts',
      highlightAsNew: {
        startDate: '2022-06-06',
        endDate: '2022-12-31',
      },
    }

    expect(isPaletteNew(palette, date)).toBe(true)
  })

  it('returns false if given date falls on the endDate', () => {
    const date = new Date(2022, 6, 6) // July 6th, 2022

    const palette = {
      displayName: 'testing',
      filename: 'testing.ts',
      highlightAsNew: {
        startDate: '2022-01-01',
        endDate: '2022-06-06',
      },
    }

    expect(isPaletteNew(palette, date)).toBe(false)
  })
})
