import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import '../../../spelling-bee/js/__tests__/domSetup'
import Toolbar from '../Toolbar/Toolbar'
import Tileset from '../Tileset/Tileset'
import ComboCounter from '../ComboCounter/ComboCounter'
import { DEFAULT_PALETTE } from '../MenuOptions/shared'

import Layout from './Layout'

jest.mock('foundation', () => ({
  getGameData: () => ({}),
  env: {
    name: 'dev',
  },
  appendSupportedParams: jest.fn(),
}))

jest.mock(
  '../Tileset/Tileset',
  () =>
    function Tileset() {
      return <div />
    },
)
jest.mock(
  '../Toolbar/Toolbar',
  () =>
    function Toolbar() {
      return <div />
    },
)

jest.mock(
  '../ComboCounter/ComboCounter',
  () =>
    function ComboCounter() {
      return <div />
    },
)

jest.mock('../moments/index', () => ({
  Moments: jest.fn().mockReturnValue(<div />),
  momentSystem: {
    load: jest.fn(),
  },
}))

jest.mock('../tilesCredits/tilesCredits', () => ({
  __esModule: true,
  getCurrentCredits: jest.fn(),
  default: jest.fn(),
}))

describe('TILES: LAYOUT', () => {
  const blue = '#0D3364'
  const white = '#FFF'

  const store = {
    getState: () => ({
      board: [{}, {}, {}, {}],
      boardSize: 4,
      palette: {
        displayName: '',
        bgColor: blue,
        fontColor: white,
        svg: '<svg></svg>',
      },
      winState: false,
      infiniteMode: false,
      perfectSolve: true,
      modalSystem: {
        modal: 'settings',
        isClosing: false,
      },
      allPalettes: [
        {
          displayName: 'Lisbon',
          filename: 'lisbon',
          createdBy: 'Robert Vinluan',
        },
        {
          displayName: 'Kuala Lumpur',
          filename: 'kuala-lumpur',
          createdBy: 'Robert Vinluan',
        },
        {
          displayName: 'Hong Kong',
          filename: 'hong-kong',
          createdBy: 'Robert Vinluan',
        },
        {
          displayName: 'Austin',
          filename: 'austin',
          createdBy: 'Robert Vinluan',
        },
        {
          displayName: 'New Haven',
          filename: 'new-haven',
          createdBy: 'Robert Vinluan',
        },
        {
          displayName: 'Paris',
          filename: 'paris',
          createdBy: 'Robert Vinluan',
        },
        {
          displayName: 'Brighton',
          filename: 'brighton',
          createdBy: 'Robert Vinluan',
        },
        {
          displayName: 'Tangier',
          filename: 'tangier',
          createdBy: 'Robert Vinluan',
        },
        {
          displayName: 'Holland',
          filename: 'holland',
          createdBy: 'Robert Vinluan',
        },
        {
          displayName: 'Los Angeles',
          filename: 'los-angeles',
          createdBy: 'Robert Vinluan',
        },
        {
          displayName: 'Utrecht',
          filename: 'utrecht',
          createdBy: 'Andrew Dore',
        },
        {
          displayName: DEFAULT_PALETTE,
          filename: 'holland',
          createdBy: 'Robert Vinluan',
        },
      ],
    }),
    subscribe: jest.fn(),
    dispatch: jest.fn(),
  }

  const renderLayout = () =>
    mount(
      <Provider store={store}>
        <Layout
          creditsLeft={3}
          deviceType={{ isMobile: true }}
          links={{}}
        />
      </Provider>,
    )

  it('should render the toolbar, moments and game', () => {
    const layout = renderLayout()
    expect(layout.find(Toolbar).exists()).toEqual(true)
    expect(layout.find(Tileset).exists()).toEqual(true)
    expect(layout.find(ComboCounter).exists()).toEqual(true)
  })
})
