import React from 'react'

import { Palette } from '../../shared'
import { isPaletteNew } from '../../helpers/utils'

import PaletteButton from './PaletteButton'
import { DEFAULT_PALETTE } from './shared'

export interface Props {
  palette?: Palette
  allPalettes: Palette[]
  changePalette?: (palette: Palette) => void
  disabled: boolean
}

const GridPaletteList = ({
  allPalettes,
  palette,
  changePalette,
  disabled = false,
}: Props) => {
  return (
    <ul
      className={`tlz-palette-grid ${
        disabled ? 'tlz-palette-grid-disabled' : ''
      }`}
    >
      {[...allPalettes].map((p) => {
        const isNew = isPaletteNew(p, new Date())
        return (
          <li key={`${p.filename}-${p.displayName}`}>
            <PaletteButton
              palette={p}
              changePalette={changePalette}
              isSelected={
                (palette && palette.displayName === p.displayName) ||
                false
              }
              excludeSVG={p.displayName === DEFAULT_PALETTE}
              key={`palette-${p.filename}`}
              disabled={disabled}
              isNew={isNew}
            />
          </li>
        )
      })}
    </ul>
  )
}

export default GridPaletteList
