import React, { useEffect } from 'react'

import { useUser } from 'user'
import { UserType } from 'foundation'
import { isMobile } from 'responsive'

import { Palette } from '../../shared'
import { trackEvent } from '../tilesTracker/tilesTracker'
import { handleNativeLogin } from '../../../helpers/hybridLoginLinkClick'
import {
  getSubscribeLink,
  handleSubscribe,
} from '../../../helpers/subscribeLinks'
import getLoginLink from '../../../helpers/loginLinks'
import { playCopyHelper } from '../modals/helpers'

import GridPaletteList from './GridPaletteList'

export interface DisabledProps {
  allPalettes: Palette[]
  creditsLeft: number
  isLoggedIn: boolean
}

interface BtnProps {
  text: string
  href: string
  onClick: (e: React.MouseEvent<Element, MouseEvent>) => void
}

const login = (
  updateUserType: (val: Partial<UserType>) => void,
): BtnProps => {
  return {
    href: getLoginLink(
      window || undefined,
      '&asset=tiles-settings-paywall',
    ),
    onClick: (e: React.MouseEvent<Element, MouseEvent>) => {
      trackEvent('LOGIN', 'settings-paywall')

      if (window.isHybridWebView && window.NativeBridge) {
        e.preventDefault()
        handleNativeLogin(updateUserType)
      }
    },
    text: 'Log In',
  }
}

const subscribe = (
  updateUserType: (val: Partial<UserType>) => void,
  isMobile: boolean,
): BtnProps => {
  return {
    href: getSubscribeLink(
      `tilesSettings${isMobile ? 'Mobile' : 'Desktop'}`,
    ),
    onClick: (e: React.MouseEvent<Element, MouseEvent>) => {
      trackEvent('SUBSCRIBE', 'settings-paywall')

      if (window.isHybridWebView && window.NativeBridge) {
        e.preventDefault()
        handleSubscribe('tilesCutoffSettings', updateUserType)
      }
    },
    text: 'Subscribe',
  }
}

const playCopy = (playCount: number) => {
  const { numberText, playText } = playCopyHelper(playCount)
  return `You have ${numberText} ${playText} left.`
}

const MenuOptionsDisabled = ({
  allPalettes,
  creditsLeft,
  isLoggedIn,
}: DisabledProps) => {
  const { updateUserType } = useUser()
  let btnProps = isLoggedIn
    ? subscribe(updateUserType, isMobile)
    : login(updateUserType)

  useEffect(() => {
    btnProps = isLoggedIn
      ? login(updateUserType)
      : subscribe(updateUserType, isMobile)
  }, [isLoggedIn])

  return (
    <>
      <div className="modal-centered-container">
        <section>
          <h3 className="btn__bold" data-testid="credits-left">
            {playCopy(creditsLeft)}
          </h3>
          <p className="shorten-width" data-testid="message">
            {`${
              isLoggedIn ? 'Subscribe' : 'Register or subscribe'
            } to unlock more features.`}
          </p>
        </section>
        <a
          href={btnProps.href}
          onClick={btnProps.onClick}
          className="pz-modal__button lrg_text medium white"
        >
          {btnProps.text}
        </a>
      </div>
      <GridPaletteList disabled allPalettes={allPalettes} />
    </>
  )
}

export default MenuOptionsDisabled
