import React from 'react'
import { shallow } from 'enzyme'

import useWindowSize from '../../../shared/hooks/use-window-size'

import MenuOptionsEnabled from './MenuOptionsEnabled'
import PaginatedPaletteList from './PaginatedPaletteList'
import GridPaletteList from './GridPaletteList'

jest.mock('../../../shared/hooks/use-window-size', () => ({
  __esModule: true,
  default: jest.fn(),
}))

const props = {
  narrowScreen: false,
  palette: {
    displayName: 'Foo Bar',
    filename: 'fooBar',
  },
  allPalettes: [
    {
      displayName: 'Foo Bar',
      filename: 'fooBar',
    },
    {
      displayName: 'Lorem Ispum',
      filename: 'loremIspum',
    },
  ],
}

const changePaletteMock = jest.fn

describe('TILES - MENU OPTIONS ENABLED: MOBILE', () => {
  beforeEach(() => {
    jest.resetAllMocks()
  })

  it('renders paginated palette list', () => {
    // @ts-ignore
    useWindowSize.mockReturnValue({
      winWidth: 300,
    })

    const menuOptionsEnabledMobile = shallow(
      <MenuOptionsEnabled
        {...props}
        changePalette={changePaletteMock}
        narrowScreen
      />,
    )
    const list = menuOptionsEnabledMobile.find(PaginatedPaletteList)
    expect(list).toHaveLength(1)
    expect(list.props().showArrows).toBe(false)
    expect(list.props().palettesPerColumn).toBe(6)
    expect(list.props().columnsPerPage).toBe(1)

    expect(
      menuOptionsEnabledMobile.find(GridPaletteList),
    ).toHaveLength(0)
  })
})

describe('TILES - MENU OPTIONS ENABLED: TABLET', () => {
  it('renders paginated palette list in 4 columns', () => {
    // @ts-ignore
    useWindowSize.mockReturnValue({
      winWidth: 500,
    })

    const menuOptionsEnabledTablet = shallow(
      <MenuOptionsEnabled
        {...props}
        changePalette={changePaletteMock}
        narrowScreen={false}
      />,
    )
    const list = menuOptionsEnabledTablet.find(PaginatedPaletteList)
    expect(list).toHaveLength(1)
    expect(list.props().showArrows).toBe(true)
    expect(list.props().palettesPerColumn).toBe(4)
    expect(list.props().columnsPerPage).toBe(3)

    expect(
      menuOptionsEnabledTablet.find(GridPaletteList),
    ).toHaveLength(0)
  })
})

describe('TILES - MENU OPTIONS ENABLED: DESKTOP', () => {
  it('renders paginated palette list in 4 columns', () => {
    // @ts-ignore
    useWindowSize.mockReturnValue({
      winWidth: 600,
    })

    const menuOptionsEnabledDesktop = shallow(
      <MenuOptionsEnabled
        {...props}
        changePalette={changePaletteMock}
        narrowScreen={false}
      />,
    )
    const list = menuOptionsEnabledDesktop.find(PaginatedPaletteList)
    expect(list).toHaveLength(1)
    expect(list.props().showArrows).toBe(true)
    expect(list.props().palettesPerColumn).toBe(4)
    expect(list.props().columnsPerPage).toBe(3)
    expect(
      menuOptionsEnabledDesktop.find(GridPaletteList),
    ).toHaveLength(0)
  })
})
