import React, { useRef } from 'react'
import { mount, shallow } from 'enzyme'

import { handleNavigation } from '../../../../shared/components/Pagination/handleScroll'

import PaginatedPaletteList from './PaginatedPaletteList'
import PaletteButton from './PaletteButton'

jest.mock(
  '../../../../shared/components/Pagination/handleScroll',
  () => ({
    __esModule: true,
    handleNavigation: jest.fn(),
  }),
)

const props = {
  columnsPerPage: 3,
  showArrows: true,
  palettesPerColumn: 4,
  narrowScreen: false,
  palette: {
    displayName: 'b',
    filename: 'B',
  },
  allPalettes: 'abcdefghijklm'.split('').map((char) => ({
    displayName: char.toLocaleUpperCase(),
    filename: char.toLowerCase(),
  })),
}

const changePaletteMock = jest.fn

describe('TILES - PAGINATED PALETTE LIST', () => {
  it('on load, disables previous arrow and enables next arrow', () => {
    const list = mount(
      <PaginatedPaletteList
        {...props}
        changePalette={changePaletteMock}
      />,
    )
    expect(
      list.find('.tlz-palette-prev').first().props().disabled,
    ).toBe(true)
    expect(
      list.find('.tlz-palette-next').first().props().disabled,
    ).toBe(false)
  })

  it('calls handleNavigation on arrow clicks', () => {
    const useRefSpy = jest
      .spyOn(React, 'useRef')
      .mockImplementation(() => ({ current: { focus: jest.fn() } }))

    const list = mount(
      <PaginatedPaletteList
        {...props}
        changePalette={changePaletteMock}
      />,
    )

    expect(useRefSpy).toHaveBeenCalledTimes(1)
    const nextArrow = list.find('.tlz-palette-next').first()
    expect(handleNavigation).not.toHaveBeenCalled()

    nextArrow.simulate('click')
    expect(handleNavigation).toHaveBeenCalled()
  })
})
