import React from 'react'
import cn from 'classnames'

import { Palette } from '../../shared'
import { handleNavigation } from '../../../../shared/components/Pagination/handleScroll'
import { isPaletteNew } from '../../helpers/utils'

import PaletteButton from './PaletteButton'
import { DEFAULT_PALETTE } from './shared'
import {
  getActivePage,
  pageWidthCalculator,
  totalPageCount,
} from './helper'

export interface Props {
  palette: Palette
  allPalettes: Palette[]
  palettesPerColumn: number
  columnsPerPage: number
  changePalette?: (palette: Palette) => void
  showArrows?: boolean
}

const PaginatedPaletteList = ({
  allPalettes,
  palette,
  changePalette,
  columnsPerPage,
  showArrows = false,
  palettesPerColumn,
}: Props) => {
  const containerRef = React.useRef<HTMLDivElement>(null)
  const [activePage, setActivePage] = React.useState(0)
  const numberOfPages = totalPageCount(
    allPalettes.length,
    palettesPerColumn * columnsPerPage,
  )

  let pageWidth: number

  const handleScroll = React.useCallback(() => {
    if (pageWidth === undefined && containerRef.current) {
      pageWidth = pageWidthCalculator(
        containerRef.current,
        numberOfPages,
      )
    }

    setActivePage(
      getActivePage(
        pageWidth,
        numberOfPages,
        containerRef.current?.scrollLeft || 0,
      ),
    )
  }, [])

  return (
    <>
      {showArrows && (
        <>
          <div className="tlz-palette-heading-arrows">
            <p className="modal-system-description">Tileset</p>
            <div className="tlz-palette-arrows">
              <button
                disabled={!(activePage > 0)}
                type="button"
                onClick={() => {
                  handleNavigation(containerRef, 'prev')
                }}
                className={cn(
                  'tlz-palette-arrow',
                  'tlz-palette-prev',
                  {
                    active: activePage > 0,
                  },
                )}
              >
                <span className="tlz-palette-text">Prev</span>
              </button>
              <button
                type="button"
                disabled={!(activePage < numberOfPages - 1)}
                onClick={() => {
                  handleNavigation(containerRef, 'next')
                }}
                className={cn(
                  'tlz-palette-arrow',
                  'tlz-palette-next',
                  {
                    active: activePage < numberOfPages - 1,
                  },
                )}
              >
                <span className="tlz-palette-text">Next</span>
              </button>
            </div>
          </div>
        </>
      )}
      <div
        className="tlz-palettelist-pag"
        ref={containerRef}
        onScroll={handleScroll}
      >
        <ul
          className={cn(
            'tlz-palettelist-items-pag',
            `tlz-palettelist-items-pag-${palettesPerColumn}`,
          )}
        >
          {allPalettes.map((p, i) => {
            const isNew = isPaletteNew(p, new Date())
            return (
              <li key={`${p.filename}-${p.displayName}`}>
                <PaletteButton
                  palette={p}
                  changePalette={changePalette}
                  isSelected={palette.displayName === p.displayName}
                  excludeSVG={p.displayName === DEFAULT_PALETTE}
                  key={`palette-${p.filename}`}
                  isNew={isNew}
                />
              </li>
            )
          })}
        </ul>
      </div>
      <div className="tlz-kebob">
        {[...Array(numberOfPages)].map((_, index) => (
          <div
            className={cn('tlz-bob', {
              active: index === activePage,
            })}
            key={`paginated-dot-${index}`}
          />
        ))}
      </div>
    </>
  )
}

export default PaginatedPaletteList
