import React from 'react'
import cn from 'classnames'

import { Palette } from '../../shared'
import Pill from '../../../../shared/components/Pill'

import { paletteDisplayText } from './shared'

const PaletteButton = ({
  palette,
  changePalette,
  isSelected,
  excludeSVG,
  disabled,
  isNew,
}: {
  palette: Palette
  changePalette?: (palette: Palette) => void
  isSelected: boolean
  excludeSVG?: boolean
  disabled?: boolean
  isNew: boolean
}) => {
  return (
    <button
      id={`palette-${palette.filename}`}
      data-testid={`palette-${palette.filename}`}
      key={`palette-${palette.filename}`}
      type="button"
      onClick={() => {
        if (changePalette === undefined || isSelected) return

        changePalette(palette)
      }}
      className={cn('tlz-palette-button', {
        selected: isSelected,
      })}
      disabled={disabled}
    >
      {excludeSVG ? (
        <div />
      ) : (
        <span>
          <svg>
            {!excludeSVG && (
              <use xlinkHref={`#${palette.filename}`} />
            )}
          </svg>
        </span>
      )}
      <span className="tlz-tileset-info">
        {paletteDisplayText(palette.displayName, {
          addTilesetSuffix: true,
        })}
        {isNew && <Pill text="New" />}
      </span>
    </button>
  )
}

export default PaletteButton
