import {
  pageWidthCalculator,
  totalPageCount,
  getActivePage,
} from './helper'

describe('totalPageCount()', () => {
  it('returns correct number when evenly divisible', () => {
    expect(totalPageCount(6, 2)).toEqual(3)
  })

  it('returns correct number when evenly divisible', () => {
    expect(totalPageCount(7, 2)).toEqual(4)
  })
})

describe('getActivePage()', () => {
  it('returns 0 with a negative number', () => {
    expect(getActivePage(10, 3, -1)).toEqual(0)
  })

  it('returns 0 with 0', () => {
    expect(getActivePage(10, 3, 0)).toEqual(0)
  })

  it('returns max page when scroll matches last page number', () => {
    expect(getActivePage(10, 3, 30)).toEqual(2)
  })

  it('returns max page with number too large', () => {
    expect(getActivePage(10, 3, 3000)).toEqual(2)
  })

  it('returns expected page', () => {
    // first page
    expect(getActivePage(10, 3, 1)).toEqual(0)
    expect(getActivePage(10, 3, 2)).toEqual(0)
    expect(getActivePage(10, 3, 9)).toEqual(0)

    // second page
    expect(getActivePage(10, 3, 10)).toEqual(1)
    expect(getActivePage(10, 3, 11)).toEqual(1)
    expect(getActivePage(10, 3, 19)).toEqual(1)

    // third page
    expect(getActivePage(10, 3, 20)).toEqual(2)
    expect(getActivePage(10, 3, 21)).toEqual(2)
    expect(getActivePage(10, 3, 29)).toEqual(2)
  })
})

describe('pageWidthCalculator()', () => {
  it('returns expected width', () => {
    const pageWidth = pageWidthCalculator(
      { scrollWidth: 360, clientWidth: 60 },
      3,
    )
    expect(pageWidth).toEqual(100)
  })

  it('returns expected width', () => {
    const pageWidth = pageWidthCalculator(
      { scrollWidth: 370, clientWidth: 10 },
      6,
    )
    expect(pageWidth).toEqual(60)
  })
})
