import React from 'react'
import pt from 'prop-types'
import { connect } from 'react-redux'

import Selector from '../Selector/Selector'
import TileLayer from '../TileLayer/TileLayer'
import MessageBubble from '../MessageBubble/MessageBubble'
import { initiateLoop } from '../store/store'
import {
  animationDelay,
  transitionDelay,
} from '../../helpers/helpers'

const Tile = ({
  id,
  selected,
  layers,
  initiateLoop,
  free,
  palette,
  zLayer,
}) => {
  return (
    <div
      role="gridcell"
      key={id}
      onClick={() => {
        if (
          selected === id ||
          layers.every((layer) => layer.hidden)
        ) {
          return
        }

        initiateLoop(id)
      }}
      className="tls-tile"
    >
      <Selector
        id={id}
        selected={selected}
        free={free}
        selectionColor={palette.selectionColor}
      />
      <MessageBubble id={id} />
      <div className="tls-tile__frame">
        <TileLayer
          layer="zLayer"
          {...zLayer}
          animationDelay={animationDelay(id)}
        />
        {layers.map((layer, i) => (
          <TileLayer
            transitionDelay={transitionDelay(i)}
            key={i}
            layer={`${i}Layer`}
            {...layer}
          />
        ))}
      </div>
    </div>
  )
}

Tile.propTypes = {
  id: pt.number.isRequired,
  zLayer: pt.shape({
    id: pt.string.isRequired,
    hidden: pt.bool,
  }).isRequired,
  layers: pt.arrayOf(pt.shape({})),
  selected: pt.number,
  palette: pt.shape({
    selectionColor: pt.string.isRequired,
  }).isRequired,
  free: pt.number,
  board: pt.arrayOf(pt.shape({})),
  initiateLoop: pt.func.isRequired,
}

const mapStateToProps = ({ palette, selected, free, board }) => ({
  palette,
  selected,
  free,
  board,
})

const mapDispatchToProps = { initiateLoop }

export default connect(mapStateToProps, mapDispatchToProps)(Tile)
