import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import {
  animationDelay,
  transitionDelay,
} from '../../helpers/helpers'
import TileLayer from '../TileLayer/TileLayer'

import Tile from './Tile'

jest.mock(
  '../TileLayer/TileLayer',
  () =>
    function TileLayer() {
      return <svg />
    },
)
jest.mock('../store/store', () => ({
  initiateLoop: jest.fn(),
}))

describe('TILES: TILE UNIT', () => {
  let tile
  let dispatch
  let connectTile
  let tileObj

  beforeEach(() => {
    dispatch = jest.fn()

    connectTile = (props) => {
      const store = {
        getState: () => ({
          selected: 0,
          palette: {
            selectionColor: 'red',
          },
          message: {
            id: 1,
            text: '',
            animate: false,
          },
        }),
        subscribe: jest.fn(),
        dispatch,
      }

      return mount(
        <Provider store={store}>
          <Tile {...props} />
        </Provider>,
      )
    }

    tileObj = {
      id: 3,
      zLayer: { id: 'Z1', hidden: false },
      layers: [
        { id: 'A4', hidden: false },
        { id: 'B2', hidden: false },
        { id: 'C10', hidden: false },
      ],
    }

    tile = connectTile(tileObj)
  })

  it('should apply the layer class name to the TileLayer', () => {
    expect.assertions(4)
    const tileLayer = tile.find(TileLayer)
    expect(tileLayer.at(0).prop('layer')).toEqual('zLayer')
    expect(tileLayer.at(1).prop('layer')).toEqual('0Layer')
    expect(tileLayer.at(2).prop('layer')).toEqual('1Layer')
    expect(tileLayer.at(3).prop('layer')).toEqual('2Layer')
  })

  it('should apply the id to the TileLayer', () => {
    expect.assertions(4)

    const tileLayer = tile.find(TileLayer)
    expect(tileLayer.at(0).prop('id')).toEqual('Z1')
    expect(tileLayer.at(1).prop('id')).toEqual('A4')
    expect(tileLayer.at(2).prop('id')).toEqual('B2')
    expect(tileLayer.at(3).prop('id')).toEqual('C10')
  })

  it('should respond to click', () => {
    tile.find('.tls-tile').simulate('click')
    expect(dispatch).toHaveBeenCalled()
  })

  it('should not respond to click if tile is cleared', () => {
    const hiddenTileObj = {
      id: 3,
      zLayer: { id: 'Z1', hidden: false },
      layers: [
        { id: 'A4', hidden: true },
        { id: 'B2', hidden: true },
        { id: 'C10', hidden: true },
      ],
    }
    tile = connectTile(hiddenTileObj)
    tile.find('.tls-tile').simulate('click')
    expect(dispatch).not.toHaveBeenCalled()
  })

  it('should not respond to click if tile is selected', () => {
    const selectedTileObj = {
      id: 0,
      zLayer: { id: 'Z1', hidden: false },
      layers: [
        { id: 'A4', hidden: false },
        { id: 'B2', hidden: false },
        { id: 'C10', hidden: false },
      ],
    }
    tile = connectTile(selectedTileObj)
    tile.find('.tls-tile').simulate('click')
    expect(dispatch).not.toHaveBeenCalled()
  })

  it('should apply the animation delay to the zLayer', () => {
    expect(
      tile.find({ layer: 'zLayer' }).prop('animationDelay'),
    ).toEqual(animationDelay(tileObj.id))
  })

  it('should apply the transition delay to the pattern layers', () => {
    expect(
      tile.find({ layer: '0Layer' }).prop('transitionDelay'),
    ).toEqual(transitionDelay(0))
  })
})
