import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import TileLayer from './TileLayer'

describe('TILES: TILELAYER UNIT', () => {
  const store = {
    getState: () => ({ winState: false }),
    subscribe: jest.fn(),
    dispatch: jest.fn(),
  }

  const tileLayer = mount(
    <Provider store={store}>
      <TileLayer layer="zLayer" id="Z1" hidden />
    </Provider>,
  )

  it('should contain a link to the sprite node', () => {
    expect(tileLayer.find('use').prop('xlinkHref')).toEqual('#Z1')
  })

  it('should apply the layer class name to the svg element', () => {
    expect(tileLayer.find('svg').prop('className')).toContain(
      'zLayer',
    )
  })

  it('should apply the matched class when layer is hidden', () => {
    expect(tileLayer.find('svg').prop('className')).toContain(
      'matched',
    )
  })
})
