import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import Tile from '../Tile/Tile'

import Tileset from './Tileset'

const board = [
  {
    id: 0,
    zLayer: { id: 'Z3', hidden: false },
    layers: [
      { id: 'A8', hidden: false },
      { id: 'B11', hidden: false },
      { id: 'C3', hidden: false },
    ],
  },
  {
    id: 1,
    zLayer: { id: 'Z1', hidden: false },
    layers: [
      { id: 'A3', hidden: false },
      { id: 'B5', hidden: false },
      { id: 'C6', hidden: false },
    ],
  },
]

const connectTileset = () => {
  const store = {
    getState: () => ({ board }),
    subscribe: jest.fn(),
    dispatch: jest.fn(),
  }

  return mount(
    <Provider store={store}>
      <Tileset />
    </Provider>,
  )
}

jest.mock(
  '../Tile/Tile',
  () =>
    function Tile() {
      return <div />
    },
)

describe('TILES: TILESET CONTAINER', () => {
  const tileset = connectTileset(board)

  it('should contain correct number of Tile components', () => {
    expect(tileset.find(Tile)).toHaveLength(board.length)
  })

  it('should pass the id prop to Tile component', () => {
    expect.assertions(2)

    board.forEach((tileObj, idx) => {
      expect(
        tileset
          .find(Tile)
          .at(idx)
          .prop('id'),
      ).toEqual(board[idx].id)
    })
  })
})
