import React from 'react'
import pt from 'prop-types'
import ReactDOM from 'react-dom'
import { connect } from 'react-redux'

import { mobileNavTools, env } from 'foundation'
import { useUser } from 'user'

import { boardSizeToggle, openModal } from '../store/store'
import { trackEvent } from '../tilesTracker/tilesTracker'

const barRoot = document.getElementById('portal-game-toolbar')

export const Toolbar = ({
  boardSize,
  boardSizeToggle,
  openModal,
}) => {
  const { userType } = useUser()
  const showShortzMode = userType.inShortzMode || env.name !== 'prod'

  const mobileTools = [
    {
      icon: 'tiles-app__help-icon',
      action: () => {
        openModal('howToPlay')
        trackEvent('HELP')
      },
    },
    {
      icon: 'tiles-app__settings-icon',
      action: () => {
        openModal('settings')
        trackEvent('SETTINGS')
      },
    },
  ]

  if (showShortzMode) {
    mobileTools.push({
      value: boardSize === 30 ? 'Small Board' : 'Large Board',
      action: () => boardSizeToggle(),
    })
  }

  mobileNavTools.create(mobileTools)

  const boardSizeToggleButton = (
    <span
      role="button"
      className="pz-toolbar-button"
      onClick={() => boardSizeToggle()}
    >
      {boardSize === 30 ? 'Small Board' : 'Large Board'}
    </span>
  )

  return ReactDOM.createPortal(
    <>
      <span>{showShortzMode && boardSizeToggleButton}</span>
      <span>
        <button
          type="button"
          aria-label="how to play"
          className="pz-toolbar-button"
          onClick={() => {
            openModal('howToPlay')
            trackEvent('HELP')
          }}
        >
          <i className="tiles-app__help-icon" />
        </button>
        <button
          type="button"
          aria-label="settings"
          className="pz-toolbar-button"
          onClick={() => {
            openModal('settings')
            trackEvent('SETTINGS')
          }}
        >
          <i className="tiles-app__settings-icon" />
        </button>
      </span>
    </>,
    barRoot,
  )
}

Toolbar.propTypes = {
  boardSize: pt.number,
  boardSizeToggle: pt.func,
}

const mapStateToProps = ({ boardSize }) => ({ boardSize })

const mapDispatchToProps = { boardSizeToggle, openModal }

export default connect(mapStateToProps, mapDispatchToProps)(Toolbar)
