import React from 'react'
import { shallow } from 'enzyme'

import { useUser } from 'user'

// import { modalSystem } from '../../../shared/modals/index'
import { openModal } from '../store/store'
import { trackEvent } from '../tilesTracker/tilesTracker'

import { Toolbar } from './Toolbar'

// jest.mock('../modals/Modals', () => ({
//   modalSystem: {
//     open: jest.fn(),
//     close: jest.fn(),
//   },
// }))
jest.mock('../store/store', () => ({
  openModal: jest.fn(),
}))

jest.mock('foundation', () => ({
  mobileNavTools: {
    activate: jest.fn(),
    create: jest.fn(),
  },
  env: {
    name: 'dev',
  },
  getGameData: () => ({}),
}))

jest.mock('user', () => ({
  useUser: jest.fn(),
}))

jest.mock('../tilesTracker/tilesTracker', () => ({
  trackEvent: jest.fn(),
}))

jest.mock('react-dom', () => ({
  createPortal: (jsx) => jsx,
}))

const props = {
  infiniteMode: false,
  paletteFilename: 'palette',
  boardSizeToggle: jest.fn(),
  openModal: jest.fn(),
}

describe('TILES: TOOLBAR', () => {
  beforeEach(() => {
    jest.resetAllMocks()
    window.location = {
      href: '/puzzles/tiles',
    }
    useUser.mockReturnValue({
      userType: {
        inShortzMode: true,
      },
    })
  })

  afterEach(() => {
    delete window.location
  })

  it('should toggle board size in shortz mode', () => {
    const toolbar = shallow(<Toolbar {...props} />)
    const button = toolbar.find('.pz-toolbar-button').at(0)

    button.simulate('click')

    expect(props.boardSizeToggle).toHaveBeenCalled()
  })

  it('should open help modal', () => {
    process.env.name = 'dev'
    const toolbar = shallow(<Toolbar {...props} />)
    const button = toolbar.find('.pz-toolbar-button').at(1)

    button.simulate('click')

    // expect(modalSystem.open).toHaveBeenCalledWith('help')
    expect(trackEvent).toHaveBeenCalledWith('HELP')
  })

  it('should open settings modal', () => {
    const toolbar = shallow(<Toolbar {...props} />)
    const button = toolbar.find('.pz-toolbar-button').at(2)

    button.simulate('click')

    // expect(modalSystem.open).toHaveBeenCalledWith('settings')
    expect(trackEvent).toHaveBeenCalledWith('SETTINGS')
  })
})
