import React from 'react'

import { SEND_EMAIL_TYPE } from 'foundation'

import FeedbackLink from '../../../helpers/FeedbackLink'
import ModalWrapper from '../../../shared/ModalSystem/ModalWrapper'
import { ModalProps } from '../../../shared/ModalSystem/modalTypes'

const RulesNew = ({ onRemove, isClosing, close }: ModalProps) => {
  return (
    <ModalWrapper
      bodyClassName="modal-rules-body"
      close={close}
      isClosing={isClosing}
      onRemove={onRemove}
    >
      <div>
        <h1 className="modal-system-header">How to play Tiles</h1>
        <p className="modal-system-description">
          Match identical shapes or backgrounds in every tile.
        </p>
        <div className="modal-system-centered-container">
          <span>Example:</span>
          <div className="tlz-how-to-play-image modal-system-content-icon" />
          <span>and</span>
          <div className="tlz-how-to-play-image modal-system-content-icon" />
          <span>share</span>
          <div className="tlz-how-to-play-image modal-system-content-icon" />
        </div>
        <ul className="bullet-list">
          <li className="modal-system-body">
            Find <span className="italic">combos</span>: Same-colored
            shapes or backgrounds shared by 2 tiles. Each tile has
            multiple visual elements.
          </li>
          <li className="modal-system-body">
            Tap tiles to remove the matches you find. Tiles don’t have
            to be adjacent.
          </li>
          <li className="modal-system-body">
            To create a long combo, match the second tile you tap to a
            new one.
          </li>
          <li className="modal-system-body">
            Continue matching until the board is cleared. You won’t
            lose your long combo if you end on an empty tile.
          </li>
        </ul>
        <h1 className="modal-system-header">Play modes and tips</h1>
        <ul className="bullet-list">
          <li className="modal-system-body">
            Normal mode: Game ends after the board is cleared.
          </li>
          <li className="modal-system-body">
            Zen mode: Tiles regenerate so the game keeps going.
          </li>
          <li className="modal-system-body">
            Only for subscribers: Tap{' '}
            <i className="settings-icon inline-icon" /> to change the
            tileset design.
          </li>
          <li className="modal-system-body">
            Tilesets rotate at midnight, every day.
          </li>
        </ul>
        <p className="modal-system-body paragraph">
          Have feedback?{' '}
          <FeedbackLink
            subject="Tiles Feedback"
            useEnhancedHybridDebugInfo
            type={SEND_EMAIL_TYPE.TILES}
          >
            Email us
          </FeedbackLink>
          .
        </p>
      </div>
    </ModalWrapper>
  )
}

export default RulesNew
