import React, { useState } from 'react'
import { connect } from 'react-redux'

import { useUser } from 'user'

import ModalWrapper from '../../../shared/ModalSystem/ModalWrapper'
import { ModalProps } from '../../../shared/ModalSystem/modalTypes'
import { changePalette } from '../store/store'
import { Palette } from '../../shared'
import MenuOptions from '../MenuOptions/MenuOptions'
import useWindowSize from '../../../shared/hooks/use-window-size'

interface SettingsProps extends ModalProps {
  creditsLeft: number
  palette: Palette
  allPalettes: Palette[]
  changePalette: (palette: Palette) => void
}

const Settings = ({
  onRemove,
  isClosing,
  close,
  creditsLeft,
  palette,
  allPalettes,
  changePalette,
  meterResponse,
}: SettingsProps) => {
  const { userType } = useUser()
  const [paletteHighlight, setPaletteHighlight] = useState(palette)
  const { winWidth } = useWindowSize()
  const narrowScreen = winWidth < 500
  const { granted } = meterResponse
  const subAccess = granted || userType.hasXwd

  return (
    <ModalWrapper
      bodyClassName={`modal-settings-body su-modal-settings modal-body ${
        !subAccess
          ? 'modal-settings-disabled'
          : 'modal-settings-enabled'
      }`}
      close={close}
      isClosing={isClosing}
      onRemove={onRemove}
    >
      <h1 className="modal-system-header">Settings</h1>
      {subAccess && narrowScreen && (
        <p className="modal-system-description">Tileset</p>
      )}
      <MenuOptions
        allPalettes={allPalettes}
        changePalette={(palette: Palette) => {
          setPaletteHighlight(palette)
          changePalette(palette)
        }}
        palette={paletteHighlight}
        disabled={!subAccess}
        isLoggedIn={userType.isLoggedIn}
        creditsLeft={creditsLeft}
        narrowScreen={narrowScreen}
      />
    </ModalWrapper>
  )
}

const mapState = ({
  palette,
  allPalettes,
}: {
  palette: Palette
  allPalettes: Palette[]
}) => ({
  palette,
  allPalettes,
})

const mapDispatchToProps = { changePalette }

export default connect(mapState, mapDispatchToProps)(Settings)
