import React from 'react'
import { Provider } from 'react-redux'
import { configureStore } from '@reduxjs/toolkit'
import { Story } from '@storybook/react'

import CongratsComponent from '../Congrats'
import {
  withProvider,
  withUserProvider,
} from '../../../../../shared/storybook/helpers'

import { storyState } from './helpers'

let store = configureStore({ reducer: () => storyState })

interface Props {
  creditsLeft: number
  longestCombo: number
  perfectSolve: boolean
  hybrid: boolean
}

interface UserProps {
  hasXwd: boolean
  isLoggedIn: boolean
}

const CongratsTemplate: Story<Props & UserProps> = ({
  hybrid,
  creditsLeft,
  longestCombo,
  perfectSolve,
}: Props) => {
  store = configureStore({
    reducer: () => ({
      ...storyState,
      longestCombo,
      perfectSolve,
    }),
  })

  window.isHybridWebView = hybrid
  // @ts-ignore
  window.NativeBridge = hybrid
  return (
    <Provider store={store}>
      <CongratsComponent
        creditsLeft={creditsLeft}
        close={() => {}}
        isClosing={false}
        onRemove={() => {}}
        updateCredits={() => {}}
      />
    </Provider>
  )
}

export const Congrats = CongratsTemplate.bind({})
Congrats.args = {
  creditsLeft: 0,
  hasXwd: true,
  isLoggedIn: true,
  perfectSolve: false,
  longestCombo: 5,
  hybrid: false,
}

export default {
  component: Congrats,
  title: 'Tiles/Modals/Congrats',
  argTypes: {
    hybrid: {
      control: {
        type: 'boolean',
      },
    },
    longestCombo: {
      control: { type: 'range', min: 1, max: 60, step: 1 },
    },
    creditsLeft: {
      control: { type: 'range', min: 0, max: 5, step: 1 },
    },
    perfectSolve: {
      control: { type: 'boolean' },
    },
  },
  decorators: [
    (
      Story: Story,
      { args: { hasXwd, isLoggedIn } }: { args: UserProps },
    ) => {
      document.body.classList.add('pz-desktop')
      document.body.classList.add('pz-page')
      return (
        <div
          id="modal-system-portal"
          className="modal-system-container modal-system-active"
        >
          {withUserProvider(withProvider(<Story />, store), {
            hasXwd: hasXwd && isLoggedIn,
            isLoggedIn,
          })}
        </div>
      )
    },
  ],
}
