import React, { useEffect } from 'react'
import { Provider } from 'react-redux'
import { configureStore } from '@reduxjs/toolkit'
import { Story } from '@storybook/react'

import SettingsComponent from '../Settings'
import {
  withProvider,
  withUserProvider,
} from '../../../../../shared/storybook/helpers'

import {
  getPaletteNames,
  getSelectedPalette,
  storyState,
} from './helpers'

const store = configureStore({ reducer: () => storyState })

interface SettingsProps {
  creditsLeft: number
  palette: string
}

interface UserProps {
  hasXwd: boolean
  isLoggedIn: boolean
}

const SettingsTemplate: Story<SettingsProps & UserProps> = ({
  creditsLeft,
  palette,
}: SettingsProps) => {
  useEffect(() => {
    storyState.palette = getSelectedPalette(palette)
  }, [palette])

  return (
    <Provider store={store}>
      <SettingsComponent
        close={() => {}}
        isClosing={false}
        onRemove={() => {}}
        creditsLeft={creditsLeft}
      />
    </Provider>
  )
}

export const Settings = SettingsTemplate.bind({})
Settings.args = {
  creditsLeft: 0,
  isLoggedIn: true,
  hasXwd: true,
  palette: 'Lisbon',
}

export default {
  component: Settings,
  title: 'Tiles/Modals/Settings',
  argTypes: {
    creditsLeft: {
      control: { type: 'range', min: 0, max: 5, step: 1 },
    },
    palette: {
      control: { type: 'select', options: getPaletteNames() },
    },
  },
  decorators: [
    (
      Story: Story,
      { args: { hasXwd, isLoggedIn } }: { args: UserProps },
    ) => {
      document.body.classList.add('pz-desktop')
      document.body.classList.add('pz-page')
      return (
        <div
          id="modal-system-portal"
          className="modal-system-container modal-system-active"
        >
          {withUserProvider(withProvider(<Story />, store), {
            hasXwd: hasXwd && isLoggedIn,
            isLoggedIn,
          })}
        </div>
      )
    },
  ],
}
