import React from 'react'
import { configureStore } from '@reduxjs/toolkit'

import { storyState } from '../../modals/stories/helpers'
import {
  withProvider,
  withUserProvider,
} from '../../../../../shared/storybook/helpers'
import useAnimation from '../../../../shared/moments/components/stories/useAnimation'
import WelcomeMoment from '../WelcomeMoment'
import { grantReasons } from '../../../../../shared/meter/MeterTypes'

// Template config - including default, uncontrolled args
const store = configureStore({ reducer: () => storyState })
const staticArgs = {
  close: () => {},
  isMobile: false,
  infiniteModeToggle: () => {},
  startGame: () => {},
  updateCredits: () => {},
}

export type Props = {
  close: Function
  creditsLeft: number
  paletteName: string
  filename: string
  granted: boolean
  grantReason: grantReasons
  editor: string
}

const StoryTemplate = ({
  creditsLeft,
  paletteName,
  editor,
  granted,
  grantReason,
}: Props) => (
  <WelcomeMoment
    creditsLeft={creditsLeft}
    filename={paletteName}
    paletteName={paletteName}
    editor={editor}
    meterResponse={{
      granted,
      grantReason,
      isOffline: false,
      loggedIn: false,
    }}
    {...staticArgs}
  />
)

const defaultArgs = {
  paletteName: 'Hong Kong',
  editor: 'Robert Vinluan',
}

// Stories and their args (controllable)
export const Anon = StoryTemplate.bind({})
// @ts-ignore storybook-specific pattern
Anon.args = {
  ...defaultArgs,
  creditsLeft: 1,
  hasXwd: false,
  isLoggedIn: false,
  granted: false,
  grantReason: '',
}

export const Regi = StoryTemplate.bind({})
// @ts-ignore storybook-specific pattern
Regi.args = {
  ...defaultArgs,
  creditsLeft: 2,
  hasXwd: false,
  isLoggedIn: true,
  granted: false,
  grantReason: '',
}

export const Sub = StoryTemplate.bind({})
// @ts-ignore storybook-specific pattern
Sub.args = {
  ...defaultArgs,
  creditsLeft: Infinity,
  hasXwd: true,
  isLoggedIn: true,
  granted: false,
  grantReason: '',
}

export const Metered = StoryTemplate.bind({})
// @ts-ignore storybook-specific pattern
Metered.args = {
  ...defaultArgs,
  creditsLeft: 1,
  hasXwd: false,
  isLoggedIn: false,
  granted: true,
  grantReason: 'IP',
}

const hideControl = { table: { disable: true } }

export default {
  title: 'Tiles/Moments/Welcome Moment',
  argTypes: {
    hasXwd: hideControl,
    isLoggedIn: hideControl,
  },
  decorators: [
    (
      Story: any,
      {
        args: { hasXwd, isLoggedIn },
      }: { args: { hasXwd: boolean; isLoggedIn: boolean } },
    ) => {
      useAnimation('storybook-welcome')

      return withUserProvider(
        withProvider(
          <div id="storybook-welcome">
            <Story />
          </div>,
          store,
        ),
        { hasXwd, isLoggedIn },
      )
    },
  ],
}
