import { abra } from 'foundation'

import getTotalCredits from './getTotalCredits'

export const exposeTilesCreditsTest = ({ isLoggedIn }) => {
  if (!isLoggedIn) {
    try {
      abra.reportExposure('GAMES_TP3_TilesRegiWall2')
    } catch (e) {
      console.error('Unable to expose user to Tiles credits test')
    }
  }
}

export const setTilesCredits = (
  { isLoggedIn, hasXwd },
  { granted },
) => {
  if (hasXwd || granted) return Infinity

  const today = new Date().toDateString()
  const userCredits = getTotalCredits(isLoggedIn)

  try {
    const storedDate = window.localStorage.getItem('tilesDate')

    let storedCredits = parseInt(
      window.localStorage.getItem('tilesCredits'),
    )

    const storedUserStatus =
      window.localStorage.getItem('tilesUserStatus')
    const currentUserStatus = isLoggedIn ? 'regi' : 'anon'

    if (
      storedCredits !== null &&
      storedDate === today &&
      storedUserStatus === currentUserStatus
    ) {
      if (storedCredits !== 0) storedCredits -= 1
      window.localStorage.setItem('tilesCredits', storedCredits)
      return storedCredits
    }

    // If stored data mismatches with current data, reset credits
    window.localStorage.setItem('tilesDate', today)
    window.localStorage.setItem('tilesCredits', userCredits)
    window.localStorage.setItem(
      'tilesUserStatus',
      isLoggedIn ? 'regi' : 'anon',
    )
    return parseInt(userCredits)
  } catch (e) {
    return Infinity
  }
}

export const getCurrentCredits = (userType, meterResponse) => {
  const { granted } = meterResponse
  if (userType.hasXwd || granted) return Infinity

  const today = new Date().toDateString()

  try {
    const storedDate = window.localStorage.getItem('tilesDate')

    const storedCredits = parseInt(
      window.localStorage.getItem('tilesCredits'),
    )

    const storedUserStatus =
      window.localStorage.getItem('tilesUserStatus')

    const currentUserStatus = userType.isLoggedIn ? 'regi' : 'anon'
    if (
      storedCredits !== null &&
      storedDate === today &&
      storedUserStatus === currentUserStatus
    ) {
      return storedCredits
    }

    // Only update credits when there is a mismatch between what is current and what is stored
    return setTilesCredits(userType, meterResponse)
  } catch (e) {
    return setTilesCredits(userType, meterResponse)
  }
}
