import { track } from 'foundation'

import {
  trackEvent,
  setPlayMode,
  setPaletteName,
} from './tilesTracker'

jest.mock('foundation', () => {
  const track = jest.fn()
  track.mockImplementation((type, trackingObj) => ({
    type,
    trackingObj,
  }))
  return { track }
})

describe('TILES TRACKER', () => {
  beforeEach(() => {
    jest.spyOn(console, 'error')
    console.error.mockImplementation(() => {})
  })

  it('should throw error if event does not exist', () => {
    trackEvent('NON_EXISTENT_EVENT')
    expect(track).not.toHaveBeenCalled()
    expect(console.error.mock.calls[0][0].message).toMatch(
      "unrecognized tracking event 'NON_EXISTENT_EVENT'",
    )
  })

  it('should call track with proper event object', () => {
    trackEvent('RULES', 'extra')
    const expectedModuleObj = {
      module: {
        name: 'click',
        context: 'r-default',
        label: 'extra',
        element: {
          name: 'tiles',
          label: 'how-to-play',
        },
      },
      eventData: {
        pageType: 'game',
        type: 'click',
        trigger: 'module',
        status: '',
      },
    }
    expect(track).toHaveBeenCalledWith(
      'moduleInteraction',
      expectedModuleObj,
    )
  })

  it('should pass in right game id when palette name and/or play mode change', () => {
    const expectedModuleObj = {
      module: {
        name: 'click',
        context: '',
        label: '',
        element: {
          name: 'tiles',
          label: 'help',
        },
      },
      eventData: {
        pageType: 'game',
        type: 'click',
        trigger: 'module',
        status: '',
      },
    }

    // Expect default
    expectedModuleObj.module.context = 'r-default'
    trackEvent('HELP')
    expect(track).toHaveBeenCalledWith(
      'moduleInteraction',
      expectedModuleObj,
    )

    // Expect updated play mode and palette name
    setPlayMode('z')
    setPaletteName('fancy-name')
    expectedModuleObj.module.context = 'z-fancy-name'
    trackEvent('HELP')
    expect(track).toHaveBeenCalledWith(
      'moduleInteraction',
      expectedModuleObj,
    )
  })
})
