import React from 'react'
import ReactDOM from 'react-dom'
import { Provider } from 'react-redux'

import { getGameData } from 'foundation'
import { UserProvider } from 'user'
import AbraProviderWithUser from 'shared/abra/AbraProviderWithUser'
import { FeatureFlagProvider } from 'shared/abra/FeatureFlagProvider'

import ShortzMode from '../shared/ShortzMode'
import ClientSideScripts from '../../shared/components/ClientSideScripts'
import '../../shared/shared-styles'
import '../../shared/shared-scripts'
import './index.scss'
import App from '../vertex/App/App'
import { setUpStore } from '../vertex/store/store'

const gameRoot = document.getElementById('pz-game-root')
const gameData = getGameData()

const gameBase = () => (
  <>
    <Provider store={setUpStore(gameData)}>
      <AbraProviderWithUser>
        <FeatureFlagProvider>
          <App isMobile={gameData.isMobile} />
        </FeatureFlagProvider>
      </AbraProviderWithUser>
    </Provider>
  </>
)

ReactDOM.render(
  <>
    <ClientSideScripts />
    <UserProvider>
      <ShortzMode>{gameBase()}</ShortzMode>
    </UserProvider>
  </>,
  gameRoot,
)
