import React, { useContext } from 'react'
import pt from 'prop-types'
import { connect } from 'react-redux'
import cn from 'classnames'

import { mobileNavTools } from 'foundation'

import { MeterExperimentsContext } from '../meter/MeterExperimentsProvider'
import Welcome from '../Moments/Welcome'
import Congrats from '../Moments/Congrats'
import {
  Icon,
  Title,
  Description,
} from '../../shared/moments/components/subcomponents'
import { wait } from '../../helpers/gameUtils'
import { dispatchPlayGameEvent } from '../helpers/canvasHelpers'
import { getSubscribeLink } from '../../helpers/subscribeLinks'
import {
  isDeepLink,
  openDeepLink,
} from '../../helpers/hybridLinkHelpers'

import { load, transition } from './conciergeHelpers'

const Concierge = (props) => {
  const { children, drawnLines, drawnShapes, startGame } = props
  const { meterGranted } = useContext(MeterExperimentsContext)

  const playGame = () => {
    const concierge = document.getElementById('js-hook-concierge')

    const leaving = document.getElementById(
      'js-hook-concierge__intro',
    )

    const entering = document.getElementById(
      'js-hook-concierge__game',
    )

    startGame(true)

    transition(concierge, leaving, entering, dispatchPlayGameEvent)

    mobileNavTools.activate()
  }

  const backToGame = () => {
    const concierge = document.getElementById('js-hook-concierge')

    const leaving = document.getElementById(
      'js-hook-concierge__congrats',
    )

    const entering = document.getElementById(
      'js-hook-concierge__game',
    )

    transition(concierge, leaving, entering, dispatchPlayGameEvent)
  }

  React.useEffect(() => {
    wait(100).then(
      load().then(() => {
        const concierge = document.getElementById('js-hook-concierge')

        const leaving = document.getElementById(
          'js-hook-concierge__loading',
        )

        const entering = document.getElementById(
          'js-hook-concierge__intro',
        )
        transition(concierge, leaving, entering)
      }),
    )
  }, [])

  const conciergeProps = {
    ...props,
    toHub: () => {
      window.location.assign('/crosswords')
    },
    hasProgress: drawnLines.length > 0 || drawnShapes.length > 0,
    toSubLandingPage: (campaign) => {
      const link = getSubscribeLink(campaign)

      if (isDeepLink(link)) {
        openDeepLink(link)
      } else {
        window.location.assign(link)
      }
    },
    meterGranted,
  }

  return (
    <main
      className="pz-concierge geo-concierge"
      id="js-hook-concierge"
    >
      <section
        className="pz-concierge__frame on-stage fade-in geo-loading"
        data-concierge-frame="loading"
        id="js-hook-concierge__loading"
      >
        <Icon icon="vertex" />
        <Title text="Vertex" />
        <Description text="Start connecting the dots..." />
        <div className="geo-loader" id="pz-loading-bar">
          <div className="geo-loader__fill" />
        </div>
      </section>
      <section
        className="pz-concierge__frame geo-moment pz-concierge-sale-banner"
        id="js-hook-concierge__intro"
      >
        <Welcome playGame={playGame} {...conciergeProps} />
      </section>
      <section
        className="pz-concierge__frame geo-moment pz-concierge-sale-banner"
        id="js-hook-concierge__congrats"
      >
        <Congrats
          playGame={playGame}
          backToGame={backToGame}
          {...conciergeProps}
        />
      </section>
      <section
        className="pz-concierge__frame geo-game"
        id="js-hook-concierge__game"
      >
        {children}
      </section>
    </main>
  )
}

Concierge.propTypes = {
  children: pt.element,
  startGame: pt.func.isRequired,
  drawnLines: pt.arrayOf(pt.arrayOf(pt.number)),
  drawnShapes: pt.arrayOf(pt.number),
}

const mapStateToProps = ({
  id,
  drawnLines,
  drawnShapes,
  displayDate,
  puzzleConstructor,
  hasCompletedTutorial,
  hasCompletedStarterPack,
  starterPackPuzzles,
}) => ({
  id,
  drawnLines,
  drawnShapes,
  displayDate,
  puzzleConstructor,
  hasCompletedTutorial,
  hasCompletedStarterPack,
  starterPackPuzzles,
})

export default connect(mapStateToProps)(Concierge)
