import { wait } from '../../helpers/gameUtils'

const CLASS_ON_STAGE = 'on-stage'
const CLASS_FADE_IN = 'fade-in'
const CLASS_SLIDE_UP = 'slide-up'
const CLASS_CONTENT_CONTAINER = 'geo-moment__content'
const CLASS_MODAL_CARD = 'modal-card'
const TIME_GROW = 600 // transition duration for fade in

const now = () => Date.now()

const style = (elm, attr, value) => {
  elm.style[attr] = value
}

const addClass = (elm, className) => {
  elm.classList.add(className)
}

const removeClass = (elm, className) => {
  if (!elm.length) {
    elm.classList.remove(className)
  } else {
    elm.forEach((node) => {
      node.classList.remove(className)
    })
  }
}

export const load = () => {
  const bar = document.getElementById('pz-loading-bar').children[0]

  return new Promise((resolve) => {
    const next = (amt = 10) => {
      bar.style.right = `${Math.max(100 - amt, 0)}%`
      const paused = window.localStorage.getItem('pauseLoader')
      if (amt <= 100 || paused) {
        wait(30 + Math.random() * 150).then(() => {
          next(amt + Math.random() * 20)
        })
      } else {
        resolve()
      }
    }

    next()
  })
}

export const sequence = (nodes, duration) => {
  let delay = 0
  nodes.forEach((node) => {
    if (!node) return
    delay += duration
    style(node, 'transitionDelay', `${delay}ms`)
    addClass(node, CLASS_SLIDE_UP)
  })
}

export const transition = (
  concierge,
  leaving,
  entering,
  onComplete = () => {},
) => {
  const modalCard = document.querySelector(`.${CLASS_MODAL_CARD}`)
  const sequencedNodes = document.querySelectorAll(
    `.${CLASS_SLIDE_UP}`,
  )

  addClass(entering, CLASS_ON_STAGE)
  removeClass(leaving, CLASS_FADE_IN)
  removeClass(leaving, CLASS_ON_STAGE)
  addClass(entering, CLASS_FADE_IN)

  wait(TIME_GROW).then(() => {
    if (sequencedNodes.length) {
      removeClass(sequencedNodes, CLASS_SLIDE_UP)
    }

    const nodesToSequence = entering.querySelector(
      `.${CLASS_CONTENT_CONTAINER}`,
    )

    if (nodesToSequence) {
      sequence(
        Array.from(nodesToSequence.children).concat(modalCard),
        200,
      )
    }

    wait(100).then(onComplete)
  })
}

export const showCongrats = () => {
  const concierge = document.getElementById('js-hook-concierge')

  const leaving = document.getElementById('js-hook-concierge__game')

  const entering = document.getElementById(
    'js-hook-concierge__congrats',
  )

  transition(concierge, leaving, entering)

  return new Promise((resolve) => setTimeout(resolve, 1000))
}
