import React from 'react'
import pt from 'prop-types'
import { connect } from 'react-redux'

import CanvasManager from '../Canvas/CanvasManager'
import ShapeCounter from '../ShapeCounter/ShapeCounter'
import { drawLine, undoLine, clearConnections } from '../store/store'

export const Game = ({
  state,
  drawLine,
  undoLine,
  clearConnections,
  isMobile,
  track,
}) => {
  return (
    <div className="geo-game-container">
      <h2 className="geo-theme">{state.theme}</h2>
      <CanvasManager
        track={track}
        isMobile={isMobile}
        actions={{ drawLine, undoLine, clearConnections }}
        puzzleState={state}
      />
      <ShapeCounter
        shapeCount={
          Object.keys(state.shapes).length - state.drawnShapes.length
        }
      />
    </div>
  )
}

Game.propTypes = {
  state: pt.shape({
    theme: pt.string,
    shapes: pt.shape({}),
    drawnShapes: pt.array,
  }).isRequired,
  drawLine: pt.func.isRequired,
  undoLine: pt.func.isRequired,
  clearConnections: pt.func.isRequired,
  track: pt.func.isRequired,
  isMobile: pt.bool.isRequired,
}

const mapStateToProps = (state) => ({ state })

const mapDispatchToProps = {
  drawLine,
  undoLine,
  clearConnections,
}

export default connect(mapStateToProps, mapDispatchToProps)(Game)
