import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import CanvasManager from '../Canvas/CanvasManager'
import ShapeCounter from '../ShapeCounter/ShapeCounter'
import store from '../store/store'

import Game from './Game'

jest.mock(
  '../Canvas/CanvasManager',
  () =>
    function CanvasManager() {
      return <div />
    },
)

jest.mock(
  '../ShapeCounter/ShapeCounter',
  () =>
    function ShapeCounter() {
      return <div />
    },
)

const mockState = {
  shapes: { foo: 1 },
  drawnShapes: [1],
  theme: 'Clue',
}

jest.mock('../store/store', () => ({
  drawLine: jest.fn(),
  undoLine: jest.fn(),
  clearConnections: jest.fn(),
  getState: jest.fn().mockImplementation(() => mockState),
  subscribe: jest.fn(),
  dispatch: jest.fn(),
}))

describe('VERTEX: GAME', () => {
  const props = {
    state: mockState,
    isMobile: false,
    track: () => ({}),
    drawLine: () => ({}),
    undoLine: () => ({}),
    clearConnections: () => ({}),
  }

  it('should display theme and children', () => {
    const game = mount(
      <Provider store={store}>
        <Game {...props} />
      </Provider>,
    )
    expect(game.find('.geo-theme').text()).toEqual('Clue')
    expect(game.find(CanvasManager)).toHaveLength(1)
    expect(game.find(ShapeCounter)).toHaveLength(1)
  })
})
