import React from 'react'
import pt from 'prop-types'

import { trackClick } from 'foundation'
import { useUser } from 'user'
import useCTA from 'shared/marketing/useCTA'

import {
  navigateBack,
  CONGRATS_NAVIGATE_BACK_TEXT,
} from '../../helpers/navigateBack'
import {
  Icon,
  Title,
  Description,
  Button,
} from '../../shared/moments/components/subcomponents'
import ModalCard, { sbProps } from '../../shared/modals/ModalCard'

const CongratsDaily = ({ track, backToGame, toSubLandingPage }) => {
  const { userType, hasLoaded } = useUser()
  const { getButtonText } = useCTA()
  const buttonText = getButtonText()

  return (
    <>
      <div
        className="geo-moment__container geo-moment__congrats"
        id="geo-congrats-daily"
      >
        <div className="geo-moment__content">
          <Icon icon="vertex" />
          <Title text="Nice drawing!" />
          <Description text="Come back tomorrow to play a new puzzle." />
          <div className="geo-moment__actions">
            <button
              type="button"
              className="geo-moment__button--link"
              onClick={() => {
                backToGame()
                track('ADMIRE_MY_PUZZLE')
              }}
            >
              Admire your puzzle.
            </button>
            {hasLoaded && !userType.hasXwd && (
              <Button
                text={buttonText}
                action={() =>
                  toSubLandingPage('vertexPreviewPageNonsubs')
                }
              />
            )}
            <Button
              text={CONGRATS_NAVIGATE_BACK_TEXT}
              color={
                hasLoaded && !userType.hasXwd
                  ? 'secondary'
                  : 'primary'
              }
              action={() => {
                navigateBack()
                track('BACK_TO_HUB')
              }}
            />
          </div>
        </div>
        <ModalCard
          {...sbProps}
          clickHandler={() =>
            trackClick({
              name: 'vertex',
              context: 'spelling-bee',
              element: { name: 'vertex', label: 'next-game' },
            })
          }
        />
      </div>
    </>
  )
}

CongratsDaily.propTypes = {
  track: pt.func.isRequired,
  toHub: pt.func.isRequired,
  backToGame: pt.func.isRequired,
  toSubLandingPage: pt.func.isRequired,
}

export default CongratsDaily
