import React from 'react'
import pt from 'prop-types'

import { trackClick } from 'foundation'
import { useUser } from 'user'
import { trackImpression } from 'helpers/tracking'
import useCTA from 'shared/marketing/useCTA'

import ModalCard, { sbProps } from '../../shared/modals/ModalCard'
import {
  Icon,
  Title,
  Description,
  Button,
} from '../../shared/moments/components/subcomponents'

const CongratsStarterPack = ({
  track,
  backToGame,
  toSubLandingPage,
  meterGranted,
}) => {
  const { userType, hasLoaded } = useUser()
  const { getButtonText } = useCTA()
  const buttonText = getButtonText()

  React.useEffect(() => {
    if (hasLoaded && !userType.hasXwd && !meterGranted) {
      trackImpression(
        'hardpaywall',
        'vertex-end-of-starter-pack-congrats',
      )
    }
  }, [hasLoaded, userType])

  return (
    <>
      <div
        className="geo-moment__container geo-moment__congrats"
        id="geo-congrats-starter-pack"
      >
        <div className="geo-moment__content">
          <Icon icon="vertex" />
          <Title text="Congrats on your masterpiece!" />
          <Description
            text={
              userType.hasXwd
                ? 'As a Games subscriber, you can play Vertex every day.'
                : 'Subscribe to New York Times Games to<br/> play Vertex every day.'
            }
          />
          <div className="geo-moment__actions">
            {hasLoaded && !userType.hasXwd && (
              <Button
                text={buttonText}
                action={() =>
                  toSubLandingPage(
                    'vertexCongratsMomentEndOfStarterPack',
                  )
                }
              />
            )}
            {userType.hasXwd || meterGranted ? (
              <Button
                text="Today’s Puzzle"
                action={() => {
                  backToGame()
                  track('START_GAME')
                }}
              />
            ) : (
              <Button
                text="Today’s Puzzle"
                color="secondary"
                icon="locked"
                action={() => toSubLandingPage('vertexTodaysPuzzle')}
              />
            )}
          </div>
        </div>
        <ModalCard
          {...sbProps}
          clickHandler={() =>
            trackClick({
              name: 'vertex',
              label:
                hasLoaded && !userType.hasXwd ? 'hardpaywall' : null,
              context: 'spelling-bee',
              element: { name: 'vertex', label: 'next-game' },
            })
          }
        />
      </div>
    </>
  )
}

CongratsStarterPack.propTypes = {
  track: pt.func.isRequired,
  backToGame: pt.func.isRequired,
  toSubLandingPage: pt.func.isRequired,
  meterGranted: pt.bool.isRequired,
}

export default CongratsStarterPack
