import React from 'react'
import pt from 'prop-types'

import {
  Icon,
  Title,
  Description,
  Button,
  BodyText,
} from '../../shared/moments/components/subcomponents'

const WelcomeStarterPack = ({ track, playGame, hasProgress, id }) => {
  const trackProgress = () => {
    if (hasProgress) {
      return track('CONTINUE')
    }

    return track('START_GAME')
  }

  return (
    <>
      <div
        className="geo-moment__container geo-moment__welcome back"
        id="geo-welcome-starter-pack"
      >
        <div className="geo-moment__content">
          <div className="geo-moment__icon" />
          <h3 className="geo-moment__title">Vertex</h3>
          <h2 className="geo-moment__subtitle">Welcome back.</h2>
          <Description
            text={
              !hasProgress
                ? 'Start connecting the dots.'
                : 'Reveal the full picture'
            }
          />
          <div className="geo-moment__actions">
            <Button
              text={hasProgress ? 'Continue' : 'Play'}
              action={() => {
                playGame()
                trackProgress()
              }}
            />
          </div>
          <BodyText>
            <span className="pz-moment__info-date">
              {`Starter Puzzle ${parseInt(id) + 1}`}
            </span>
          </BodyText>
          <BodyText>By Noca Wu</BodyText>
        </div>
      </div>
    </>
  )
}

WelcomeStarterPack.propTypes = {
  track: pt.func.isRequired,
  playGame: pt.func.isRequired,
  hasProgress: pt.bool.isRequired,
  id: pt.string.isRequired,
}

export default WelcomeStarterPack
