import React from 'react'
import { mount } from 'enzyme'

import Congrats from '../Congrats'
import CongratsDaily from '../CongratsDaily'
import CongratsTutorial from '../CongratsTutorial'
import CongratsStarterPack from '../CongratsStarterPack'
import CongratsMidwayStarter from '../CongratsMidwayStarter'

const props = {
  congrats: '',
}

jest.mock(
  '../CongratsDaily',
  () =>
    function CongratsDaily() {
      return <div />
    },
)
jest.mock(
  '../CongratsTutorial',
  () =>
    function CongratsTutorial() {
      return <div />
    },
)
jest.mock(
  '../CongratsStarterPack',
  () =>
    function CongratsStarterPack() {
      return <div />
    },
)
jest.mock(
  '../CongratsMidwayStarter',
  () =>
    function CongratsMidwayStarter() {
      return <div />
    },
)

describe('VERTEX: CONGRATS', () => {
  it('should display tutorial congrats when specified and fire impression events', () => {
    props.congrats = 'tutorial'
    props.hasCompletedTutorial = true
    props.hasProgress = false

    const congrats = mount(<Congrats {...props} />)
    expect(congrats.find(CongratsDaily)).toHaveLength(0)
    expect(congrats.find(CongratsTutorial)).toHaveLength(1)
    expect(congrats.find(CongratsStarterPack)).toHaveLength(0)
    expect(congrats.find(CongratsMidwayStarter)).toHaveLength(0)
  })

  it('should display midway starter pack congrats when specified and fire impression events', () => {
    props.congrats = 'midway starter pack'
    props.hasCompletedDailyPuzzle = false
    props.hasProgress = false

    const congrats = mount(<Congrats {...props} />)
    expect(congrats.find(CongratsDaily)).toHaveLength(0)
    expect(congrats.find(CongratsTutorial)).toHaveLength(0)
    expect(congrats.find(CongratsStarterPack)).toHaveLength(0)
    expect(congrats.find(CongratsMidwayStarter)).toHaveLength(1)
  })

  it('should display starter pack congrats when specified and fire impression events', () => {
    props.congrats = 'starter pack'
    props.hasCompletedDailyPuzzle = false
    props.hasProgress = false
    props.hasCompletedStarterPack = true
    props.hasCompletedTutorial = true
    props.hasStartedGame = true

    const congrats = mount(<Congrats {...props} />)
    expect(congrats.find(CongratsDaily)).toHaveLength(0)
    expect(congrats.find(CongratsTutorial)).toHaveLength(0)
    expect(congrats.find(CongratsStarterPack)).toHaveLength(1)
    expect(congrats.find(CongratsMidwayStarter)).toHaveLength(0)
  })

  it('should display the daily congrats and  events', () => {
    props.congrats = 'daily'
    props.hasCompletedDailyPuzzle = true
    props.hasProgress = true
    props.hasStartedGame = true
    props.hasCompletedTutorial = true

    const congrats = mount(<Congrats {...props} />)
    expect(congrats.find(CongratsDaily)).toHaveLength(1)
    expect(congrats.find(CongratsTutorial)).toHaveLength(0)
    expect(congrats.find(CongratsStarterPack)).toHaveLength(0)
    expect(congrats.find(CongratsMidwayStarter)).toHaveLength(0)
  })
})
