import React from 'react'
import { mount } from 'enzyme'

import { useUser } from 'user'

import CongratsDaily from '../CongratsDaily'
import {
  CONGRATS_NAVIGATE_BACK_TEXT,
  navigateBack,
} from '../../../helpers/navigateBack'

const props = {
  track: jest.fn(),
  toHub: jest.fn(),
  backToGame: jest.fn(),
  toSubLandingPage: jest.fn(),
}

jest.mock('foundation', () => ({}))

jest.mock('user', () => ({
  useUser: jest.fn().mockReturnValue({
    userType: {
      hasXwd: false,
    },
    hasLoaded: true,
  }),
}))

jest.mock('../../../helpers/navigateBack', () => ({
  navigateBack: jest.fn(),
  CONGRATS_NAVIGATE_BACK_TEXT: 'View all games',
}))

jest.mock('shared/marketing/useCTA', () => ({
  __esModule: true,
  default: () => ({
    isGamesSaleActive: false,
    getButtonText: () => 'Subscribe',
  }),
}))

describe('VERTEX: MOMENT - CONGRATS DAILY', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })

  const congratsDaily = mount(<CongratsDaily {...props} />)

  it('should render text', () => {
    const title = congratsDaily.find('.pz-moment__title')
    const info = congratsDaily.find('.pz-moment__description')

    expect(title.text()).toEqual('Nice drawing!')
    expect(info.text()).toEqual(
      'Come back tomorrow to play a new puzzle.',
    )
  })

  it('should render subscribe button for non-subs', () => {
    const primaryButton = congratsDaily
      .find('.pz-moment__button')
      .at(0)

    expect(primaryButton.text()).toEqual('Subscribe')

    primaryButton.simulate('click')

    expect(props.toSubLandingPage).toHaveBeenCalled()
  })

  it('should render admire puzzle button', () => {
    const secondaryButton = congratsDaily
      .find('.geo-moment__button--link')
      .at(0)

    expect(secondaryButton.text()).toEqual('Admire your puzzle.')

    secondaryButton.simulate('click')

    expect(props.backToGame).toHaveBeenCalled()
    expect(props.track).toHaveBeenCalledWith('ADMIRE_MY_PUZZLE')
  })

  it('should render back to hub button', () => {
    const secondaryButton = congratsDaily
      .find('.pz-moment__button')
      .at(1)

    expect(secondaryButton.text()).toEqual(
      CONGRATS_NAVIGATE_BACK_TEXT,
    )

    secondaryButton.simulate('click')

    expect(navigateBack).toHaveBeenCalled()
    expect(props.track).toHaveBeenCalledWith('BACK_TO_HUB')
  })
})
