import React from 'react'
import { mount } from 'enzyme'

import Welcome from '../Welcome'
import WelcomeDaily from '../WelcomeDaily'
import WelcomeFirstVisit from '../WelcomeFirstVisit'
import WelcomeStarterPack from '../WelcomeStarterPack'

const props = {
  hasCompletedTutorial: false,
  hasCompletedStarterPack: false,
  playGame: jest.fn(),
  track: jest.fn(),
}

jest.mock(
  '../WelcomeDaily',
  () =>
    function WelcomeDaily() {
      return <div />
    },
)
jest.mock(
  '../WelcomeStarterPack',
  () =>
    function WelcomeStarterPack() {
      return <div />
    },
)

describe('VERTEX: WELCOME', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should render title, message, and play button', () => {
    const welcome = mount(<Welcome {...props} />)
    const title = welcome.find('.pz-moment__title')
    expect(title.text()).toEqual('Vertex')
    const message = welcome.find('.pz-moment__description')
    expect(message.text()).toEqual(
      'Connect the dots and  reveal the hidden picture.',
    )
    const play = welcome.find('.pz-moment__button')
    expect(play.text()).toEqual('Play')
  })

  it('should display first visit welcome when tutorial has not been completed', () => {
    const welcome = mount(<Welcome {...props} />)
    expect(welcome.find(WelcomeFirstVisit)).toHaveLength(1)
  })

  it('should display starter pack welcome when tutorial has completed and starter pack has not been completed', () => {
    props.hasCompletedTutorial = true
    const welcome = mount(<Welcome {...props} />)
    expect(welcome.find(WelcomeStarterPack)).toHaveLength(1)
  })

  it('should display daily welcome when tutorial and starter pack have been completed', () => {
    props.hasCompletedTutorial = true
    props.hasCompletedStarterPack = true
    const welcome = mount(<Welcome {...props} />)
    expect(welcome.find(WelcomeDaily)).toHaveLength(1)
  })
})
