import React from 'react'
import { mount } from 'enzyme'

import WelcomeStarterPack from '../WelcomeStarterPack'

const props = {
  track: jest.fn(),
  playGame: jest.fn(),
  hasProgress: true,
  id: '0',
}

describe('VERTEX: MOMENT - WELCOME STARTER PACK', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should render text', () => {
    const welcomeStarterPack = mount(
      <WelcomeStarterPack {...props} />,
    )

    const title = welcomeStarterPack.find('.geo-moment__title')

    const infoConstructor = welcomeStarterPack.find(
      '.pz-moment__body',
    )

    expect(title.text()).toEqual('Vertex')
    expect(infoConstructor.at(0).text()).toEqual('Starter Puzzle 1')

    expect(infoConstructor.at(1).text()).toEqual('By Noca Wu')
  })

  it('should render functioning play game and should fire continue event if use has progress', () => {
    const welcomeStarterPack = mount(
      <WelcomeStarterPack {...props} />,
    )

    const button = welcomeStarterPack.find('.pz-moment__button')
    expect(button.text()).toEqual('Continue')
    button.simulate('click')
    expect(props.playGame).toHaveBeenCalled()
    expect(props.track).toHaveBeenCalledWith('CONTINUE')
  })

  it('should render functioning play game and should fire start-game event if user has no progress', () => {
    props.hasProgress = false
    const welcomeStarterPack = mount(
      <WelcomeStarterPack {...props} />,
    )

    const button = welcomeStarterPack.find('.pz-moment__button')
    expect(button.text()).toEqual('Play')
    button.simulate('click')
    expect(props.playGame).toHaveBeenCalled()
    expect(props.track).toHaveBeenCalledWith('START_GAME')
  })
})
