import React from 'react'
import { Provider } from 'react-redux'
import { createStore } from 'redux'

import { UserProvider } from 'user'

import Concierge from '../Concierge/Concierge'
import { transition } from '../Concierge/conciergeHelpers'
import reducer from '../store/reducer'
import { mockState } from '../store/__tests__/mockGameData'

import Congrats from './Congrats'
import Welcome from './Welcome'

const mockTransition = (enteringID) => {
  const concierge = document.getElementById('js-hook-concierge')
  const leaving = document.getElementById('dummy-div')

  const entering = document.getElementById(enteringID)

  transition(concierge, leaving, entering)
}

export const Loading = (args) => <Concierge {...args} />

const WelcomeTemplate = ({ hasXwd, ...args }) => {
  React.useEffect(() => {
    mockTransition('js-hook-concierge__intro')
  }, [])

  return (
    <section
      className="pz-concierge__frame on-stage fade-in geo-moment"
      id="js-hook-concierge__intro"
      style={{ visibility: 'visible', position: 'static', top: '0' }}
    >
      <Welcome userType={{ hasXwd }} {...args} />
    </section>
  )
}

export const WelcomeFirstVisit = WelcomeTemplate.bind({})
WelcomeFirstVisit.args = {
  hasCompletedTutorial: false,
  hasCompletedStarterPack: false,
  hasCompletedDailyPuzzle: false,
  hasProgress: false,
  id: '0',
}

export const WelcomeStarterPack = WelcomeTemplate.bind({})
WelcomeStarterPack.args = {
  ...WelcomeFirstVisit.args,
  hasCompletedTutorial: true,
}

export const WelcomeDaily = WelcomeTemplate.bind({})
WelcomeDaily.args = {
  ...WelcomeStarterPack.args,
  hasCompletedStarterPack: true,
  hasXwd: true,
}

export const WelcomeBackDaily = WelcomeTemplate.bind({})
WelcomeBackDaily.args = {
  ...WelcomeDaily.args,
  hasProgress: true,
  hasXwd: true,
}

const CongratsTemplate = ({ hasXwd, ...args }) => {
  React.useEffect(() => {
    mockTransition('js-hook-concierge__congrats')
  }, [])

  return (
    <section
      className="pz-concierge__frame fade-in on-stage geo-moment"
      id="js-hook-concierge__congrats"
      style={{ visibility: 'visible', position: 'static', top: '0' }}
    >
      <Congrats userType={{ hasXwd }} {...args} />
    </section>
  )
}

export const CongratsDaily = CongratsTemplate.bind({})
CongratsDaily.args = {
  congrats: 'daily',
  hasXwd: true,
}

export const CongratsTutorial = CongratsTemplate.bind({})

CongratsTutorial.args = {
  congrats: 'tutorial',
}

export const CongratsMidwayStarter = CongratsTemplate.bind({})
CongratsMidwayStarter.args = {
  congrats: 'midway starter pack',
}

export const CongratsStarterPack = CongratsTemplate.bind({})
CongratsStarterPack.args = {
  congrats: 'starter pack',
}

export default {
  title: 'Vertex/Moments',
  component: Concierge,
  decorators: [
    (story, { args: { hasXwd }, args }) => {
      const withUserProvider = (children, hasXwd) => {
        return (
          <UserProvider hasLoaded userType={{ hasXwd }}>
            {children}
          </UserProvider>
        )
      }

      const mockStore = createStore(reducer, {
        ...mockState,
        ...args,
      })

      return withUserProvider(
        <Provider store={mockStore}>
          <div
            className="pz-game-field"
            id="pz-game-root"
            style={{ height: '100vh', overflow: 'hidden' }}
          >
            <div className="geo-main-container">
              <main
                className="pz-concierge geo-concierge"
                id="js-hook-concierge"
                style={{
                  overflow: 'visible',
                  position: 'static',
                  top: '0',
                }}
              >
                <div id="dummy-div" />
                {story()}
              </main>
            </div>
          </div>
        </Provider>,
        hasXwd,
      )
    },
  ],
  argTypes: {
    track: {
      table: { disable: true },
    },
    playGame: {
      table: { disable: true },
    },
    backToGame: {
      table: { disable: true },
    },
    toSubLandingPage: {
      table: { disable: true },
    },
    toHub: {
      table: { disable: true },
    },
    startGame: {
      table: { disable: true },
    },
    drawnLines: {
      table: { disable: true },
    },
    drawnShapes: {
      table: { disable: true },
    },
    children: {
      table: { disable: true },
    },
    hasCompletedTutorial: {
      table: { disable: true },
    },
    hasCompletedStarterPack: {
      table: { disable: true },
    },
    hasLoaded: {
      table: { disable: true },
    },
  },
  parameters: {
    viewport: {
      defaultViewport: 'iphonex',
    },
  },
  args: {
    puzzleConstructor: mockState.puzzleConstructor,
    displayDate: mockState.displayDate,
    track: () => {},
    playGame: () => {},
    backToGame: () => {},
    startGame: () => {},
    toSubLandingPage: () => {},
    toHub: () => {},
    hasXwd: false,
    hasLoaded: true,
  },
}
