import React from 'react'
import ReactDOM from 'react-dom'

import { mobileNavTools, env } from 'foundation'
import { useUser } from 'user'

const barRoot = document.getElementById('portal-game-toolbar')

export const Toolbar = ({
  resetGame,
  debugCompleteGame,
  skipTutorial,
  openRulesModal,
}) => {
  const { userType } = useUser()

  React.useEffect(() => {
    const ersatzShortzButtons = [
      {
        type: 'text',
        value: 'Debug Complete',
        action: debugCompleteGame,
      },
    ]

    const buttons = [
      {
        type: 'text',
        value: 'Help',
        action: openRulesModal,
      },
      {
        type: 'text',
        value: 'Reset',
        action: resetGame,
      },
    ]

    if (skipTutorial) {
      buttons.push({
        type: 'text',
        value: 'Skip',
        action: skipTutorial,
      })
    }

    mobileNavTools.create(
      userType.inShortzMode
        ? [...buttons, ...ersatzShortzButtons]
        : buttons,
    )
  }, [resetGame, debugCompleteGame, userType])

  const showDebug = userType.inShortzMode || env.name !== 'prod'

  return ReactDOM.createPortal(
    <>
      <span className="pz-toolbar-left">
        {showDebug && (
          <span
            role="button"
            className="pz-toolbar-button"
            onClick={debugCompleteGame}
          >
            Debug Complete
          </span>
        )}
        {skipTutorial && (
          <span
            role="button"
            className="pz-toolbar-button"
            onClick={skipTutorial}
          >
            Skip Tutorial
          </span>
        )}
      </span>
      <span className="pz-toolbar-right">
        <span
          role="button"
          className="pz-toolbar-button"
          onClick={openRulesModal}
        >
          Help
        </span>
        <span
          role="button"
          className="pz-toolbar-button"
          onClick={resetGame}
        >
          Reset
        </span>
      </span>
    </>,
    barRoot,
  )
}

export default Toolbar
