import React from 'react'
import { shallow } from 'enzyme'

import { Toolbar } from './Toolbar'

jest.mock('react-dom', () => ({
  createPortal: (jsx) => jsx,
}))

jest.mock('foundation', () => ({
  mobileNavTools: {
    create: jest.fn(),
  },
}))

jest.mock('user', () => ({
  useUser: jest.fn().mockReturnValue({
    userType: {
      inShortzMode: true,
    },
  }),
}))

describe('VERTEX: TOOLBAR', () => {
  it('should have some text buttons', () => {
    const toolbar = shallow(<Toolbar />)
    const debugCompleteButton = toolbar
      .find('.pz-toolbar-button')
      .at(0)

    const rulesButton = toolbar.find('.pz-toolbar-button').at(1)

    const resetButton = toolbar.find('.pz-toolbar-button').at(2)
    expect(debugCompleteButton.text()).toBe('Debug Complete')
    expect(rulesButton.text()).toBe('Help')
    expect(resetButton.text()).toBe('Reset')
  })

  it('should call debugCompleteGame function when debug complete button is pressed', () => {
    const debugCompleteGame = jest.fn()
    const toolbar = shallow(
      <Toolbar debugCompleteGame={debugCompleteGame} />,
    )

    const debugCompleteButton = toolbar
      .find('.pz-toolbar-button')
      .at(0)
    debugCompleteButton.simulate('click')
    expect(debugCompleteGame).toHaveBeenCalled()
  })

  it('should call openRulesModal function when rules button is pressed', () => {
    const openRulesModal = jest.fn()
    const toolbar = shallow(
      <Toolbar openRulesModal={openRulesModal} />,
    )

    const rulesButton = toolbar.find('.pz-toolbar-button').at(1)
    rulesButton.simulate('click')
    expect(openRulesModal).toHaveBeenCalled()
  })

  it('should call resetGame function when reset button is pressed', () => {
    const resetGame = jest.fn()
    const toolbar = shallow(<Toolbar resetGame={resetGame} />)

    const resetButton = toolbar.find('.pz-toolbar-button').at(2)
    resetButton.simulate('click')
    expect(resetGame).toHaveBeenCalled()
  })

  it('should display skip tutorial button when skip tutorial func is passed in', () => {
    const skipTutorial = jest.fn()
    const toolbar = shallow(<Toolbar skipTutorial={skipTutorial} />)

    const debugCompleteButton = toolbar
      .find('.pz-toolbar-button')
      .at(0)

    const skipTutorialButton = toolbar
      .find('.pz-toolbar-button')
      .at(1)

    const rulesButton = toolbar.find('.pz-toolbar-button').at(2)

    const resetButton = toolbar.find('.pz-toolbar-button').at(3)
    expect(debugCompleteButton.text()).toBe('Debug Complete')
    expect(skipTutorialButton.text()).toBe('Skip Tutorial')
    expect(rulesButton.text()).toBe('Help')
    expect(resetButton.text()).toBe('Reset')
  })

  it('should call skipTutorial function when skip tutorial button is pressed', () => {
    const skipTutorial = jest.fn()
    const toolbar = shallow(<Toolbar skipTutorial={skipTutorial} />)

    const skipTutorialButton = toolbar
      .find('.pz-toolbar-button')
      .at(1)
    skipTutorialButton.simulate('click')
    expect(skipTutorial).toHaveBeenCalled()
  })
})
