import { colors } from '../constants'

export const verticesSpecs = {
  zoomedOut: {
    smallScreen: {
      smallVertex: {
        fontSize: 8,
        radius: 6,
        innerStroke: 0.75,
        outerStroke: 0.5,
        lineDashSegments: [0.5, 1],
        tapArea: 4,
      },
      mediumVertex: {
        fontSize: 9,
        radius: 8,
        innerStroke: 0.75,
        outerStroke: 0.5,
        lineDashSegments: [0.5, 1],
        tapArea: 4,
      },
      largeVertex: {
        fontSize: 10,
        radius: 10,
        innerStroke: 0.75,
        outerStroke: 0.5,
        lineDashSegments: [0.5, 1],
        tapArea: 4,
      },
    },
    largerScreen: {
      smallVertex: {
        fontSize: 10,
        radius: 8,
        innerStroke: 1,
        outerStroke: 0.5,
        lineDashSegments: [0.5, 1],
        tapArea: 4,
      },
      mediumVertex: {
        fontSize: 12,
        radius: 11,
        innerStroke: 1,
        outerStroke: 0.5,
        lineDashSegments: [0.5, 1],
        tapArea: 4,
      },
      largeVertex: {
        fontSize: 12,
        radius: 14,
        innerStroke: 1,
        outerStroke: 0.5,
        lineDashSegments: [0.5, 1],
        tapArea: 4,
      },
    },
  },
  zoomedIn: {
    smallScreen: {
      smallVertex: {
        fontSize: 10,
        radius: 9,
        innerStroke: 1.5,
        outerStroke: 0.75,
        lineDashSegments: [0.75, 1],
        tapArea: 6,
      },
      mediumVertex: {
        fontSize: 14,
        radius: 12,
        innerStroke: 1.5,
        outerStroke: 0.75,
        lineDashSegments: [0.75, 1],
        tapArea: 6,
      },
      largeVertex: {
        fontSize: 18,
        radius: 18,
        innerStroke: 1.5,
        outerStroke: 0.75,
        lineDashSegments: [0.75, 1],
        tapArea: 8,
      },
    },
    largerScreen: {
      smallVertex: {
        fontSize: 14,
        radius: 14,
        innerStroke: 2,
        outerStroke: 1,
        lineDashSegments: [1, 1.5],
        tapArea: 8,
      },
      mediumVertex: {
        fontSize: 14,
        radius: 18,
        innerStroke: 2,
        outerStroke: 1,
        lineDashSegments: [1, 1.5],
        tapArea: 8,
      },
      largeVertex: {
        fontSize: 20,
        radius: 24,
        innerStroke: 2,
        outerStroke: 1,
        lineDashSegments: [1, 1.5],
        tapArea: 13,
      },
    },
  },
}

export const getVertexSpecs = (
  zoom,
  vertex,
  minZoom = 1,
  maxZoom = 3,
) => {
  const {
    pendingConnections,
    shapes,
    completedShapes,
    preDrawnShapes,
  } = vertex

  const screenWidth =
    window.innerWidth <= 444 ? 'smallScreen' : 'largerScreen'

  let size

  if (pendingConnections <= 3) {
    size = 'smallVertex'
  } else if (pendingConnections <= 6) {
    size = 'mediumVertex'
  } else {
    size = 'largeVertex'
  }

  const maxSpecs = {
    ...verticesSpecs.zoomedIn[screenWidth][size],
  }

  const minSpecs = {
    ...verticesSpecs.zoomedOut[screenWidth][size],
  }
  const zoomRatio = zoom / maxZoom

  if (
    completedShapes.length + preDrawnShapes.length ===
    shapes.length
  ) {
    minSpecs.radius = 0
    minSpecs.tapArea = 0
    maxSpecs.radius = 0
    maxSpecs.tapArea = 0
  }

  if (zoom <= minZoom) return minSpecs

  if (zoom >= maxZoom) return maxSpecs

  Object.keys(minSpecs).forEach((val) => {
    if (typeof minSpecs[val] === 'number') {
      const valIncrement = (maxSpecs[val] - minSpecs[val]) * zoomRatio

      minSpecs[val] += valIncrement
    }

    if (Array.isArray(minSpecs[val])) {
      minSpecs[val].forEach((v, idx) => {
        const valIncrement = (maxSpecs[val][idx] - v) * zoomRatio
        minSpecs[val][idx] += valIncrement
      })
    }
  })

  return minSpecs
}

export const getLineSpecs = (
  zoom,
  isMobile,
  minZoom = 1,
  maxZoom = 3,
) => {
  const zoomRatio = zoom / maxZoom
  const maxWidth = isMobile ? 4 : 5

  let minWidth = isMobile ? 2 : 3

  if (zoom <= minZoom) return minWidth

  if (zoom >= maxZoom) return maxWidth

  const widthIncrement = (maxWidth - minWidth) * zoomRatio

  minWidth += widthIncrement

  return minWidth
}

export const getVertexStyles = (id, selected, hover, cleared) => {
  const isHover = selected === null && id === hover
  const isSelected = id === selected
  const isNearby =
    selected !== null && id !== selected && id === hover

  const isApproaching =
    id === selected && hover !== null && hover !== id
  const isClearing = cleared && id === cleared.id

  const vertexStyle = {
    innerFillStyle: colors.tan,
    outerFillStyle: 'transparent',
    innerStrokeStyle: colors.black,
    outerStrokeStyle: colors.black,
    fontColor: colors.black,
  }

  if (isSelected || isHover) {
    vertexStyle.innerFillStyle = colors.black
    vertexStyle.outerFillStyle = colors.transparentBlack
    vertexStyle.fontColor = colors.tan
  }

  if (isNearby || isApproaching) {
    vertexStyle.innerFillStyle = colors.gold
    vertexStyle.innerStrokeStyle = colors.gold
    vertexStyle.outerStrokeStyle = colors.gold
    vertexStyle.outerFillStyle = colors.transparentGold
    vertexStyle.fontColor = colors.black
  }

  if (isClearing) {
    vertexStyle.innerFillStyle = colors.red
    vertexStyle.innerStrokeStyle = colors.red
    vertexStyle.outerStrokeStyle = colors.red
    vertexStyle.outerFillStyle = colors.transparentRed
    vertexStyle.fontColor = colors.tan
  }

  return vertexStyle
}

export const dispatchPlayGameEvent = () => {
  const canvas = document.getElementById('js-hook-geo-canvas')

  let event = {}

  if (document.createEvent) {
    event = document.createEvent('HTMLEvents')
    event.initEvent('playGame', true, true)
    event.eventName = 'playGame'

    canvas.dispatchEvent(event)
  } else {
    event = document.createEventObject()
    event.eventName = 'playGame'
    event.eventType = 'playGame'

    canvas.fireEvent(`on${event.eventType}`, event)
  }
}

export const getArtEdges = (points) => {
  let minX
  let maxX
  let minY
  let maxY

  points.forEach((point) => {
    const {
      coords: { 0: x, 1: y },
    } = point

    if (!minX || x < minX) {
      minX = x
    }

    if (!maxX || x > maxX) {
      maxX = x
    }

    if (!minY || y < minY) {
      minY = y
    }

    if (!maxY || y > maxY) {
      maxY = y
    }
  })

  return { minX, maxX, minY, maxY }
}
