import '../../shared/shared-styles'
import '../../shared/shared-scripts'

import React from 'react'
import ReactDOM from 'react-dom'
import { Provider } from 'react-redux'

import { getGameData } from 'foundation'
import { UserProvider } from 'user'
import AbraProviderWithUser from 'shared/abra/AbraProviderWithUser'
import { FeatureFlagProvider } from 'shared/abra/FeatureFlagProvider'
import ClientSideScripts from 'shared/components/ClientSideScripts'

import './index.scss'

import App from './App/App'
import { setUpStore } from './store/store'
import { MeterExperimentProvider } from './meter/MeterExperimentsProvider'

const gameRoot = document.getElementById('pz-game-root')
const gameData = getGameData()

ReactDOM.render(
  <>
    <ClientSideScripts />
    <Provider store={setUpStore(gameData)}>
      <UserProvider>
        <AbraProviderWithUser>
          <FeatureFlagProvider>
            <MeterExperimentProvider>
              <App isMobile={window.isMobileDevice} />
            </MeterExperimentProvider>
          </FeatureFlagProvider>
        </AbraProviderWithUser>
      </UserProvider>
    </Provider>
  </>,
  gameRoot,
)
