import { getConnections } from '../helpers/helpers'

const formatApiData = (apiData, puzzleType) => {
  const {
    id,
    vertices,
    shapes,
    palette,
    preDrawnLines = [],
  } = apiData

  const vertexKeys = Object.keys(vertices)
  const shapeKeys = Object.keys(shapes)

  const initialState = {
    // API DATA
    id,
    puzzleType,
    packId: puzzleType,
    shapes: {},
    vertices: {},
    theme: apiData.theme,
    displayDate: apiData.displayDate,
    puzzleConstructor: apiData.puzzleConstructor,

    // PRE DRAWN
    preDrawnShapes: [],
    preDrawnLines: preDrawnLines.map((line) =>
      line.sort((a, b) => a - b),
    ),

    // PROGRESS
    drawnLines: [],
    drawnShapes: [],
    pendingConnections: {},
    isComplete: false,
  }

  shapeKeys.forEach((key) => {
    const currentShape = shapes[key]

    if (currentShape.isPreDrawn) {
      initialState.preDrawnShapes.push({
        id: parseInt(key),
        vertices: currentShape.vertices.sort((a, b) => a - b),
        color: palette[currentShape.color],
      })
      initialState.preDrawnLines.push([
        currentShape.vertices[0],
        currentShape.vertices[1],
      ])
      initialState.preDrawnLines.push([
        currentShape.vertices[0],
        currentShape.vertices[2],
      ])
      initialState.preDrawnLines.push([
        currentShape.vertices[1],
        currentShape.vertices[2],
      ])
      return
    }

    initialState.shapes[key] = {
      id: parseInt(key),
      vertices: currentShape.vertices.sort((a, b) => a - b), // ascending order
      // This depends on the vertices being sorted in ascending order
      lines: [
        [currentShape.vertices[0], currentShape.vertices[1]],
        [currentShape.vertices[0], currentShape.vertices[2]],
        [currentShape.vertices[1], currentShape.vertices[2]],
      ],
      color: palette[currentShape.color],
    }
  })

  vertexKeys.forEach((key) => {
    initialState.vertices[key] = {
      id: parseInt(key),
      coords: vertices[key].coordinates,
      shapes: vertices[key].shapes,
      completedShapes: [],
      preDrawnShapes: [],
    }

    initialState.pendingConnections[key] = getConnections(
      initialState.shapes,
      key,
      initialState.preDrawnLines,
    )
  })

  initialState.preDrawnShapes.forEach((shape) => {
    Object.values(initialState.vertices).forEach((vertex) => {
      if (shape.vertices.includes(vertex.id)) {
        initialState.vertices[vertex.id].preDrawnShapes.push(shape.id)
      }
    })
  })

  return initialState
}

export default formatApiData
