import {
  getConnections,
  clearConnections,
  restorePendingConnections,
  calculatePendingConnections,
} from '../helpers/helpers'

const reducer = (state, action) => {
  switch (action.type) {
    case 'DRAW_LINE': {
      return {
        ...state,
        pendingConnections: {
          ...state.pendingConnections,
          [action.line[0]]:
            state.pendingConnections[action.line[0]] - 1,
          [action.line[1]]:
            state.pendingConnections[action.line[1]] - 1,
        },
        drawnLines: [...state.drawnLines, action.line],
      }
    }

    case 'DRAW_SHAPE': {
      return {
        ...state,
        pendingConnections: {
          ...state.pendingConnections,
          [action.line[0]]:
            state.pendingConnections[action.line[0]] - 1,
          [action.line[1]]:
            state.pendingConnections[action.line[1]] - 1,
        },
        drawnShapes: [...state.drawnShapes, ...action.newShapeIds],
        drawnLines: [...state.drawnLines, action.line],
      }
    }

    case 'COMPLETE_GAME': {
      return {
        ...state,
        isComplete: true,
        pendingConnections: {
          ...state.pendingConnections,
          [action.line[0]]:
            state.pendingConnections[action.line[0]] - 1,
          [action.line[1]]:
            state.pendingConnections[action.line[1]] - 1,
        },
        drawnShapes: [...state.drawnShapes, ...action.newShapeIds],
        drawnLines: [...state.drawnLines, action.line],
      }
    }

    case 'CLEAR_CONNECTIONS': {
      const { drawnLines, otherVertices } = clearConnections(
        action.vertexId,
        state,
      )

      return {
        ...state,
        pendingConnections: {
          ...state.pendingConnections,
          ...restorePendingConnections(
            state,
            otherVertices,
            action.vertexId,
          ),
        },
        drawnLines,
      }
    }

    case 'UNDO_CONNECTION': {
      const { drawnLines } = state
      const newDrawnLines = [...drawnLines]
      const line = newDrawnLines.splice(action.idx, 1)[0]

      return {
        ...state,
        pendingConnections: {
          ...state.pendingConnections,
          ...restorePendingConnections(state, [line[0]], line[1]),
        },
        drawnLines: newDrawnLines,
      }
    }

    case 'RESET_GAME': {
      const resetPendingConnections = {
        ...state.pendingConnections,
      }
      Object.keys(resetPendingConnections).forEach((key) => {
        resetPendingConnections[key] = getConnections(
          state.shapes,
          key,
          state.preDrawnLines,
        )
      })

      return {
        ...state,
        isComplete: false,
        pendingConnections: resetPendingConnections,
        drawnLines: [],
        drawnShapes: [],
      }
    }

    case 'DEBUG_COMPLETE_GAME': {
      return {
        ...state,
        isComplete: true,
        drawnShapes: [
          ...Object.keys(state.shapes).map((id) => parseInt(id)),
        ],
      }
    }

    case 'SET_CURRENT_PUZZLE': {
      const { timestamp, ...progress } = action.progress
      return {
        ...state,
        ...action.puzzle,
        ...progress,
        pendingConnections: calculatePendingConnections(
          action.puzzle,
          action.progress,
        ),
      }
    }

    case 'COMPLETE_TUTORIAL': {
      return {
        ...state,
        hasCompletedTutorial: true,
      }
    }

    case 'COMPLETE_STARTER_PACK': {
      return {
        ...state,
        hasCompletedTutorial: true,
        hasCompletedStarterPack: true,
      }
    }

    default:
      return state
  }
}

export default reducer
