import { track } from 'foundation'

import { trackEvent } from './vertexTracker'

jest.mock('foundation', () => {
  const track = jest.fn()

  track.mockImplementation((type, trackingObj) => ({
    type,
    trackingObj,
  }))

  return { track }
})

describe('VERTEX: TRACKER', () => {
  beforeEach(() => {
    jest.spyOn(console, 'error')
    console.error.mockImplementation(() => {})
  })

  it('should throw error if event does not exist', () => {
    trackEvent('NON_EXISTENT_EVENT')

    expect(track).not.toHaveBeenCalled()
    expect(console.error.mock.calls[0][0].message).toMatch(
      "unrecognized tracking event 'NON_EXISTENT_EVENT'",
    )
  })

  it('should call track with proper event object', () => {
    trackEvent('START_GAME', '03041217', 'starter-pack')

    const expectedModuleObj = {
      module: {
        name: 'click',
        context: '03041217',
        label: 'starter-pack',
        element: {
          name: 'vertex',
          label: 'start-game',
        },
      },
      eventData: {
        pageType: 'game',
        type: 'click',
        trigger: 'module',
        status: '',
      },
    }

    expect(track).toHaveBeenCalledWith(
      'moduleInteraction',
      expectedModuleObj,
    )
  })
})
