import React from 'react'
import { Provider } from 'react-redux'
import { render } from '@testing-library/react'

import createStore from '../../store'
import { selectMoogleUser } from '../../store/api/api.selectors'

import ActivationRegiModal from './ActivationRegiModal'
import styles from './ActivationRegiModal.module.scss'

jest.mock('foundation', () => ({
  env: { version: 'test' },
  trackImpression: jest.fn(),
}))

jest.mock('../../store/api/api.selectors', () => ({
  ...jest.requireActual('../../store/api/api.selectors'),
  selectMoogleUser: jest.fn(() => ''),
}))

describe('<ActivationRegiModal />', () => {
  const renderHelp = () => {
    const store = createStore()

    render(
      <Provider store={store}>
        <ActivationRegiModal />,
      </Provider>,
    )
  }

  afterEach(() => jest.resetAllMocks())

  it('does not render login section if logged in', () => {
    // @ts-ignore
    selectMoogleUser.mockImplementation(() => '123')
    renderHelp()
    expect(document.querySelector(`.${styles.loginLink}`)).toBeFalsy()
  })

  it('does render login section if not logged in', () => {
    renderHelp()
    expect(
      document.querySelector(`.${styles.loginLink}`),
    ).toBeTruthy()
  })

  it('renders login section if no arguments are passed', () => {
    renderHelp()
    expect(
      document.querySelector(`.${styles.loginLink}`),
    ).toBeTruthy()
  })
})
