import React, { useEffect } from 'react'

import { trackImpression } from 'foundation'

import useAbra from '../../../../../shared/abra/useAbra'
import LoginCTA from '../LoginLink/LoginCTA'
import { ACTIVATION_REGI_MODAL } from '../../abra-constants'
import { useWordleSelector } from '../../store/types'
import { selectMoogleUser } from '../../store/api/api.selectors'

import styles from './ActivationRegiModal.module.scss'

export const REGI_MODAL_COOKIE = 'activation-regi-modal'
export const FREQ_CAP = 4

export const getRegiModalViewCount = () => {
  const cookieVal = document.cookie.split('; ').reduce((acc, val) => {
    const parts = val.split('=')
    return parts[0] === REGI_MODAL_COOKIE ? parts[1] : acc
  }, '')

  return Number.isNaN(parseInt(cookieVal)) ? 0 : parseInt(cookieVal)
}

export default function ActivationRegiModal() {
  const moogleUser = useWordleSelector(selectMoogleUser)
  const isLoggedIn = !!moogleUser
  const abra = useAbra()
  const setFreqCapCookie = () => {
    const count = getRegiModalViewCount()

    if (count < FREQ_CAP) {
      // Set frequency cap cookie with expiration date one year from current date and increment count
      const expiryDate = new Date()
      expiryDate.setMonth(expiryDate.getMonth() + 12)
      document.cookie = `${REGI_MODAL_COOKIE}=${
        count + 1
      }; expires=${expiryDate.toUTCString()};`
    }
  }

  useEffect(() => {
    trackImpression(
      'regi-modal',
      'wordle-welcome',
      ACTIVATION_REGI_MODAL,
      '',
    )
    abra.reportExposure(ACTIVATION_REGI_MODAL)
    setFreqCapCookie()
  }, [])

  return (
    <div
      data-testid="activationRegiModalContainer"
      className={styles.regiModalContainer}
    >
      <img
        alt="Large sized wordle stats icon"
        className={styles.statsIcon}
        style={{ content: 'var(--large-stats)' }}
      />
      <div className={styles.copyContainer}>
        <div className={styles.copyHeader}>
          Wordle is even better with a free New York Times account.
        </div>
        <div className={styles.copyBody}>
          You can save your stats wherever you play and you’ll never
          lose a streak again.
        </div>
      </div>
      {!isLoggedIn && (
        <LoginCTA
          lireOfferAsset="wordle-regi-modal"
          trackEvent={{
            eventName: 'moduleInteraction',
            sendContext: true,
            element: {
              name: 'wordle',
              label: 'log-in-regi-modal',
            },
          }}
          styles={styles.loginLink}
        >
          Log in or create an account
        </LoginCTA>
      )}
    </div>
  )
}
