import hasAdBlock, { DEFAULT_SEED_URL } from '../hasAdBlock'

describe('hasAdBlock', () => {
  afterEach(() => {
    jest.restoreAllMocks()
  })
  it('should call expected default seed url', () => {
    const openSpy = jest.fn()
    const xhrMock: Partial<XMLHttpRequest> = {
      onreadystatechange: jest.fn(),
      open: openSpy,
      send: () => {
        ;(xhrMock.onreadystatechange as EventListener)(new Event(''))
      },
      setRequestHeader: jest.fn(),
      HEADERS_RECEIVED: 2,
      readyState: 2,
      status: 200,
      response: 'Hello World!',
      abort: jest.fn(),
    }
    jest
      .spyOn(global, 'XMLHttpRequest')
      .mockImplementation(() => xhrMock as XMLHttpRequest)
    hasAdBlock()
    expect(openSpy).toHaveBeenCalledWith(
      expect.anything(),
      expect.stringMatching(DEFAULT_SEED_URL),
      expect.anything(),
    )
  })
  it('should resolve to false if headers received', async () => {
    const xhrMock: Partial<XMLHttpRequest> = {
      onreadystatechange: jest.fn(),
      open: jest.fn(),
      send: () => {
        ;(xhrMock.onreadystatechange as EventListener)(new Event(''))
      },
      setRequestHeader: jest.fn(),
      HEADERS_RECEIVED: 2,
      readyState: 2,
      status: 200,
      response: 'Hello World!',
      abort: jest.fn(),
    }
    jest
      .spyOn(global, 'XMLHttpRequest')
      .mockImplementation(() => xhrMock as XMLHttpRequest)
    const usingAdBlockTest = await hasAdBlock()
    expect(usingAdBlockTest).toEqual(false)
  })
  it('should resolve to true if xmlhttprequest returns error', async () => {
    const xhrMock: Partial<XMLHttpRequest> = {
      onerror: jest.fn(),
      open: jest.fn(),
      send: () => {
        ;(xhrMock.onerror as EventListener)(new Event(''))
      },
      setRequestHeader: jest.fn(),
      HEADERS_RECEIVED: 2,
      readyState: 2,
      status: 200,
      response: 'Hello World!',
      abort: jest.fn(),
    }
    jest
      .spyOn(global, 'XMLHttpRequest')
      .mockImplementation(() => xhrMock as XMLHttpRequest)
    const usingAdBlockTest = await hasAdBlock()
    expect(usingAdBlockTest).toEqual(true)
  })
})
