export const DEFAULT_SEED_URL = 'https://www.nytimes.com/ads.txt'
/**
 * Promise to determine if user currently has ad block enabled.
 * For now this is using a default seed but we may want to pass in an alternative seed or list of seeds.
 * We will call seed url and await headers (this comes much faster than waiting for a whole file to complete),
 * if our header load is successful, we can assume the user does not have ad blockers enabled.
 * This however, may change in the future if /ads.txt is added to a white list
 */
const hasAdBlock = (): Promise<boolean> => {
  return new Promise((resolve, reject) => {
    const client = new XMLHttpRequest()
    client.open('HEAD', DEFAULT_SEED_URL, true)

    client.onreadystatechange = () => {
      if (client.readyState === client.HEADERS_RECEIVED) {
        client.abort()
        resolve(false)
      }
    }

    client.onerror = (evt) => {
      resolve(true)
    }

    client.send()
  })
}
export default hasAdBlock
