import { useEffect, useState } from 'react'

import { EventData } from 'shared/foundation/js/ads/adTracking/constants'

import shouldShowAd from './shouldShowAd'
import hasAdBlock from './hasAdBlock'

const useAd = () => {
  const couldHaveAd = shouldShowAd()
  const [height, setHeight] = useState(0)
  const [hasAd, setHasAd] = useState(true)
  const [hasAdError, setHasAdError] = useState(false)
  const [subscribed, setSubscribed] = useState(false)
  const [pageScrollable, setPageScrollable] = useState(false)

  useEffect(() => {
    hasAdBlock().then((isBlocked) => {
      setHasAdError(isBlocked)
      setHasAd(!isBlocked)
    })
  }, [])
  const addBodyClass = () => {
    if (
      document &&
      !document.body.classList.contains('scrollable') &&
      hasAd
    ) {
      document.body.classList.add('scrollable')
      setPageScrollable(true)
    } else if (!hasAd) {
      document.body.classList.remove('scrollable')
      setPageScrollable(false)
    }
  }
  useEffect(() => {
    addBodyClass()
  }, [hasAd])
  useEffect(() => {
    if (!couldHaveAd || subscribed) {
      return
    }

    const onAdFailure =
      (failureType: number) => (param: EventData) => {
        const { slot, id, type, isEmpty } = param
        if (failureType === 0 || isEmpty) {
          setHasAd(false)
          setHasAdError(true)
        }
      }

    const onEvent = (evt: string) => (param: EventData) => {
      const { slot, id, type } = param
      const queryId = (id || (slot && slot.getSlotElementId())) ?? ''
      if (id || slot) {
        const element = document.getElementById(queryId)

        const { height: elementHeight = 0 } =
          element?.getBoundingClientRect?.() || {}

        if (elementHeight > height || evt === 'AdEmpty') {
          // for some reason the game tiles don't resize so we need to set twice for now
          setHeight(elementHeight - 1)
          setHeight(elementHeight)
        }
        setHasAd(evt !== 'AdEmpty')
      }
    }
    let subs: Array<{ remove: () => void } | undefined> = []
    if (window.AdSlot4 && couldHaveAd) {
      setSubscribed(true)
      window.AdSlot4.cmd.push(() => {
        const PubSub = window?.AdSlot4?.events
        subs = [
          PubSub?.subscribe({
            name: 'script_loader_error',
            callback: onAdFailure(0),
            scope: 'all',
          }),
          PubSub?.subscribe({
            name: 'BidderError',
            callback: onAdFailure(0),
            scope: 'all',
          }),
          PubSub?.subscribe({
            name: 'AdEmpty',
            callback: onAdFailure(1),
            scope: 'all',
          }),
          PubSub?.subscribe({
            name: 'AdEnteredViewport',
            callback: onEvent('AdEnteredViewport'),
            scope: 'all',
          }),
          PubSub?.subscribe({
            name: 'AdViewable',
            callback: onEvent('AdViewable'),
            scope: 'all',
          }),
          PubSub?.subscribe({
            name: 'AdRefreshed',
            callback: onEvent('AdRefreshed'),
            scope: 'all',
          }),
        ]
      })
    }

    return () => {
      while (subs.length) {
        subs.pop()?.remove()
      }
    }
  }, [couldHaveAd, hasAd])
  return {
    height,
    hasAd,
    couldHaveAd,
    hasAdError,
    pageScrollable,
  }
}
export default useAd
