import React from 'react'
import classNames from 'classnames'

import getMessage from './getMessage'
import getButton from './getButton'
import styles from './Skip.module.scss'

/**
 *
 * @param {number} timeUntilEnabled
 * @param {function} onClick
 * @constructor
 */
const SkipButton = ({
  timeUntilEnabled,
  onClick,
}: {
  timeUntilEnabled: number
  onClick: () => void
}) => {
  // clean up number just in case we get negative or decimal
  const cleanTime = Math.round(Math.max(0, timeUntilEnabled))
  const btnClassNames = classNames(styles.skipButton)
  return (
    <div
      className={btnClassNames}
      role="button"
      onClick={cleanTime ? undefined : onClick}
      onKeyDown={cleanTime ? undefined : onClick}
      tabIndex={0}
    >
      {getMessage()}
      {getButton(cleanTime)}
    </div>
  )
}

export default SkipButton
