import React from 'react'

import { useUser } from 'user'

import AdInterstitial from '.'

import type {
  MomentComponentProps,
  WordleMoments,
} from '../Moment/wordleMomentConfig'
import { useWordleSelector } from '../../store/types'
import { selectGameStatus } from '../../store/game/game.selectors'
import { useStatsSelectionTool } from '../StatsSelectionTool/useStatsSelectionTool'

import shouldShow from './utils/shouldShow'

export const AdIntersitialMoment = ({
  transition,
  hasLoaded,
}: MomentComponentProps<WordleMoments>) => {
  const showStatsSelection = useStatsSelectionTool(hasLoaded)
  const nextMoment = showStatsSelection ? 'statsSelection' : 'game'

  return (
    <AdInterstitial
      id="intsl"
      position="intsl"
      onClose={() => transition(nextMoment)}
    />
  )
}

export const useShowAdInterstitial = () => {
  const { hasLoaded: hasUserLoaded, userType } = useUser()
  const gameStatus = useWordleSelector(selectGameStatus)

  return (
    hasUserLoaded && // guaranteed to be true past WelcomeLoading, but keep the check just in case
    !userType.hasXwd && // non-subs only
    shouldShow(gameStatus) // game in progress, mobile web
  )
}
