import React, { useEffect, useRef } from 'react'
import classNames from 'classnames'

import { useUser } from 'user'

import PageViewId from '../../../../../shared/foundation/js/utils/pageViewId'

import useAdEvents from './useAdEvents'
import Skip from './Skip'
import trackSkip from './utils/trackSkip'
import styles from './AdInterstitial.module.scss'
import checkAdSlotKVP from './utils/checkAdSlotKVP'

const AdInterstitial = ({
  id,
  position,
  className,
  adClassName,
  onClose,
}: {
  id: string
  position: string
  className?: string
  adClassName?: string
  onClose: () => void
}) => {
  const { isFluid, hasIntAdError, hasIntAd, isAdReady } =
    useAdEvents()
  const { userType } = useUser()
  const adRef = useRef<HTMLDivElement>(null)
  const callAd = () => {
    const adUnitPath = `${window?.AdSlot4?.props?.adUnitPath}/special`
    window?.AdSlot4?.initializeAd?.(adRef.current as HTMLDivElement, {
      id,
      position,
      adUnitPath,
    })
  }
  useEffect(() => {
    checkAdSlotKVP('sub', userType.entitlement)
    checkAdSlotKVP('page_view_id', PageViewId.current)
    if (!window?.AdSlot4?.props?.adUnitPath) {
      window.AdSlot4?.events.subscribe({
        name: 'AdSlotReady',
        scope: 'all',
        callback: callAd,
      })
    } else {
      callAd()
    }
  }, [])
  const handleSkipClick = () => {
    onClose()
    trackSkip()
  }
  useEffect(() => {
    if (hasIntAdError) {
      onClose()
    }
  }, [hasIntAdError])
  /*
    adding in ad label for usage later on
   */
  const interstitialClassName = classNames(
    styles.modalOverlay,
    { [styles.interstitialPlaceholder]: !isAdReady },
    className,
  )

  const adSlugClassName = classNames(styles.adSlug, {
    [styles.adSlugVisible]: isAdReady,
  })

  const adContainerClassName = classNames(styles.ad, adClassName, {
    [styles.fluid]: isFluid,
  })

  return (
    <dialog className={interstitialClassName}>
      <div className={adSlugClassName}>
        {isAdReady && <h3>advertisement</h3>}
        <div
          ref={adRef}
          className={adContainerClassName}
          id={id}
          data-position={position}
        />
      </div>
      <Skip onClick={handleSkipClick} timeUntilEnabled={0} />
    </dialog>
  )
}

export default AdInterstitial
