import isInInterstitialVariant, {
  WORDLE_MOBILE_WEB_TEST_NAME,
  WORDLE_MOBILE_WEB_TEST_VARIANT_1,
} from '../isInInterstitialVariant'

describe('isInInterstitialVariant', () => {
  afterEach(() => {
    jest.restoreAllMocks()
  })
  it('returns false if no variant', () => {
    jest.spyOn(require('foundation'), 'abra', 'get').mockReturnValue({
      getVariant: () => undefined,
    })
    expect(isInInterstitialVariant()).toEqual(false)
  })
  it('returns false if variant is not expected variant', () => {
    jest.spyOn(require('foundation'), 'abra', 'get').mockReturnValue({
      getVariant: () => '0_Control',
      reportExposure: jest.fn(),
    })
    expect(isInInterstitialVariant()).toEqual(false)
  })
  it('calls reportExposure with expected value if variant is truthy', () => {
    const reportExposureSpy = jest.fn()
    jest.spyOn(require('foundation'), 'abra', 'get').mockReturnValue({
      getVariant: () => WORDLE_MOBILE_WEB_TEST_VARIANT_1,
      reportExposure: reportExposureSpy,
    })
    isInInterstitialVariant()
    expect(reportExposureSpy).toHaveBeenCalledWith(
      WORDLE_MOBILE_WEB_TEST_NAME,
    )
  })
  it('returns true if variant is expected variant', () => {
    jest.spyOn(require('foundation'), 'abra', 'get').mockReturnValue({
      getVariant: () => WORDLE_MOBILE_WEB_TEST_VARIANT_1,
      reportExposure: jest.fn(),
    })
    expect(isInInterstitialVariant()).toEqual(true)
  })
})
