import * as isInInterstitialVariant from '../isInInterstitialVariant'
import * as isPhone from '../isPhone'
import shouldShow from '../shouldShow'

describe('shouldShow', () => {
  beforeEach(() => {
    jest
      .spyOn(isInInterstitialVariant, 'default')
      .mockReturnValue(true)
    jest.spyOn(isPhone, 'default').mockReturnValue(true)
    jest
      .spyOn(
        require('../../../../../../../shared/utils/deviceIdentifiers'),
        'isInNewsreader',
      )
      .mockReturnValue(false)
    jest
      .spyOn(
        require('../../../../../../../shared/utils/deviceIdentifiers'),
        'isHybridWebView',
      )
      .mockReturnValue(false)
  })
  afterEach(() => {
    jest.restoreAllMocks()
  })

  it('returns true if all conditions are met', () => {
    expect(shouldShow('IN_PROGRESS')).toEqual(true)
  })
  it('returns false if the user has won', () => {
    expect(shouldShow('WIN')).toEqual(false)
  })
  it('returns false if the user has lost', () => {
    expect(shouldShow('FAIL')).toEqual(false)
  })
  it('returns false if no game status is provided', () => {
    // @ts-ignore for testing purposes
    expect(shouldShow()).toEqual(false)
  })
  it('returns false if is in hybrid web view', () => {
    jest
      .spyOn(
        require('../../../../../../../shared/utils/deviceIdentifiers'),
        'isHybridWebView',
      )
      .mockReturnValue(true)
    expect(shouldShow('IN_PROGRESS')).toEqual(false)
  })
  it('returns false if is in news reader', () => {
    jest
      .spyOn(
        require('../../../../../../../shared/utils/deviceIdentifiers'),
        'isInNewsreader',
      )
      .mockReturnValue(true)
    expect(shouldShow('IN_PROGRESS')).toEqual(false)
  })
  it('returns false if device is not a phone', () => {
    jest.spyOn(isPhone, 'default').mockReturnValue(false)
    expect(shouldShow('IN_PROGRESS')).toEqual(false)
  })
  it('returns false if user not in interstitial abra variant', () => {
    jest
      .spyOn(isInInterstitialVariant, 'default')
      .mockReturnValue(false)
    expect(shouldShow('IN_PROGRESS')).toEqual(false)
  })
})
