import { useEffect } from 'react'

import {
  BridgeListener,
  BridgeListenerResponse,
  EVENT_ON_NAVIGATE_BACK,
} from '../../../../../shared/foundation/js/hybrid/commands'
import {
  closeModal,
  closePage,
} from '../../store/overlays/overlays.actions'
import {
  selectModal,
  selectPage,
} from '../../store/overlays/overlays.selectors'
import {
  useWordleDispatch,
  useWordleSelector,
} from '../../store/types'

// in hybrid, respond android's physical back button
export const useAndroidBack = () => {
  const modal = useWordleSelector(selectModal)
  const page = useWordleSelector(selectPage)
  const dispatch = useWordleDispatch()

  useEffect(() => {
    if (window.isHybridWebView && window.NativeBridge) {
      // if a modal or page is open, close it
      // otherwise, tell the android app to navigate back from wordle
      const navigateBack: BridgeListener = (event) => {
        const response: BridgeListenerResponse = {}
        if (modal || page) {
          dispatch(closeModal())
          dispatch(closePage())
          response[EVENT_ON_NAVIGATE_BACK] = true
          event.respondWith(response)
        } else {
          response[EVENT_ON_NAVIGATE_BACK] = false
          event.respondWith(response)
        }
      }

      window.NativeBridge.addEventListener(
        EVENT_ON_NAVIGATE_BACK,
        navigateBack,
      )

      return () => {
        window.NativeBridge?.removeEventListener(
          EVENT_ON_NAVIGATE_BACK,
          navigateBack,
        )
      }
    }
  }, [modal, page, dispatch])
}
