import React from 'react'
import { Provider } from 'react-redux'
import { render, screen } from '@testing-library/react'

import { openError } from '../../store/overlays/overlays.actions'
import createStore from '../../store'

import Error from './Error'

jest.mock('foundation', () => ({
  env: { version: 'test' },
}))

describe('<Error />', () => {
  const renderError = () => {
    const store = createStore()

    const board = render(
      <Provider store={store}>
        <Error />
      </Provider>,
    )

    return store
  }

  it('should be closed by default', () => {
    renderError()
    expect(screen.queryByRole('dialog')).toBeFalsy()
  })

  it('should open the default error page', () => {
    const store = renderError()
    store.dispatch(openError('default'))
    expect(screen.queryByRole('dialog')).toBeTruthy()
    expect(
      screen.queryByText('something went wrong', { exact: false }),
    ).toBeTruthy()
  })

  it('should open the offline error page', () => {
    const store = renderError()
    store.dispatch(openError('offline'))
    expect(screen.queryByRole('dialog')).toBeTruthy()
    expect(
      screen.queryByText('offline', { exact: false }),
    ).toBeTruthy()
  })

  it('should show the back button if user was referred internally', () => {
    Object.defineProperty(document, 'referrer', {
      value: 'nytimes.com',
      configurable: true,
    })
    const store = renderError()
    store.dispatch(openError('default'))
    expect(screen.queryByText('Back')).toBeTruthy()
    expect(screen.queryByText('Reload')).toBeFalsy()
  })

  it('should not show the back button if user was referred externally', () => {
    Object.defineProperty(document, 'referrer', {
      value: 'google.com',
      configurable: true,
    })
    const store = renderError()
    store.dispatch(openError('default'))
    expect(screen.queryByText('Back')).toBeFalsy()
    expect(screen.queryByText('Reload')).toBeFalsy()
  })

  it('should not show the back button if the error is a profile error', () => {
    Object.defineProperty(document, 'referrer', {
      value: 'nytimes.com',
      configurable: true,
    })
    const store = renderError()
    store.dispatch(openError('profile'))
    expect(screen.queryByText('Back')).toBeFalsy()
    expect(screen.queryByText('Reload')).toBeTruthy()
  })
})
