import React from 'react'

import { navigateBack } from '../../../../helpers/navigateBack'
import {
  useWordleDispatch,
  useWordleSelector,
} from '../../store/types'
import { selectError } from '../../store/overlays/overlays.selectors'
import { trackAuthClick } from '../../store/overlays/overlays.actions'

import styles from './Error.module.scss'

const ErrorTiles = ({ text = 'error' }: { text?: string }) => (
  <div className={styles.errorTilesContainer}>
    {text.split('').map((letter, i) => (
      <div className={styles.errorTiles} key={`${i}-${letter}`}>
        {letter}
      </div>
    ))}
  </div>
)

const OfflineMessage = () => (
  <div className={styles.errorText}>
    You&rsquo;re offline.
    <br />
    Find a connection and come back.
  </div>
)

const DefaultMessage = () => (
  <div className={styles.errorText}>
    Oops, something went wrong.
    <br />
    Please try again later.
  </div>
)

export default function Error() {
  // Only show the "Back" button if user was referred internally
  const errorType = useWordleSelector(selectError)
  const profileError = errorType === 'profile'
  const isHybrid = window.isHybridWebView
  const showCTA =
    document.referrer.includes('nytimes') && !profileError
  const dispatch = useWordleDispatch()
  if (!errorType) return null

  const errorOptions = {
    offline: {
      tiles: <ErrorTiles text="yikes" />,
      content: <OfflineMessage />,
    },
    default: {
      tiles: <ErrorTiles />,
      content: <DefaultMessage />,
    },
    profile: {
      tiles: <ErrorTiles />,
      content: <DefaultMessage />,
    },
  }

  const profileButton = (
    <button
      className={styles.backButton}
      type="button"
      onClick={() => {
        dispatch(
          trackAuthClick('', false, {
            label: 'stats-link-error',
            name: 'wordle',
          }),
        )
        if (!isHybrid) {
          document.location.reload()
        } else {
          navigateBack()
        }
      }}
    >
      {!isHybrid ? 'Reload' : 'Back'}
    </button>
  )

  const { tiles, content } = errorOptions[errorType]

  return (
    <div className={styles.container} role="dialog">
      <div className={styles.errorContainer}>
        {tiles}
        {content}
        {showCTA && (
          <button
            className={styles.backButton}
            type="button"
            data-testid="back"
            onClick={() => {
              if (errorType === 'offline') {
                dispatch(trackAuthClick('stats-link-offline', false))
              }
              navigateBack()
            }}
          >
            Back
          </button>
        )}
        {profileError && profileButton}
      </div>
    </div>
  )
}
