import React from 'react'

import LoginCTA from '../LoginLink/LoginCTA'

import { explainerContent } from './explainerContent'
import styles from './Explainer.module.scss'

type ExplainerProps = {
  type: 'linkInfo' | 'statsProblem'
  loggedIn?: boolean
  closeButton: () => JSX.Element
  trackExplainerClick: (label: string) => void
}

export default function Explainer({
  type,
  loggedIn = false,
  closeButton,
  trackExplainerClick,
}: ExplainerProps) {
  const {
    getText,
    title,
    icon,
    alt,
    text2 = '',
  } = explainerContent[type]

  const paragraphs = getText(loggedIn)

  const showFooterText = !!text2 && !loggedIn
  const container =
    type === 'linkInfo'
      ? styles.containerLink
      : styles.containerProblems

  return (
    <>
      <div className={styles.headerNew}>
        <p>
          <img
            className={styles.gamesIcon}
            alt="NYT Games Logo"
            style={{ content: `${'var(--gameslogo)'}` }}
          />
        </p>
        {closeButton()}
      </div>
      <div className={container}>
        <img alt={alt} style={{ content: icon }} />
        <h2 className={styles.title}>{title}</h2>
        <div>
          {paragraphs.map((paragraph, index) => (
            <p
              key={index}
              className={styles.text}
              dangerouslySetInnerHTML={{ __html: paragraph }}
            />
          ))}
        </div>
        <div className={styles.statsLinkContainer}>
          <a
            className={styles.helpButton}
            href="https://help.nytimes.com/hc/en-us/articles/360029050872-Word-Games-and-Logic-Puzzles#h_01FVGCB2Z00ZQMDMCYWBPWJNXB"
            target="_blank"
            rel="noopener noreferrer"
            onClick={() =>
              trackExplainerClick(`help-center-broken-stats`)
            }
          >
            Visit the Help Center
          </a>
          {!loggedIn && (
            <LoginCTA
              styles={styles.loginButton}
              trackEvent={{
                eventName: '',
                sendContext: false,
                element: {
                  label: 'log-in-broken-stats',
                  name: 'wordle',
                },
              }}
            >
              Log in or create a free account
            </LoginCTA>
          )}
        </div>
      </div>
      {showFooterText && (
        <p
          className={styles.explainerFooterText}
          dangerouslySetInnerHTML={{ __html: text2 }}
        />
      )}
    </>
  )
}
