type content = {
  title: string
  getText: (loggedIn?: boolean, optedIn?: boolean) => string[]
  text2?: string
  icon: string
  alt: string
}

type explainerContentType = {
  [key: string]: content
}

export const explainerContent: explainerContentType = {
  linkInfo: {
    title:
      'You can now link your Wordle stats to a free New York Times account.',
    getText: () => [
      'Wordle stats are currently saved locally in the browser where you play, which means different devices may save different stats.',
      'If the browser memory is cleared, your stats will be lost.',
      "Linking your stats to a free account means keeping your streak and stats anywhere you're logged in.",
    ],
    text2:
      '<b>You can continue to play Wordle without an account,</b> but your stats will not appear across devices and may reset if the browser data is cleared.',
    icon: 'var(--link-info)',
    alt: 'Wordle Icon with NYT Logo',
  },
  statsProblem: {
    title: "Something doesn't look right.",
    getText: (loggedIn) => {
      // user is logged out
      if (!loggedIn) {
        return [
          'Experiencing a problem? By default, Wordle saves your stats and game progress to your device or browser. You can also link your data to a New York Times account so your data is available anywhere.',
          '<b>If your data is incorrect,</b> you may need to log in to your New York Times account. If you do not have an account, you may have played on a different device or browser today, or someone else may have played on the device or browser you are currently using.',
          'For more information about playing Wordle, visit our <a target="_blank" href="https://help.nytimes.com/hc/en-us/articles/360029050872-Word-Games-and-Logic-Puzzles#h_01FVGCB2Z00ZQMDMCYWBPWJNXB">Help Center</a> for assistance.',
        ]
      }

      // user is logged in
      return [
        'Experiencing a problem? Wordle currently saves your stats and game progress to your New York Times account.',
        '<b>If your data is incorrect,</b> make sure you are logged in to the correct account. If you share your account, you may be seeing game data from another user of your account.',
        'For more information about playing Wordle, visit our <a target="_blank" href="https://help.nytimes.com/hc/en-us/articles/360029050872-Word-Games-and-Logic-Puzzles#h_01FVGCB2Z00ZQMDMCYWBPWJNXB">Help Center</a> for assistance.',
      ]
    },
    icon: 'var(--stats-problem)',
    alt: 'Wordle Icon with Question Mark',
  },
}
