import React from 'react'
import { render, screen } from '@testing-library/react'
import { Provider } from 'react-redux'

import createStore from '../../store'

import FeedbackLink from './FeedbackLink'

jest.mock('user', () => ({
  useUser: () => ({ userType: { regiId: 123, entitlement: 'sub' } }),
}))

describe('Feedback Link', () => {
  const renderFeedbackLink = ({
    description,
    subject,
  }: {
    description?: string
    subject?: string
  }) => {
    const store = createStore()

    return render(
      <Provider store={store}>
        <FeedbackLink description={description} subject={subject}>
          Email
        </FeedbackLink>
      </Provider>,
    )
  }

  it('renders a link with the expected default title and aria label', () => {
    renderFeedbackLink({})

    const title = screen.getByTitle(
      'Send feedback to nytgames@nytimes.com',
    )

    expect(title).toBeTruthy()
  })

  it('renders a link with the expected custom title', () => {
    renderFeedbackLink({ description: 'Send bug report' })

    const title = screen.getByTitle('Send bug report')

    expect(title).toBeTruthy()
  })

  it('handles hybrid links through onClick instead of href', () => {
    // @ts-ignore
    window.NativeBridge = {}
    // @ts-ignore
    window.isHybridWebView = true

    renderFeedbackLink({})
    const href = screen
      .getByTitle('Send feedback to nytgames@nytimes.com')
      .getAttribute('href')

    expect(href).toBeFalsy()
  })
})
