import React, { ReactElement } from 'react'

import { SEND_EMAIL_TYPE } from 'foundation'
import { useUser } from 'user'

import { getFeedbackLink, feedbackHybrid } from '../../utils/feedback'
import { useWordleSelector } from '../../store/types'

type FeedbackLinkProps = {
  children: ReactElement | string
  description?: string
  styles?: string
  subject?: string
  destination?: string
  type?: SEND_EMAIL_TYPE
  tracking?: () => void
}

export default function FeedbackLink({
  children,
  description = 'Send feedback to nytgames@nytimes.com',
  styles,
  subject,
  destination,
  type,
  tracking,
}: FeedbackLinkProps) {
  const { userType } = useUser()
  const { regiId, entitlement } = userType || {}
  const autoOptIn = useWordleSelector(
    (state) => !!state.persist.stats.autoOptInTimestamp,
  )

  const isHybrid = window.isHybridWebView && window.NativeBridge
  const feedbackLink = !isHybrid
    ? getFeedbackLink({
        emailSubject: subject,
        entitlement,
        regiId,
        autoOptIn,
      })
    : undefined

  return (
    <a
      className={styles}
      href={feedbackLink}
      tabIndex={0}
      title={description}
      onClick={(e) => {
        if (tracking) {
          tracking()
        }

        if (isHybrid) {
          e.preventDefault()
          feedbackHybrid({
            regiId,
            type,
            emailTitle: subject,
            emailDestination: destination,
            autoOptIn,
          })
        }
      }}
    >
      {children}
    </a>
  )
}
