import React from 'react'
import { Provider } from 'react-redux'
import { render, screen, fireEvent } from '@testing-library/react'

import createStore from '../../store'
import { openModal } from '../../store/overlays/overlays.actions'

import HardModeAwareness from './HardModeAwareness'
import styles from './HardModeAwareness.module.scss'

jest.mock('../../../../../shared/abra/useFeatureFlag', () =>
  jest.fn(),
)

describe('Hard Mode Awareness', () => {
  const renderModal = () => {
    const store = createStore()
    store.dispatch = jest.fn()

    const modal = render(
      <Provider store={store}>
        <HardModeAwareness />,
      </Provider>,
    )

    return { modal, store }
  }

  it('should render modal with text and a button that opens settings', () => {
    const { store } = renderModal()
    const instructions = document.querySelector(
      `.${styles.instructions}`,
    )
    const button = screen.getByRole('button')

    expect(instructions?.textContent).toContain('Hard Mode')
    expect(button.textContent).toContain('Settings')
    fireEvent.click(button)
    expect(store.dispatch).toHaveBeenCalledWith(openModal('settings'))
  })
})
