import React from 'react'

import { trackClick, trackImpression } from 'foundation'

import Icon from '../Icon/Icon'
import {
  useWordleDispatch,
  useWordleSelector,
} from '../../store/types'
import { openModal } from '../../store/overlays/overlays.actions'
import { selectGameDayOffset } from '../../store/game/game.selectors'

import styles from './HardModeAwareness.module.scss'

export default function HardModeAwareness() {
  const dispatch = useWordleDispatch()

  const gameDayOffset = useWordleSelector(selectGameDayOffset)

  React.useEffect(() => {
    trackImpression(
      'tool-tip',
      'wordle',
      'hard-mode',
      `${gameDayOffset}`,
    )
  }, [])

  return (
    <div className={styles.hardModeText}>
      <p className={styles.instructions}>
        For an extra challenge, turn on Hard Mode.
      </p>
      <button
        type="button"
        className={styles.settingsButton}
        onClick={() => {
          trackClick({
            element: { name: 'wordle', label: 'settings' },
            region: 'tool-tip',
            context: gameDayOffset,
            useBeacon: true,
          })
          dispatch(openModal('settings'))
        }}
      >
        Go to Settings
        <Icon icon="settings" />
      </button>
    </div>
  )

  return null
}
