import React from 'react'
import { Provider } from 'react-redux'
import {
  render,
  fireEvent,
  act,
  screen,
  waitFor,
} from '@testing-library/react'

import createStore from '../../store'
import tileStyles from '../Tile/Tile.module.scss'

import Help from './Help'
import styles from './Help.module.scss'

jest.mock('foundation', () => ({
  env: { version: 'test' },
}))

describe('Help', () => {
  beforeAll(() => jest.useFakeTimers())
  afterAll(() => jest.useRealTimers())
  const renderHelp = () => {
    const store = createStore()

    render(
      <Provider store={store}>
        <Help />,
      </Provider>,
    )
  }

  it('renders three examples', () => {
    renderHelp()
    const weary = screen.getByLabelText('weary')
    const pills = screen.getByLabelText('pills')
    const vague = screen.getByLabelText('vague')

    expect(weary).toBeTruthy()
    expect(pills).toBeTruthy()
    expect(vague).toBeTruthy()
  })

  it('can be styled as a modal', () => {
    renderHelp()
    const page = document.querySelector(`.${styles.page}`)

    expect(page).toBeFalsy()
  })

  it('renders a Tile for each letter in a helpWord', () => {
    renderHelp()
    const tiles = screen.getAllByTestId('weary-letter')
    expect(tiles).toHaveLength(5)
  })

  it('renders Tile aria-label correctly on render and animation end', async () => {
    await act(async () => {
      renderHelp()
      jest.advanceTimersByTime(101)
      const tileDiv = screen.getByLabelText('1st letter, W')

      await waitFor(() => {
        expect(tileDiv.getAttribute('data-animation')).toEqual(
          'flip-in',
        )
      })

      fireEvent.animationEnd(tileDiv, {
        animationName: tileStyles.FlipIn,
      })

      await waitFor(() => {
        expect(tileDiv.getAttribute('data-state')).toEqual('correct')
        expect(tileDiv?.getAttribute('aria-label')).toEqual(
          '1st letter, W, correct',
        )
      })
    })
  })

  it('does not render login section on default', () => {
    renderHelp()
    expect(
      document.querySelector(`.${styles.statsLogin}`),
    ).toBeTruthy()
  })
})
