import React from 'react'

import * as SVG_PATHS from './iconPathSvgs'
import useResponsiveIcon from './useResponsiveIcon'

const icons = {
  help: SVG_PATHS.HELP,
  settings: SVG_PATHS.SETTINGS,
  backspace: SVG_PATHS.BACKSPACE,
  close: SVG_PATHS.CLOSE,
  share: SVG_PATHS.SHARE,
  statistics: SVG_PATHS.STATISTICS,
}

type IconProps = {
  icon:
    | 'help'
    | 'settings'
    | 'backspace'
    | 'close'
    | 'share'
    | 'statistics'
  disabled?: boolean
  onClick?: () => void
  id?: string
  fillColor?: string
}

export default function Icon({
  icon,
  onClick,
  disabled = false,
  id,
  fillColor,
}: IconProps) {
  const fill = () => {
    if (fillColor) return fillColor

    if (disabled) return 'var(--icon-disabled)'

    if (icon === 'share') {
      return 'var(--white)'
    }

    return 'var(--color-tone-1)'
  }

  // For icons in the header that change size based on viewport
  const svgProps = useResponsiveIcon(icon)

  return (
    <svg
      id={id}
      aria-hidden="true"
      xmlns="http://www.w3.org/2000/svg"
      height={svgProps.height}
      viewBox={svgProps.viewBox}
      width={svgProps.width}
      className="game-icon"
      onClick={onClick}
      data-testid={`icon-${icon}`}
    >
      <path fill={fill()} d={icons[icon]} />
    </svg>
  )
}
