import { useEffect, useState } from 'react'

/**
 * Props set by useResponsiveIcon to change the size and viewbox of the header icons
 */
export type SvgProps = {
  width: string
  height: string
  viewBox: string
}

const nonResponsiveSvgProps: SvgProps = {
  width: '20',
  height: '20',
  viewBox: '0 0 24 24',
}

const phoneHeaderSvgProps: SvgProps = {
  width: '24',
  height: '24',
  viewBox: '4 4 24 24',
}

const tabletHeaderSvgProps: SvgProps = {
  width: '28',
  height: '28',
  viewBox: '4 4 24 24',
}

/**
 * Given an icon type, will attach event listeners to the dom to resize the svg based on viewport
 */
export default (
  icon:
    | 'help'
    | 'settings'
    | 'backspace'
    | 'close'
    | 'share'
    | 'statistics',
) => {
  const [svgProps, setSvgProps] = useState<SvgProps>(
    phoneHeaderSvgProps,
  )

  const isResponsiveIcon =
    icon === 'help' || icon === 'statistics' || icon === 'settings'

  useEffect(() => {
    function determineHeaderSvgProps() {
      let props = phoneHeaderSvgProps

      if (window.matchMedia('(min-width: 768px)').matches) {
        props = tabletHeaderSvgProps
      }

      setSvgProps(props)
    }

    if (isResponsiveIcon) {
      determineHeaderSvgProps()
      window.addEventListener('resize', determineHeaderSvgProps)
    } else {
      setSvgProps(nonResponsiveSvgProps)
    }

    return () => {
      if (isResponsiveIcon) {
        window.removeEventListener('resize', determineHeaderSvgProps)
      }
    }
  }, [])

  return svgProps
}
