import React from 'react'
import { Provider } from 'react-redux'
import { render, screen } from '@testing-library/react'

import useScreenSizeWarning from '../../../../shared/hooks/use-screen-size-warning'
import createStore from '../../store'

import LandscapeWarning from './LandscapeWarning'

jest.mock('../../../../shared/hooks/use-screen-size-warning', () => ({
  __esModule: true,
  ...jest.requireActual(
    '../../../../shared/hooks/use-screen-size-warning',
  ),
  default: jest.fn(() => true),
}))

describe('<LandscapeWarning />', () => {
  // @ts-ignore
  beforeAll(() => useScreenSizeWarning.mockImplementation(() => true))
  const renderLandscapeWarning = () => {
    const store = createStore()
    store.dispatch = jest.fn()

    render(
      <Provider store={store}>
        <LandscapeWarning />
      </Provider>,
    )

    return { store }
  }

  it('should return null for appropriate screen sizes', () => {
    // @ts-ignore
    useScreenSizeWarning.mockImplementation(() => false)
    renderLandscapeWarning()

    expect(screen.queryByTestId('landscape-warning')).toBeNull()
  })

  it('should render a landscape warning for screens that are too small', () => {
    // @ts-ignore
    useScreenSizeWarning.mockImplementation(() => true)

    renderLandscapeWarning()
    expect(screen.queryByTestId('landscape-warning')).toBeTruthy()
  })
})
