import React from 'react'
import cn from 'classnames'

import useScreenSizeWarning, {
  CheckScreenSize,
} from '../../../../shared/hooks/use-screen-size-warning'
import { useWordleSelector } from '../../store/types'
import { selectDarkMode } from '../../store/settings/settings.selectors'

import styles from './LandscapeWarning.module.scss'

const checkScreenSize: CheckScreenSize = ({
  winHeight,
  winWidth,
}) => {
  const aspectRatio = winWidth / winHeight
  const flatTablet = winHeight <= 650 && aspectRatio > 1.8
  const tinyPhone = winHeight < 400 && aspectRatio > 1

  return flatTablet || tinyPhone
}

const LandscapeWarning = () => {
  const showScreenSizeWarning = useScreenSizeWarning(checkScreenSize)
  const darkMode = useWordleSelector(selectDarkMode)

  if (!showScreenSizeWarning) return null

  return (
    <>
      <div
        data-testid="landscape-warning"
        className={cn(
          styles.landscapeWarning,
          darkMode ? styles.darkMode : '',
        )}
      >
        <i className={styles.rotate} />
        <p>
          Oh no! We can’t fit everything on your screen.
          <br />
          <span>Please rotate your device.</span>
        </p>
      </div>
    </>
  )
}

export default LandscapeWarning
