import React from 'react'
import { Provider } from 'react-redux'
import { act, render, screen, waitFor } from '@testing-library/react'

import createStore from '../../store'

import Loading from './Loading'

jest.mock('foundation', () => ({
  env: { version: 'test' },
}))

describe('<Loading />', () => {
  beforeAll(() => jest.useFakeTimers())
  afterAll(() => jest.useRealTimers())
  const renderLoading = () => {
    const store = createStore()
    store.dispatch = jest.fn()

    render(
      <Provider store={store}>
        <Loading />
      </Provider>,
    )

    return { store }
  }

  it('should render spinner after 300 seconds', async () => {
    await act(async () => {
      renderLoading()

      expect(screen.queryByTestId('spinner')).toBeNull()
      jest.advanceTimersByTime(301)
      await waitFor(() => {
        expect(screen.findByTestId('spinner')).toBeTruthy()
      })
    })
  })
})
