import React from 'react'

import { useWordleSelector } from '../../store/types'
import { selectDarkMode } from '../../store/settings/settings.selectors'
import useTimeout from '../../../../shared/hooks/use-timeout'

import styles from './Loading.module.scss'
import Spinner from './Spinner'

const WAIT_FOR = 300

type LoadingProps = {
  // allowing these to be optionally dynamic for Storybook purposes
  waitFor?: number
  setBackground?: 'light' | 'dark'
}

export default function Loading({
  waitFor = WAIT_FOR,
  setBackground = 'dark',
}: LoadingProps) {
  const [showSpinner, setShowSpinner] = React.useState<boolean>(false)
  const darkMode = useWordleSelector(selectDarkMode)
  const useDarkMode = setBackground !== 'light' && darkMode
  const backgroundColor = useDarkMode ? '#121213' : '#FFF'

  useTimeout(() => setShowSpinner(true), waitFor)

  if (!showSpinner) return null

  return (
    <div
      className={styles.container}
      style={backgroundColor ? { backgroundColor } : {}}
      data-testid="loading"
    >
      <div className={styles.loadingContainer}>
        <Spinner
          circleColor={useDarkMode ? '#666666' : '#DFDFDF'}
          barColor={useDarkMode ? '#DFDFDF' : '#959595'}
        />
      </div>
    </div>
  )
}
