import React from 'react'
import { Provider } from 'react-redux'
import { render, screen } from '@testing-library/react'

import createStore from '../../store'

import Spinner from './Spinner'

jest.mock('foundation', () => ({
  env: { version: 'test' },
}))

describe('<Spinner />', () => {
  type SpinnerProps = {
    circleColor?: string
    barColor?: string
  }
  const renderSpinner = (props: SpinnerProps) => {
    const store = createStore()

    return render(
      <Provider store={store}>
        <Spinner {...props} />
      </Provider>,
    )
  }

  it('should show passed in elements', () => {
    const props = { circleColor: '#666666', barColor: '#959595' }

    renderSpinner(props)

    expect(screen.queryByTestId('spinner')).toBeTruthy()

    const children = screen.queryByTestId('spinner')?.children
    expect(
      // @ts-ignore
      children[0].getAttribute('stroke'),
    ).toEqual('#666666')
    expect(
      // @ts-ignore
      children[1].getAttribute('fill'),
    ).toEqual('#959595')
  })

  it('should show light mode as default props', () => {
    renderSpinner({})

    expect(screen.queryByTestId('spinner')).toBeTruthy()

    const children = screen.queryByTestId('spinner')?.children
    expect(
      // @ts-ignore
      children[0].getAttribute('stroke'),
    ).toEqual('#DFDFDF')
    expect(
      // @ts-ignore
      children[1].getAttribute('fill'),
    ).toEqual('#959595')
  })
})
