import React from 'react'
import { Provider } from 'react-redux'
import { render, screen } from '@testing-library/react'

import { useUser } from 'user'
import { abra } from 'foundation'

import createStore from '../../store'

import LoginPrompt, { getLireEnvironment } from './LoginPrompt'

jest.mock('foundation', () => ({
  env: { version: 'test' },
  trackModuleInteraction: jest.fn(),
  trackImpression: jest.fn(),
  abra: {
    getVariant: jest.fn(),
    reportExposure: jest.fn(),
  },
}))

jest.mock('user', () => ({
  useUser: jest.fn(() => ({
    userType: { isLoggedIn: true, hasXwd: false },
  })),
}))

describe('getLireEnvironment', () => {
  it('should return production for prod environments', () => {
    const mockProdUrl =
      'https://www.nytimes.com/games/wordle/index.html'

    const env = getLireEnvironment(mockProdUrl)
    expect(env).toEqual('production')
  })

  it('should return staging for dev environments', () => {
    const mockStagingUrl =
      'https://www.stg.nytimes.com/games/wordle/index.html'

    const env = getLireEnvironment(mockStagingUrl)
    expect(env).toEqual('staging')
  })

  it('should return staging for dev environments', () => {
    const mockDevUrl =
      'https://games-feat-query-articles-wordle.dev.nytimes.com/games/wordle/index.html'

    const env = getLireEnvironment(mockDevUrl)
    expect(env).toEqual('staging')
  })

  it('should return staging for local environments', () => {
    const mockLocalUrl =
      'https://local.nytimes.com/games/wordle/index.html'

    const env = getLireEnvironment(mockLocalUrl)
    expect(env).toEqual('staging')
  })
})

describe('<LoginPrompt />', () => {
  const renderLoginPrompt = () => {
    const store = createStore()
    render(
      <Provider store={store}>
        <LoginPrompt />
      </Provider>,
    )
    return store
  }

  it('should be closed by default', () => {
    // @ts-ignore
    abra.getVariant.mockReturnValue('0_control')

    renderLoginPrompt()
    expect(screen.findByText('Statistics')).toBeTruthy()
  })

  it('should display LIRE form if in 1_modal bucket', () => {
    // @ts-ignore
    abra.getVariant.mockReturnValue('1_modal')

    renderLoginPrompt()

    expect(screen.getByTestId('login-container')).toBeTruthy()
    const submitButtons = screen.queryAllByText('Statistics')
    expect(submitButtons).toHaveLength(0)
  })

  it('should display LIRE form if in 2_congrats bucket', () => {
    // @ts-ignore
    abra.getVariant.mockReturnValue('2_congrats')

    renderLoginPrompt()

    expect(screen.getByTestId('login-container')).toBeTruthy()
    const submitButtons = screen.queryAllByText('Statistics')
    expect(submitButtons).toHaveLength(0)
  })
})
