import React, { useEffect } from 'react'
import Lire from '@nyt/components/lib/Lire'
import cn from 'classnames'

import { useUser } from 'user'
import { abra, trackImpression } from 'foundation'

import { restartLoad } from '../../store/api/api.actions'
import {
  addToast,
  openModal,
} from '../../store/overlays/overlays.actions'
import {
  useWordleDispatch,
  useWordleSelector,
} from '../../store/types'
import { selectGameDayOffset } from '../../store/game/game.selectors'
import Stats from '../Stats/Stats'

import styles from './LoginPrompt.module.scss'

export const getLireEnvironment = (currentUrl: string) => {
  if (
    currentUrl.indexOf('.dev.') > -1 ||
    currentUrl.indexOf('local.') > -1 ||
    currentUrl.indexOf('.stg.') > -1
  ) {
    return 'staging'
  }

  return 'production'
}

export default function LoginPrompt() {
  const dispatch = useWordleDispatch()
  const { setHasLoaded } = useUser()
  const gameDayOffset = useWordleSelector(selectGameDayOffset)

  const regiwallPromptVariant = abra.getVariant(
    'GAMES_wordleWebStatsRegiWall_1023',
  )

  const showControl =
    regiwallPromptVariant === null ||
    regiwallPromptVariant === '0_control'

  // GAMES_wordleWebStatsRegiWall_1023 experiment
  useEffect(() => {
    // w-52 impression: stats regiwall LIRE form popup for 1_modal var
    if (regiwallPromptVariant === '1_modal') {
      // AB expose event
      abra.reportExposure('GAMES_wordleWebStatsRegiWall_1023')
      trackImpression(
        'softregiwall',
        'wordle',
        'stats-regiwall',
        `${gameDayOffset}`,
      )
    }
  }, [])

  if (showControl) {
    return <Stats />
  }

  const currentUrl = window.location.href
  const currentEnv = getLireEnvironment(currentUrl)

  return (
    <div data-testid="login-container" className={cn(styles.parent)}>
      <div className={cn(styles.cta)}>
        {/* icon */}
        <div className={cn(styles.flexCenter)}>
          <div className={cn(styles.icon)} />
        </div>
        {/* headings */}
        <div className={cn(styles.flexCenter)}>
          <h1 className={cn(styles.heading)}>
            Create a free account to access your stats and streaks
          </h1>
          <h2 className={cn(styles.subheading)}>
            You need one to track your stats online and in our apps.
          </h2>
        </div>
      </div>
      <Lire
        onSuccess={(data) => {
          setHasLoaded && setHasLoaded(false)
          dispatch(restartLoad())
          dispatch(openModal('stats'))
          dispatch(
            addToast({
              text: 'You are now logged in to your Times account.',
              duration: 2000,
              isSystem: true,
            }),
          )
        }}
        env={currentEnv}
        params={{
          client_id: 'games',
          response_type: 'cookie',
          redirect_uri: currentUrl,
          application: 'nyt-lire',
          asset: 'wordle',
          // @ts-ignore
          display: 'GAMES_wordleWebStatsRegiWall_1023',
        }}
      />
    </div>
  )
}
