import React from 'react'
import { Provider } from 'react-redux'
import { render, screen } from '@testing-library/react'

import createStore from '../../store'

import LoginCTA from './LoginCTA'

jest.mock('foundation', () => ({
  env: { version: 'test' },
}))

describe('LoginCTA', () => {
  const renderLoginCTA = ({
    children,
  }: {
    children: React.ReactElement | string
  }) => {
    const store = createStore()

    render(
      <Provider store={store}>
        <LoginCTA>{children}</LoginCTA>
      </Provider>,
    )
  }

  it('renders a link by default', () => {
    renderLoginCTA({ children: 'login woooo!' })

    const cta = screen.getByRole('link')
    expect(cta).toBeInTheDocument()
  })

  it('renders a button in hybrid webview', () => {
    window.isHybridWebView = true
    renderLoginCTA({ children: 'login woooo!' })

    const cta = screen.getByRole('button')
    expect(cta).toBeInTheDocument()
  })

  it('renders text inside the button when provided', () => {
    window.isHybridWebView = true
    renderLoginCTA({ children: 'login woooo!' })

    const ctaText = screen.getByText('login woooo!')
    expect(ctaText).toBeInTheDocument()
  })

  it('renders children inside the link when provided', () => {
    window.isHybridWebView = true
    const donutIcon = <img alt="donut information" />
    renderLoginCTA({ children: donutIcon })

    const ctaText = screen.getByAltText('donut information')
    expect(ctaText).toBeInTheDocument()
  })
})
