import React from 'react'

import { useWordleDispatch } from '../../store/types'
import { LOGIN_URL, buildLoginOfferUrl } from '../../utils/constants'
import { trackAuthClick } from '../../store/overlays/overlays.actions'
import useFeatureFlag from '../../../../../shared/abra/useFeatureFlag'
import { isInNewsreader } from '../../../../../shared/utils/deviceIdentifiers'

import { hybridLogin } from './hybridLogin'

type TrackingProps = {
  eventName: string
  sendContext: boolean
  element?: {
    label: string
    name: string
  }
}

type LoginCTAProps = {
  children: React.ReactElement | string
  styles?: string
  lireOfferAsset?: string
  trackEvent?: TrackingProps
  handleClick?: () => void
}

export default function LoginCTA({
  children,
  lireOfferAsset,
  styles = '',
  trackEvent,
  handleClick,
}: LoginCTAProps) {
  const dispatch = useWordleDispatch()
  const offerFlag = useFeatureFlag('loginOffer')
  const isHybrid = window.isHybridWebView
  let nonHybridLink = LOGIN_URL
  if (!!lireOfferAsset && offerFlag && !isInNewsreader()) {
    // NSO-2372: show users an offer page after LIRE
    nonHybridLink = buildLoginOfferUrl(lireOfferAsset)
  }
  const href = !isHybrid ? nonHybridLink : undefined

  const trackClickEvent = (trackEvent: TrackingProps) => {
    const { eventName, sendContext, element } = trackEvent
    dispatch(trackAuthClick(eventName, sendContext, element))
  }

  const loginCallback = () => {
    if (handleClick) handleClick()
  }

  // if hybrid, render a button
  if (isHybrid) {
    return (
      <button
        type="button"
        className={styles}
        onClick={() => {
          if (trackEvent) {
            trackClickEvent(trackEvent)
          }

          loginCallback()

          hybridLogin(dispatch)
        }}
      >
        {children}
      </button>
    )
  }

  // if web, render a link
  return (
    <a
      className={styles}
      href={href}
      onClick={() => {
        if (trackEvent) {
          trackClickEvent(trackEvent)
        }

        loginCallback()
      }}
    >
      {children}
    </a>
  )
}
