import React from 'react'
import { Provider } from 'react-redux'
import { fireEvent, render, screen } from '@testing-library/react'

import { abra } from 'foundation'

import createStore from '../../store'
import { openModal } from '../../store/overlays/overlays.actions'

import modalStyles from './Modal.module.scss'
import Modal from './Modal'

jest.mock('foundation', () => ({
  env: { version: 'test' },
  trackModuleInteraction: jest.fn(),
  trackImpression: jest.fn(),
  abra: {
    getVariant: jest.fn(),
  },
}))

describe('<Modal />', () => {
  const renderModal = () => {
    const store = createStore()
    render(
      <Provider store={store}>
        <Modal />
      </Provider>,
    )
    return store
  }

  it('should be closed by default', () => {
    renderModal()
    expect(screen.queryByRole('button')).toBeFalsy()
  })

  it('should open the help modal', () => {
    const store = renderModal()
    store.dispatch(openModal('help'))
    expect(screen.queryByText('How To Play')).toBeTruthy()
    expect(
      screen.queryByText('Each guess must be a valid 5-letter word.'),
    ).toBeTruthy()
  })

  it('should open the stats modal', () => {
    const store = renderModal()
    store.dispatch(openModal('stats'))
    expect(screen.queryByTestId('modal-overlay')).toBeTruthy()
    expect(screen.queryByText('Statistics')).toBeTruthy()
  })

  // NSO-2385 - Activation Regi Modal test
  it('should open the Activation regi modal', () => {
    const store = renderModal()
    store.dispatch(openModal('activationRegiModal'))
    expect(
      screen.queryByText(
        'Wordle is even better with a free New York Times account.',
      ),
    ).toBeTruthy()
  })

  it('should animate the modal closed on click', async () => {
    const store = renderModal()
    store.dispatch(openModal('help'))
    const overlay = screen.getByRole('dialog')
    fireEvent.click(overlay)
    expect(overlay.firstElementChild?.classList).toContain(
      modalStyles.closing,
    )
    await fireEvent.animationEnd(overlay, {
      animationName: modalStyles.SlideOut,
    })
    expect(screen.queryByRole('dialog')).toBeFalsy()
  })
})
