import React from 'react'
import { Provider } from 'react-redux'
import {
  act,
  fireEvent,
  render,
  screen,
} from '@testing-library/react'

import createStore from '../../store'

import styles from './MomentSystem.module.scss'
import MomentSystem from './MomentSystem'
import { wordleMomentConfig } from './wordleMomentConfig'

jest.mock('foundation', () => ({
  env: { version: 'test' },
  trackModuleInteraction: jest.fn(),
  trackImpression: jest.fn(),
  trackClick: jest.fn(),
  abra: {
    getVariant: jest.fn(),
  },
}))

describe('<MomentSystem />', () => {
  beforeAll(() => jest.useFakeTimers())
  afterAll(() => jest.useRealTimers())
  window.navigationLinks = { login: '', subscribe: { default: '' } }

  const renderMoment = () => {
    const store = createStore()
    return render(
      <Provider store={store}>
        <MomentSystem
          hasLoaded
          config={wordleMomentConfig}
          initialMoment="welcome"
        />
      </Provider>,
    )
  }

  it('should transition between moments', () => {
    act(() => {
      const { container } = renderMoment()

      let moment = container.getElementsByClassName(styles.moment)

      expect(screen.queryAllByRole('button')).toBeTruthy()
      const overlay = screen.queryAllByRole('button')

      expect(overlay[1]).toBeTruthy()
      fireEvent.click(overlay[1])

      moment = container.getElementsByClassName(styles.moment)
      jest.advanceTimersByTime(401)

      expect(screen.getByTestId('icon-settings')).toBeTruthy()
      expect(screen.queryByText('Settings')).toBeNull()
    })
  })
})
