import React from 'react'
import {
  CSSTransition,
  TransitionGroup,
} from 'react-transition-group'

import styles from './MomentSystem.module.scss'
import { MomentConfig } from './wordleMomentConfig'

type MomentSystemProps<M extends string> = {
  hasLoaded: boolean
  config: MomentConfig<M>
  initialMoment: M
}

// keep in sync w/ MomentSystem.module.scss
const TRANSITION_TIME = 400

export default function MomentSystem<M extends string>({
  hasLoaded,
  config,
  initialMoment,
}: MomentSystemProps<M>) {
  const [momentType, setMomentType] = React.useState<M>(initialMoment)

  const momentConfig = config[momentType]

  const exitClassNames = {
    exit: styles.momentExit,
    exitActive: styles.momentExitActive,
  }

  const enterClassNames = {
    enter: styles.momentEnter,
    enterActive: styles.momentEnterActive,
  }

  const classNames = {
    ...(momentConfig.animateIn ? enterClassNames : {}),
    ...(momentConfig.animateOut ? exitClassNames : {}),
  }

  return (
    <TransitionGroup>
      <CSSTransition
        key={momentType}
        timeout={{
          enter: momentConfig.animateIn ? TRANSITION_TIME : 0,
          exit: momentConfig.animateOut ? TRANSITION_TIME : 0,
        }}
        classNames={classNames}
      >
        <div className={styles.moment}>
          <momentConfig.component
            hasLoaded={hasLoaded}
            transition={setMomentType}
          />
        </div>
      </CSSTransition>
    </TransitionGroup>
  )
}
