import { Welcome } from '../Welcome/Welcome'
import { WelcomeLoading } from '../Welcome/WelcomeLoading'
import Game from '../App/Game'
import { StatsSelectionTool } from '../StatsSelectionTool/StatsSelectionTool'
import { AdIntersitialMoment } from '../AdInterstitial/adMoment'

export type WordleMoments =
  | 'loading'
  | 'welcome'
  | 'game'
  | 'statsSelection'
  | 'ad'

export type MomentComponentProps<M extends string> = {
  hasLoaded: boolean
  transition: (to: M) => void
}

export type MomentComponent<M extends string> = React.ComponentType<
  MomentComponentProps<M>
>

export type MomentConfig<M extends string> = Record<
  M,
  {
    component: MomentComponent<M>
    animateIn?: boolean
    animateOut?: boolean
  }
>

export const wordleMomentConfig: MomentConfig<WordleMoments> = {
  welcome: {
    component: Welcome,
    animateOut: true,
  },
  loading: {
    component: WelcomeLoading,
  },
  game: {
    component: Game,
  },
  statsSelection: {
    component: StatsSelectionTool,
    animateOut: true,
  },
  ad: {
    component: AdIntersitialMoment,
  },
}

export const getInitialMoment = (): WordleMoments => {
  return 'loading'
}
