import React from 'react'
import { render, screen } from '@testing-library/react'
import { Provider } from 'react-redux'

import { ccpa, parsePurrCookieValue } from 'foundation'

import { PURR_DIRECTIVE_FORMAT } from '../../../../../server/util/parsePurrDirectiveHeader'
import createStore from '../../store'

import Nav from './Nav'

jest.mock('foundation', () => ({
  env: { version: 'test' },
  ccpa: jest.fn(),
  parsePurrCookieValue: jest.fn(),
  searchToObject: jest.fn(),
  findPurrCookieValue: jest.fn(),
}))

jest.mock('shared/marketing/useCTA', () => ({
  __esModule: true,
  default: () => ({
    isGamesSaleActive: false,
    getButtonText: () => '',
  }),
}))

// @ts-ignore
window.purrDirectiveFormat = PURR_DIRECTIVE_FORMAT
const store = createStore()

describe('Nav', () => {
  window.navigationLinks = window.navigationLinks || {}
  window.navigationLinks.account = ''

  const renderNav = () => {
    render(
      <Provider store={store}>
        <Nav />
      </Provider>,
    )
  }

  it('includes a list of expected Games links', () => {
    // @ts-ignore
    parsePurrCookieValue.mockReturnValue({
      PURR_DataSaleOptOutUI_v2: 'hide',
      PURR_CaliforniaNoticesUI: 'show',
    })

    renderNav()
    const sb = screen.getByText('Spelling Bee')

    expect(sb).toBeTruthy()
  })

  it('includes a list of expected NYT links', () => {
    // @ts-ignore
    parsePurrCookieValue.mockReturnValue({
      PURR_DataSaleOptOutUI_v2: 'hide',
      PURR_CaliforniaNoticesUI: 'show',
    })

    renderNav()
    const wirecutter = screen.getByText('New York Times Wirecutter')

    expect(wirecutter).toBeTruthy()
  })

  it('includes a link to our privacy policy', () => {
    // @ts-ignore
    parsePurrCookieValue.mockReturnValue({
      PURR_DataSaleOptOutUI_v2: 'hide',
      PURR_CaliforniaNoticesUI: 'show',
    })

    renderNav()
    const privacyLink = screen.getByText('Privacy Policy')

    expect(privacyLink).toBeTruthy()
  })

  it('calls ccpa and parsePurrCookieValue', () => {
    // @ts-ignore
    parsePurrCookieValue.mockReturnValue({
      PURR_DataSaleOptOutUI_v2: 'hide',
      PURR_CaliforniaNoticesUI: 'show',
    })

    renderNav()

    expect(ccpa).toHaveBeenCalled()
    expect(parsePurrCookieValue).toHaveBeenCalled()
  })

  it('shows data sale notice when appropriate', () => {
    // @ts-ignore
    parsePurrCookieValue.mockReturnValue({
      PURR_DataSaleOptOutUI_v2: 'show',
      PURR_CaliforniaNoticesUI: 'show',
    })

    renderNav()

    const privacyHubLink = screen.getByText('Your Privacy Choices')

    expect(privacyHubLink).toBeTruthy()
  })

  it('hides notice when appropriate', () => {
    // @ts-ignore
    parsePurrCookieValue.mockReturnValue({
      PURR_DataSaleOptOutUI_v2: 'hide',
      PURR_CaliforniaNoticesUI: 'show',
    })

    renderNav()
    const privacyHubLink = screen.queryByText('Your Privacy Choices')

    expect(privacyHubLink).toBeNull()
  })

  it('shows cali notice when appropriate', () => {
    // @ts-ignore
    parsePurrCookieValue.mockReturnValue({
      PURR_DataSaleOptOutUI_v2: 'hide',
      PURR_CaliforniaNoticesUI: 'show',
    })

    renderNav()

    const caliNotices = screen.getByText('California Notices')

    expect(caliNotices).toBeTruthy()
  })

  it('hides cali notice when appropriate', () => {
    // @ts-ignore
    parsePurrCookieValue.mockReturnValue({
      PURR_DataSaleOptOutUI_v2: 'hide',
      PURR_CaliforniaNoticesUI: 'hide',
    })

    renderNav()

    const caliNotices = screen.queryByText('California Notices')

    expect(caliNotices).toBeNull()
  })
})
