import React, { useEffect } from 'react'
import cn from 'classnames'

import { ccpa, parsePurrCookieValue } from 'foundation'

import NytIcon from '../Icon/NytIcon'
import { trackNavModalItem } from '../../store/overlays/overlays.actions'
import { useWordleDispatch } from '../../store/types'
import { DIGITS_ON, CONNECTIONS_ON } from '../../utils/constants'

import styles from './Nav.module.scss'

export default function Nav() {
  useEffect(() => {
    ccpa()
  }, [])

  const directives = parsePurrCookieValue()

  const gameNavItems = [
    {
      id: 'spelling-bee',
      name: 'Spelling Bee',
      url: '/puzzles/spelling-bee?utm_source=wordle&utm_medium=referral&utm_campaign=wordle_nav',
      backgroundImage: `${'var(--spelling-bee)'}`,
      dataTrackLabel: 'spelling-bee-nav',
    },
    {
      id: 'crossword',
      name: 'The Crossword',
      url: '/crosswords/game/daily?utm_source=wordle&utm_medium=referral&utm_campaign=wordle_nav',
      backgroundImage: `${'var(--daily)'}`,
      dataTrackLabel: 'daily-page-nav',
    },
    {
      id: 'mini',
      name: 'The Mini',
      url: '/crosswords/game/mini?utm_source=wordle&utm_medium=referral&utm_campaign=wordle_nav',
      backgroundImage: `${'var(--mini)'}`,
      dataTrackLabel: 'mini-page-nav',
    },
    {
      id: 'connections',
      name: 'Connections',
      url: '/games/connections',
      backgroundImage: `${'var(--connections)'}`,
      dataTrackLabel: 'connections-nav',
    },
    {
      id: 'digits',
      name: 'Digits',
      url: '/games/digits',
      backgroundImage: `${'var(--digits)'}`,
      dataTrackLabel: 'digits-nav',
    },
    {
      id: 'wordlebot',
      name: `Wordlebot: Your Daily, Personalized Wordle Score`,
      url: '/interactive/2022/upshot/wordle-bot.html?utm_source=wordle&utm_medium=referral&utm_campaign=wordle_nav',
      backgroundImage: `${'var(--wordlebot-walking-icon)'}`,
      dataTrackLabel: 'wordle-bot-nav',
    },
    {
      id: 'gameplay-stories',
      name: 'Gameplay Stories',
      url: '/column/wordplay?utm_source=wordle&utm_medium=referral&utm_campaign=wordle_nav',
      dataTrackLabel: 'gameplay-stories-nav',
    },
    {
      id: 'more-games',
      name: 'More Games',
      url: '/puzzles?utm_source=wordle&utm_medium=referral&utm_campaign=wordle_nav',
      dataTrackLabel: 'all-games-nav',
    },
  ].filter(
    (item) =>
      (item.id !== 'digits' || DIGITS_ON) &&
      (item.id !== 'connections' || CONNECTIONS_ON),
  )

  const nytNavItems = [
    {
      id: 'nyt',
      name: 'The New York Times',
      url: 'https://www.nytimes.com/?utm_source=wordle&utm_medium=referral&utm_campaign=wordle_nav',
      backgroundImage: `${'var(--nyt)'}`,
      dataTrackLabel: 'nyt-nav',
    },
    {
      id: 'cooking',
      name: 'New York Times Cooking',
      url: 'https://cooking.nytimes.com',
      backgroundImage: `${'var(--cooking)'}`,
      dataTrackLabel: 'cooking-nav',
    },
    {
      id: 'wirecutter',
      name: 'New York Times Wirecutter',
      url: 'https://www.nytimes.com/wirecutter/?utm_source=wordle&utm_medium=referral&utm_campaign=wordle_nav',
      backgroundImage: `${'var(--wirecutter)'}`,
      dataTrackLabel: 'wirecutter-nav',
    },
    {
      id: 'athletic',
      name: 'The Athletic',
      url: 'https://theathletic.com/?utm_source=wordle&utm_medium=referral&utm_campaign=wordle_nav',
      backgroundImage: `${'var(--athletic)'}`,
      dataTrackLabel: 'athletic-nav',
    },
  ]

  const backgroundImage = (image = '') => {
    return {
      backgroundImage: image,
      backgroundSize: '20px',
    }
  }

  const dispatch = useWordleDispatch()

  return (
    <nav className={styles.container}>
      <h2 className={styles.navHeader}>
        <span className="visually-hidden">Games</span>
        <NytIcon />
      </h2>
      <h3 className={styles.moreText}>
        More From New York Times Games
      </h3>
      <div className={styles.gameList}>
        <ul>
          {gameNavItems.map((item) => {
            return (
              <li key={item.id}>
                <a
                  className={styles.navLink}
                  href={item.url}
                  onClick={() =>
                    dispatch(
                      trackNavModalItem(
                        'wordle',
                        item.dataTrackLabel,
                        true,
                        null,
                      ),
                    )
                  }
                >
                  <div className={styles.navItem}>
                    <span
                      style={backgroundImage(item.backgroundImage)}
                      className={styles.navIcon}
                    />
                    <div className={styles.navDescription}>
                      {item.name}
                    </div>
                  </div>
                </a>
              </li>
            )
          })}
        </ul>
      </div>
      <div className={styles.nytList}>
        <hr />
        <ul>
          {nytNavItems.map((item) => {
            return (
              <li key={item.id}>
                <a
                  href={item.url}
                  className={styles.navLink}
                  onClick={() =>
                    dispatch(
                      trackNavModalItem(
                        'wordle',
                        item.dataTrackLabel,
                        true,
                        null,
                      ),
                    )
                  }
                  id={item.id}
                  key={item.id}
                  data-track-label={item.dataTrackLabel}
                >
                  <div className={styles.navItem}>
                    <span
                      style={backgroundImage(item.backgroundImage)}
                      className={styles.navIcon}
                    />
                    {item.name}
                  </div>
                </a>
              </li>
            )
          })}
        </ul>
      </div>
      <div className={styles.privacyStatic}>
        <hr />
        <a
          className={styles.privacyItem}
          href="https://www.nytimes.com/privacy/privacy-policy"
          data-track-label="privacy-policy-nav"
          onClick={() =>
            dispatch(
              trackNavModalItem(
                'wordle',
                'privacy-policy-nav',
                true,
                null,
              ),
            )
          }
        >
          Privacy Policy
        </a>
        <>
          {directives.PURR_DataSaleOptOutUI_v2 === 'show' && (
            <a
              href="https://www.nytimes.com/privacy/your-privacy-choices"
              data-region="menu"
              data-track="linkOptOut"
              className={cn(styles.privacyItem, 'ccpa-link')}
            >
              <div className={styles.ccpaIcon} />
              Your Privacy Choices
            </a>
          )}
          {/* CALIFORNIA NOTICES  */}
          {directives.PURR_CaliforniaNoticesUI === 'show' && (
            <a
              target="_blank"
              rel="noopener noreferrer"
              href="https://www.nytimes.com/privacy/privacy-policy#california-notice"
              data-region="menu"
              data-track="linkCANotice"
              className={cn(styles.privacyItem, 'ccpa-link')}
            >
              California Notices
            </a>
          )}
        </>
      </div>
    </nav>
  )
}
