import React from 'react'
import { Provider } from 'react-redux'
import { render, screen } from '@testing-library/react'

import { useUser } from 'user'

import createStore from '../../store'

import NavAccount from './NavAccount'

jest.mock('foundation', () => ({
  env: { version: 'test' },
}))

jest.mock('user', () => ({
  useUser: jest.fn(() => ({ userType: { hasXwd: false } })),
}))

window.navigationLinks = window.navigationLinks || {}
window.navigationLinks.account = 'https://foo.bar/account'

describe('Nav', () => {
  const renderNavFooter = () => {
    const store = createStore()
    render(
      <Provider store={store}>
        <NavAccount />
      </Provider>,
    )
  }

  it('displays the subscriber experience', () => {
    ;(useUser as jest.Mock).mockReturnValueOnce({
      userType: { isLoggedIn: true, hasXwd: true },
    })
    renderNavFooter()
    const accountDetails = screen.getByText('Account details')
    const profile = screen.getByText('Profile')
    const logoutButton = screen.getByText('Log Out')
    expect(accountDetails).toBeTruthy()
    expect(profile).toBeTruthy()
    expect(logoutButton).toBeTruthy()
  })

  it('displays the non subscriber experience', () => {
    ;(useUser as jest.Mock).mockReturnValueOnce({
      userType: { isLoggedIn: true, hasXwd: false },
    })
    renderNavFooter()
    const logout = screen.getByText('Log Out')
    const subscribe = screen.getByText('Subscribe')
    expect(logout).toBeTruthy()
    expect(subscribe).toBeTruthy()
  })

  it('hides the subscribe button in newsreader', () => {
    window.newsreaderAppPlatform = 'ios'
    renderNavFooter()
    const login = screen.getByText('Log In')
    const subscribe = screen.queryByText('Subscribe')
    expect(login).toBeTruthy()
    expect(subscribe).toBeFalsy()
  })
})
