/* eslint jsx-a11y/anchor-is-valid: 0 */
import React from 'react'
import cn from 'classnames'

import { useUser } from 'user'
import { trackClick } from 'foundation'
import useCTA from 'shared/marketing/useCTA'

import {
  SUBSCRIBE_URL,
  LOGIN_URL,
  LOGOUT_URL,
} from '../../utils/constants'
import {
  isAndroidNewsreader,
  isiOSNewsreader,
} from '../../../../../shared/foundation/js/hybrid/detection'
import { selectGameDayOffset } from '../../store/game/game.selectors'
import { useWordleSelector } from '../../store/types'

import styles from './NavAccount.module.scss'

export default function NavAccount() {
  const isNewsreader = isiOSNewsreader() || isAndroidNewsreader()
  const { userType } = useUser()
  const gameDayOffset = `${useWordleSelector(selectGameDayOffset)}`
  const { isGamesSaleActive, getButtonText } = useCTA()

  const subscribeCopy = getButtonText()

  const subscribeButton = (
    <a
      href={SUBSCRIBE_URL}
      role="button"
      className={cn(styles.subscribeButton, {
        [styles.subscribeGamesSale]: isGamesSaleActive,
      })}
      onClick={() =>
        trackClick({
          name: 'wordle',
          element: {
            name: 'wordle',
            label: 'subscribe-nav',
          },
          useBeacon: true,
          context: gameDayOffset,
        })
      }
    >
      {subscribeCopy}
    </a>
  )

  const loginButton = (
    <a
      href={LOGIN_URL}
      role="button"
      className={styles.loginButton}
      data-track-label="log-in-nav"
      onClick={() =>
        trackClick({
          name: 'wordle',
          element: {
            name: 'wordle',
            label: 'log-in-nav',
          },
          useBeacon: true,
          context: gameDayOffset,
        })
      }
    >
      Log In
    </a>
  )

  const logoutButton = (
    <a
      href={LOGOUT_URL}
      role="button"
      className={styles.logoutButton}
      data-track-label="log-out-nav"
      onClick={() =>
        trackClick({
          name: 'wordle',
          element: {
            name: 'wordle',
            label: 'log-out-nav',
          },
          useBeacon: true,
          context: gameDayOffset,
        })
      }
    >
      Log Out
    </a>
  )

  const defaultLoggedinLayout = (
    <div className={styles.navProfileAccount}>
      <h4 className={styles.navDrawerHeading}>Profile</h4>
      <a
        href={window.navigationLinks.account}
        className={styles.navDrawerLink}
      >
        Account details
      </a>
      <div className={styles.navLoggedIn}>
        {!isNewsreader && !userType.hasXwd && subscribeButton}
        {logoutButton}
      </div>
    </div>
  )

  const loggedInGamesSaleLayout = (
    <div className={styles.navProfileAccount}>
      <h4 className={styles.navDrawerHeading}>Profile</h4>
      <a
        href={window.navigationLinks.account}
        className={styles.navDrawerLink}
      >
        Account details
      </a>
      <div className={styles.navGamesSale}>
        {logoutButton}
        {subscribeButton}
      </div>
    </div>
  )

  const loggedInLayout = isGamesSaleActive
    ? loggedInGamesSaleLayout
    : defaultLoggedinLayout

  return (
    <div className={styles.navDrawerAccount}>
      {userType.isLoggedIn ? (
        loggedInLayout
      ) : (
        <div className={styles.navLoggedOut}>
          {!isNewsreader && !userType.hasXwd && subscribeButton}
          {loginButton}
        </div>
      )}
    </div>
  )
}
