import React from 'react'
import { Provider } from 'react-redux'
import { fireEvent, render, screen } from '@testing-library/react'

import { parsePurrCookieValue } from '../../../../../shared/foundation'
import createStore from '../../store'
import { openNavModal } from '../../store/overlays/overlays.actions'

import navModalStyles from './NavModal.module.scss'
import NavModal from './NavModal'

jest.mock('foundation', () => ({
  env: { version: 'test' },
  trackClick: jest.fn(),
  ccpa: jest.fn(),
  findPurrCookieValue: jest.fn(),
  searchToObject: jest.fn(),
  parsePurrCookieValue: jest.fn(),
}))

describe('<NavModal />', () => {
  window.navigationLinks = window.navigationLinks || {}
  window.navigationLinks.account = ''

  const renderNavModal = () => {
    const store = createStore()
    render(
      <Provider store={store}>
        <NavModal />
      </Provider>,
    )

    // @ts-ignore
    parsePurrCookieValue.mockReturnValue({
      PURR_DataSaleOptOutUI_v2: 'hide',
      PURR_CaliforniaNoticesUI: 'show',
    })

    return store
  }

  it('should be closed by default', () => {
    renderNavModal()
    expect(screen.queryByTestId('nav-modal-overlay')).toBeFalsy()
  })

  it('should open the NavModal', () => {
    const store = renderNavModal()
    store.dispatch(openNavModal())
    expect(screen.queryByTestId('nav-modal-overlay')).toBeTruthy()
  })

  it('should animate the NavModal closed on click', async () => {
    const store = renderNavModal()
    store.dispatch(openNavModal())
    const overlay = screen.getByTestId('nav-modal-overlay')
    fireEvent.click(overlay)

    expect(overlay.firstElementChild?.classList).toContain(
      navModalStyles.closingNav,
    )
    await fireEvent.animationEnd(overlay, {
      animationName: navModalStyles.SlideLeft,
    })
    expect(screen.queryByTestId('nav-modal-overlay')).toBeFalsy()
  })
})
