/* eslint-disable jsx-a11y/no-noninteractive-tabindex */
import React, { useState, AnimationEvent, useRef } from 'react'
import cn from 'classnames'

import useToggleElFocus from '../../../../shared/hooks/use-toggle-el-focus'
import useKeyboardTrap from '../../../../shared/hooks/use-keyboard-trap'
import Icon from '../Icon/Icon'
import Nav from '../Nav/Nav'
import NavAccount from '../Nav/NavAccount'
import { navMenuAriaControlsId } from '../App/AppHeader'
import { closeNavModal } from '../../store/overlays/overlays.actions'
import { selectNavModalOpen } from '../../store/overlays/overlays.selectors'
import {
  useWordleDispatch,
  useWordleSelector,
} from '../../store/types'

import styles from './NavModal.module.scss'

export default function NavModal() {
  const dispatch = useWordleDispatch()
  const navOpen = useWordleSelector(selectNavModalOpen)
  const [closing, setClosing] = useState(false)

  // focus close button when NavModal is launched, when modal closes
  // release focus via hole
  const closeRef = useRef<HTMLButtonElement>(null)
  useToggleElFocus(Boolean(navOpen), closeRef)

  // when modal is open enable keyboard trapping within element
  const navRef = useRef<HTMLDivElement>(null)
  useKeyboardTrap(Boolean(navOpen), navRef)

  if (!navOpen) {
    return null
  }

  const handleClick = () => {
    setClosing(true)
  }

  const handleAnimatedEnd = (e: AnimationEvent) => {
    if (e.animationName !== styles.SlideLeft) {
      return
    }
    setClosing(false)
    dispatch(closeNavModal())
  }

  return (
    // note on below element, even though this file is named "NavModal" this component functions as a fly-out nav
    // as the rest of content is not visually-obscured, `section` tag was a better semantic fit then `dialog`
    // eslint-disable-next-line jsx-a11y/no-noninteractive-element-interactions, jsx-a11y/no-static-element-interactions
    <section
      ref={navRef}
      className={styles.overlayNav}
      id={navMenuAriaControlsId}
      data-testid="nav-modal-overlay"
      onClick={handleClick}
      onKeyDown={(event) => {
        // support closing navigation with escape like any other "modal"-like interface
        if (event.key === 'Escape') {
          setClosing(true)
        }

        // stop propagation of keyboard submitting word on enter while navigation is open
        if (event.key === 'Enter') {
          event.stopPropagation()
        }
      }}
      onAnimationEnd={handleAnimatedEnd}
    >
      <div
        className={cn(styles.contentNav, {
          [styles.closingNav]: closing,
        })}
        id="content-nav"
      >
        <button
          ref={closeRef}
          className={styles.closeIconNav}
          aria-label="Close"
          type="button"
          onClick={(event) => {
            setClosing(true)
          }}
        >
          <Icon aria-hidden="true" icon="close" />
        </button>
        <Nav />
        <NavAccount />
      </div>
    </section>
  )
}
