import React from 'react'
import { Provider } from 'react-redux'
import {
  fireEvent,
  render,
  screen,
  waitFor,
} from '@testing-library/react'

import createStore from '../../store'
import {
  willClosePage,
  openPage,
} from '../../store/overlays/overlays.actions'
import {
  FeatureFlagContext,
  FeatureFlagContextType,
} from '../../../../../shared/abra/FeatureFlagProvider'

import pageStyles from './Page.module.scss'
import Page from './Page'

jest.mock('foundation', () => ({
  env: { version: 'test' },
  trackModuleInteraction: jest.fn(),
}))

describe('<Page />', () => {
  const renderPage = () => {
    const store = createStore()
    render(
      <Provider store={store}>
        <Page />
      </Provider>,
    )
    return store
  }

  const renderPageWithFlags = (
    flags: Partial<FeatureFlagContextType> = {},
  ) => {
    const store = createStore()
    render(
      <Provider store={store}>
        {/* @ts-ignore */}
        <FeatureFlagContext.Provider value={flags}>
          <Page />
        </FeatureFlagContext.Provider>
      </Provider>,
    )
    return store
  }

  it('should be closed by default', () => {
    renderPage()
    expect(screen.queryByRole('dialog')).toBeFalsy()
  })

  it('should show new page if page type is linkInfo or statsProblem', () => {
    const store = renderPageWithFlags()
    store.dispatch(openPage('linkInfo'))
    const linkPage = screen.getByTestId('pageNew')
    expect(linkPage.classList).toContain(pageStyles.pageNew)
    const closeButton = screen.getByTestId('close')
    fireEvent.click(closeButton)
    store.dispatch(openPage('statsProblem'))
    const statsProblemPage = screen.getByTestId('pageNew')
    expect(statsProblemPage.classList).toContain(pageStyles.pageNew)
  })

  it('should set page to close if willClosePage becomes true', async () => {
    const store = renderPageWithFlags()
    store.dispatch(openPage('linkInfo'))
    const page = screen.getByTestId('pageNew')
    expect(page.classList).not.toContain('closing')
    store.dispatch(willClosePage())
    await waitFor(() => {
      expect(page.classList).toContain('closing')
    })
  })
})
