import React, { AnimationEvent } from 'react'
import cn from 'classnames'

import Tile from '../Tile/Tile'
import { Evaluation } from '../../utils/gamelogic'
import { useWordleSelector } from '../../store/types'
import { selectIsRestoringSession } from '../../store/transient/transient.selectors'

import styles from './Row.module.scss'

export type RowProps = {
  letters: string
  evaluation: Evaluation[] | null
  rowIndex: number
  length: number
  invalid: boolean
  win: boolean
  removeInvalid: () => void
  onFlipEnd: () => void
}

export default function Row(props: RowProps) {
  const {
    letters,
    evaluation,
    rowIndex,
    length,
    invalid,
    win,
    removeInvalid,
    onFlipEnd,
  } = props

  const isRestoringSession = useWordleSelector(
    selectIsRestoringSession,
  )

  const flipInterval = isRestoringSession
    ? 100 // flip faster if evaluation is present while loading old game state
    : 300 // flip slower when a new guess is made

  const handleAnimationEnd = (e: AnimationEvent) => {
    if (e.animationName === styles.Shake) {
      removeInvalid()
    }
  }

  return (
    <div
      className={cn(styles.row, { [styles.invalid]: invalid })}
      onAnimationEnd={handleAnimationEnd}
      role="group"
      aria-label={`Row ${rowIndex + 1}`}
    >
      {Array(length)
        .fill(true)
        .map((_, i) => (
          <div
            key={i}
            className={win ? styles.win : ''}
            style={{ animationDelay: `${i * 100}ms` }}
          >
            <Tile
              letter={letters[i] || ''}
              letterIndex={i}
              evaluation={evaluation && evaluation[i]}
              flipDelay={i * flipInterval}
              onFlipEnd={i === length - 1 ? onFlipEnd : undefined}
              isAriaLiveActive={!!letters[i]}
            />
          </div>
        ))}
    </div>
  )
}
