import { useEffect } from 'react'

import hybridDebugger from '../../../../../shared/foundation/js/hybrid/hybridDebugger'
import { NATIVE_COLOR_THEME_ENUM } from '../../../../../shared/foundation/js/hybrid/commands'
import {
  selectColorblindMode,
  selectDarkMode,
} from '../../store/settings/settings.selectors'
import { useWordleSelector } from '../../store/types'
import {
  writeToLocalStorage,
  DARK_MODE_KEY,
} from '../../store/moogle/moogle.helpers'

export const useThemeManager = () => {
  const darkMode = useWordleSelector(selectDarkMode)
  const colorblindMode = useWordleSelector(selectColorblindMode)

  useEffect(() => {
    const body = document.querySelector('body')
    if (!body) return

    writeToLocalStorage(DARK_MODE_KEY, darkMode)

    if (darkMode && !body.classList.contains('dark')) {
      body.classList.add('dark')
    } else if (!darkMode) {
      body.classList.remove('dark')
    }

    if (window.isHybridWebView && window.NativeBridge) {
      const theme = darkMode
        ? NATIVE_COLOR_THEME_ENUM.DARK
        : NATIVE_COLOR_THEME_ENUM.LIGHT
      window.NativeBridge.gamesSetNativeColorTheme(theme).catch(
        (e) => {
          console.error(
            `Failed to set native color theme: ${theme}`,
            e,
          )
          hybridDebugger(`Failed to set native color theme: ${theme}`)
        },
      )
    }
  }, [darkMode])

  useEffect(() => {
    const body = document.querySelector('body')
    if (!body) return

    if (colorblindMode && !body.classList.contains('colorblind')) {
      body.classList.add('colorblind')
    } else if (!colorblindMode) {
      body.classList.remove('colorblind')
    }
  }, [colorblindMode])
}
