import React from 'react'

import styles from './Promo.module.scss'

type PromoProps = { trackClick: () => void; promoParam?: string }

export default function Promo({
  trackClick,
  promoParam = '',
}: PromoProps) {
  return (
    <div className={styles.promo}>
      <div className={styles.rule} />
      <a
        href={`/puzzles/spelling-bee${promoParam}`}
        className={styles.promoLink}
        onClick={(e) => {
          e.stopPropagation()
          trackClick()
        }}
      >
        <div className={styles.promoIcon}>
          <svg
            width="42"
            height="44"
            viewBox="0 0 42 44"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path
              d="M24.9528 14.8924L28.952 21.8171L24.9528 28.7417H16.9628L12.9636 21.8171L16.9628 14.8924H24.9528Z"
              fill="#F7DA21"
              stroke="#F7DA21"
              strokeWidth="0.495011"
            />
            <path
              d="M12.9892 21.7667L16.9884 28.6914L12.9892 35.616H4.99921L1 28.6914L4.99921 21.7667H12.9892Z"
              fill="white"
              stroke="#121212"
              strokeWidth="1.5"
            />
            <path
              d="M17.0056 14.8493L13.0064 7.92463L17.0056 1L24.9955 1L28.9948 7.92463L24.9955 14.8493L17.0056 14.8493Z"
              fill="white"
              stroke="#121212"
              strokeWidth="1.5"
            />
            <path
              d="M37.0008 7.96736L41 14.892L37.0008 21.8166H29.0108L25.0116 14.892L29.0108 7.96736H37.0008Z"
              fill="white"
              stroke="#121212"
              strokeWidth="1.5"
            />
            <path
              d="M12.9972 7.96736L16.9964 14.892L12.9972 21.8166H5.00727L1.00806 14.892L5.00727 7.96736H12.9972Z"
              fill="white"
              stroke="#121212"
              strokeWidth="1.5"
            />
            <path
              d="M37.0008 21.8089L41 28.7335L37.0008 35.6582H29.0108L25.0116 28.7335L29.0108 21.8089H37.0008Z"
              fill="white"
              stroke="#121212"
              strokeWidth="1.5"
            />
            <path
              d="M24.9947 28.7333L28.9939 35.658L24.9947 42.5826H17.0047L13.0055 35.658L17.0047 28.7333H24.9947Z"
              fill="white"
              stroke="#121212"
              strokeWidth="1.5"
            />
          </svg>
        </div>
        <div className={styles.promoText}>
          <span className={styles.promoTextPrimary}>
            How many words can you find{' '}
          </span>
          <span className={styles.promoTextSecondary}>
            using 7 letters?
          </span>
          <span className={styles.promoCta}>Play Spelling Bee</span>
        </div>
        <div className={styles.promoArrow}>
          <svg
            width="24"
            height="24"
            viewBox="0 0 24 24"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <circle
              cx="12"
              cy="12"
              r="12"
              fill="var(--svg-arrow-fill)"
            />
            <path
              d="M10.4038 6L15.8076 11.4038L10.4038 16.8076"
              stroke="var(--svg-arrow-stroke)"
              strokeWidth="1.5"
              strokeLinecap="round"
            />
          </svg>
        </div>
      </a>
    </div>
  )
}
