import React from 'react'
import { Provider } from 'react-redux'
import { render, screen } from '@testing-library/react'

import { useUser } from 'user'
import { abra } from 'foundation'

import createStore from '../../store'
import { openModal } from '../../store/overlays/overlays.actions'
import { selectGameStatus } from '../../store/game/game.selectors'
import { selectWasModalOpenedByClick } from '../../store/overlays/overlays.selectors'

import RegiwallPrompt from './RegiwallPrompt'

jest.mock('foundation', () => ({
  env: { version: 'test' },
  trackImpression: jest.fn(),
  trackInteraction: jest.fn(),
  abra: {
    getVariant: jest.fn(),
    reportExposure: jest.fn(),
  },
  trackModuleInteraction: jest.fn(),
  mockImplementationOnce: jest.fn(),
}))

jest.mock('user', () => ({
  useUser: jest.fn(() => ({
    userType: { isLoggedIn: false, hasXwd: false },
  })),
}))

jest.mock('../../store/game/game.selectors', () => ({
  ...jest.requireActual('../../store/game/game.selectors'),
  selectCurrentRowIndex: jest.fn(() => 0),
  selectGameStatus: jest.fn(() => 'IN_PROGRESS'),
}))

jest.mock('../../store/overlays/overlays.selectors', () => ({
  ...jest.requireActual('../../store/overlays/overlays.selectors'),
  selectWasModalOpenedByClick: jest.fn(() => false),
}))

describe('<RegiwallPrompt />', () => {
  const renderRegiwallPrompt = () => {
    const store = createStore()

    const regiwallPrompt = render(
      <Provider store={store}>
        <RegiwallPrompt />
      </Provider>,
    )

    return { store, regiwallPrompt }
  }

  afterEach(() => {
    jest.clearAllMocks()
  })

  // GAMES_wordleWebStatsRegiWall_1023 - 1_modal
  it('1_modal - should open the regiwall modal if reloaded', () => {
    const { store, regiwallPrompt } = renderRegiwallPrompt()

    // @ts-ignore
    selectWasModalOpenedByClick.mockImplementationOnce(() => false)
    store.dispatch(openModal('regiwallModal', true))
    expect(
      screen.queryByText('Here to see your stats and streaks?'),
    ).toBeTruthy()
  })

  // GAMES_wordleWebStatsRegiWall_1023 - 2_congrats
  it('2_congrats - should open the congrats regiwall modal if game is successful', () => {
    // @ts-ignore
    selectGameStatus.mockImplementation(() => 'WIN')

    const { store, regiwallPrompt } = renderRegiwallPrompt()
    store.dispatch(openModal('regiwallModal', false))
    screen.debug()
    expect(screen.queryByText('Congratulations!')).toBeTruthy()
  })

  // GAMES_wordleWebStatsRegiWall_1023 - 2_congrats
  it('2_congrats - should open the failed congrats regiwall modal if game failed', () => {
    // @ts-ignore
    selectGameStatus.mockImplementation(() => 'FAIL')

    const { store, regiwallPrompt } = renderRegiwallPrompt()
    store.dispatch(openModal('regiwallModal', false))
    expect(
      screen.queryByText('Thanks for playing today!'),
    ).toBeTruthy()
  })
})
