import React, { useEffect } from 'react'
import cn from 'classnames'

import { abra, trackImpression, trackInteraction } from 'foundation'

import {
  useWordleDispatch,
  useWordleSelector,
} from '../../store/types'
import { openModal } from '../../store/overlays/overlays.actions'
import { selectWasModalOpenedByClick } from '../../store/overlays/overlays.selectors'
import { selectGameDayOffset } from '../../store/game/game.selectors'

import Header, { HEADER_TYPE } from './molecules/Header'
import Footer from './molecules/Footer'
import BotLink from './molecules/BotLink'
import styles from './RegiwallPrompt.module.scss'

export default function RegiwallPrompt() {
  const dispatch = useWordleDispatch()
  const gameDayOffset = useWordleSelector(selectGameDayOffset)
  const isEndScreen = !useWordleSelector(selectWasModalOpenedByClick)
  const gameId = `${useWordleSelector(selectGameDayOffset)}`

  // GAMES_wordleWebStatsRegiWall_1023 experiment
  useEffect(() => {
    // w-53 impression: congrats/stats screen for both variants
    trackImpression(
      'softregiwall',
      'wordle',
      'congrats-modal',
      `${gameDayOffset}`,
    )
    // AB expose event
    abra.reportExposure('GAMES_wordleWebStatsRegiWall_1023')
  }, [])

  return (
    <>
      <div className={cn(styles.flexCenter)}>
        <div className={cn(styles.parentContainer)}>
          <Header type={HEADER_TYPE.regiwall} />

          {/* register button */}
          <button
            type="button"
            className={cn(styles.regiButton)}
            onClick={() => {
              // w-54 interaction: users clicks register button
              trackInteraction({
                element: { name: 'wordle', label: 'register' },
                context: `${gameId}`,
                region: isEndScreen ? 'congrats' : 'stats-regiwall',
              })
              dispatch(openModal('loginPrompt'))
            }}
          >
            <span>Create a free account</span>
          </button>

          {/* login button */}
          <button
            className={cn(styles.loginButton)}
            type="button"
            onClick={() => {
              // w-64 interaction: users clicks register button
              trackInteraction({
                element: { name: 'wordle', label: 'log-in-stats' },
                context: `${gameId}`,
                region: isEndScreen ? 'congrats' : 'stats',
              })
              dispatch(openModal('loginPrompt'))
            }}
          >
            <h3
              className={cn(
                styles.regiwallText,
                styles.regiwallText_link,
              )}
            >
              Already Registered? Log In
            </h3>
          </button>

          {/* smaller components shared with stats page */}
          <div className={styles.flexCenter}>
            <div className={cn(styles.bot, styles.flexCenter)}>
              <BotLink />
            </div>
          </div>
          <Footer />
        </div>
      </div>
    </>
  )
}