import React from 'react'
import { render } from '@testing-library/react'

import SpellingBeeCTA from './SpellingBeeCTA'

describe('<SpellingBeeCTA />', () => {
  beforeEach(() => {
    window.newsreaderAppPlatform = ''
    window.isHybridWebView = false
  })

  it('should render link normally', () => {
    const props = {
      handleTrack: jest.fn(),
      promoParam: '',
    }

    const { queryByRole } = render(<SpellingBeeCTA {...props} />)
    const link = queryByRole('link')
    expect(link?.getAttribute('href')).toBe('/puzzles/spelling-bee')
  })

  it('should render link with promo query param', () => {
    const props = {
      handleTrack: jest.fn(),
      promoParam: '?embed=ios',
    }

    const { queryByRole } = render(<SpellingBeeCTA {...props} />)
    const link = queryByRole('link')
    expect(link?.getAttribute('href')).toBe(
      '/puzzles/spelling-bee?embed=ios',
    )
  })

  it('should render link with hybrid news param', () => {
    window.newsreaderAppPlatform = 'ios'
    window.isHybridWebView = true
    const props = {
      handleTrack: jest.fn(),
      promoParam: '',
    }

    const { queryByRole } = render(<SpellingBeeCTA {...props} />)
    const link = queryByRole('link')
    expect(link?.getAttribute('href')).toBe(
      '/puzzles/spelling-bee?hybrid=news',
    )
  })

  it('should render link with both promo param and hybrid news param', () => {
    window.newsreaderAppPlatform = 'ios'
    window.isHybridWebView = true
    const props = {
      handleTrack: jest.fn(),
      promoParam: '?embed=ios',
    }

    const { queryByRole } = render(<SpellingBeeCTA {...props} />)
    const link = queryByRole('link')
    expect(link?.getAttribute('href')).toBe(
      '/puzzles/spelling-bee?embed=ios&hybrid=news',
    )
  })
})
