import React from 'react'
import { Provider } from 'react-redux'
import { render } from '@testing-library/react'

import createStore from '../../store'

import StatisticsContainer from './StatisticsContainer'

jest.mock('foundation', () => ({
  env: { version: 'test' },
}))

describe('<StatisticsContainer />', () => {
  const props = {
    stats: {
      averageGuesses: 4,
      currentStreak: 0,
      gamesPlayed: 2,
      gamesWon: 1,
      guesses: {
        '1': 0,
        '2': 0,
        '3': 0,
        '4': 1,
        '5': 0,
        '6': 0,
        fail: 1,
      },
      hasPlayed: true,
      isOnStreak: false,
      maxStreak: 1,
      winPercentage: 50,
    },
  }

  it('should display a correct aria-label for Played', () => {
    const store = createStore()
    const { container } = render(
      <Provider store={store}>
        <StatisticsContainer {...props} />
      </Provider>,
    )

    const hiddenLabel =
      container.getElementsByClassName('visually-hidden')

    expect(hiddenLabel[0].innerHTML).toBe('Number of games played, 2')
  })

  it('should display a correct aria-label for Win %', () => {
    const store = createStore()
    const { container } = render(
      <Provider store={store}>
        <StatisticsContainer {...props} />
      </Provider>,
    )

    const hiddenLabel =
      container.getElementsByClassName('visually-hidden')

    expect(hiddenLabel[1].innerHTML).toBe('Win percentage, 50')
  })

  it('should display a correct aria-label for Current Streak', () => {
    const store = createStore()
    const { container } = render(
      <Provider store={store}>
        <StatisticsContainer {...props} />
      </Provider>,
    )

    const hiddenLabel =
      container.getElementsByClassName('visually-hidden')

    expect(hiddenLabel[2].innerHTML).toBe('Current Streak count, 0')
  })

  it('should display a correct aria-label for Max Streak', () => {
    const store = createStore()
    const { container } = render(
      <Provider store={store}>
        <StatisticsContainer {...props} />
      </Provider>,
    )

    const hiddenLabel =
      container.getElementsByClassName('visually-hidden')

    expect(hiddenLabel[3].innerHTML).toBe('Max Streak count, 1')
  })
})
