import React from 'react'
import cn from 'classnames'

import { WordleStatsState } from '../../store/stats/stats.state'

import styles from './Stats.module.scss'

const statNameToLabelMap = {
  currentStreak: 'Current Streak',
  maxStreak: 'Max Streak',
  winPercentage: 'Win %',
  gamesPlayed: 'Played',
  gamesWon: 'Won',
  averageGuesses: 'Av. Guesses',
} as const

const currentStats = [
  'gamesPlayed',
  'winPercentage',
  'currentStreak',
  'maxStreak',
] as const

type Props = {
  stats: WordleStatsState
  small?: boolean
}

export default function StatisticsContainer({ stats, small }: Props) {
  const getAriaLabel = (stat: number, label: string) => {
    let ariaLabel
    switch (label) {
      case 'Played':
        ariaLabel = `Number of games played, ${stat}`
        break
      case 'Win %':
        ariaLabel = `Win percentage, ${stat}`
        break
      case 'Current Streak':
        ariaLabel = `Current Streak count, ${stat}`
        break
      case 'Max Streak':
        ariaLabel = `Max Streak count, ${stat}`
        break
      default:
      // skipping default since each label is unique to the stat
    }

    return ariaLabel
  }

  return (
    <ul className={styles.statistics}>
      {currentStats.map((statName) => {
        const label = statNameToLabelMap[statName]
        const stat = stats[statName]

        return (
          <li className={styles.statisticContainer} key={statName}>
            <span className="visually-hidden">
              {getAriaLabel(stat, label)}
            </span>
            <div
              className={cn(styles.statistic, {
                [styles.small]: small,
              })}
              aria-hidden="true"
            >
              {stat}
            </div>
            <div className={styles.label} aria-hidden="true">
              {label}
            </div>
          </li>
        )
      })}
    </ul>
  )
}
