import React from 'react'
import { Provider } from 'react-redux'
import { render, screen } from '@testing-library/react'

import { abra } from 'foundation'

import createStore from '../../store'
import { openModal } from '../../store/overlays/overlays.actions'
import { selectGameStatus } from '../../store/game/game.selectors'
import { selectWasModalOpenedByClick } from '../../store/overlays/overlays.selectors'

import Stats from './Stats'

jest.mock('foundation', () => ({
  env: { version: 'test' },
  trackImpression: jest.fn(),
  abra: {
    getVariant: jest.fn(),
    reportExposure: jest.fn(),
  },
  trackModuleInteraction: jest.fn(),
  mockImplementationOnce: jest.fn(),
}))

jest.mock('../../store/game/game.selectors', () => ({
  ...jest.requireActual('../../store/game/game.selectors'),
  selectCurrentRowIndex: jest.fn(() => 0),
  selectGameStatus: jest.fn(() => 'IN_PROGRESS'),
}))

jest.mock('../../store/overlays/overlays.selectors', () => ({
  ...jest.requireActual('../../store/overlays/overlays.selectors'),
  selectWasModalOpenedByClick: jest.fn(() => false),
}))

describe('<Stats />', () => {
  const renderStats = () => {
    const store = createStore()

    const stats = render(
      <Provider store={store}>
        <Stats />
      </Provider>,
    )

    return { store, stats }
  }

  afterEach(() => {
    jest.clearAllMocks()
  })

  it('should include auth content', () => {
    const store = createStore()
    const { queryByTestId } = render(
      <Provider store={store}>
        <Stats />
      </Provider>,
    )
    const authContainer = queryByTestId('authContainer')
    expect(authContainer).toBeTruthy()
  })

  // GAMES_wordleWebStatsRegiWall_1023 - 1_modal
  it('1_modal - should open the stats modal if reloaded', () => {
    // @ts-ignore
    abra.getVariant.mockReturnValue('1_modal')

    // @ts-ignore
    selectWasModalOpenedByClick.mockImplementationOnce(() => true)
    const { store, stats } = renderStats()
    store.dispatch(openModal('stats', true))
    expect(screen.queryByText('Wordle')).toBeTruthy()
  })

  // GAMES_wordleWebStatsRegiWall_1023 - 2_congrats
  it('2_congrats - should open the congrats stats modal if game is successful', () => {
    // @ts-ignore
    abra.getVariant.mockReturnValue('2_congrats')
    // @ts-ignore
    selectGameStatus.mockImplementation(() => 'WIN')

    const { store, stats } = renderStats()
    store.dispatch(openModal('stats', false))
    expect(screen.queryByText('Congratulations!')).toBeTruthy()
  })

  // GAMES_wordleWebStatsRegiWall_1023 - 2_congrats
  it('2_congrats - should open the failed congrats stats modal if game failed', () => {
    // @ts-ignore
    abra.getVariant.mockReturnValue('2_congrats')
    // @ts-ignore
    selectGameStatus.mockImplementation(() => 'FAIL')

    const { store, stats } = renderStats()
    store.dispatch(openModal('stats', false))
    expect(
      screen.queryByText('Thanks for playing today!'),
    ).toBeTruthy()
  })
})
