import React, { useEffect } from 'react'
import cn from 'classnames'

import { abra } from 'foundation'

import {
  selectCurrentRowIndex,
  selectGameStatus,
} from '../../store/game/game.selectors'
import { selectWordleStats } from '../../store/stats/stats.selectors'
import { closeNavModal } from '../../store/overlays/overlays.actions'
import { selectNavModalOpen } from '../../store/overlays/overlays.selectors'
import { trackStatsImpression } from '../../store/stats/stats.actions'
import {
  useWordleDispatch,
  useWordleSelector,
} from '../../store/types'
import { selectMoogleUser } from '../../store/api/api.selectors'
import { WORDLE_REGIWALL_TEST } from '../../abra-constants'

import MiniAuthCTA from './MiniAuthCTA'
import StatisticsContainer from './StatisticsContainer'
import GuessDistribution from './GuessDistribution'
import Header, { HEADER_TYPE } from './molecules/Header'
import Footer from './molecules/Footer'
import BotLink from './molecules/BotLink'
import styles from './Stats.module.scss'

export default function Stats() {
  const dispatch = useWordleDispatch()
  const stats = useWordleSelector(selectWordleStats)
  const gameStatus = useWordleSelector(selectGameStatus)
  const rowIndex = useWordleSelector(selectCurrentRowIndex)
  const loggedIn = !!useWordleSelector(selectMoogleUser)
  const isInGamesApp = !!window.gamesAppPlatform
  const isNavMenuOpen = useWordleSelector(selectNavModalOpen)

  // GAMES_wordleWebStatsRegiWall_1023 experiment
  const regiwallPromptVariant = abra.getVariant(WORDLE_REGIWALL_TEST)
  const showRegiwallStats =
      regiwallPromptVariant === '1_modal' ||
      regiwallPromptVariant === '2_congrats'

  useEffect(() => {
    if (regiwallPromptVariant) {
      // AB expose event
      abra.reportExposure('GAMES_wordleWebStatsRegiWall_1023')
    }
  }, [])

  useEffect(() => {
    if (isNavMenuOpen) dispatch(closeNavModal())
  }, [isNavMenuOpen])

  useEffect(() => {
    dispatch(trackStatsImpression(gameStatus !== 'IN_PROGRESS'))
  }, [])

  return (
    <>
      <div
        data-testid="authContainer"
        className={cn(styles.gameStats, styles.testGameStats, showRegiwallStats && styles.testGameStats_regiwall)} // GAMES_wordleWebStatsRegiWall_1023 experiment
      >
        <div className={styles.statsContainer}>
          {showRegiwallStats && <Header type={HEADER_TYPE.stats} />}
          <h2 className={styles.statisticsHeading}>Statistics</h2>
          <StatisticsContainer stats={stats} />
          <GuessDistribution
            guesses={stats.guesses}
            rowIndex={rowIndex}
            gameStatus={gameStatus}
            loggedIn={loggedIn}
            showRegiwall={showRegiwallStats}
          />
        </div>
        {!isInGamesApp && <BotLink/>}
        <div className={styles.ctaContainer}>
          {!showRegiwallStats && !loggedIn && <MiniAuthCTA />}
          <Footer />
        </div>
      </div>
    </>
  )
}
