import React from 'react'
import cn from 'classnames'

import { trackClick } from 'foundation'

import {
  useWordleSelector,
  useWordleDispatch,
} from '../../../store/types'
import { addToast } from '../../../store/overlays/overlays.actions'
import { selectColorblindMode } from '../../../store/settings/settings.selectors'
import { selectGameDayOffset } from '../../../store/game/game.selectors'
import { selectShareMessage } from '../../../store/stats/stats.selectors'
import Icon from '../../Icon/Icon'
import { isPlayTab } from '../../../../../../shared/foundation/js/hybrid/detection'
import { share } from '../../../../../../shared/utils/share'
import SpellingBeeCTA from '../SpellingBeeCTA'

import styles from './Footer.module.scss'

export default function Footer() {
  const isColorBlindMode = useWordleSelector(selectColorblindMode)
  const colorBlindFillColor = isColorBlindMode ? 'var(--black)' : ''

  const dispatch = useWordleDispatch()
  const gameId = `${useWordleSelector(selectGameDayOffset)}`
  const shareMessage = useWordleSelector(selectShareMessage)
  const isLinkBackVariant = false
  const promoParam = isPlayTab() ? '?embed=ios&entry=playTab' : ''

  const spellingBeeAnalyticsClick = () => {
    trackClick({
      name: 'wordle',
      label: 'next-game',
      context: 'spelling-bee',
      useBeacon: true,
    })
  }

  const handleShareClick = (
    e: React.MouseEvent<HTMLButtonElement>,
  ) => {
    e.preventDefault()
    e.stopPropagation()

    const onCopy = () => {
      dispatch(
        addToast({
          text: 'Copied results to clipboard',
          duration: 2000,
          isSystem: true,
        }),
      )
    }

    const onFail = () => {
      dispatch(
        addToast({
          text: 'Share failed',
          duration: 2000,
          isSystem: true,
        }),
      )
    }

    trackClick({
      name: 'wordle',
      label: 'share',
      context: gameId,
    })

    if (isLinkBackVariant) {
      const variantShare = {
        text: `${shareMessage.text}\n\nnyt.com/wordle\u200C`,
      }
      share(variantShare, onCopy, onFail, e)
    } else {
      share(shareMessage, onCopy, onFail, e)
    }
  }

  return (
    <div className={cn(styles.bottomSheet, styles.sbButtonFooter)}>
      <div className={styles.bottomSheetContainer}>
        <button
          type="button"
          className={styles.shareButton}
          onClick={handleShareClick}
        >
          <span className={styles.shareText}>Share</span>
          <Icon
            id={styles.shareIcon}
            icon="share"
            fillColor={colorBlindFillColor}
          />
        </button>
        <SpellingBeeCTA
          handleTrack={spellingBeeAnalyticsClick}
          promoParam={promoParam}
        />
      </div>
    </div>
  )
}
