import React, { useEffect, useState } from 'react'
import cn from 'classnames'

import { selectGameStatus } from '../../../store/game/game.selectors'
import { selectWasModalOpenedByClick } from '../../../store/overlays/overlays.selectors'
import { trackStatsImpression } from '../../../store/stats/stats.actions'
import {
  useWordleDispatch,
  useWordleSelector,
} from '../../../store/types'

import styles from './Header.module.scss'

export enum HEADER_TYPE {
  'stats',
  'regiwall',
}

type HeaderProps = {
  type: HEADER_TYPE
}

export default function Header({ type }: HeaderProps) {
  const dispatch = useWordleDispatch()
  const gameStatus = useWordleSelector(selectGameStatus)
  // show end screen if it was not opened by click
  const showEndScreen = !useWordleSelector(
    selectWasModalOpenedByClick,
  )

  const [heading, setHeading] = useState('Wordle')
  const [subheading, setSubheading] = useState('')
  const [icon, setIcon] = useState(styles.icon_wordle)

  const [headingClass, setHeadingClass] = useState(
    styles.regiwallText_heading,
  )

  useEffect(() => {
    dispatch(trackStatsImpression(gameStatus !== 'IN_PROGRESS'))
  }, [])

  useEffect(() => {
    // if this is an end screen Regiwall or Stats modal not opened by click
    if (showEndScreen) {
      // check if the user won or lost
      if (gameStatus === 'WIN') {
        setHeading('Congratulations!')
        setIcon(styles.icon_congrats)
        setSubheading(
          type === HEADER_TYPE.stats
            ? ''
            : 'Want to see your stats and streaks?',
        )
        setHeadingClass(styles.regiwallText_heading)
      } else if (gameStatus === 'FAIL') {
        setHeading('Thanks for playing today!')
        setSubheading(
          type === HEADER_TYPE.stats
            ? ''
            : 'Want to see your stats and streaks?',
        )
        setHeadingClass(styles.regiwallText_heading)
      } else if (gameStatus === 'IN_PROGRESS') {
        setHeading('Here to see your stats and streaks?')
        setSubheading('')
        setHeadingClass(styles.regiwallText_heading_condensed)
      }
    }

    if (!showEndScreen) {
      setSubheading('')
      // if it's being added to the Regiwall modal opened by click
      if (type === HEADER_TYPE.regiwall) {
        setHeading('Here to see your stats and streaks?')
        setSubheading('')
        setHeadingClass(styles.regiwallText_heading_condensed)
        // if it's being added to the Stats modal
      } else if (type === HEADER_TYPE.stats) {
        setHeading('Wordle')
        setIcon(styles.icon_wordle)
        setHeadingClass(styles.regiwallText_heading)
        setSubheading('')
      }
    }
  }, [])

  return (
    <>
      {/* icon */}
      <div className={cn(styles.flexCenter)}>
        <div className={cn(styles.icon, icon)} />
      </div>
      {/* headings */}
      <h1 className={cn(styles.regiwallText, headingClass)}>
        {heading}
      </h1>
      <h2
        className={cn(
          styles.regiwallText,
          styles.regiwallText_subheading,
        )}
      >
        {subheading}
      </h2>
    </>
  )
}
