import React from 'react'
import cn from 'classnames'
import { formatDistance } from 'date-fns'
import type { WordleGameData } from '@nyt/games-schema'

import StatisticsContainer from '../Stats/StatisticsContainer'

import styles from './StatsSelectionTool.module.scss'

export type StatsOption = 'device' | 'account'

type Props = {
  option: StatsOption
  state: WordleGameData
  selectedOption: StatsOption | null
  todayStatus: 'unplayed' | 'in progress' | 'completed'
  label: string
  timestamp: number
  setOption: (opt: StatsOption) => void
}

export const StatsSelectionOption = ({
  option,
  selectedOption,
  todayStatus,
  label,
  state,
  timestamp,
  setOption,
}: Props) => {
  const now = React.useRef(new Date())
  const id = `s4t-${option}`
  const lastSaved = formatDistance(
    new Date(timestamp * 1000),
    now.current,
  )

  return (
    <label className={styles.option} htmlFor={id}>
      <div className={styles.optionHeader}>
        <span className={styles.label}>{label}</span>
        <span className={styles.lastSaved}>
          Last saved {lastSaved} ago
        </span>
      </div>
      <div
        className={cn(styles.box, {
          [styles.selected]: selectedOption === option,
          [styles.unselected]:
            selectedOption !== option && selectedOption !== null,
        })}
      >
        <div className={styles.boxTop}>
          <input
            name="statsSelection"
            className={styles.radio}
            value={option}
            type="radio"
            id={id}
            checked={selectedOption === option}
            onChange={() => setOption(option)}
          />
          <div className={styles.stats}>
            <StatisticsContainer stats={state.stats} small />
          </div>
        </div>
        <div
          className={cn(styles.boxBottom, {
            [styles.incomplete]: todayStatus !== 'completed',
          })}
        >
          Todayʼs puzzle {todayStatus}
        </div>
      </div>
    </label>
  )
}
