import React from 'react'
import { Provider } from 'react-redux'

import createStore from '../../store/index'
import { openError } from '../../store/overlays/overlays.actions'
import ErrorComponent from '../Error/Error'
import AppHeader from '../App/AppHeader'

const store = createStore()

const ErrorTemplate = ({ errorType = 'default' }) => {
  React.useEffect(() => {
    store.dispatch(openError(errorType))
  }, [errorType])

  return (
    <div>
      <AppHeader />
      <ErrorComponent />
    </div>
  )
}

export const Error = ErrorTemplate.bind({})
Error.args = {
  errorType: 'default',
}

export default {
  title: 'Wordle/Error',
  component: Error,
  decorators: [
    (Story) => (
      <Provider store={store}>
        <Story />
      </Provider>
    ),
  ],
  argTypes: {
    errorType: {
      options: ['default', 'offline'],
      control: {
        type: 'select',
      },
    },
    // Storybook doesn't like CSS variables, which is how dark mode is managed
    // in Wordle. We should find a workaround and restore this in the future.
    //  darkMode: {},
  },
}
