import React from 'react'
import { Provider } from 'react-redux'

import createStore from '../../store/index'
import LoadingComponent from '../Loading/Loading'
import AppHeader from '../App/AppHeader'

const store = createStore()

const LoadingTemplate = ({
  showSpinner = true,
  waitFor = 300,
  darkMode = false,
}) => {
  return (
    <div>
      <AppHeader />
      {showSpinner && (
        <LoadingComponent
          waitFor={waitFor}
          setBackground={darkMode ? 'dark' : 'light'}
        />
      )}
    </div>
  )
}

export const Loading = LoadingTemplate.bind({})
Loading.args = {
  showSpinner: true,
  waitFor: 300,
  darkMode: false,
}

export default {
  title: 'Wordle/Loading',
  component: Loading,
  decorators: [
    (Story) => (
      <Provider store={store}>
        <Story />
      </Provider>
    ),
  ],
  argTypes: {
    showSpinner: { control: 'boolean', default: true },
    waitFor: {
      control: {
        type: 'range',
        min: 0,
        max: 10000,
        step: 100,
        default: 300,
      },
    },
  },
}
