import React from 'react'
import { Provider } from 'react-redux'

import createStore from '../../store/index'
import { Welcome as WelcomeTemp } from '../Welcome/Welcome'
import {
  MOOGLE_GET_SUCCESS,
  SOLUTION_SUCCESS,
} from '../../store/api/api.actions'
import { START_GAME } from '../../store/game/game.actions'

const store = createStore()

const WelcomeTemplate = ({
  editor = 'Tracy Bennett',
  dayOffset = 245,
  loggedIn = false,
}) => {
  store.dispatch({
    type: START_GAME,
    payload: {
      dayOffset,
      id: 2,
      numRows: 6,
    },
  })

  store.dispatch({
    type: SOLUTION_SUCCESS,
    payload: {
      data: {
        dayOffset,
        editor: editor.length > 0 ? editor : undefined,
        solution: 'testy',
        id: 4,
      },
    },
  })

  if (loggedIn) {
    store.dispatch({
      type: MOOGLE_GET_SUCCESS,
      payload: {
        data: { user_id: 45 },
        optIn: true,
      },
    })
  }

  return (
    <div
      style={{
        position: 'absolute',
        width: '100%',
        height: '100%',
        top: 0,
        left: 0,
      }}
    >
      <WelcomeTemp transition={() => {}} />
    </div>
  )
}

export const Welcome = WelcomeTemplate.bind({})
Welcome.args = {
  editor: 'Tracy Bennett',
  dayOffset: 501,
  loggedIn: false,
}

export default {
  title: 'Wordle/Moments/Welcome',
  component: Welcome,
  decorators: [
    (Story) => (
      <Provider store={store}>
        <Story />
      </Provider>
    ),
  ],
}
