import React, { useState } from 'react'
import cn from 'classnames'

import useTimeout from '../../../../shared/hooks/use-timeout'
import { removeToast } from '../../store/overlays/overlays.actions'
import { ToastState } from '../../store/overlays/overlays.state'
import { useWordleDispatch } from '../../store/types'

import styles from './Toast.module.scss'

type ToastProps = {
  toast: ToastState
}

export default function Toast({ toast }: ToastProps) {
  const { text, duration, timestamp } = toast
  const dispatch = useWordleDispatch()
  const [fade, setFade] = useState(false)
  
  // GAMES_wordleWebStatsRegiWall_1023 experiment
  const isRegiwallToast = text === 'You are now logged in to your Times account.'

  useTimeout(
    () => setFade(true),
    duration === Infinity ? null : duration,
  )

  return (
    <div
      className={cn(styles.toast, isRegiwallToast && styles.toast_regiwall, { [styles.fade]: fade })}
      onTransitionEnd={() => {
        dispatch(removeToast(text, timestamp))
      }}
      aria-live="polite"
    >
      {text}
    </div>
  )
}
