import React from 'react'

import { selectToasts } from '../../store/overlays/overlays.selectors'
import { ToastState } from '../../store/overlays/overlays.state'
import { useWordleSelector } from '../../store/types'

import styles from './ToastContainer.module.scss'
import Toast from './Toast'

export default function ToastContainer() {
  const toasts = useWordleSelector(selectToasts)

  const systemToasts = toasts.filter((t) => t.isSystem)
  const gameToasts = toasts.filter((t) => !t.isSystem)

  const renderToasts = (toasts: ToastState[], id: string) => (
    <div className={styles.toastContainer}>
      <div className={styles.toaster} id={id}>
        {toasts.map((toast) => {
          return (
            <Toast
              key={`${toast.text}-${toast.timestamp}`}
              toast={toast}
            />
          )
        })}
      </div>
    </div>
  )

  return (
    <>
      {renderToasts(gameToasts, styles.gameToaster)}
      {renderToasts(systemToasts, styles.systemToaster)}
    </>
  )
}
