import React from 'react'
import { Provider } from 'react-redux'
import { fireEvent, render, screen } from '@testing-library/react'

import createStore from '../../store'
import { openPage } from '../../store/overlays/overlays.actions'

import Note from './Note'

jest.mock('foundation', () => ({
  env: { version: 'test' },
  trackModuleInteraction: jest.fn(),
}))

const closeMoment = jest.fn()
const trackLink = jest.fn()

describe('Note', () => {
  const renderNote = () => {
    const store = createStore()
    store.dispatch = jest.fn()

    render(
      <Provider store={store}>
        <Note closeMoment={closeMoment} trackLink={trackLink} />,
      </Provider>,
    )

    return { store }
  }

  it('renders text on screen', () => {
    renderNote()
    const noteDescription = screen.getByText(
      'See your stats wherever you play.',
    )

    const noteSummary = screen.getByText(
      'To see your stats in the app, go to where you normally play and link them to a free account.',
    )

    expect(noteDescription).toBeTruthy()
    expect(noteSummary).toBeTruthy()
  })

  it('fires actions on `Tell me more` click', () => {
    const { store } = renderNote()

    const tellMeMoreButton = screen.getByText('Tell me more')
    fireEvent.click(tellMeMoreButton)

    expect(closeMoment).toHaveBeenCalled()
    expect(store.dispatch).toHaveBeenCalledWith(openPage('linkInfo'))
    expect(trackLink).toHaveBeenCalled()
  })
})
