import React from 'react'

import { useWordleDispatch } from '../../store/types'
import { openPage } from '../../store/overlays/overlays.actions'

import styles from './Note.module.scss'

type NoteProps = {
  closeMoment: () => void
  trackLink: () => void
}

export default function Note({ closeMoment, trackLink }: NoteProps) {
  const dispatch = useWordleDispatch()

  const tellMeMore = () => {
    closeMoment()
    dispatch(openPage('linkInfo'))
    trackLink()
  }

  return (
    <div className={styles.container}>
      <div className={styles.note}>
        <div className={styles.statsIcon}>
          <img
            alt="Wordle"
            style={{ content: 'var(--wordle-stats-mini)' }}
          />
        </div>
        <div>
          <div className={styles.noteHeader}>NOTE</div>
          <div className={styles.noteDescription}>
            See your stats wherever you play.
          </div>
          <div className={styles.noteSummary}>
            To see your stats in the app, go to where you normally
            play and link them to a free account.
          </div>
          <button
            className={styles.moreLink}
            type="button"
            onClick={tellMeMore}
          >
            Tell me more
          </button>
        </div>
      </div>
    </div>
  )
}
