import React from 'react'
import { Provider } from 'react-redux'
import {
  act,
  fireEvent,
  render,
  screen,
  waitFor,
} from '@testing-library/react'

import createStore from '../../store'

import { WelcomeLoading } from './WelcomeLoading'

jest.mock('foundation', () => ({
  env: { version: 'test' },
}))

const transition = jest.fn((to: 'welcome') => {})

describe('WelcomeLoading', () => {
  beforeAll(() => jest.useFakeTimers())
  afterAll(() => jest.useRealTimers())

  const renderLoading = (
    hasLoaded: boolean,
    transition: (to: 'welcome') => void,
  ) => {
    const store = createStore()

    render(
      <Provider store={store}>
        <WelcomeLoading
          hasLoaded={hasLoaded}
          transition={transition}
        />
        ,
      </Provider>,
    )
    return { store }
  }

  it('does not show back button for non-hybrid', () => {
    const { store } = renderLoading(true, transition)

    const backButton = screen.queryByTestId('back-button')
    expect(backButton).toBeNull()
  })

  it('shows back button for hybrid', () => {
    window.isHybridWebView = true
    // @ts-ignore
    window.NativeBridge = true
    const { store } = renderLoading(true, transition)

    const backButton = screen.queryByTestId('back-button')
    expect(backButton).toBeTruthy()
  })

  it('does not show spinner and calls transition and if hasLoaded is true', async () => {
    renderLoading(true, transition)
    expect(screen.queryByTestId('spinner')).toBeNull()
    jest.advanceTimersByTime(301)
    await waitFor(() => {
      expect(transition).toHaveBeenCalled()
      expect(screen.queryByTestId('spinner')).toBeNull()
    })
  })

  it('shows spinner after 300ms when hasLoaded is true', () => {
    act(() => {
      renderLoading(false, transition)
      expect(screen.queryByTestId('spinner')).toBeNull()
      jest.advanceTimersByTime(301)
      expect(screen.queryByTestId('spinner')).toBeTruthy()
    })
  })
})
