import React from 'react'

import useTimeout from '../../../../shared/hooks/use-timeout'
import { BackButton, HybridOnly } from '../../../../shared/Hybrid'
import Spinner from '../Loading/Spinner'

import styles from './Welcome.module.scss'
import { IconAndTitle } from './WelcomeHelpers'

type WelcomeLoadingProps = {
  hasLoaded: boolean
  transition: (to: 'welcome') => void
}

export const WelcomeLoading = ({
  hasLoaded,
  transition,
}: WelcomeLoadingProps) => {
  const [showSpinner, setShowSpinner] = React.useState(false)

  useTimeout(() => setShowSpinner(true), hasLoaded ? null : 300)

  React.useEffect(() => {
    if (hasLoaded) {
      transition('welcome')
    }
  }, [hasLoaded])

  return (
    <div className={styles.contentWelcome}>
      <HybridOnly>
        <div className={styles.back}>
          <BackButton
            trackData={{
              elementName: 'wordle',
              moduleLabel: 'loading',
            }}
          />
        </div>
      </HybridOnly>
      <div className={styles.contentWelcomeContainer}>
        {showSpinner && (
          <>
            <IconAndTitle small />
            <div className={styles.spinner}>
              <Spinner />
            </div>
          </>
        )}
      </div>
    </div>
  )
}
