import { Reducer } from 'redux'

import type { WordleAction } from '../types'

import {
  LOAD_MOOGLE_GET,
  LOAD_SOLUTION,
  MOOGLE_GET_ERROR,
  MOOGLE_GET_SUCCESS,
  SOLUTION_ERROR,
  SOLUTION_SUCCESS,
  LOAD_MOOGLE_POST,
  MOOGLE_POST_SUCCESS,
  MOOGLE_POST_ERROR,
  MOOGLE_POST_RESET,
  APP_LOADED,
  DATA_FETCHED,
  RESTART_LOAD,
} from './api.actions'
import { WordleApiState } from './api.state'

const initialState: WordleApiState = {
  moogleGet: {
    isLoading: false,
    error: false,
    errorMessage: null,
    data: null,
  },
  mooglePost: {
    isLoading: false,
    error: false,
    lastFailedSaveData: null,
  },
  solution: {
    isLoading: false,
    error: false,
    data: null,
  },
  dataFetched: false,
  appLoaded: false,
}

const reducer: Reducer<WordleApiState, WordleAction> = (
  state = initialState,
  action,
): WordleApiState => {
  switch (action.type) {
    case LOAD_MOOGLE_GET: {
      return {
        ...state,
        moogleGet: {
          ...state.moogleGet,
          isLoading: true,
        },
      }
    }

    case LOAD_SOLUTION: {
      return {
        ...state,
        solution: {
          ...state.solution,
          isLoading: true,
        },
      }
    }

    case MOOGLE_GET_SUCCESS: {
      const { data } = action.payload
      return {
        ...state,
        moogleGet: {
          ...state.moogleGet,
          data,
          isLoading: false,
          error: false,
        },
      }
    }

    case SOLUTION_SUCCESS: {
      const { solution, id, dayOffset, editor } = action.payload.data

      return {
        ...state,
        solution: {
          ...state.solution,
          data: {
            solution,
            id,
            dayOffset,
            editor,
          },
          isLoading: false,
          error: false,
        },
      }
    }

    case MOOGLE_GET_ERROR: {
      return {
        ...state,
        moogleGet: {
          ...state.moogleGet,
          isLoading: false,
          error: true,
          errorMessage: action.payload.message,
        },
      }
    }

    case SOLUTION_ERROR: {
      return {
        ...state,
        solution: {
          ...state.solution,
          isLoading: false,
          error: true,
        },
      }
    }

    case LOAD_MOOGLE_POST: {
      return {
        ...state,
        mooglePost: {
          ...state.mooglePost,
          isLoading: true,
          error: false,
        },
      }
    }

    case MOOGLE_POST_SUCCESS: {
      return {
        ...state,
        mooglePost: {
          isLoading: false,
          error: false,
          lastFailedSaveData: null,
        },
      }
    }

    case MOOGLE_POST_ERROR: {
      return {
        ...state,
        mooglePost: {
          isLoading: false,
          error: true,
          // TODO: do we need a timestamp comparison, here? is there an edge case bug, if multiple failures happen but are captured in incorrect order?
          lastFailedSaveData: action.payload.saveData,
        },
      }
    }

    case APP_LOADED: {
      return {
        ...state,
        appLoaded: true,
      }
    }

    case DATA_FETCHED: {
      return {
        ...state,
        dataFetched: true,
      }
    }

    case RESTART_LOAD: {
      return {
        ...state,
        appLoaded: false,
        dataFetched: false,
      }
    }

    // TODO: what is this for and how is it different from MOOGLE_POST_SUCCESS?
    case MOOGLE_POST_RESET: {
      return {
        ...state,
        mooglePost: {
          isLoading: false,
          error: false,
          lastFailedSaveData: null,
        },
      }
    }

    default:
      return state
  }
}

export default reducer
