import { createSelector } from 'reselect'
import { WordleGameData } from '@nyt/games-schema'

import type { WordleStoreState } from '../types'

const selectApi = (state: WordleStoreState) => state.api

//        //
// Moogle //
//        //
export const selectMoogleGetState = createSelector(
  selectApi,
  (state) => state.moogleGet,
)

export const selectMoogleError = createSelector(
  selectApi,
  (state) => state.moogleGet.error,
)

export const selectAppLoaded = createSelector(
  selectApi,
  (state) => state.appLoaded,
)

export const selectDataFetched = createSelector(
  selectApi,
  (state) => state.dataFetched,
)

export const selectMoogleIsLoading = createSelector(
  selectApi,
  (state) => state.moogleGet.isLoading,
)

const selectMoogleData = createSelector(
  selectApi,
  (state) => state.moogleGet.data,
)

export const selectMoogleGameData = createSelector(
  selectMoogleData,
  (data): WordleGameData | null =>
    (data?.game_data as WordleGameData) || null,
)

export const selectMoogleTimestamp = createSelector(
  selectMoogleData,
  (data) => data?.timestamp,
)

export const selectMoogleUser = createSelector(
  selectMoogleData,
  (data) => data?.user_id,
)

export const selectIsSavingState = createSelector(
  [selectMoogleUser],
  (user) => !!user,
)

export const selectIsFirstMoogleSave = createSelector(
  [selectMoogleUser, selectMoogleTimestamp],
  (regiId, timestamp) =>
    // no timestamp means we had no backend data stored for this user when the page loaded
    !!regiId && !timestamp,
)

export const selectMooglePostIsLoading = createSelector(
  selectApi,
  (state) => state.mooglePost.isLoading,
)

export const selectMooglePostError = createSelector(
  selectApi,
  (state) => state.mooglePost.error,
)

export const selectMooglePostUnsavedData = createSelector(
  selectApi,
  (state) => state.mooglePost.lastFailedSaveData,
)

//          //
// Solution //
//          //
export const selectSolutionState = createSelector(
  selectApi,
  (state) => state?.solution,
)

export const selectSolutionIsLoading = createSelector(
  selectSolutionState,
  (state) => state?.isLoading,
)

export const selectSolutionData = createSelector(
  selectSolutionState,
  (state) => state?.data,
)

export const selectId = createSelector(
  selectSolutionData,
  (state) => state?.id || 0,
)

export const selectEditor = createSelector(
  selectSolutionData,
  (state) => state?.editor || undefined,
)

export const selectSolution = createSelector(
  selectSolutionData,
  (state) => {
    return state?.solution || ''
  },
)

export const selectApiDayOffset = createSelector(
  selectSolutionData,
  (state) => {
    return state?.dayOffset || 0
  },
)
