import { Reducer } from 'redux'

import type { WordleAction } from '../types'
import { SET_INITIAL_STATE } from '../moogle/moogle.actions'

import {
  START_GAME,
  ADD_LETTER,
  BACKSPACE,
  EVALUATE_ROW,
} from './game.actions'
import { WordleGameState } from './game.state'

const initialState: WordleGameState = {
  id: null,
  boardState: [],
  dayOffset: null,
  currentRowIndex: 0,
  timestamps: {
    lastPlayed: null,
    lastCompleted: null,
  },
  status: 'IN_PROGRESS',
}

const reducer: Reducer<WordleGameState, WordleAction> = (
  state = initialState,
  action,
): WordleGameState => {
  switch (action.type) {
    case SET_INITIAL_STATE: {
      if (action.payload?.game) {
        return action.payload.game
      }

      return state
    }

    case START_GAME: {
      const { numRows, id, dayOffset } = action.payload

      return {
        ...state,
        id,
        dayOffset,
        boardState: Array(numRows).fill(''),
        currentRowIndex: 0,
        status: 'IN_PROGRESS',
      }
    }

    case ADD_LETTER: {
      return {
        ...state,
        boardState: state.boardState.map((guess, i) => {
          if (i === state.currentRowIndex) {
            return `${guess}${action.payload.letter}`
          }

          return guess
        }),
      }
    }

    case BACKSPACE: {
      return {
        ...state,
        boardState: state.boardState.map((guess, i) => {
          if (i === state.currentRowIndex) {
            return guess.slice(0, guess.length - 1)
          }

          return guess
        }),
      }
    }

    case EVALUATE_ROW: {
      const { now, status } = action.payload

      return {
        ...state,
        currentRowIndex: state.currentRowIndex + 1,
        // these timestamps are deprecated and should not be used in any logic,
        // but we'll continue writing to them
        timestamps: {
          ...state.timestamps,
          lastCompleted:
            status === 'IN_PROGRESS'
              ? state.timestamps.lastCompleted
              : now,
          lastPlayed: now,
        },
        status,
      }
    }

    default:
      return state
  }
}

export default reducer
