import { ModalName, PageName, ErrorName } from './overlays.state'

export const OPEN_MODAL = 'wordle/overlays/OPEN_MODAL'
export const CLOSE_MODAL = 'wordle/overlays/CLOSE_MODAL'
export const OPEN_PAGE = 'wordle/overlays/OPEN_PAGE'
export const CLOSE_PAGE = 'wordle/overlays/CLOSE_PAGE'
export const WILL_CLOSE_PAGE = 'wordle/overlays/WILL_CLOSE_PAGE'
export const OPEN_ERROR = 'wordle/overlays/OPEN_ERROR'
export const CLOSE_ERROR = 'wordle/overlays/CLOSE_ERROR'
export const OPEN_NAV_MODAL = 'wordle/overlays/OPEN_NAV_MODAL'
export const CLOSE_NAV_MODAL = 'wordle/overlays/CLOSE_NAV_MODAL'
export const TRACK_NAV_MODAL_ITEM =
  'wordle/overlays/TRACK_NAV_MODAL_ITEM'
export const ADD_TOAST = 'wordle/overlays/ADD_TOAST'
export const REMOVE_TOAST = 'wordle/overlays/REMOVE_TOAST'
export const TRACK_AUTH_CLICK = 'wordle/overlays/TRACK_AUTH_CLICK'
export const TRACK_AUTH_IMPRESSION =
  'wordle/overlays/TRACK_AUTH_IMPRESSION'

type OpenModalAction = {
  type: typeof OPEN_MODAL
  payload: {
    modal: ModalName
    isClicked: boolean
  }
}

type CloseModalAction = {
  type: typeof CLOSE_MODAL
}

type OpenPageAction = {
  type: typeof OPEN_PAGE
  payload: {
    page: PageName
  }
}

type ClosePageAction = {
  type: typeof CLOSE_PAGE
}

type WillClosePageAction = {
  type: typeof WILL_CLOSE_PAGE
}

type OpenErrorAction = {
  type: typeof OPEN_ERROR
  payload: {
    error: ErrorName
  }
}

type CloseErrorAction = {
  type: typeof CLOSE_ERROR
}

type OpenNavModalAction = {
  type: typeof OPEN_NAV_MODAL
}

type TrackNavModalItemAction = {
  type: typeof TRACK_NAV_MODAL_ITEM
  payload: {
    name: string
    label: string
    useBeacon: boolean
    context: null
  }
}

type CloseNavModalAction = {
  type: typeof CLOSE_NAV_MODAL
}

export type AddToastAction = {
  type: typeof ADD_TOAST
  payload: {
    text: string
    duration?: number
    isSystem?: boolean
    timestamp: number
    invalidate?: boolean
    win?: boolean
  }
}

export type RemoveToastAction = {
  type: typeof REMOVE_TOAST
  payload: {
    text: string
    timestamp: number
  }
}

type TrackAuthClick = {
  type: typeof TRACK_AUTH_CLICK
  payload: {
    label: string | null
    sendContext: boolean
    element?: {
      label: string
      name: string
    }
  }
}

type TrackAuthImpression = {
  type: typeof TRACK_AUTH_IMPRESSION
  payload: {
    name: string
    region: string
    label?: string
  }
}

export const openModal = (
  name: ModalName,
  isClicked: boolean = false,
): OpenModalAction => ({
  type: OPEN_MODAL,
  payload: { modal: name, isClicked },
})

export const openPage = (name: PageName): OpenPageAction => ({
  type: OPEN_PAGE,
  payload: { page: name },
})

export const closeModal = (): CloseModalAction => ({
  type: CLOSE_MODAL,
})

export const closePage = (): ClosePageAction => ({
  type: CLOSE_PAGE,
})

export const willClosePage = (): WillClosePageAction => ({
  type: WILL_CLOSE_PAGE,
})

export const openError = (name: ErrorName): OpenErrorAction => ({
  type: OPEN_ERROR,
  payload: { error: name },
})

export const closeError = (): CloseErrorAction => ({
  type: CLOSE_ERROR,
})

export const openNavModal = (): OpenNavModalAction => ({
  type: OPEN_NAV_MODAL,
})

export const closeNavModal = (): CloseNavModalAction => ({
  type: CLOSE_NAV_MODAL,
})

export const trackNavModalItem = (
  name: string,
  label: string,
  useBeacon: boolean,
  context: null,
): TrackNavModalItemAction => ({
  type: TRACK_NAV_MODAL_ITEM,
  payload: { name, label, useBeacon, context },
})

export const addToast = (
  payload: Omit<AddToastAction['payload'], 'timestamp'>,
): AddToastAction => ({
  type: ADD_TOAST,
  payload: { ...payload, timestamp: Date.now() },
})

export const removeToast = (
  text: string,
  timestamp: number,
): RemoveToastAction => ({
  type: REMOVE_TOAST,
  payload: { text, timestamp },
})

// Note: DIG said that all interactions should have
// element.label and element.name. The label property
// is used when additional info is necessary
export const trackAuthClick = (
  label: string | null = null,
  sendContext: boolean,
  element?: {
    label: string
    name: string
  },
): TrackAuthClick => ({
  type: TRACK_AUTH_CLICK,
  payload: { label, sendContext, element },
})

export const trackAuthImpression = (
  name: string,
  region: string,
  label?: string,
): TrackAuthImpression => ({
  type: TRACK_AUTH_IMPRESSION,
  payload: { name, region, label },
})

export type WordleOverlaysAction =
  | OpenModalAction
  | CloseModalAction
  | OpenPageAction
  | ClosePageAction
  | WillClosePageAction
  | OpenErrorAction
  | CloseErrorAction
  | OpenNavModalAction
  | CloseNavModalAction
  | TrackNavModalItemAction
  | AddToastAction
  | RemoveToastAction
  | TrackAuthClick
  | TrackAuthImpression
