import { Reducer } from 'redux'

import type { WordleAction } from '../types'

import { ToastState, WordleOverlaysState } from './overlays.state'
import {
  OPEN_MODAL,
  CLOSE_MODAL,
  OPEN_PAGE,
  CLOSE_PAGE,
  WILL_CLOSE_PAGE,
  OPEN_ERROR,
  CLOSE_ERROR,
  OPEN_NAV_MODAL,
  CLOSE_NAV_MODAL,
  ADD_TOAST,
  REMOVE_TOAST,
} from './overlays.actions'

const DEFAULT_TOAST_VISIBLE_TIME = 1000

const initialState: WordleOverlaysState = {
  modal: null,
  page: null,
  error: null,
  isNavModalOpen: false,
  toasts: [],
  isPageClosing: false,
  wasModalOpenedByClick: false,
}

const reducer: Reducer<WordleOverlaysState, WordleAction> = (
  state = initialState,
  action,
) => {
  switch (action.type) {
    case OPEN_MODAL: {
      return {
        ...state,
        modal: action.payload.modal,
        wasModalOpenedByClick: action.payload.isClicked,
      }
    }

    case CLOSE_MODAL: {
      return {
        ...state,
        modal: null,
        wasModalOpenedByClick: false,
      }
    }

    case OPEN_PAGE: {
      return {
        ...state,
        page: action.payload.page,
      }
    }

    case CLOSE_PAGE: {
      return {
        ...state,
        page: null,
        isPageClosing: false,
      }
    }

    case OPEN_ERROR: {
      return {
        ...state,
        error: action.payload.error,
      }
    }

    case CLOSE_ERROR: {
      return {
        ...state,
        error: null,
      }
    }

    case OPEN_NAV_MODAL: {
      return {
        ...state,
        isNavModalOpen: true,
      }
    }

    case CLOSE_NAV_MODAL: {
      return {
        ...state,
        isNavModalOpen: false,
      }
    }

    case ADD_TOAST: {
      const { text, duration, isSystem, timestamp } = action.payload

      const toast: ToastState = {
        text,
        duration: duration || DEFAULT_TOAST_VISIBLE_TIME,
        isSystem,
        timestamp,
      }

      const { toasts } = state
      return {
        ...state,
        toasts: [toast, ...toasts],
      }
    }

    case REMOVE_TOAST: {
      const { text, timestamp } = action.payload
      const { toasts } = state
      const filteredToasts = toasts.filter(
        (t) => t.text !== text || t.timestamp !== timestamp,
      )

      return {
        ...state,
        toasts: filteredToasts,
      }
    }

    case WILL_CLOSE_PAGE: {
      return {
        ...state,
        isPageClosing: true,
      }
    }

    default:
      return state
  }
}

export default reducer
