import { Reducer } from 'redux'

import type { WordleAction } from '../types'
import { SET_INITIAL_STATE } from '../moogle/moogle.actions'

import { CHANGE_SETTING } from './settings.actions'
import { WordleSettingsState } from './settings.state'

const getInitialDarkMode = () => {
  return document.body?.className?.includes('dark') || false
}

const initialState: WordleSettingsState = {
  hardMode: false,
  darkMode: getInitialDarkMode(),
  colorblindMode: false,
}

const reducer: Reducer<WordleSettingsState, WordleAction> = (
  state = initialState,
  action,
) => {
  switch (action.type) {
    case SET_INITIAL_STATE: {
      if (action.payload?.settings) {
        return action.payload.settings
      }

      return state
    }

    case CHANGE_SETTING: {
      const { name, value } = action.payload
      return {
        ...state,
        [name]: value,
      }
    }

    default:
      return state
  }
}

export default reducer
