import { DeepPartial } from 'redux'

import { WordleStoreState } from '../types'

import { selectShareMessage } from './stats.selectors'

describe('stats selectors: selectShareMessage', () => {
  const buildState = ({
    colorblindMode = false,
    darkMode = false,
    hardMode = false,
    boardState = ['testy'],
  } = {}) => {
    const state: DeepPartial<WordleStoreState> = {
      persist: {
        game: {
          boardState,
          currentRowIndex: boardState.length,
          dayOffset: 42,
          status: 'WIN',
        },
        settings: {
          hardMode,
          darkMode,
          colorblindMode,
        },
      },
      api: {
        solution: {
          data: {
            solution: 'testy',
            id: 1,
            dayOffset: 1,
          },
        },
      },
    }

    return state as WordleStoreState
  }

  it('should share a genius answer', () => {
    const state = buildState()
    const { text } = selectShareMessage(state)
    expect(text).toEqual(`Wordle 42 1/6\n\n🟩🟩🟩🟩🟩`)
  })

  it('should share in hard mode', () => {
    const state = buildState({ hardMode: true })
    const { text } = selectShareMessage(state)
    expect(text).toEqual(`Wordle 42 1/6*\n\n🟩🟩🟩🟩🟩`)
  })

  it('should share a 2 guess answer in colorblind mode', () => {
    const state = buildState({
      colorblindMode: true,
      boardState: ['guess', 'testy'],
    })
    const { text } = selectShareMessage(state)
    expect(text).toEqual(`Wordle 42 2/6\n\n⬜⬜🟦🟦⬜\n🟧🟧🟧🟧🟧`)
  })

  it('should share a 2 guess answer in dark mode', () => {
    const state = buildState({
      darkMode: true,
      boardState: ['guess', 'testy'],
    })
    const { text } = selectShareMessage(state)
    expect(text).toEqual(`Wordle 42 2/6\n\n⬛⬛🟨🟨⬛\n🟩🟩🟩🟩🟩`)
  })
})
