import { abra } from 'foundation'

import {
  selectCurrentRowIndex,
  selectGameStatus,
} from '../game/game.selectors'
import { WINNING_STRINGS } from '../game/game.constants'
import type { WordleThunk } from '../types'
import { addToast, openModal } from '../overlays/overlays.actions'
import {
  selectMoogleUser,
  selectSolution,
} from '../api/api.selectors'

import { selectIsRestoringSession } from './transient.selectors'

export const LAST_TILE_REVEAL = 'wordle/transient/LAST_TILE_REVEAL'
export const REMOVE_INVALID = 'wordle/transient/REMOVE_INVALID'

type LastTileRevealAction = {
  type: typeof LAST_TILE_REVEAL
}

type RemoveInvalidAction = {
  type: typeof REMOVE_INVALID
}

export type WordleTransientAction =
  | LastTileRevealAction
  | RemoveInvalidAction

export const removeInvalid = (): RemoveInvalidAction => ({
  type: REMOVE_INVALID,
})

export const lastTileRevealed =
  (rowIndex: number): WordleThunk =>
  (dispatch, getState) => {
    const state = getState()

    const currentRowIndex = selectCurrentRowIndex(state)
    const status = selectGameStatus(state)
    const solution = selectSolution(state)
    const isRestoringSession = selectIsRestoringSession(state)
    const isLoggedIn = !!selectMoogleUser(state)

    // GAMES_wordleWebStatsRegiWall_1023 experiment
    const regiwallPromptVariant = abra.getVariant(
      'GAMES_wordleWebStatsRegiWall_1023',
    )

    const showRegiwallModal =
      !isLoggedIn &&
      (regiwallPromptVariant === '1_modal' ||
        regiwallPromptVariant === '2_congrats')

    const regiwallModal =
      regiwallPromptVariant === '1_modal'
        ? 'loginPrompt'
        : 'regiwallModal'

    if (rowIndex !== currentRowIndex - 1) {
      return
    }

    dispatch({ type: LAST_TILE_REVEAL })

    // Shows the modal on win, or after reload with a win in localStorage
    if (['WIN', 'FAIL'].includes(status)) {
      // If we're restoring a previous game session, we want to bypass winning/losing states
      if (isRestoringSession) {
        return dispatch(
          openModal(
            showRegiwallModal ? 'regiwallModal' : 'stats',
            true,
          ),
        )
      }

      if (status === 'WIN') {
        const text = WINNING_STRINGS[currentRowIndex - 1]
        dispatch(addToast({ text, duration: 2000, win: true }))
      }

      if (status === 'FAIL') {
        dispatch(
          addToast({
            text: solution.toUpperCase(),
            duration: Infinity,
          }),
        )
      }

      setTimeout(() => {
        return dispatch(
          openModal(
            showRegiwallModal ? regiwallModal : 'stats',
            false,
          ),
        )
      }, 2500)
    }
  }
