import { Reducer } from 'redux'

import {
  BACKSPACE,
  CONTINUE_GAME,
  EVALUATE_ROW,
} from '../game/game.actions'
import { ADD_TOAST } from '../overlays/overlays.actions'
import type { WordleAction } from '../types'

import { LAST_TILE_REVEAL, REMOVE_INVALID } from './transient.actions'
import { WordleTransientState } from './transient.state'

const initialState: WordleTransientState = {
  isAnimatingRow: false,
  lastRowInvalid: false,
  lastRowWin: false,
  isRestoringSession: false,
}

const reducer: Reducer<WordleTransientState, WordleAction> = (
  state = initialState,
  action,
) => {
  switch (action.type) {
    case BACKSPACE: {
      return {
        ...state,
        lastRowInvalid: false,
      }
    }

    case ADD_TOAST: {
      const { invalidate, win } = action.payload

      if (invalidate) {
        // triggers shake animation on invalid guess
        return {
          ...state,
          lastRowInvalid: true,
        }
      }

      if (win) {
        // triggers win animation on winning guess
        return {
          ...state,
          lastRowWin: true,
        }
      }

      return state
    }

    case REMOVE_INVALID: {
      return {
        ...state,
        lastRowInvalid: false,
      }
    }

    case CONTINUE_GAME: {
      // if there are no rows to animate, don't disable input
      if (action.payload.currentRowIndex === 0) {
        return state
      }

      return {
        ...state,
        isAnimatingRow: true,
        isRestoringSession: true,
      }
    }

    case EVALUATE_ROW: {
      return {
        ...state,
        isAnimatingRow: true,
      }
    }

    case LAST_TILE_REVEAL: {
      return {
        ...state,
        isAnimatingRow: false,
        isRestoringSession: false,
      }
    }

    default:
      return state
  }
}

export default reducer
