import { DeepPartial } from 'redux'

import { WordleStoreState } from '../types'

import { selectKeyboardLetterEvaluations } from './transient.selectors'

describe('selectKeyboardLetterEvaluations', () => {
  const buildState = ({
    boardState = ['testy'],
    currentRowIndex = 1,
    isRestoringSession = false,
    isAnimatingRow = false,
  } = {}) => {
    const state: DeepPartial<WordleStoreState> = {
      persist: {
        game: {
          boardState,
          currentRowIndex,
        },
      },
      transient: {
        isRestoringSession,
        isAnimatingRow,
      },
      api: {
        solution: {
          data: {
            solution: 'testy',
            id: 1,
            dayOffset: 1,
          },
        },
      },
    }

    return state as WordleStoreState
  }

  it('should include correct letters', () => {
    const state = buildState()
    const letterEvals = selectKeyboardLetterEvaluations(state)
    expect(letterEvals.t).toEqual('correct')
    expect(letterEvals.e).toEqual('correct')
    expect(letterEvals.s).toEqual('correct')
    expect(letterEvals.y).toEqual('correct')
    expect(Object.keys(letterEvals).length).toEqual(4)
  })

  it('should be empty while restoring session', () => {
    const state = buildState({ isRestoringSession: true })
    const letterEvals = selectKeyboardLetterEvaluations(state)
    expect(Object.keys(letterEvals).length).toEqual(0)
  })

  it('should include correct, present, and absent evaluations', () => {
    const state = buildState({ boardState: ['toast'] })
    const letterEvals = selectKeyboardLetterEvaluations(state)
    expect(letterEvals.t).toEqual('correct')
    expect(letterEvals.o).toEqual('absent')
    expect(letterEvals.a).toEqual('absent')
    expect(letterEvals.s).toEqual('present')
    expect(Object.keys(letterEvals).length).toEqual(4)
  })

  it('should not include last row while animating', () => {
    const state = buildState({
      boardState: ['toast', 'testy'],
      currentRowIndex: 2,
      isAnimatingRow: true,
    })
    const letterEvals = selectKeyboardLetterEvaluations(state)
    expect(letterEvals.t).toEqual('correct')
    expect(letterEvals.o).toEqual('absent')
    expect(letterEvals.a).toEqual('absent')
    expect(letterEvals.s).toEqual('present')
    expect(Object.keys(letterEvals).length).toEqual(4)
  })
})
