import { createSelector } from 'reselect'

import {
  Evaluation,
  getLetterEvaluations,
} from '../../utils/gamelogic'
import { NUM_ROWS } from '../game/game.constants'
import {
  selectModal,
  selectPage,
} from '../overlays/overlays.selectors'
import {
  selectGameStatus,
  selectCurrentRowIndex,
  selectBoardState,
  selectEvaluations,
} from '../game/game.selectors'
import type { WordleStoreState } from '../types'

const selectTransientState = (state: WordleStoreState) =>
  state.transient

const selectIsAnimatingRow = createSelector(
  selectTransientState,
  (state) => state.isAnimatingRow,
)

export const selectIsRestoringSession = createSelector(
  selectTransientState,
  (state) => state.isRestoringSession,
)

export const selectLastRowInvalid = createSelector(
  selectTransientState,
  (state) => state.lastRowInvalid,
)

export const selectLastRowWin = createSelector(
  selectTransientState,
  (state) => state.lastRowWin,
)

export const selectInputDisabled = createSelector(
  [
    selectGameStatus,
    selectIsAnimatingRow,
    selectCurrentRowIndex,
    selectModal,
    selectPage,
  ],
  (
    status,
    isAnimating,
    rowIndex,
    currentModalOpen,
    currentPageOpen,
  ) =>
    status !== 'IN_PROGRESS' ||
    isAnimating ||
    currentModalOpen ||
    currentPageOpen ||
    rowIndex >= NUM_ROWS,
)

export const selectKeyboardLetterEvaluations = createSelector(
  [
    selectBoardState,
    selectEvaluations,
    selectCurrentRowIndex,
    selectIsAnimatingRow,
    selectIsRestoringSession,
  ],
  (
    boardState,
    allEvaluations,
    currentRowIndex,
    isAnimatingRow,
    isRestoringSession,
  ): Record<string, Evaluation> => {
    // don't show keyboard colors during opening row animation
    if (isRestoringSession) {
      return {}
    }

    // if the row is animating, don't include it in evals yet
    const rowIndex = isAnimatingRow
      ? currentRowIndex - 1
      : currentRowIndex
    const evaluations = allEvaluations.slice(0, rowIndex)
    return getLetterEvaluations(boardState, evaluations)
  },
)
