import { Middleware } from 'redux'
import {
  TypedUseSelectorHook,
  useDispatch,
  useSelector,
} from 'react-redux'
import { ThunkAction, ThunkDispatch } from 'redux-thunk'

import type { WordleGameAction } from './game/game.actions'
import type { WordleMoogleAction } from './moogle/moogle.actions'
import type { WordleOverlaysAction } from './overlays/overlays.actions'
import type { WordleSettingsAction } from './settings/settings.actions'
import type { WordleTransientAction } from './transient/transient.actions'
import type { WordleStatsAction } from './stats/stats.actions'
import { WordleApiAction } from './api/api.actions'
import { rootReducer } from './wordleReducer'

export type WordleStoreState = ReturnType<typeof rootReducer>

export type WordleAction =
  | WordleGameAction
  | WordleOverlaysAction
  | WordleSettingsAction
  | WordleMoogleAction
  | WordleTransientAction
  | WordleStatsAction
  | WordleApiAction

export type WordleThunk<ReturnType = void> = ThunkAction<
  ReturnType,
  WordleStoreState,
  unknown,
  WordleAction
>

export type WordleDispatch = ThunkDispatch<
  WordleStoreState,
  unknown,
  WordleAction
>

export type WordleMiddleware = Middleware<
  {},
  WordleStoreState,
  WordleDispatch
>

export const useWordleDispatch = () => useDispatch<WordleDispatch>()

export const useWordleSelector: TypedUseSelectorHook<WordleStoreState> =
  useSelector
