type Environment = 'prod' | 'stg' | 'dev'

const environment = (window.env?.name as Environment) || 'dev'

export const envify = (values: Record<Environment, any>) => {
  return values[environment] || values.dev
}

const ACCOUNT_HOST = envify({
  prod: 'https://myaccount.nytimes.com',
  stg: 'https://myaccount.stg.nytimes.com',
  dev: 'https://myaccount.dev.nytimes.com',
})

export const SUBSCRIBE_URL = envify({
  prod: 'https://www.nytimes.com/subscription/games?campaignId=8RRFW',
  stg: 'https://www.stg.nytimes.com/subscription/games?campaignId=8RRFW',
  dev: 'https://www.stg.nytimes.com/subscription/games?campaignId=8RRFW',
})

export const OFFER_URI = envify({
  prod: 'https://www.nytimes.com/subscription/wordle-offer?campaignId=8YUQL',
  stg: 'https://www.stg.nytimes.com/subscription/wordle-offer?campaignId=8YUQL',
  dev: 'https://www.stg.nytimes.com/subscription/wordle-offer?campaignId=8YUQL',
}) // NSO-2372

const REDIRECT_URI = envify({
  prod: 'https://www.nytimes.com/games/wordle/index.html',
  stg: `${window.location.origin}/games/wordle/index.html`,
  dev: 'https://local.nytimes.com/games/wordle/index.html',
})

const encodedRedirectUri = encodeURIComponent(REDIRECT_URI)

const encodedOfferRedirectUri = encodeURIComponent(
  `${OFFER_URI}&EXIT_URI=${encodedRedirectUri}`,
) // NSO-2372

export const LOGIN_URL = `${ACCOUNT_HOST}/auth/enter-email?response_type=cookie&client_id=games&application=nyt-lires&redirect_uri=${encodedRedirectUri}`

export const buildLoginOfferUrl = (asset: string) => {
  return `${ACCOUNT_HOST}/auth/enter-email?response_type=cookie&client_id=games&application=nyt-lire&asset=${asset}&redirect_uri=${encodedOfferRedirectUri}`
} // NSO-2372

const WORDLE_HOME = envify({
  prod: 'https://www.nytimes.com/games/wordle/index.html',
  stg: `${window.location.origin}/games/wordle/index.html`,
  dev: 'https://local.nytimes.com/games/wordle/index.html',
})

export const LOGOUT_URL = `${ACCOUNT_HOST}/auth/logout?redirect_uri=${WORDLE_HOME}`

export const DIGITS_ON = new Date() < new Date('8/8/2023')

export const CONNECTIONS_ON =
  new Date() >= new Date('6/12/2023 10:00 AM EDT')
