describe('envify', () => {
  beforeEach(() => {
    jest.resetModules()
  })

  it('uses the appropriate environment', () => {
    window.env.name = 'prod'

    const { envify } = require('./constants')

    const url = envify({
      prod: 'https://myaccount.nytimes.com',
      stg: 'https://myaccount.stg.nytimes.com',
      dev: 'https://myaccount.dev.nytimes.com',
    })

    expect(url).toEqual('https://myaccount.nytimes.com')
  })

  it('uses the appropriate environment for successive calls', () => {
    window.env.name = 'stg'

    const { envify } = require('./constants')

    const accountHost = envify({
      prod: 'https://myaccount.nytimes.com',
      stg: 'https://myaccount.stg.nytimes.com',
      dev: 'https://myaccount.dev.nytimes.com',
    })

    const wordleHome = envify({
      prod: 'https://www.nytimes.com/games/wordle/index.html',
      stg: 'https://stg.nytimes.com/games/wordle/index.html',
      dev: 'https://local.nytimes.com/games/wordle/index.html',
    })

    const logoutUrl = `${accountHost}/auth/logout?redirect_uri=${wordleHome}`

    expect(logoutUrl).toEqual(
      'https://myaccount.stg.nytimes.com/auth/logout?redirect_uri=https://stg.nytimes.com/games/wordle/index.html',
    )
  })

  it('uses dev as the default environment', () => {
    window.env.name = ''

    const { envify } = require('./constants')

    const accountHost = envify({
      prod: 'https://myaccount.nytimes.com',
      stg: 'https://myaccount.stg.nytimes.com',
      dev: 'https://myaccount.dev.nytimes.com',
    })

    expect(accountHost).toEqual('https://myaccount.dev.nytimes.com')
  })
})
