/* eslint-disable */
import { browserDetect } from 'shared/utils/deviceIdentifiers'
import { getMoogleDataForFeedback } from '../store/moogle/moogle.helpers'
import { SEND_EMAIL_TYPE } from 'foundation'

const FEEDBACK_LINK = 'mailto:nytgames@nytimes.com'

const mapStatus = {
  anon: 'anon',
  sub: 'news sub',
  cr: 'games sub',
  reg: 'regi',
  'sub,cr': 'all access sub',
  'anon,sub': 'anon app sub',
}

function capitalize(str) {
  return str.charAt(0).toUpperCase() + str.slice(1)
}

const createQueryString = function (obj) {
  const outStr = []

  Object.keys(obj).forEach((p) => {
    outStr.push(
      `${encodeURIComponent(p)}=${encodeURIComponent(obj[p])}`,
    )
  })

  return `?${outStr.join('&')}`
}

export const getFeedbackLink = ({
  regiId,
  emailSubject = 'Wordle Feedback',
  entitlement,
  autoOptIn = false,
}) => {
  const tz = new Date().getTimezoneOffset()
  const data = getMoogleDataForFeedback(regiId)
  const mobileDevice = window.isMobileDevice

  const body = `\r\n\r\n
--
Device summary:
Page: /games/wordle
Platform: ${mobileDevice ? 'Web (Mobile)' : 'Web (Desktop)'} 
Browser: ${capitalize(browserDetect())}
Screen Resolution: ${window.screen.width} x ${window.screen.height}
Viewport Size: ${document.documentElement.clientWidth} x ${
    document.documentElement.clientHeight
  }
Timezone: ${`UTC${tz > 0 ? '' : '+'}${tz / -60}`}
Build: ${window.sentryConfig?.release}

Automatic Opt in? ${autoOptIn ? 'Yes' : 'No'}

Anon Local Storage:
${data.anon}

Local Storage for regi: ${regiId || '[NONE]'}:
${data.regi}

Status: ${
    mapStatus[entitlement] ? mapStatus[entitlement] : entitlement
  }

Regi ID: ${regiId || 'anon'}
  `

  return (
    FEEDBACK_LINK + createQueryString({ subject: emailSubject, body })
  )
}

export const feedbackHybrid = ({
  regiId,
  type = SEND_EMAIL_TYPE.WORDLE,
  emailTitle = 'Wordle Feedback',
  emailDestination = 'nytgames@nytimes.com',
  autoOptIn = false,
}) => {
  const data = getMoogleDataForFeedback(regiId)
  const regi = regiId || '[NONE]'
  const tz = new Date().getTimezoneOffset()
  const abraTestsString = Object.entries(window.abra.tests)
    .map((t) => t.join('='))
    .join(',')

  const debugInfo = [
    `Hybrid summary:`,
    `Platform: ${
      window.newsreaderAppPlatform ? 'News App' : 'XW App'
    }`,
    `Viewport Size: ${document.documentElement.clientWidth} x ${document.documentElement.clientHeight}`,
    `Timezone: ${`UTC${tz > 0 ? '' : '+'}${tz / -60}`}`,
    `Logged In: ${!!regiId ? 'yes' : 'no'}`,
    `Regi: ${regi}`,
    `Web Version: ${window.env.version}`,
    `Flags: ${abraTestsString}`,
    `Automatic Opt in? ${autoOptIn ? 'Yes' : 'No'}`,
    `Anon Local Storage: ${data.anon}`,
    `Local Storage for regi ${regi}: ${data.regi}`,
    `Build: ${window.sentryConfig?.release}`,
  ].join('\n')

  return window.NativeBridge.gamesSendEmail({
    type,
    debugInfo,
    emailTitle,
    emailDestination,
  })
}
