const express = require('express')

const {
  WORDLE_ASSET_BASE,
  CONNECTIONS_ASSET_BASE,
} = require('../constants')

const mw = require('./middleware')
const svc = require('./services')
const createPageProps = require('./util/createPageProps')

const router = express.Router()

router.get(
  '/wordle/index.html',
  mw.injectMetadata({
    title: 'Wordle - The New York Times',
    manifestId: 'wordle',
    metaTags: [
      {
        name: 'sourceApp',
        content: 'games-crosswords',
      },
      {
        property: 'description',
        content:
          'Guess the hidden word in 6 tries. A new puzzle is available each day.',
      },
      {
        property: 'og:title',
        content: 'Wordle - A daily word game',
      },
      {
        property: 'og:url',
        content: 'https://www.nytimes.com/games/wordle', // TODO
      },
      {
        property: 'og:description',
        content:
          'Guess the hidden word in 6 tries. A new puzzle is available each day.',
      },
      {
        property: 'og:image',
        content: `${WORDLE_ASSET_BASE}/wordle_og_1200x630.png`,
      },
      {
        property: 'twitter:card',
        content: 'summary_large_image',
      },
      {
        property: 'twitter:domain',
        content: 'nytimes.com',
      },
      {
        property: 'theme-color',
        content: '#6aaa64',
      },
    ],
    linkTags: [
      {
        href: `${WORDLE_ASSET_BASE}/wordle_logo_32x32.png`,
        rel: 'icon shortcut',
        sizes: '3232',
      },
      {
        href: `${WORDLE_ASSET_BASE}/wordle_logo_192x192.png`,
        rel: 'apple-touch-icon',
      },
    ],
  }),
  mw.cacheInFastly({
    surrogateKey: 'wordle-next',
  }),
  mw.renderView(
    'Wordle',
    createPageProps({
      pageName: 'wordle',
      adUnitPath: 'wordle',
      entry: 'wordle',
      includeScreenIntercept: true,
    }),
  ),
)

// -----
// CONNECTIONS WRAPPER
// -----
router.get(
  '/connections',
  mw.injectMetadata({
    title: 'Connections: Group words by topic. New puzzles daily.',
    manifestId: 'connections',
    metaTags: [
      {
        name: 'sourceApp',
        content: 'games-crosswords',
      },
      {
        property: 'description',
        content:
          'Group words that share a common thread. A new puzzle is available each day.',
      },
      {
        property: 'og:title',
        content:
          'Connections - Group words that share a common thread',
      },
      {
        property: 'og:url',
        content: 'https://www.nytimes.com/games/connections',
      },
      {
        property: 'og:image',
        content: `${CONNECTIONS_ASSET_BASE}/NYT-Connections-og-image.png`,
      },
      {
        property: 'og:description',
        content:
          'Group words that share a common thread. A new puzzle is available each day.',
      },
      {
        property: 'twitter:card',
        content: 'summary_large_image',
      },
      {
        property: 'twitter:domain',
        content: 'nytimes.com',
      },
      {
        property: 'theme-color',
        content: '#000000',
      },
    ],
    linkTags: [
      {
        href: `${CONNECTIONS_ASSET_BASE}/NYT-Connections-Icon.svg`,
        rel: 'icon shortcut',
        sizes: '3232',
      },
      {
        href: `${CONNECTIONS_ASSET_BASE}/NYT-Connections-Icon.svg`,
        rel: 'apple-touch-icon',
      },
    ],
  }),
  mw.cacheInFastly({
    surrogateKey: 'connections-phoenix',
  }),
  mw.renderView(
    'Connections',
    createPageProps({
      pageName: 'connections',
      adUnitPath: 'connections',
      entry: 'connections',
      gameData: (_, res) => res.locals.connectionsData,
      includeScreenIntercept: true,
    }),
  ),
)

module.exports = router
