/**
 * This middleware is responsible for sending the appropriate headers to cache a route in Fastly
 * @jest-environment node
 */

const request = require('supertest')
const express = require('express')

const { cacheInFastly } = require('..')

jest.mock('../renderView', () => ({}))
jest.mock('../../services/getShortz', () => true)

describe('APP/MIDDLEWARE: CACHE IN FASTLY', () => {
  let app
  const surrogateKey = 'foo'

  beforeEach(() => {
    app = express()
    app.use(cacheInFastly({ surrogateKey }))
    app.get('*', (req, res) => {
      res.send(200)
    })
  })

  it('sends the correct cache-control header values no-cache, max-age, s-maxage, stale-if-error to cache for 1 day on 5xx and 5 minutes on 200', () => {
    expect.assertions(1)

    return request(app)
      .get('/page')
      .then((r) => {
        expect(r.header['cache-control']).toEqual(
          'no-cache,max-age=0,s-maxage=300,stale-if-error=86400,stale-while-revalidate=60',
        )
      })
  })

  it('sends the correct surrogate-control header values max-age, stale-if-error to cache for 1 day on 5xx and 5 minutes on 200', () => {
    expect.assertions(1)

    return request(app)
      .get('/page')
      .then((r) => {
        expect(r.header['surrogate-control']).toEqual(
          'max-age=300,stale-if-error=86400,stale-while-revalidate=60',
        )
      })
  })

  it(`sends the correct surrogate-key header value to identify a game's cache in fastly`, () => {
    expect.assertions(1)

    return request(app)
      .get('/page')
      .then((r) => {
        expect(r.header['surrogate-key']).toEqual(
          `games ${surrogateKey}`,
        )
      })
  })
})
