const request = require('supertest')
const express = require('express')

const { GLOBAL_REDIRECTS } = require('../../../constants')
const { handleRedirects } = require('..')

jest.mock('../../services/getShortz', () => true)

describe('APP/MIDDLEWARE: HANDLE REDIRECTS', () => {
  const paths = Object.keys(GLOBAL_REDIRECTS)
  const pathNotInGlobalRedirects = '/foo'
  const sudokuExtendedPath = '/crosswords/game/sudoku/easy'

  const acrosticPath = '/crosswords/game/acrostic/2023/01/01'
  const varietyPath = '/crosswords/game/variety/2017/01/01'

  let app

  beforeEach(() => {
    app = express()
    app.get(paths, handleRedirects, (req, res) => res.sendStatus(200))
    app.get(sudokuExtendedPath, handleRedirects, (req, res) =>
      res.sendStatus(200),
    )
    app.get(acrosticPath, handleRedirects, (req, res) =>
      res.sendStatus(200),
    )
    app.get(varietyPath, handleRedirects, (req, res) =>
      res.sendStatus(200),
    )
    app.get(pathNotInGlobalRedirects, handleRedirects, (req, res) =>
      res.sendStatus(200),
    )
  })

  it('redirects users trying to access paths defined in GLOBAL_REDIRECTS', () => {
    return Promise.all(
      paths.map((path) => request(app).get(path).expect(301)),
    )
  })

  it('redirects users trying to access paths defined in sudokuExtendedPath', () => {
    return request(app).get(sudokuExtendedPath).expect(301)
  })

  it('redirects users trying to access an acrostic puzzle', () => {
    return request(app).get(acrosticPath).expect(301)
  })

  it('redirects users trying to access a variety puzzle', () => {
    return request(app).get(varietyPath).expect(301)
  })

  it('paths not defined in GLOBAL_REDIRECTS should pass through', () => {
    return request(app).get(pathNotInGlobalRedirects).expect(200)
  })
})
