const injectCompliance = require('../injectCompliance')

jest.mock('../../../constants', () => ({
  RUNTIME_ENV: 'dev',
}))

describe('APP/MIDDLEWARE: INJECT COMPLIANCE', () => {
  let req
  let res
  let next

  beforeEach(() => {
    req = { headers: {}, query: {} }
    res = { locals: {} }
    next = jest.fn()
  })

  test('ccpa opt out - hide', () => {
    req.headers['x-nyt-purr-directives'] = 'xxxxxxxh'
    injectCompliance(req, res, next)
    expect(next).toHaveBeenCalled()
    expect(res.locals.compliance.PURR_DataSaleOptOutUI_v2).toEqual(
      'hide',
    )
  })

  test('ccpa opt out - show', () => {
    req.headers['x-nyt-purr-directives'] = 'xxxxxxxs'
    injectCompliance(req, res, next)
    expect(next).toHaveBeenCalled()
    expect(res.locals.compliance.PURR_DataSaleOptOutUI_v2).toEqual(
      'show',
    )
  })

  test('ccpa opt out - show opted out', () => {
    req.headers['x-nyt-purr-directives'] = 'xxxxxxxo'
    injectCompliance(req, res, next)
    expect(next).toHaveBeenCalled()
    expect(res.locals.compliance.PURR_DataSaleOptOutUI_v2).toEqual(
      'show-opted-out',
    )
  })

  test('california notices - hide', () => {
    req.headers['x-nyt-purr-directives'] = 'xxxxxxxxh'
    injectCompliance(req, res, next)
    expect(next).toHaveBeenCalled()
    expect(res.locals.compliance.PURR_CaliforniaNoticesUI).toEqual(
      'hide',
    )
  })

  test('california notices - show', () => {
    req.headers['x-nyt-purr-directives'] = 'xxxxxxxxs'
    injectCompliance(req, res, next)
    expect(next).toHaveBeenCalled()
    expect(res.locals.compliance.PURR_CaliforniaNoticesUI).toEqual(
      'show',
    )
  })

  test('california limited sensitive info - show', () => {
    req.headers['x-nyt-purr-directives'] = 'xxxxxxxxxxxxs'
    injectCompliance(req, res, next)
    expect(next).toHaveBeenCalled()
    expect(res.locals.compliance.PURR_LimitSensitivePI).toEqual(
      'show',
    )
  })

  test('california limited sensitive info - hide', () => {
    req.headers['x-nyt-purr-directives'] = 'xxxxxxxxxxxxh'
    injectCompliance(req, res, next)
    expect(next).toHaveBeenCalled()
    expect(res.locals.compliance.PURR_LimitSensitivePI).toEqual(
      'hide',
    )
  })

  test('purr disable ads - limited ads', () => {
    req.headers['x-nyt-purr-directives'] = 'xxxxxxxxxxxl'
    injectCompliance(req, res, next)
    expect(next).toHaveBeenCalled()
    expect(res.locals.compliance.PURR_AdConfiguration_v3).toEqual(
      'ltd',
    )
  })

  test('purr disable ads - adluce-socrates', () => {
    req.headers['x-nyt-purr-directives'] = 'xxxxxxxxxxxs'
    injectCompliance(req, res, next)
    expect(next).toHaveBeenCalled()
    expect(res.locals.compliance.PURR_AdConfiguration_v3).toEqual(
      'adluce-socrates',
    )
  })

  test('purr ad restriction - rdp', () => {
    req.headers['x-nyt-purr-directives'] = 'xxxxxxxxxxxr'
    injectCompliance(req, res, next)
    expect(next).toHaveBeenCalled()
    expect(res.locals.compliance.PURR_AdConfiguration_v3).toEqual(
      'rdp',
    )
  })
})
