describe('MIDDLEWARE: INJECT FEATURE FLAGS', () => {
  let mockReq
  let mockRes
  let mockNext

  beforeEach(() => {
    jest.resetModules()
    mockReq = {}
    mockRes = { locals: {} }
    mockNext = jest.fn()
  })

  test('should mutate response object to contain the feature flags configuration', () => {
    jest.doMock('../../../constants', () => ({
      FEATURE_FLAGS: {
        testFeatureFlags: true,
        anotherTestFeatureFlags: false,
      },
    }))

    const injectFeatureFlags = require('../injectFeatureFlags')

    injectFeatureFlags(mockReq, mockRes, mockNext)
    expect(mockRes.locals.featureFlags).toEqual({
      testFeatureFlags: true,
      anotherTestFeatureFlags: false,
    })
  })

  test('should call next', () => {
    jest.doMock('../../../constants', () => ({
      FEATURE_FLAGS: { testFeatureFlags: true },
    }))

    const injectFeatureFlags = require('../injectFeatureFlags')

    injectFeatureFlags(mockReq, mockRes, mockNext)
    expect(mockNext).toHaveBeenCalled()
  })

  test('should not mutate the response object if provided a non-object FEATURE_FLAGS and then call next', () => {
    jest.doMock('../../../constants', () => ({
      FEATURE_FLAGS: 'notAnObject',
    }))

    const injectFeatureFlags = require('../injectFeatureFlags')

    injectFeatureFlags(mockReq, mockRes, mockNext)
    expect(mockRes.locals.featureFlags).toEqual(undefined)
    expect(mockNext).toHaveBeenCalled()
  })

  test('should not mutate the response object if provided null FEATURE_FLAGS and then call next', () => {
    jest.doMock('../../../constants', () => ({
      FEATURE_FLAGS: null,
    }))

    const injectFeatureFlags = require('../injectFeatureFlags')

    injectFeatureFlags(mockReq, mockRes, mockNext)
    expect(mockRes.locals.featureFlags).toEqual(undefined)
    expect(mockNext).toHaveBeenCalled()
  })
})
