const React = require('react')
const request = require('supertest')
const express = require('express')

const loadServerViews = require('../../util/loadServerViews')
const renderer = require('../renderView')

jest.mock('../../util/createRenderer', () => (renderOutput) => {
  const render = (view, props) => {
    return (req, res) => {
      const output = renderOutput(view, props)
      res.set('content-type', 'text/html; charset=utf-8')
      res.write('<!DOCTYPE html>\n')
      output.pipe(res)
    }
  }

  return { renderView: render, renderError: render }
})

jest.mock('../../util/loadServerViews', () => jest.fn())

/* eslint-disable react/prop-types, react/display-name */
loadServerViews.mockReturnValue({
  MyView: ({ content }) => React.createElement('div', null, content),
  ProvideServerData: ({ children, className }) =>
    React.createElement('div', { className }, children),
})

describe('APP/MIDDLEWARE: RENDER VIEW', () => {
  it('wraps pages in server prop provider', () => {
    const app = express()
    app.get(
      '*',
      renderer.renderView('MyView', {
        className: 'provider',
        content: 42,
      }),
    )
    app.use((error, req, res) => {
      res.send(error.message)
    })

    return request(app)
      .get('/page')
      .expect(
        '<!DOCTYPE html>\n<div class="provider"><div>42</div></div>',
      )
  })

  it('throws a helpful message if there is no matching view', () => {
    const app = express()
    app.get('*', renderer.renderView('BadView', {}))
    /* eslint-disable no-unused-vars */
    app.use((error, req, res, next) => {
      res.send(error.message)
    })

    return request(app)
      .get('/page')
      .expect(
        'Missing react Page: \'BadView\' \nAvailable: ["MyView","ProvideServerData"]',
      )
  })
})
