const request = require('supertest')
const express = require('express')
const cookieParser = require('cookie-parser')

const { standardizeAuthCookie } = require('..')

jest.mock('../../services/getShortz', () => true)

describe('APP/MIDDLEWARE: STANDARDIZE AUTH COOKIE', () => {
  let app

  beforeEach(() => {
    app = express()
    app.use(cookieParser())
    app.use(standardizeAuthCookie)
    app.get('*', (req, res) => {
      res.send({
        cookies: req.cookies,
      })
    })
  })

  it('nulls the NYT-G value when both NYT-S and NYT-G are present', () => {
    return request(app)
      .get('/page')
      .set('Cookie', ['NYT-G=1234;NYT-S=4321'])
      .then((r) => {
        expect(r.body).toEqual({
          cookies: {
            'NYT-G': null,
            'NYT-S': '4321',
          },
        })
      })
  })

  it('uses the NYT-G value for the NYT-S cookie when only the NYT-G cookie is present', () => {
    return request(app)
      .get('/page')
      .set('Cookie', ['NYT-G=ANON.1234'])
      .then((r) => {
        expect(r.body).toEqual({
          cookies: {
            'NYT-G': null,
            'NYT-S': 'ANON.1234',
          },
        })
      })
  })

  it('allows the NYT-S value to pass through when no NYT-G value is present', () => {
    return request(app)
      .get('/page')
      .set('Cookie', ['NYT-S=1234'])
      .then((r) => {
        expect(r.body).toEqual({
          cookies: {
            'NYT-S': '1234',
          },
        })
      })
  })
})
