const axios = require('axios')
const request = require('supertest')
const express = require('express')
const cookieParser = require('cookie-parser')

const { verifyAnonSubs } = require('..')
const standardizeAuthCookie = require('../standardizeAuthCookie')

jest.mock('axios')
jest.mock('../../services/getShortz', () => true)

describe('APP/MIDDLEWARE: VERIFY ANON SUBS', () => {
  let app

  beforeEach(() => {
    app = express()
    app.use(cookieParser())
    app.use(standardizeAuthCookie)
    app.use(verifyAnonSubs)
    app.get('*', (req, res) => {
      res.send({
        headers: req.headers,
      })
    })
  })

  it('sets the nyts-xwd header to true when the anon cookie is valid', () => {
    axios.mockResolvedValue({
      data: {
        products: {
          XWD: 1111111111,
        },
      },
    })

    return request(app)
      .get('/page')
      .set('Cookie', ['NYT-S=ANON.valid'])
      .then((r) => {
        expect(r.body.headers['nyts-xwd']).toEqual('1111111111')
      })
  })

  it('sets the nyts-xwd header to an empty string when the anon cookie is invalid', () => {
    axios.mockResolvedValue({})

    return request(app)
      .get('/page')
      .set('Cookie', ['NYT-S=ANON.invalid'])
      .then((r) => {
        expect(r.body.headers['nyts-xwd']).toEqual('')
      })
  })

  it('allows the nyts-xwd header to pass through when the cookie is for a registered user', () => {
    // we don't need to mock the resolve value here because
    // only anon cookies hit the anon entitlements api
    jest.resetAllMocks()

    return request(app)
      .get('/page')
      .set('nyts-xwd', '1111111111') // for regis, this would have already been set via the proxy
      .set('Cookie', ['NYT-S=registereduser'])
      .then((r) => {
        expect(r.body.headers['nyts-xwd']).toEqual('1111111111')
        expect(axios).not.toHaveBeenCalled()
      })
  })
})
