const axios = require('axios')

const constants = require('../../constants')
const logger = require('../../serverLogger')
const isSubInfoBypassed = require('../util/isSubInfoBypassed')

const getSubInfo = async (req, res, next) => {
  const bypassSubInfo = isSubInfoBypassed(req.path)

  if (bypassSubInfo) {
    return next()
  }

  /**
   * Side effect of storing hasHd on the response's locals object.
   *
   * @param {Object} res The express response object
   * @param {Boolean} hasHd If the user is determined to have Home Delivery
   */
  const addHasHdToLocals = (res, hasHd) => {
    // userType is created in another middleware. But to be safe, we'll check
    // it exists before adding to it.
    if (!res.locals.userType) {
      res.locals.userType = {}
    }

    res.locals.userType.hasHd = hasHd
  }

  const { headers } = req
  const { 'nyts-regiid': id } = headers
  const requestUrl = `${constants.SARTRE_SUBINFO_HOST}/svc/subinfo/accounts/${id}/subscriptions`
  const hdBundleTypes = [
    'E',
    'H',
    'H_PLUS',
    'HD_Premium',
    'HD_Premium_VR',
    'HD_VAC_NOCORE',
    'HD_VAC_NOCORE_PREM',
    'HD_ADA',
  ]

  const nyts = req.cookies['NYT-S']

  if (!id) {
    addHasHdToLocals(res, false)
    next()
  } else if (
    req.cookies['nyt-xwd-hashd'] === true ||
    req.cookies['nyt-xwd-hashd'] === 'true'
  ) {
    addHasHdToLocals(res, true)
    next()
  } else {
    let hasHd = false

    await axios({
      url: requestUrl,
      withCredentials: true,
      method: 'GET',
      headers: {
        Cookie: `NYT-S=${nyts}`,
      },
    })
      .then(({ data }) => {
        hasHd =
          data &&
          data.length > 0 &&
          data
            .filter((a) => a.status === 'ACTIVE')
            .filter((a) => hdBundleTypes.includes(a.bundleType))
            .length > 0
      })
      .catch((e) => {
        logger.warn(e)
        hasHd = false
      })
      .finally(() => {
        addHasHdToLocals(res, hasHd)

        next()
      })
  }
}

module.exports = getSubInfo
