const pinoHttp = require('pino-http')
const clf = require('common-log-string')

const logger = require('../../serverLogger')

const getWebviewType = (ua) => {
  const agent = ua || ''

  if (agent.match(/nytios/) !== null) return 'ios'

  if (agent.match(/nyt[-_]?android/) !== null) return 'android'

  return null
}
/**
 * Get the iOS Newsreader version from the UA header string.
 * @param {String} ua The user agent header
 * @returns {String} The substring of the UA related to iOS version
 */

const getiOSNewsreaderVersion = (ua) => {
  const agent = ua || ''

  // UA will look something like:
  // Mozilla/5.0 (iPhone; CPU iPhone OS 13_6 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) nytios/9.33.0
  const matches = agent.match(/nyt[-_]?ios[/0-9.]*/i)

  if (matches !== null && matches.length > 0) {
    return matches[0]
  }

  return 'na' // Not available
}

const httpLogger = pinoHttp({
  logger,
  quietReqLogger: true,
  // remove sensitive fields
  redact: {
    paths: ['req.headers.cookie'],
    remove: true,
  },
  customSuccessMessage: (req, res) =>
    clf(req, res, { ipHeader: 'x-forwarded-for' }),
  serializers: {
    res: function customReqSerializer(serialized) {
      const webviewType = getWebviewType(
        serialized.raw.locals.device.ua,
      )

      const uaString =
        webviewType === 'ios'
          ? getiOSNewsreaderVersion(serialized.raw.locals.device.ua)
          : 'na' // Not available

      serialized.webviewDebugString = webviewType
        ? `webview-type=${webviewType} v=${uaString} NYT-S:${(
            serialized.raw.req.cookies['NYT-S'] || ''
          ).slice(0, 10)}...`
        : ``

      return serialized
    },
  },
  wrapSerializers: true,
})

module.exports = httpLogger
