const getShortz = require('../services/getShortz')

const getUserEntitlement = (isLoggedIn, hasDigi, hasXwd) => {
  if (!isLoggedIn) return 'anon'

  if (hasDigi && hasXwd) return 'sub,cr'

  if (hasDigi) return 'sub'

  return hasXwd ? 'cr' : 'reg'
}

module.exports = function injectUserType(req, res, next) {
  const { headers } = req

  /** extract useful data from nyt user */
  const {
    'nyts-regiid': id,
    'nyts-username': username,
    'nyts-xwd': xwd,
    'nyts-mm': mm,
    'nyts-msd': msd,
    'nyts-mtd': mtd,
  } = headers
  const regi = parseInt(id, 10) || undefined
  const isErsatzShortz = getShortz(regi)

  // not cachable
  res.locals.user = {
    id: regi,
    displayName: username,
  }

  const isLoggedIn = !!regi
  const hasDigi = !!(mm || msd || mtd) // indicates a digital News (basic) subscriber WITHOUT Games access, not an all digital access subscriber
  const hasXwd = !!xwd
  const hasHd = false // This value will be set in getSubInfo() middleware

  // vs cachable
  res.locals.userType = {
    isLoggedIn,
    hasXwd,
    hasDigi,
    hasHd,
    isErsatzShortz,
    inShortzMode: isErsatzShortz, // TODO: for now there is no toggle ie: && cookies.shortzMode === 'on',
    entitlement: getUserEntitlement(isLoggedIn, hasDigi, hasXwd),
    regiId: regi,
  }

  next()
}
