const logger = require('../../serverLogger')
const { RUNTIME_ENV } = require('../../constants')

const logError =
  RUNTIME_ENV !== 'dev'
    ? // In kubernetes, logs must be a single line of json
      ({ stack, message, status }) =>
        console.error(JSON.stringify({ stack, message, status }))
    : (err) => logger.error(`${err.message}\n\n${err.stack}\n`)

const logErrors = (err, req, res, next) => {
  // do not clog up logs with standard error pages
  if (
    err.status === 404 ||
    err.status === 401 ||
    err.status === 428
  ) {
    return next(err)
  }

  logError(err)

  next(err)
}

module.exports = logErrors
