const React = require('react')
const ReactDOMServer = require('react-dom/server')
const { ErrorReporting } = require('@google-cloud/error-reporting')

const createRenderer = require('../util/createRenderer')
const loadServerViews = require('../util/loadServerViews')
const {
  CLOUD_ERROR_REPORTING_ENABLED,
  CLOUD_SERVICE_CONTEXT: serviceContext,
} = require('../../constants')

const logErrors = require('./logErrors')

const errorHandlers = []

if (CLOUD_ERROR_REPORTING_ENABLED) {
  const errorReportingConfig = {
    serviceContext,
    logLevel: 1,
  }
  errorHandlers.push(new ErrorReporting(errorReportingConfig).express)
}

errorHandlers.push(logErrors)

module.exports = createRenderer((view, props) => {
  const serverViews = loadServerViews()

  if (!serverViews[view]) {
    throw new Error(
      `Missing react Page: '${view}' \nAvailable: ${JSON.stringify(
        Object.keys(serverViews),
      )}`,
    )
  }

  const pageElement = React.createElement(
    serverViews.ProvideServerData,
    props,
    React.createElement(serverViews[view], props),
  )

  return ReactDOMServer.renderToStaticNodeStream(pageElement)
}, errorHandlers)
