const Sentry = require('@sentry/node')

/**
 * Generate an identifier for this request
 */
const generateSentryUserIdentifier = () =>
  `request-${Math.random().toString().substring(2)}`

/**
 * Given a request url path, returns a route tag for Sentry issues
 */
const getRouteTag = (pathname) => {
  switch (true) {
    case /games\/wordle/.test(pathname):
      return 'wordle'
    case /puzzles\/spelling-bee/.test(pathname):
      return 'spelling-bee'
    case /games\/connections/.test(pathname):
      return 'connections'
    case /puzzles\/vertex/.test(pathname):
      return 'vertex'
    case /puzzles\/tiles/.test(pathname):
      return 'tiles'
    case /puzzles\/sudoku/.test(pathname):
      return 'sudoku'
    case /puzzles\/letter-boxed/.test(pathname):
      return 'letter-boxed'
    case /leaderboards/.test(pathname):
      return 'leaderboards'
    case /crosswords\/game\/daily/.test(pathname):
      return 'crossword'
    case /crosswords\/game\/mini/.test(pathname):
      return 'mini'
    case /crosswords\/archive/.test(pathname):
      return 'archive'
    case /crosswords/.test(pathname):
      return 'hub'
    default:
      return null
  }
}

/**
 * Inject metadata into every request that Sentry processes
 */
module.exports = function sentryMetaData() {
  return (req, res, next) => {
    const route = getRouteTag(req.path)

    // Only annotate for requests for content pages (as opposed to things like /puzzles/user?bust)
    if (route) {
      Sentry.setTag('app', 'server')
      Sentry.setUser({ id: generateSentryUserIdentifier() })
      Sentry.setTag('route', route)
    }
    next()
  }
}
