module.exports = function standardizeAuthCookie(req, res, next) {
  // since we can't remove the NYT-G cookie from the request
  // we're nullifying it so that downstream handlers
  // have no choice but to use the NYT-S value.

  if (req.cookies['NYT-S'] && req.cookies['NYT-G']) {
    // if we have both cookies NYT-S can be favored since it will
    // represent a registered user and will have the games
    // entitlements the user would expect.

    req.cookies['NYT-G'] = null
  } else if (req.cookies['NYT-G']) {
    // if all we have is an NYT-G we will rename it to NYT-S
    // and allow later middleware to verify entitlements from
    // the NYT-S per our other entitlements handling

    req.cookies['NYT-S'] = req.cookies['NYT-G']
    req.cookies['NYT-G'] = null
  }

  next()
}
