const get = require('lodash/get')
const axios = require('axios')

const { ANON_ENTITLEMENTS_API } = require('../../constants')
const logger = require('../../serverLogger')

module.exports = async function verifyAnonSubs(req, res, next) {
  const nyts = req.cookies['NYT-S']

  if (nyts && nyts.startsWith('ANON.')) {
    const request = axios({
      url: ANON_ENTITLEMENTS_API,
      method: 'GET',
      headers: {
        Cookie: `NYT-S=${nyts}`,
      },
    })

    try {
      const response = await request
      const hasXwd = get(response, 'data.products.XWD')
      req.headers['nyts-xwd'] = hasXwd ? String(hasXwd) : ''
    } catch (err) {
      logger.error(err)
      req.headers['nyts-xwd'] = ''
    }
  }

  next()
}
