const cloneDeep = require('lodash/cloneDeep')

const {
  CONNECTIONS_ASSET_BASE,
  MAGNOLIA_DAM_ASSET_PATH,
  WORDLE_ASSET_BASE,
} = require('../constants')

const svc = require('./services')

const puzzleRouterConfig = {
  letterBoxed: {
    pageProps: {
      pageName: 'letter-boxed',
      adUnitPath: 'letterboxed', // NOTE: ad frameworks team asked us to not use a `-` in this path
      entry: 'letter-boxed',
      gameData: svc.getLetterBoxedGame,
      includeScreenIntercept: true,
    },
    metaData: {
      manifestId: 'lb',
      title: 'Letter Boxed - The New York Times',
      trackingPageType: 'letter boxed',
      alternateName: [
        'NYTimes letter boxed',
        'New York Times letter boxed',
        'NYT letter boxed',
      ],
      image: [
        {
          url: 'https://storage.googleapis.com/games-assets/v2/assets/icons/letter-boxed.svg',
          height: 20,
          width: 20,
          '@context': 'http://schema.org',
          '@type': 'ImageObject',
        },
      ],
      metaTags: [
        {
          property: 'og:title',
          content: 'Letter Boxed - New York Times Logic Puzzles',
        },
        {
          property: 'og:url',
          content: 'https://www.nytimes.com/puzzles/letter-boxed',
        },
        {
          property: 'og:description',
          content:
            'Create words using letters around the square. Solve the puzzle in as few words as you can.',
        },
        {
          property: 'og:image',
          content: `${MAGNOLIA_DAM_ASSET_PATH}letter-boxed.png`,
        },
        {
          name: 'description',
          content:
            'Create words using letters around the square. Solve the puzzle in as few words as you can',
        },
        {
          property: 'twitter:card',
          content: 'summary_large_image',
        },
        {
          property: 'twitter:domain',
          content: 'nytimes.com',
        },
      ],
    },
  },
  spellingBeeHub: {
    pageProps: {
      pageName: 'spelling-bee-hub',
      entry: 'spelling-bee-hub',
      gameData: svc.getSpellingBee,
    },
    metaData: {
      manifestId: 'sb-hub',
      trackingPageType: 'spelling bee hub',
      title: 'Play Spelling Bee puzzles',
      metaTags: [
        {
          property: 'description',
          content:
            'Solve today’s Spelling Bee or catch up on past puzzles.',
        },
        {
          property: 'og:title',
          content: 'Play Spelling Bee puzzles',
        },
        {
          property: 'og:url',
          content: 'https://www.nytimes.com/puzzles/spelling-bee/hub',
        },
        {
          property: 'og:description',
          content:
            'Solve today’s Spelling Bee or catch up on past puzzles.',
        },
        {
          property: 'og:image',
          content: `${MAGNOLIA_DAM_ASSET_PATH}spelling-bee.png`,
        },
      ],
    },
  },
  spellingBeeDate: {
    metaData: {
      manifestId: 'sb',
      trackingPageType: 'spelling bee',
      alternateName: [
        'NYTimes spelling bee',
        'New York Times spelling bee',
        'NYT spelling bee',
      ],
      image: [
        {
          url: 'https://storage.googleapis.com/games-assets/v2/assets/icons/spelling-bee.svg',
          height: 20,
          width: 20,
          '@context': 'http://schema.org',
          '@type': 'ImageObject',
        },
      ],
      metaTags: [
        {
          property: 'og:title',
          content: 'Play Spelling Bee',
        },
        {
          property: 'og:url',
          content: 'https://www.nytimes.com/puzzles/spelling-bee',
        },
        {
          property: 'og:description',
          content: 'How many words can you make with 7 letters?',
        },
        {
          property: 'og:image',
          content: `${MAGNOLIA_DAM_ASSET_PATH}spelling-bee.png`,
        },
      ],
    },
    pageProps: {
      pageName: 'spelling-bee',
      adUnitPath: 'spellingbee',
      entry: 'spelling-bee',
      gameData: svc.getSpellingBee,
      // NOTE: figure out a better way to handle the screen intercept
      includeScreenIntercept: true,
    },
  },
  tiles: {
    metaData: {
      manifestId: 'tls',
      title: 'Tiles - The New York Times',
      alternateName: [
        'NYTimes tiles',
        'New York Times tiles',
        'NYT tiles',
      ],
      image: [
        {
          url: 'https://storage.googleapis.com/games-assets/v2/assets/icons/tiles.svg',
          height: 20,
          width: 20,
          '@context': 'http://schema.org',
          '@type': 'ImageObject',
        },
      ],
      metaTags: [
        {
          property: 'og:title',
          content: 'Play Tiles',
        },
        {
          property: 'og:url',
          content: 'https://www.nytimes.com/puzzles/tiles',
        },
        {
          property: 'og:description',
          content:
            'Have a stress-free moment, courtesy of our soothing matching game.',
        },
        {
          property: 'og:image',
          content: `${MAGNOLIA_DAM_ASSET_PATH}tiles.png`,
        },
        {
          name: 'description',
          content:
            'Have a stress-free moment, courtesy of our soothing matching game.',
        },
        {
          property: 'twitter:card',
          content: 'summary_large_image',
        },
        {
          property: 'twitter:domain',
          content: 'nytimes.com',
        },
      ],
    },
    pageProps: {
      pageName: 'tiles',
      adUnitPath: 'tiles',
      entry: 'tiles',
      gameData: svc.getTiles,
      includeScreenIntercept: true,
    },
  },
  vertexDate: {
    metaData: {
      title: 'Vertex - The New York Times',
      alternateName: [
        'NYTimes vertex',
        'New York Times vertex',
        'NYT vertex',
      ],
      image: [
        {
          url: 'https://storage.googleapis.com/games-assets/v2/assets/icons/vertex.svg',
          height: 20,
          width: 20,
          '@context': 'http://schema.org',
          '@type': 'ImageObject',
        },
      ],
      metaTags: [
        {
          property: 'og:title',
          content: 'Play Vertex',
        },
        {
          property: 'og:url',
          content: 'https://www.nytimes.com/puzzles/vertex',
        },
        {
          property: 'og:description',
          content:
            'Connect the dots to form triangles and reveal the hidden picture.',
        },
        {
          property: 'og:image',
          content: `${MAGNOLIA_DAM_ASSET_PATH}vertex.png`,
        },
      ],
    },
    pageProps: {
      pageName: 'vertex',
      adUnitPath: 'vertex',
      entry: 'vertex',
      includeScreenIntercept: true,
      gameData: svc.getVertex,
    },
  },
  wordle: {
    metaData: {
      title: 'Wordle - The New York Times',
      manifestId: 'wordle',
      metaTags: [
        {
          name: 'sourceApp',
          content: 'games-crosswords',
        },
        {
          property: 'description',
          content:
            'Guess the hidden word in 6 tries. A new puzzle is available each day.',
        },
        {
          property: 'og:title',
          content: 'Wordle - A daily word game',
        },
        {
          property: 'og:url',
          content: 'https://www.nytimes.com/games/wordle',
        },
        {
          property: 'og:description',
          content:
            'Guess the hidden word in 6 tries. A new puzzle is available each day.',
        },
        {
          property: 'og:image',
          content: `${WORDLE_ASSET_BASE}/wordle_og_1200x630.png`,
        },
        {
          property: 'twitter:card',
          content: 'summary_large_image',
        },
        {
          property: 'twitter:domain',
          content: 'nytimes.com',
        },
        {
          property: 'theme-color',
          content: '#6aaa64',
        },
      ],
      linkTags: [
        {
          href: `${WORDLE_ASSET_BASE}/wordle_logo_32x32.png`,
          rel: 'icon shortcut',
          sizes: '3232',
        },
        {
          href: `${WORDLE_ASSET_BASE}/wordle_logo_192x192.png`,
          rel: 'apple-touch-icon',
        },
      ],
    },
    pageProps: {
      pageName: 'wordle',
      adUnitPath: 'wordle',
      entry: 'wordle',
      includeScreenIntercept: true,
    },
  },
  sudoku: {
    metaData: {
      title: 'Sudoku - New York Times Number Puzzles',
      trackingPageType: 'sudoku',
      alternateName: [
        'NYTimes sudoku',
        'New York Times sudoku',
        'NYT sudoku',
      ],
      image: [
        {
          url: 'https://storage.googleapis.com/games-assets/v2/assets/icons/sudoku.svg',
          height: 20,
          width: 20,
          '@context': 'http://schema.org',
          '@type': 'ImageObject',
        },
      ],
      metaTags: [
        {
          property: 'og:title',
          content: 'Play Sudoku',
        },
        {
          property: 'og:url',
          content: 'https://www.nytimes.com/puzzles/sudoku',
        },
        {
          property: 'og:description',
          content:
            'This popular logic puzzle is a numbers game, minus the math.',
        },
        {
          property: 'og:image',
          content: `${MAGNOLIA_DAM_ASSET_PATH}sudoku.png`,
        },
        {
          name: 'description',
          content:
            'This popular logic puzzle is a numbers game, minus the math.',
        },
        {
          property: 'twitter:card',
          content: 'summary_large_image',
        },
        {
          property: 'twitter:domain',
          content: 'nytimes.com',
        },
      ],
    },
    pageProps: {
      pageName: 'sudoku',
      adUnitPath: 'sudoku',
      entry: 'sudoku',
      gameData: svc.getSudoku,
      includeScreenIntercept: true,
    },
  },
  maintenance: {
    metaData: {
      title: 'Maintenance — New York Times Games',
      trackingPageType: 'maintenance',
      metaTags: [
        {
          property: 'og:title',
          content: 'Maintenance — New York Times Games',
        },
        {
          property: 'og:url',
          content: 'https://www.nytimes.com/puzzles/maintenance',
        },
        {
          property: 'og:description',
          content:
            'Our site is down for maintenance. Check back later, but in the meantime explore The New York Times.',
        },
        {
          property: 'og:image',
          content:
            'https://static01.nyt.com/packages/other/crossword/fb-og/games.png',
        },
        { name: 'robots', content: 'noindex' },
      ],
    },
    pageProps: {
      pageName: 'maintenance',
      entry: 'maintenance',
    },
  },
  connections: {
    metaData: {
      title: 'Connections: Group words by topic. New puzzles daily.',
      manifestId: 'connections',
      metaTags: [
        {
          name: 'sourceApp',
          content: 'games-crosswords',
        },
        {
          property: 'description',
          content:
            'Group words that share a common thread. A new puzzle is available each day.',
        },
        {
          property: 'og:title',
          content:
            'Connections - Group words that share a common thread',
        },
        {
          property: 'og:url',
          content: 'https://www.nytimes.com/games/connections',
        },
        {
          property: 'og:image',
          content: `${CONNECTIONS_ASSET_BASE}/NYT-Connections-og-image.png`,
        },
        {
          property: 'og:description',
          content:
            'Group words that share a common thread. A new puzzle is available each day.',
        },
        {
          property: 'twitter:card',
          content: 'summary_large_image',
        },
        {
          property: 'twitter:domain',
          content: 'nytimes.com',
        },
        {
          property: 'theme-color',
          content: '#b4a8ff',
        },
      ],
      linkTags: [
        {
          href: `${CONNECTIONS_ASSET_BASE}/NYT-Connections-Icon.svg`,
          rel: 'icon shortcut',
          sizes: '3232',
        },
        {
          href: `${CONNECTIONS_ASSET_BASE}/NYT-Connections-Icon.svg`,
          rel: 'apple-touch-icon',
        },
      ],
    },
    pageProps: {
      pageName: 'connections-v2',
      adUnitPath: 'connections-v2',
      entry: 'connections-v2',
      includeScreenIntercept: true,
    },
  },
  testing: {
    pageProps: {
      entry: 'testing',
      metadata: {},
      pageName: 'testing',
    },
    metaData: {},
  },
}

// overwrite webpack bundle entry

// tiles
puzzleRouterConfig.tilesShortz = cloneDeep(puzzleRouterConfig.tiles)
puzzleRouterConfig.tilesShortz.pageProps.entry = 'tilesshortz'

// wordle
puzzleRouterConfig.wordleShortz = cloneDeep(puzzleRouterConfig.wordle)
puzzleRouterConfig.wordleShortz.pageProps.entry = 'wordleshortz'
puzzleRouterConfig.letterBoxedShortz = cloneDeep(
  puzzleRouterConfig.letterBoxed,
)
puzzleRouterConfig.letterBoxedShortz.pageProps.entry =
  'letterboxedshortz'
// spelling bee
puzzleRouterConfig.spellingBeeShortz = cloneDeep(
  puzzleRouterConfig.spellingBeeDate,
)
puzzleRouterConfig.spellingBeeShortz.pageProps.entry =
  'spellingbeeshortz'

// vertex
puzzleRouterConfig.vertexShortz = cloneDeep(
  puzzleRouterConfig.vertexDate,
)
puzzleRouterConfig.vertexShortz.pageProps.entry = 'vertexshortz'

module.exports = {
  puzzleRouterConfig,
}
