/**
 * SENTRY OUTBOUND FILTER
 *
 * This file contains the filter applied to all server-side Sentry events *before* they are transmitted.
 *
 * When a noisy issue has been identified, please add the error message to the ignoreErrors
 * array. This helps keep our Sentry usage down and minimizes the network calls our users make
 * during gameplay.
 */

/**
 * An array containing strings which are used by the Sentry SDK outbound filter. An includes() is
 * performed with these values which means *these strings are case sensitive*
 *
 * Add a portion of an error message string here if you wish for it to be filtered before being sent to Sentry.
 */
const ignoreErrors = [
  /**
   * NETWORK ERRORS
   * Errors related to intermittent connections or temporarily down endpoints. We use DataDog to capture this
   * so having Sentry do it too is unecesary and ends up pinging web folks when APIs go down.
   */
  'bad req',
  'No Internet',
  'Failed to fetch',
  'Load failed',
  'timed out',
  'Something went wrong',
  // These will usually get picked up by Datadog first, so no need to duplicate alerting
  'failed to process puzzle', // LetterBoxed and Vertex puzzles endpoint are down
  'SUDOKU FAILED', // Sudoku puzzle data failed to fetch
  'Non-Error promise rejection',
]

module.exports = ignoreErrors
