const Sentry = require('@sentry/node')

const constants = require('../../constants')
const logger = require('../../serverLogger')

const ignoreErrors = require('./filter')

const { SENTRY_DSN, COMMIT_HASH, SENTRY_SAMPLE_RATE, RUNTIME_ENV } =
  constants

const isSentryEnabled = RUNTIME_ENV === 'stg' || RUNTIME_ENV === 'prd'

/**
 * Initialize Sentry and set basic metadata about the session
 */
const initSentry = () => {
  logger.info('capturing server-side errors with Sentry')

  Sentry.init({
    dsn: SENTRY_DSN,
    release: COMMIT_HASH,
    // Cut the server-side sample rate a bit
    sampleRate: SENTRY_SAMPLE_RATE * 0.35,
    ignoreErrors,
    integrations: [
      new Sentry.Integrations.Console(),
      new Sentry.Integrations.LocalVariables({
        captureAllExceptions: true,
      }),
    ],
  })
}

module.exports = { initSentry, isSentryEnabled }
