/**
 * @jest-environment node
 */
const axios = require('axios')

const logger = require('../../../serverLogger')
const getAbraConfig = require('../getAbraConfig')

jest.mock('axios', () => ({
  get: jest.fn(),
}))

jest.mock('../../../serverLogger', () => ({
  error: jest.fn(),
}))

jest.mock('../../../constants', () => ({
  IS_PROD: false,
  ABRA_CONFIG_ORIGIN: 'https://a1.nyt.com',
}))

describe('SERVICE: GET ABRA CONFIG', () => {
  // This test is order dependent (which is bad)
  // The abra config client will cache the initial response
  // in a local object and return it before a bad request can be made
  // if we run the tests in the other order
  it('should handle and log errors', async () => {
    axios.get.mockReturnValue(
      Promise.reject(new Error('bad request')),
    )

    await getAbraConfig()
    expect(logger.error).toHaveBeenCalled()
  })

  it('should get configs from the correct environment', async () => {
    axios.get.mockReturnValue(
      Promise.resolve({
        data: {
          '.ver': 1234,
        },
      }),
    )

    const result = await getAbraConfig()
    expect(axios.get).toHaveBeenCalledWith(
      'https://a1.nyt.com/abra-config/current/games-stg.json',
    )
    expect(result).toEqual({
      '.ver': 1234,
    })
  })
})
