import getCrossword, { Tutorials } from '../getCrossword'

describe('api: puzzle', () => {
  let puzz
  const get = jest.fn()

  beforeEach(() => {
    puzz = {
      data: {
        assets: 'assets',
        body: [
          {
            board: 'SVG',
            cells: 'cells',
            clues: 'clues',
            dimensions: 'dimensions',
          },
        ],
        foo: 'foo',
        bar: 'bar',
      },
    }

    /** default response */
    get.mockReturnValue(Promise.resolve(puzz))
  })

  afterEach(jest.clearAllMocks)

  test('get puzzle rejects', () => {
    expect.assertions(1)
    return getCrossword.byId({ params: {} }).catch((e) => {
      expect(e.status).toBe(404)
    })
  })

  test('get puzzle by id', async () => {
    const { filename } = await getCrossword.byId({
      params: { id: '123' },
    })
    expect(filename).toEqual('123')
  })

  test('get puzzle by tutorial name', async () => {
    const title = Object.keys(Tutorials)[0]
    const { filename } = await getCrossword.byTutorial({
      params: { title },
    })

    expect(filename).toEqual(Tutorials[title])
  })

  test('get puzzle by stream name', async () => {
    const { filename } = await getCrossword.byStream({
      params: { stream: 'abc' },
    })
    expect(filename).toEqual('abc')
  })

  test('get puzzle by slug', async () => {
    const { filename } = await getCrossword.bySlug({
      params: { slug: 'abc' },
    })
    expect(filename).toEqual('named/abc')
  })

  test('get puzzle by date', async () => {
    const { filename } = await getCrossword.byDate(
      { params: { stream: 's', yyyy: '2016', m: '08', d: '03' } },
      { locals: { api: { get } } },
    )
    expect(filename).toEqual('s/2016-08-03')
  })

  test('get puzzle by date (single digits)', async () => {
    const { filename } = await getCrossword.byDate({
      params: { stream: 's', yyyy: '2016', m: '8', d: '3' },
    })
    expect(filename).toEqual('s/2016-08-03')
  })

  test('get puzzle by date (for bonus)', async () => {
    const { filename } = await getCrossword.byDate({
      params: { stream: 'bonus', yyyy: '2016', m: '8' },
    })
    expect(filename).toEqual('bonus/2016-08-01')
  })

  test('get puzzle by date (for bad dates)', async () => {
    let error = false
    await getCrossword
      .byDate(
        { params: { stream: 's', yyyy: '2016', m: '8' } },
        { locals: { api: { get } } },
      )
      .catch(() => {
        error = true
      })
    expect(error).toBe(true)
  })

  test('get puzzle by date (for really bad dates)', async () => {
    let error = false
    await getCrossword
      .byDate(
        { params: { stream: 's', yyyy: '2016', m: '8', d: 'mraid' } },
        { locals: { api: { get } } },
      )
      .catch(() => {
        error = true
      })
    expect(error).toBe(true)
  })
})
