const getLeaderboard = require('../getFriends')

describe('SERVICE: GET FRIENDS', () => {
  let req
  let res

  beforeEach(() => {
    req = {}
    res = {
      locals: {
        api: {
          get: jest.fn(),
        },
      },
    }
  })

  test('it should adapt API to manageFriends props', () => {
    res.locals.api.get.mockReturnValue(
      Promise.resolve({
        data: {
          name: 'bob',
          list: [1, 2, 3],
          pending: [4, 5, 6],
          blocked: [7, 8, 9],
        },
      }),
    )

    return expect(getLeaderboard(req, res)).resolves.toEqual({
      connections: {
        self: [{ name: 'bob' }],
        friends: [1, 2, 3],
        pending: [4, 5, 6],
        blocked: [7, 8, 9],
      },
    })
  })

  test('it should handle missing lists', () => {
    res.locals.api.get.mockReturnValue(
      Promise.resolve({
        data: {
          name: 'bob',
        },
      }),
    )

    return expect(getLeaderboard(req, res)).resolves.toEqual({
      connections: {
        self: [{ name: 'bob' }],
        friends: [],
        pending: [],
        blocked: [],
      },
    })
  })

  test('should throw for 500s', () => {
    const error = new Error('bad request')
    error.status = 500
    res.locals.api.get.mockImplementation(() => Promise.reject(error))

    expect.assertions(1)

    return getLeaderboard(req, res).catch((e) => {
      expect(e).toEqual(error)
    })
  })

  test('should throw for unknown errors', () => {
    const error = new Error('bad code')
    res.locals.api.get.mockImplementation(() => Promise.reject(error))

    expect.assertions(1)
    return getLeaderboard(req, res).catch((e) => {
      expect(e).toEqual(error)
    })
  })

  test('should add in awaiting requests', () => {
    res.locals.api.get.mockReturnValue(
      Promise.resolve({
        data: {
          name: 'bob',
          list: [1, 2, 3],
          pending: [
            { userID: 1, name: 'foo' }, // duplicate
          ],
          blocked: [7, 8, 9],
          awaiting: [
            { userID: 1, name: 'foo' },
            { userID: 2, name: 'bar' },
          ],
        },
      }),
    )

    return expect(getLeaderboard(req, res)).resolves.toEqual({
      connections: {
        self: [{ name: 'bob' }],
        friends: [1, 2, 3],
        pending: [
          { userID: 1, name: 'foo' },
          {
            userID: 2,
            name: 'bar',
            pendingState: 'awaiting',
          },
        ],
        blocked: [7, 8, 9],
      },
    })
  })
})
