const getGamesHubPuzzles = require('../getGamesHubPuzzles')

describe('SERVICES: GET GAMES HUB PUZZLES', () => {
  let req
  let res

  beforeEach(() => {
    req = { params: {} }
    res = {
      locals: {
        api: {
          get: jest.fn(),
        },
      },
    }
  })

  it('should return puzzle data correctly', () => {
    res.locals.api.get.mockResolvedValueOnce({
      data: {
        status: 'OK',
        results: {
          daily_puzzle: [
            {
              puzzle_id: 18454,
              title: '',
            },
          ],
          bonus_puzzle: [],
          entitlement: 'basic',
        },
      },
    })

    const expectedData = {
      daily_puzzle: [
        {
          puzzle_id: 18454,
          title: '',
        },
      ],
      bonus_puzzle: [],
      entitlement: 'basic',
    }

    return getGamesHubPuzzles(req, res).then((data) => {
      expect(data).toEqual(expectedData)
    })
  })

  it('should return an empty object if there is a network error', () => {
    res.locals.api.get.mockRejectedValueOnce({
      Error: 'Request failed with status code 500',
      status: 500,
      data: '',
    })

    return getGamesHubPuzzles(req, res).then((data) => {
      expect(data).toEqual({})
    })
  })

  it('should return an empty object is there are no results', () => {
    res.locals.api.get.mockResolvedValueOnce({
      data: {},
    })

    return getGamesHubPuzzles(req, res).then((data) => {
      expect(data).toEqual({})
    })
  })
})
