const getLeaderboard = require('../getLeaderboard')

jest.mock('../../util/formatTime', () => (t) => `formatted(${t})`)

describe('SERVICE: GET LEADERBOARD', () => {
  let req
  let res

  beforeEach(() => {
    req = {}
    res = {
      locals: {
        api: {
          get: jest.fn(),
        },
      },
    }
  })

  test('it should adapt API to scorelist', () => {
    const apiResults = {
      'svc/crosswords/v6/leaderboard/mini.json': {
        data: {
          printDate: '2018-11-16',
          publishType: 'mini',
          data: [
            {
              me: true,
              userID: 80521154,
              name: 'Player one',
              rank: '1',
              score: {
                secondsSpentSolving: 10,
              },
            },
            {
              userID: 345,
              name: 'Player two',
              rank: '2',
              score: {
                secondsSpentSolving: 20,
              },
            },
            {
              userID: 345,
              name: 'Player three',
              rank: '3',
              score: {
                secondsSpentSolving: 30,
              },
            },
            {
              userID: 345,
              name: 'Player four',
            },
            {
              userID: 345,
              name: 'Player five',
              score: {},
            },
          ],
        },
      },
    }

    res.locals.api.get.mockImplementation((v) =>
      Promise.resolve(apiResults[v]),
    )

    expect(getLeaderboard(req, res)).resolves.toEqual({
      printDate: '2018-11-16',
      displayDate: 'Friday, November 16, 2018',
      puzzleLink: '/crosswords/game/mini/2018/11/16',
      pendingRequests: 0,
      scoreList: [
        {
          isMe: true,
          name: 'Player one',
          rank: '1',
          solveTime: 'formatted(10)',
          finished: true,
        },
        {
          isMe: false,
          name: 'Player two',
          rank: '2',
          solveTime: 'formatted(20)',
          finished: true,
        },
        {
          isMe: false,
          name: 'Player three',
          rank: '3',
          solveTime: 'formatted(30)',
          finished: true,
        },
        {
          isMe: false,
          name: 'Player four',
          rank: null,
          solveTime: null,
          finished: false,
        },
        {
          isMe: false,
          name: 'Player five',
          rank: null,
          solveTime: null,
          finished: false,
        },
      ],
    })
  })

  test('should return pending requests', async () => {
    const apiResults = {
      'svc/crosswords/v6/leaderboard/mini.json': {
        data: {
          printDate: '2018-11-16',
          pendingConnectionsCount: 2,
        },
      },
    }

    res.locals.api.get.mockImplementation((v) =>
      Promise.resolve(apiResults[v]),
    )

    const { pendingRequests } = await getLeaderboard(req, res)
    expect(pendingRequests).toEqual(2)
  })

  test('should throw for 500s', () => {
    const error = new Error('bad request')
    error.status = 500
    res.locals.api.get.mockImplementation(() => Promise.reject(error))

    expect.assertions(1)
    return getLeaderboard(req, res).catch((e) => {
      expect(e).toEqual(error)
    })
  })

  test('should throw for unknown errors', () => {
    const error = new Error('bad code')
    res.locals.api.get.mockImplementation(() => Promise.reject(error))

    expect.assertions(1)
    return getLeaderboard(req, res).catch((e) => {
      expect(e).toEqual(error)
    })
  })
})
