const moment = require('moment')

const getLetterBoxed = require('../getLetterBoxedGame')

describe('SERVICE: Get Letter Boxed', () => {
  const req = { params: {} }
  const res = {
    locals: {
      api: {
        get: jest.fn(),
      },
    },
  }

  const todayPuzzle = {
    id: 1,
    printDate: '2019-02-11',
    expiration: 1549958400,
    par: 4,
    sides: ['ARK', 'BNW', 'VYO', 'DEI'],
    dictionary: ['DICTIONARY', 'WORDS'],
    ourSolution: ['TEST', 'TESTING'],
    isFree: true,
    editor: 'test',
    editorImage: 'testImage',
  }

  const yesterdayPuzzle = {
    id: 2,
    printDate: '2019-02-11',
    expiration: 1549958400,
    par: 6,
    sides: ['EWQ', 'UYT', 'POI', 'LKJ'],
    dictionary: ['TEST', 'TWO'],
    ourSolution: ['YESTERDAY', 'YEESUS'],
    editor: 'test',
    editorImage: 'testImage',
  }

  const examplePuzzles = {
    'svc/letter-boxed/v1/yesterday.json': {
      data: { ...yesterdayPuzzle, is_free: false },
    },
    'svc/letter-boxed/v1/puzzle.json': {
      data: { ...todayPuzzle, is_free: false },
    },
  }

  const expectedResponse = {
    ...todayPuzzle,
    date: moment(todayPuzzle.printDate, 'YYYY-M-D').format(
      'MMMM D, YYYY',
    ),
    dictionary: todayPuzzle.dictionary.map((s) => s.toUpperCase()),
    yesterdaysSolution: yesterdayPuzzle.ourSolution,
    yesterdaysSides: yesterdayPuzzle.sides,
    isFree: false,
  }

  it('adapts api data correctly', () => {
    expect.assertions(1)

    res.locals.api.get.mockImplementation((file) =>
      Promise.resolve(examplePuzzles[file]),
    )
    return getLetterBoxed(req, res).then((v) => {
      expect(v).toEqual(expectedResponse)
    })
  })

  it('uses date when provided', () => {
    expect.assertions(1)

    const today = '2021-06-29'
    const yesterday = '2021-06-28'
    const exampleDatedPuzzles = {
      [`svc/letter-boxed/v1/${yesterday}.json`]: {
        data: yesterdayPuzzle,
      },
      [`svc/letter-boxed/v1/${today}.json`]: {
        data: todayPuzzle,
      },
    }
    res.locals.api.get.mockImplementation((file) =>
      Promise.resolve(exampleDatedPuzzles[file]),
    )

    return getLetterBoxed({ params: { date: today } }, res).then(
      (v) => {
        expect(v).toEqual(expectedResponse)
      },
    )
  })

  it('rejects invalid dates', () => {
    expect.assertions(1)
    return getLetterBoxed({ params: { date: 'foobar' } }, res).catch(
      (err) => {
        expect(err).toMatchObject({
          status: 404,
          message: 'Invalid date (status: 404)',
        })
      },
    )
  })

  it('rejects with any api failures', () => {
    expect.assertions(1)

    const testError = new Error('abc')
    res.locals.api.get.mockReturnValue(Promise.reject(testError))

    return getLetterBoxed(req, res).catch((err) => {
      expect(err).toBe(testError)
    })
  })
})
