const getProfile = require('../getProfile')

describe('SERVICE: GET PROFILE', () => {
  let req
  let res

  beforeEach(() => {
    req = { params: {} }

    res = {
      locals: {
        api: {
          get: jest.fn(),
        },
      },
    }
  })

  test('get user profile', async () => {
    res.locals.api.get.mockReturnValue(
      Promise.resolve({
        data: {
          name: 'TEST_NAME',
          URL: 'TEST_URL',
        },
      }),
    )

    const profile = await getProfile(req, res)

    expect(res.locals.api.get).toHaveBeenCalledWith(
      'svc/crosswords/v6/leaderboard/profile.json',
    )

    expect(profile).toEqual({
      name: 'TEST_NAME',
      shareURL: 'TEST_URL',
      view: 'inviteStepOne',
      shareCode: undefined,
    })
  })

  test('get connection profile', async () => {
    req.params.code = 'abc'

    res.locals.api.get.mockReturnValue(
      Promise.resolve({
        data: {
          name: 'TEST_NAME',
          URL: 'TEST_URL',
        },
      }),
    )

    const profile = await getProfile(req, res)

    expect(res.locals.api.get).toHaveBeenCalledWith(
      '/svc/crosswords/v6/leaderboard/connection/profile/abc.json',
    )

    expect(profile).toEqual({
      name: 'TEST_NAME',
      shareURL: 'TEST_URL',
      view: 'inviteStepTwo',
      shareCode: 'abc',
    })
  })

  test('handles invalid Invite link', async () => {
    const err = new Error('not found')

    req.params.code = '123'
    err.status = 400
    err.data = {
      errorCode: 2, // the code the api returns
    }
    res.locals.api.get.mockReturnValue(Promise.reject(err))

    const profile = await getProfile(req, res)

    expect(profile).toEqual({
      view: 'inviteError',
      error: {
        message: 'not found',
        status: 400,
      },
    })
  })

  test('passes on unknown errors', async () => {
    const err = new Error('unknown')
    res.locals.api.get.mockReturnValue(Promise.reject(err))

    expect.assertions(1)

    try {
      await getProfile(req, res)
    } catch (e) {
      expect(e).toBe(err)
    }
  })
})
