require('moment-timezone')

const moment = require('moment')
const MockDate = require('mockdate')

const getSponsorship = require('../getSponsorship')

const BEGINNING = '2020-01-01 09:00'
const END = '2020-01-02 03:00'
const TEST_KEYWORD = 'tenet'

describe('SERVICE: GET SPONSORSHIP', () => {
  let req

  beforeEach(() => {
    req = { query: {} }
    MockDate.set(
      moment.tz(BEGINNING, 'America/New_York').subtract(1, 'seconds'),
    )
  })

  afterEach(() => {
    MockDate.reset()
  })

  it('should support testing', () => {
    req.query['ad-keywords'] = TEST_KEYWORD
    expect(getSponsorship(req)).toHaveProperty('image')
    expect(getSponsorship(req)).toHaveProperty('link')
  })

  it('should return null just before beginning', () => {
    MockDate.set(
      moment.tz(BEGINNING, 'America/New_York').subtract(1, 'seconds'),
    )
    expect(getSponsorship(req)).toBe(null)
  })

  it('should return null just after end', () => {
    MockDate.set(moment.tz(END, 'America/New_York').add(1, 'seconds'))
    expect(getSponsorship(req)).toBe(null)
  })

  it('should return sponsorship just after beginning', () => {
    MockDate.set(
      moment.tz(BEGINNING, 'America/New_York').add(1, 'seconds'),
    )
    expect(getSponsorship(req)).toHaveProperty('image')
    expect(getSponsorship(req)).toHaveProperty('link')
  })

  it('should return sponsorship just before end', () => {
    MockDate.set(
      moment.tz(END, 'America/New_York').subtract(1, 'seconds'),
    )
    expect(getSponsorship(req)).toHaveProperty('image')
    expect(getSponsorship(req)).toHaveProperty('link')
  })
})
