const getSudoku = require('../getSudoku')

describe('SERVICE: GET SUDOKU', () => {
  let get

  beforeEach(() => {
    get = jest.fn()
  })

  test('fetches puzzle data', async () => {
    get.mockReturnValue(
      Promise.resolve({
        data: {
          results: {
            easy: {
              print_date: '1990-07-03',
              puzzle: [0, 1, 2],
            },
            medium: {
              print_date: '1990-07-03',
              puzzle: [0, 1, 2],
            },
          },
        },
      }),
    )
    const data = await getSudoku(
      { query: {} },
      {
        locals: {
          api: { get },
        },
      },
    )
    expect(data).toEqual({
      displayDate: 'July 3, 1990',
      easy: {
        print_date: '1990-07-03',
        puzzle: [0, 1, 2],
      },
      medium: {
        print_date: '1990-07-03',
        puzzle: [0, 1, 2],
      },
    })
  })

  test('handles errors', async () => {
    expect.assertions(1)
    get.mockReturnValue(Promise.reject(new Error('failed')))
    try {
      await getSudoku(
        { query: {} },
        {
          locals: {
            api: { get },
          },
        },
      )
    } catch (err) {
      expect(err.message).toBe('SUDOKU FAILED: failed')
    }
  })

  test('allows faking the date', async () => {
    get.mockReturnValue(
      Promise.resolve({
        data: {
          results: {
            easy: {
              print_date: '1990-07-03',
              puzzle: [0, 1, 2],
            },
            medium: {
              print_date: '1990-07-03',
              puzzle: [0, 1, 2],
            },
          },
        },
      }),
    )
    const data = await getSudoku(
      { query: { 'fake-date': '2017-07-03' } },
      {
        locals: {
          api: { get },
        },
      },
    )
    expect(data).toEqual({
      displayDate: 'July 3, 2017',
      easy: {
        print_date: '2017-07-03',
        puzzle: [0, 1, 2],
      },
      medium: {
        print_date: '2017-07-03',
        puzzle: [0, 1, 2],
      },
    })
  })
})
