const axios = require('axios')

const getVertex = require('../getVertex')

jest.mock('axios', () => ({
  get: jest.fn(),
}))

jest.mock('../../../constants', () => ({
  APPLICATION_HOST_SERVER: 'http://local.nytimes.com/',
  RUNTIME_ENV: 'dev',
  ROUTE_ASSETS: 'route-assets',
  GOOGLE_STORAGE_API: 'gcs',
}))

const puzzle = {
  id: 'puzzle-id-007',
  printDate: '2019-10-01',
  theme: 'A tricky puzzle',
  constructors: ['me', 'myself', 'i'],
  body: {
    vertices: [
      {
        coordinates: [0, 10],
      },
      {
        coordinates: [10, 20],
      },
      {
        coordinates: [5, 10],
      },
      {
        coordinates: [15, 30],
      },
    ],
    shapes: [
      {
        vertices: [0, 1, 2],
        color: 0,
      },
      {
        vertices: [1, 2, 3],
        color: 1,
      },
      {
        vertices: [1, 2, 3],
        color: 0,
      },
      {
        vertices: [0, 1, 3],
        color: 0,
      },
    ],
    palette: ['#FFFFFF', '#000000'],
  },
}

const exampleGCSCall = {
  'svc/vertex/v1/puzzle/today.json': {
    data: puzzle,
  },
  'http://local.nytimes.com/route-assets/assets/vertex/tutorial.json':
    {
      data: {
        0: puzzle,
        1: puzzle,
      },
    },
  'http://local.nytimes.com/route-assets/assets/vertex/starter-pack.json':
    {
      data: {
        0: puzzle,
        1: puzzle,
      },
    },
}

describe('SERVICE: GET VERTEX', () => {
  const req = { params: {} }
  const res = {
    locals: {
      api: {
        get: jest.fn(),
      },
    },
  }
  it('gets proper puzzle and returns derived data', () => {
    res.locals.api.get.mockImplementation((url) =>
      Promise.resolve(exampleGCSCall[url]),
    )
    axios.get.mockImplementation((url) =>
      Promise.resolve(exampleGCSCall[url]),
    )

    expect.assertions(5)

    return getVertex(req, res).then((data) => {
      expect(data.puzzleConstructor).toEqual('me, myself and i')
      expect(data.vertices['0'].shapes).toEqual(['0', '3'])
      expect(data.vertices['1'].shapes).toEqual(['0', '1', '2', '3'])
      expect(data.vertices['2'].shapes).toEqual(['0', '1', '2'])
      expect(data.vertices['3'].shapes).toEqual(['1', '2', '3'])
    })
  })
})
