const { ROUTE_ASSETS } = require('../../constants')
const StatusError = require('../util/StatusError')

const isUndefined = (v) => typeof v === 'undefined'

const dateLike = /\d{4}-\d{2}-\d{2}/

const createNotFoundError = () =>
  new StatusError('Crossword not found', 404)

const Tutorials = {
  'clue-answer-agreement': 9501,
  'question-mark-clues': 9505,
  crosswordese: 9503,
  themes: 9506,
  'rebus-answers': 9504,
}

// simply determines the filename and stream from params and passes
// them along to the client, where the call to the puzzle API happens
const crosswordGetter = (getPuzzFilename) => (req) => {
  const filename = getPuzzFilename(req.params)
  if (!filename) {
    return Promise.reject(createNotFoundError())
  }

  return Promise.resolve({
    filename,
    stream: req.params.stream,
    assetBasePath: ROUTE_ASSETS,
  })
}

module.exports.byId = crosswordGetter((params) => params.id)

module.exports.byTutorial = crosswordGetter(
  (params) => Tutorials[params.title],
)

module.exports.byStream = crosswordGetter((params) => params.stream)

module.exports.bySlug = crosswordGetter(
  (params) => `named/${params.slug}`,
)

module.exports.byDate = crosswordGetter((params) => {
  const { stream, yyyy, m } = params
  let { d } = params
  if (stream === 'bonus') d = '1'

  /** if there is no day and this is not a bonus puzzle */
  if (isUndefined(m) || isUndefined(d)) return undefined

  const mm = m.length === 1 ? `0${m}` : m
  const dd = d.length === 1 ? `0${d}` : d
  const date = `${yyyy}-${mm}-${dd}`

  if (!dateLike.test(date)) return undefined

  return `${stream}/${date}`
})

module.exports.Tutorials = Tutorials
