const moment = require('moment')

const StatusError = require('../util/StatusError')

const SVC_ROOT = 'svc/letter-boxed/v1/'
const TODAY = `${SVC_ROOT}puzzle.json`
const YESTERDAY = `${SVC_ROOT}yesterday.json`
const validDate = /\d{4}-\d{2}-\d{2}/

const getTodaysPuzzle = (api) =>
  api.get(TODAY).then(({ data }) => data)

const getYesterdaysPuzzle = (api) =>
  api.get(YESTERDAY).then(({ data }) => data)

const getPuzzleByDate = (api, date) =>
  api.get(`${SVC_ROOT}${date}.json`).then(({ data }) => data)

const getYesterdaysPuzzleByDate = (api, date) =>
  getPuzzleByDate(
    api,
    moment(date).add(-1, 'days').format('yyyy-MM-DD'),
  )

const mergePuzzleData = ([today, yesterday]) => {
  return {
    id: today.id,
    expiration: today.expiration,
    ourSolution: today.ourSolution,
    printDate: today.printDate,
    sides: today.sides,
    date: moment(today.printDate, 'YYYY-M-D').format('MMMM D, YYYY'),
    dictionary: today.dictionary.map((s) => s.toUpperCase()),
    par: today.par,
    yesterdaysSolution: yesterday.ourSolution,
    yesterdaysSides: yesterday.sides,
    isFree: false,
    editor: today.editor,
    editorImage: today.editorImage,
  }
}

const getLetterBoxedGame = (req, res) => {
  const { api } = res.locals
  if (req.params.date && !validDate.test(req.params.date)) {
    return Promise.reject(new StatusError('Invalid date', 404))
  }

  return Promise.all(
    req.params.date
      ? [
          getPuzzleByDate(api, req.params.date),
          getYesterdaysPuzzleByDate(api, req.params.date),
        ]
      : [getTodaysPuzzle(api), getYesterdaysPuzzle(api)],
  )
    .then(mergePuzzleData)
    .catch((e) => {
      if (req.params.date && e.status === 401) {
        // Having a date param means that a user is trying to access
        // shortz mode behavior. A 401 from the backend means they're
        // not authorized to have the puzzle data. Serving a 404
        // instead of a 401 to match the previous implementation
        // in puzzleRouter.js
        throw new StatusError('Not Found', 404)
      } else {
        e.message = `failed to process puzzle: ${e}`
        throw e
      }
    })
}

module.exports = getLetterBoxedGame
