const profileApi = `svc/crosswords/v6/leaderboard/profile.json`
const connectionProfileApi = `/svc/crosswords/v6/leaderboard/connection/profile`

// @see https://github.com/nytimes/games-leaderboards/blob/main/leaderboards.proto
const INVALID_CODE = 2

module.exports = async function getProfile(req, res) {
  try {
    const profile = req.params.code
      ? await res.locals.api.get(
          `${connectionProfileApi}/${req.params.code}.json`,
        )
      : await res.locals.api.get(profileApi)

    return {
      view: req.params.code ? 'inviteStepTwo' : 'inviteStepOne',
      name: profile.data.name,
      shareURL: profile.data.URL,
      shareCode: req.params.code,
    }
  } catch (error) {
    if (
      req.params.code &&
      error.data &&
      error.data.errorCode === INVALID_CODE
    ) {
      return {
        view: 'inviteError',
        error: {
          status: error.status,
          message: error.message,
        },
      }
    }
    throw error
  }
}
