const moment = require('moment')

const finesseStats = ({ stats, streaks }) => {
  const today = moment().format('dddd')
  const statsByDay = stats.stats_by_day
  const bestTimes = statsByDay.map((d) => d.best_time)

  return {
    today,
    puzzlesSolved: stats.puzzles_solved,
    solveRate: `${Math.round(stats.solve_rate * 100 * 10) / 10}%`,
    currentStreak: streaks.current_streak,
    longestStreak: streaks.longest_streak,
    fastestTime: Math.min(...bestTimes),
    slowestTime: Math.max(
      stats.longest_avg_time,
      stats.longest_latest_time,
    ),
    byDay: stats.stats_by_day.map((day) => {
      return {
        label: day.label,
        isToday: day.label === today,
        averageTime: day.avg_time,
        bestTime: day.best_time,
        bestDate: moment(day.best_date).format('MM-DD-YYYY'),
        latestTime: day.this_weeks_time,
      }
    }),
  }
}

const fakeStats = finesseStats({
  stats: {
    longest_avg_time: 1268,
    longest_latest_time: 310,
    puzzles_attempted: 645,
    puzzles_solved: 345,
    solve_rate: 0.651,
    stats_by_day: [
      {
        avg_denominator: 7,
        avg_time: 533,
        best_date: '2017-05-22',
        best_time: 300,
        label: 'Monday',
        latest_date: '2017-06-26',
        latest_time: 355,
        this_weeks_time: 355,
      },
      {
        avg_denominator: 7,
        avg_time: 733,
        best_date: '2017-05-23',
        best_time: 265,
        label: 'Tuesday',
        latest_date: '2017-06-27',
        latest_time: 555,
        this_weeks_time: 555,
      },
      {
        avg_denominator: 7,
        avg_time: 933,
        best_date: '2017-05-24',
        best_time: 465,
        label: 'Wednesday',
        latest_date: '2017-06-28',
        latest_time: 755,
        this_weeks_time: 755,
      },
      {
        avg_denominator: 4,
        avg_time: 1104,
        best_date: '2017-02-23',
        best_time: 604,
        label: 'Thursday',
        latest_date: '2017-02-23',
        latest_time: 904,
        this_weeks_time: 904,
      },
      {
        avg_denominator: 11,
        avg_time: 1368,
        best_date: '2017-04-28',
        best_time: 828,
        label: 'Friday',
        latest_date: '2017-04-28',
        latest_time: 1128,
        this_weeks_time: 1128,
      },
      {
        avg_denominator: 4,
        avg_time: 1517,
        best_date: '2017-03-11',
        best_time: 1005,
        label: 'Saturday',
        latest_date: '2017-03-25',
        latest_time: 1310,
        this_weeks_time: 1310,
      },
      {
        avg_denominator: 7,
        avg_time: 1033,
        best_date: '2017-03-12',
        best_time: 604,
        label: 'Sunday',
        latest_date: '2017-03-26',
        latest_time: 755,
        this_weeks_time: 755,
      },
    ],
  },
  streaks: {
    msg: 'Start date <date_start> is empty',
    current_streak: 1,
    longest_streak: 12,
  },
})

module.exports = function fetchStats(req, res) {
  const { api, user } = res.locals

  return api
    .get(`/svc/crosswords/v3/${user.id}/stats-and-streaks.json`, {
      params: {
        date_start: '1988-01-01',
        start_on_monday: true,
      },
    })
    .then((response) => {
      return finesseStats(response.data.results)
    })
    .catch((e) => {
      if (e.status === 403 || e.status === 401) {
        return fakeStats
      }
      throw e
    })
}
