const axios = require('axios')
const yup = require('yup')

const { ZENDESK_API } = require('../../constants')

const { PUZZLE_SUBMISSION_BRAND_ID, ZENDESK_API_TOKEN } = process.env

const brandId = Number(PUZZLE_SUBMISSION_BRAND_ID)

const bodySchema = yup.object().shape({
  email: yup
    .string()
    .email()
    .required(),
  name: yup.string().required(),
  note: yup.string(),
  size: yup.string().required(),
})

module.exports = async (req) => {
  const { puzzle } = req.files
  const { email, name, note, size } = req.body

  await bodySchema.isValid({
    email,
    name,
    note,
    size,
  })

  const response = await axios({
    data: puzzle.data,
    headers: {
      Authorization: `Basic ${ZENDESK_API_TOKEN}`,
      'Content-Type': 'application/binary',
    },
    method: 'post',
    url: `${ZENDESK_API}/uploads.json?filename=${puzzle.name}`,
  })

  const { upload } = response.data

  await axios({
    data: {
      ticket: {
        brand_id: brandId,
        comment: {
          body: `Size: ${size} Note: ${note}`,
          uploads: [upload.token],
        },
        requester: {
          email,
          name,
        },
        subject: `${name} ${size}`,
        tags: ['crossword_puzzle_submission'],
      },
    },
    headers: {
      'Content-Type': 'application/json',
      Authorization: `Basic ${ZENDESK_API_TOKEN}`,
    },
    method: 'post',
    url: `${ZENDESK_API}/tickets.json`,
  })
}
