/**
 * StatusError allows us to handle status codes in the express app
 * @see: https://medium.com/@xjamundx/custom-javascript-errors-in-es6-aa891b173f87
 */
class StatusError extends Error {
  constructor(
    inMessage = 'something went wrong',
    inStatus,
    inData = {},
  ) {
    let message = inMessage
    let status = inStatus
    let data = inData

    const { stack } = message

    if (message.response) {
      /** axios response error */
      status = message.response.status
      data = message.response.data // attach api data
      message = `${message.response.config.url} => ${message.response.statusText}`
    } else if (message.request) {
      /** axios request error */
      status = message.request.status
      message = `axios request error`
    } else if (message instanceof StatusError) {
      /** another status error */
      status = status || message.status
      message = message.originalMessage
    } else if (message instanceof Error) {
      /** a standard error error */
      message = message.message
    }

    status = status || 500

    super(`${message} (status: ${status})`)

    this.status = status
    this.originalMessage = message
    this.data = data

    if (stack) {
      this.stack = stack
    } else {
      Error.captureStackTrace(this, StatusError)
    }
  }
}

module.exports = StatusError
