const createMetadata = require('../createMetadata')

jest.mock('../../../constants', () => ({
  PUBLIC_ROOT: 'src/public',
}))

describe('APP/UTIL: CREATE METADATA', () => {
  test('merges with defaults', () => {
    expect(
      createMetadata({
        title: 'Foobar',
      }),
    ).toHaveProperty('title', 'Foobar')
  })

  test('deeply merges with defaults', () => {
    expect(
      createMetadata({
        metaTags: [
          {
            test: true,
          },
        ],
      }).metaTags,
    ).toContainEqual({
      test: true,
    })
  })

  test('adds link with same structure as existing default', () => {
    expect(
      createMetadata({
        linkTags: [
          {
            rel: 'manifest',
            href: 'foo.json',
          },
        ],
      }).linkTags,
    ).toContainEqual({
      rel: 'manifest',
      href: 'foo.json',
    })
  })

  test('rejects invalid manifest', () => {
    expect(() =>
      createMetadata({
        manifestId: 'non-existent-prefix',
      }),
    ).toThrow(/unknown manifest/)
  })

  test('merge multiple metadata objects', () => {
    expect(
      createMetadata(
        { foo: true, bar: { baz: 1 } },
        { bar: { baz: 2 } },
      ),
    ).toMatchObject({ foo: true, bar: { baz: 2 } })
  })
})
