const getProps = require('../createPropGetter')

describe('APP/UTIL: CREATE PROP GETTER', () => {
  it('supports sync props', () => {
    expect.assertions(1)

    const propDefinition = {
      foo: 1,
      bar: 2,
    }

    const req = {}
    const res = {}

    return expect(
      getProps(propDefinition)(req, res),
    ).resolves.toEqual({
      foo: 1,
      bar: 2,
    })
  })

  it('supports computed props', () => {
    expect.assertions(1)

    const propDefinition = {
      foo: (req) => req.foo,
      bar: (req, res) => res.bar,
    }

    const req = { foo: 1 }
    const res = { bar: 2 }

    return expect(
      getProps(propDefinition)(req, res),
    ).resolves.toEqual({
      foo: 1,
      bar: 2,
    })
  })

  it('supports async props', () => {
    expect.assertions(1)

    const propDefinition = {
      foo: (req) => Promise.resolve(req.foo),
      bar: (req, res) => Promise.resolve(res.bar),
    }

    const req = { foo: 1 }
    const res = { bar: 2 }

    return expect(
      getProps(propDefinition)(req, res),
    ).resolves.toEqual({
      foo: 1,
      bar: 2,
    })
  })

  it('supports a sequence of async props', () => {
    expect.assertions(1)

    const propDefinition = [
      {
        foo: (req) => Promise.resolve(req.foo),
      },
      {
        bar: (req, res, props) => Promise.resolve(props.foo + 1),
      },
      {
        baz: (req, res, props) => props.bar + 1,
        extra: 'yay',
      },
    ]

    const req = { foo: 1 }
    const res = { bar: 2 }

    return expect(
      getProps(propDefinition)(req, res),
    ).resolves.toEqual({
      foo: 1,
      bar: 2,
      baz: 3,
      extra: 'yay',
    })
  })

  it('should pass error through', () => {
    expect.assertions(1)

    const err = new Error('bad thing')

    const propDefinition = {
      foo: () => Promise.reject(err),
    }

    const req = { foo: 1 }
    const res = { bar: 2 }

    return expect(getProps(propDefinition)(req, res)).rejects.toEqual(
      err,
    )
  })
})
