const url = require('url')

const express = require('express')
const request = require('supertest')

const { gtSemverCompare } = require('../newsreader')
const createNavLinks = require('../createNavigationLinks')

jest.mock('../newsreader', () => ({
  gtSemverCompare: jest.fn(),
}))

describe('APP/UTIL: Always call gtSemverCompare', () => {
  let app
  let deviceType

  beforeEach(() => {
    deviceType = {}
    app = express()
    app.use((req, res) => {
      res.locals.deviceType = deviceType
      res.send(createNavLinks(req, res))
    })

    jest.resetAllMocks()
  })

  test('should always call gtSemverCompare for ios newsreader users', () => {
    deviceType.newsreaderAppPlatform = 'ios'
    deviceType.newsreaderAppVersion = '9.40.0'

    return request(app)
      .get('/page?query=abc')
      .then((res) => {
        expect(gtSemverCompare).toHaveBeenCalled()
      })
  })

  test('should always call gtSemverCompare for android newsreader users', () => {
    deviceType.newsreaderAppPlatform = 'android'
    deviceType.newsreaderAppVersion = '9.46'

    return request(app)
      .get('/page?query=abc')
      .then((res) => {
        expect(gtSemverCompare).toHaveBeenCalled()
      })
  })

  test('should not call gtSemverCompare for ios xwd users', () => {
    deviceType.gamesAppPlatform = 'ios'
    deviceType.gamesAppVersion = '9.40.0'

    return request(app)
      .get('/page?query=abc')
      .then((res) => {
        expect(gtSemverCompare).not.toHaveBeenCalled()
      })
  })

  test('should not call gtSemverCompare for android xwd users', () => {
    deviceType.gamesAppPlatform = 'android'
    deviceType.gamesAppVersion = '9.46'

    return request(app)
      .get('/page?query=abc')
      .then((res) => {
        expect(gtSemverCompare).not.toHaveBeenCalled()
      })
  })

  test('should not call gtSemberCompare for web users', () => {
    deviceType = {
      isMobile: false,
      isPhone: false,
      isTablet: false,
    }

    return request(app)
      .get('/page?query=abc')
      .then((res) => {
        expect(gtSemverCompare).not.toHaveBeenCalled()
      })
  })
})
