/**
 * This handles redirecting to 404 for bad dates
 */
const moment = require('moment')

const { PUZZLE_DATES } = require('../../constants')

const VALID_MONTH_YEAR = /\d{2}-\d{4}/
const VALID_YEAR = /\d{4}/

module.exports = ({ type, year, month }) => {
  /** allow implied type * */
  if (!type) return false

  /** rule out bad types */
  if (
    !PUZZLE_DATES[type] ||
    !moment.isMoment(PUZZLE_DATES[type].earliestDate)
  ) {
    return true
  }

  /** allow implied date * */
  if (!year && !month) return false

  /** rule out non date numbers */
  const useMonth = typeof month !== 'undefined'
  const dateString = useMonth ? `${month}-${year}` : year
  const regex = useMonth ? VALID_MONTH_YEAR : VALID_YEAR
  if (!regex.exec(dateString)) return true

  /** reject months if type only supports years */
  if (useMonth && !PUZZLE_DATES[type].hasMonths) return true

  /** rule out high month numbers */
  if (useMonth && parseInt(month, 10) > 12) return true

  /** reject out of range */
  const date = moment(dateString, useMonth ? 'MM-YYYY' : 'YYYY')
  const upper = moment()
  const lower = PUZZLE_DATES[type].earliestDate
  if (date.isAfter(upper) || date.isBefore(lower)) return true

  /** everything else should be fine */
  return false
}
