const path = require('path')
const fs = require('fs')

const deepmerge = require('deepmerge')

const {
  APPLICATION_HOST_CLIENT,
  ROUTE_ASSETS,
  PUBLIC_ROOT,
  PACKAGE_VERSION,
} = require('../../constants')

const createMetadataDefaults = (metadata) => {
  const { manifestId = 'nyt', trackingPageType = 'crosswords' } =
    metadata
  const createPrefixed = (file) => `${manifestId}-${file}`
  const createLinkUrl = (file) =>
    `${APPLICATION_HOST_CLIENT}${ROUTE_ASSETS}/metadata/${createPrefixed(
      file,
    )}?v=${PACKAGE_VERSION}`

  let manifest
  const manpath = path.resolve(
    PUBLIC_ROOT,
    'metadata',
    createPrefixed('web-manifest.json'),
  )

  try {
    manifest = require(path.resolve(
      PUBLIC_ROOT,
      'metadata',
      createPrefixed('web-manifest.json'),
    ))
  } catch (e) {
    try {
      manifest = JSON.parse(fs.readFileSync(manpath, 'utf8'))
    } catch (e) {
      throw new Error(`cannot parse or unknown manifest @ ${manpath}`)
    }
  }

  return {
    title: manifest.name || 'Puzzles',
    contentGroup: 'Crosswords/Games',
    pageType: trackingPageType,
    metaTags: [
      {
        name: 'apple-mobile-web-app-title',
        content: manifest.short_name,
      },
      {
        name: 'application-name',
        content: manifest.name,
      },
      {
        name: 'msapplication-TileColor',
        content: manifest.background_color,
      },
      {
        name: 'theme-color',
        content: manifest.theme_color,
      },
    ],
    linkTags: [
      {
        rel: 'manifest',
        href: createLinkUrl('web-manifest.json'),
      },
      {
        rel: 'apple-touch-icon',
        sizes: '180x180',
        href: createLinkUrl('apple-touch-icon.png'),
      },
      {
        rel: 'mask-icon',
        color: manifest.theme_color,
        href: createLinkUrl('safari-pinned-tab.svg'),
      },
      {
        rel: 'shortcut icon',
        href: createLinkUrl('favicon.ico'),
      },
    ],
  }
}

const createMetadata = (...metadata) => {
  const mergedMetadata = deepmerge.all(metadata)
  return deepmerge(
    createMetadataDefaults(mergedMetadata),
    mergedMetadata,
  )
}

module.exports = createMetadata
