const adManagerCode = require('@nyt/ad-slot/lib/core/manager.str')()
// eslint-disable-next-line
const adScriptsCode =
  require('@nyt/ad-slot/lib/core/scriptsMixin.str')()
const abraScriptCode = require('@nyt/abra-js/browser-global-src')

const getAbraConfig = require('../services/getAbraConfig')
const getSponsorship = require('../services/getSponsorship')
const getLeaderboardsPromo = require('../services/getLeaderboardsPromo')
const {
  UNIVERSAL_ENVIRONMENT,
  SENTRY_DSN,
  SENTRY_SAMPLE_RATE,
  COMMIT_HASH,
} = require('../../constants')

const {
  PURR_DIRECTIVE_FORMAT,
} = require('./parsePurrDirectiveHeader')
const { isPlayTab } = require('./newsreader')
const createMetadata = require('./createMetadata')
const createAssets = require('./createAssets')
const createNavigationLinks = require('./createNavigationLinks')

const adCode = adManagerCode + adScriptsCode

/**
 * For Games that are not cached in Fastly, determine here whether or not to enable
 * them to use Hybrid Webviews.
 *
 * For Games, cached in Fastly, see responsive/hybrid.js
 */
const isHybridEnabledEntry = (entry) => {
  const HYBRID_ENABLED = ['spelling-bee']
  return HYBRID_ENABLED.includes(entry)
}

const getDeviceType = (req, res) => res.locals.deviceType
const getUserType = (req, res) => res.locals.userType
const getFeatureFlags = (req, res) => res.locals.featureFlags
const getCompliance = (req, res) => res.locals.compliance
const getHybrid = (req, res, entry) =>
  /**
   * DEPRECATED
   * The use of nyt-games-hybrid is being phased out in favor of a more universal header
   * across the NYT. Please use x-nyt-app-webview header going forward.
   */
  req.headers['nyt-games-hybrid'] === 'true' ||
  /**
   * DEPRECATED
   * The use of ?hybrid=news is being phased out in favor of a universal header
   * across the NYT. We intend to keep this for local development only. Do not instruct
   * teams to send this parameter to Phoenix.
   */
  req.query.hybrid ||
  /**
   * All teams must use this header to instruct Phoenix to render Hybrid html output
   * See: https://github.com/nytimes/fastly-www/blob/main/vcl/webview-identifier.vcl
   *
   * Older versions of the newsreader app, for certain entry points, load Spelling Bee
   * without proper native bridge support. Out of an abundance of caution, we detect hybrid
   * in this way only in the iOS Games App.
   */
  (req.headers['x-nyt-app-webview'] === '1' &&
    getDeviceType(req, res).gamesAppPlatform === 'ios' &&
    isHybridEnabledEntry(entry))

const getPlayTab = (req) =>
  isPlayTab(req.query, req.headers['user-agent'])

const getGeo = (req) => req.cookies['nyt-geo']

/**
 * Create an object of page props and prop getters used in a route's renderer.
 *
 * @param {Object} options    The initial set of page props and prop getters, provided by route config
 * @returns {Object} options  The modified set of page props and prop getters used to render views
 */
const createPageProps = (options) => {
  if (!options.entry) {
    throw new Error('page props must have entry')
  }

  options.sentrySampleRate = SENTRY_SAMPLE_RATE
  options.sentryDSN = SENTRY_DSN
  options.purrDirectiveFormat = PURR_DIRECTIVE_FORMAT
  options.commitHash = COMMIT_HASH
  options.env = UNIVERSAL_ENVIRONMENT
  options.userType = getUserType
  options.deviceType = getDeviceType
  options.featureFlags = getFeatureFlags
  options.sponsorship = getSponsorship
  options.navigationLinks = createNavigationLinks
  options.assets = createAssets(options.entry)
  options.url = (req) => req.originalUrl
  options.params = (req) => req.query
  options.abraCode = abraScriptCode
  options.abraConfig = getAbraConfig
  options.adManagerCode = adCode
  options.compliance = getCompliance
  options.userGeo = getGeo

  options.isHybridWebView = (req, res) =>
    getHybrid(req, res, options.entry)
  options.isPlayTab = getPlayTab
  options.duringLeaderboardsPromo = getLeaderboardsPromo

  const { metadata } = options
  options.metadata = (req, res) =>
    createMetadata(res.locals.metadata || {}, metadata || {})

  return options
}

module.exports = createPageProps
