const deepmerge = require('deepmerge')

function promiseMap(m) {
  /** store the list of keys */
  const keys = Object.keys(m)

  /** create a way to turn the results back into a map */
  const assembleMap = (values) => {
    const assembled = {}
    for (let i = 0; i < values.length; i += 1) {
      assembled[keys[i]] = values[i]
    }

    return assembled
  }

  /** converts the values to a list of promised values based on arguments */
  return (...args) => {
    const makeGetter = (k) =>
      typeof m[k] === 'function' ? m[k].apply(null, args) : m[k]

    return Promise.all(keys.map(makeGetter)).then(assembleMap)
  }
}

/** handles a series of promise maps, merging the results deeply */
const seriesPromiseMap = (series) => {
  const promiseMaps = series.map(promiseMap)
  return (...args) => {
    return promiseMaps.reduce((final, step) => {
      return Promise.resolve(final).then((f) =>
        step(...args, f).then((v) => deepmerge(f, v)),
      )
    }, {})
  }
}

module.exports = function createPropGetter(definition) {
  return Array.isArray(definition)
    ? seriesPromiseMap(definition)
    : promiseMap(definition)
}
