const getIOSCrosswordVersion = require('./getIOSCrosswordVersion')

/**
 * Get the Android Crossword version number from the user agent.
 *
 * Example UA: Crosswords/4.12.0 (Android; Android 8.1.0; Build 0/debug)
 *
 * @param {String} userAgent
 * @returns {String}
 */
function getAndroidCrosswordVersion(userAgent = '') {
  const androidRegex = /Crosswords\/([0-9]+\.[0-9]+(\.[0-9]+)?)/i
  const matches = userAgent.match(androidRegex) // matches will be ['Crosswords/4.12.0', '4.12.0']

  if (matches && matches.length >= 2) {
    return matches[1]
  }

  return ''
}

/**
 * Get the crossword version.
 *
 * @param {String} userAgent
 * @returns {String} The version
 */
const getCrosswordVersion = (userAgent) =>
  getIOSCrosswordVersion(userAgent) ||
  getAndroidCrosswordVersion(userAgent) ||
  ''

module.exports = getCrosswordVersion
