/**
 * Determine if the user agent indicates we're in the Android Crossword WebView.
 * Example UA: "Crosswords/4.12.0 (Android; Android 8.1.0; Build 0/debug)"
 *
 * @param {String} userAgent
 * @returns {Bool}
 */
function isAndroidCrosswordWebView(userAgent = '') {
  return userAgent.includes('Crosswords/')
}

/**
 * Determine if the user agent indicates we're in the iOS Crossword WebView.
 * Example UA: "Mozilla/5.0 (iPhone; CPU iPhone OS 15_5 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) nyt_xwords_ios/AppVersion(string: \"4.36\")"
 *
 * @param {String} userAgent
 * @returns {Bool}
 */
function isIOSCrosswordWebView(userAgent = '') {
  return userAgent.includes('nyt_xwords_ios/')
}

/**
 * Determine if we are in a Crossword WebView based on the user agent.
 *
 * @param {String} userAgent
 * @returns {String} The Crossword platform ios|android|''
 */
function getCrosswordWebView(userAgent = '', query = {}) {
  if (isIOSCrosswordWebView(userAgent) || query.hybrid === 'games') {
    return 'ios'
  }

  if (isAndroidCrosswordWebView(userAgent)) {
    return 'android'
  }

  return ''
}

module.exports = getCrosswordWebView
