/**
 * Get the iOS Crossword version number from the user agent.
 *
 * Example UA:
 * "Mozilla/5.0 (iPhone; CPU iPhone OS 15_5 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) nyt_xwords_ios/AppVersion(string: "4.37")" = $2"
 * "Mozilla/5.0 (iPhone; CPU iPhone OS 15_5 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) nyt_xwords_ios/AppVersion(string: "4.37.1")" = $2"
 * "Mozilla/5.0 (iPhone; CPU iPhone OS 15_5 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) nyt_xwords_ios/4.37 = $2"
 * "Mozilla/5.0 (iPhone; CPU iPhone OS 15_5 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) nyt_xwords_ios/4.37.1 = $2"
 *
 * @param {String} userAgent
 * @returns {String}
 */
function getIOSCrosswordVersion(userAgent = '') {
  const iOSRegex =
    /nyt[-_]?xwords[-_]?ios\/(?:AppVersion\(string: "|.{0})([0-9]+\.[0-9]+(\.[0-9]+)?).*/i
  const matches = userAgent.match(iOSRegex) // matches will be ['nyt_xwords_ios/AppVersion(string: "4.37")', '4.37'] or ['nyt_xwords_ios/4.37', '4.37']

  if (matches && matches.length >= 2) {
    return matches[1]
  }

  return ''
}

module.exports = getIOSCrosswordVersion
