import React from 'react'
import cn from 'classnames'

import { jsHook } from '../util'
import Icon from '../../../shared/components/Icon/Icon'

import { withServerData } from './withServerData'

/**
 * disable react/jsx-no-target-blank
 * to prevent obscure bug from returning with feedback emails
 */
/* eslint-disable react/jsx-no-target-blank */
export const CacheSafeFooter = withServerData(
  ({ env, navigationLinks, suppressFooterOnMobile }) => {
    const origin =
      env.name === 'prod'
        ? 'https://www.nytimes.com'
        : 'https://www.stg.nytimes.com'

    return (
      <footer
        className={cn('pz-footer pz-hide-loading', {
          'pz-hide-mobile': suppressFooterOnMobile,
        })}
      >
        <div className="pz-footer__wrapper">
          <section className="pz-footer__section pz-footer__about-us">
            {/* About New York Times Games */}
            <h4 className="pz-footer__section-header">
              About New York Times Games
            </h4>
            <p className="pz-footer__featured-text">
              Since the launch of The Crossword in 1942, The Times has
              captivated solvers by providing engaging word and logic
              games. In 2014, we introduced The Mini Crossword —
              followed by Spelling Bee, Letter Boxed, Tiles and
              Vertex. In early 2022, we proudly added Wordle to our
              collection. We strive to offer puzzles for all skill
              levels that everyone can enjoy playing every day.
            </p>
            <p className="pz-footer__featured-text pz-hide-sub">
              <a
                href={navigationLinks.subscribe.branding}
                data-track-label="subscribe-now-footer"
                className={jsHook('footer-tracking')}
              >
                Subscribe now
              </a>
              {` `}
              for unlimited access.
            </p>
          </section>

          <section className="pz-footer__section pz-footer__section-link-col">
            {/* New York Times Games */}
            <h4 className="pz-footer__section-header">
              New York Times Games
            </h4>
            <ul className="pz-footer__list">
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.daily}
                  data-track-label="daily-page-footer"
                  className={jsHook('footer-tracking')}
                >
                  <Icon icon="daily" />
                  The Crossword
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.mini}
                  data-track-label="mini-page-footer"
                  className={jsHook('footer-tracking')}
                >
                  <Icon icon="mini" />
                  The Mini Crossword
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.spellingBee}
                  data-track-label="spelling-bee-footer"
                  className={jsHook('footer-tracking')}
                >
                  <Icon icon="spelling-bee" />
                  Spelling Bee
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.wordle}
                  data-track-label="wordle-footer"
                  className={jsHook('footer-tracking')}
                >
                  <Icon icon="wordle" />
                  Wordle
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.connections}
                  data-track-label="connections-footer"
                  className={jsHook('footer-tracking')}
                >
                  <Icon icon="connections" />
                  Connections
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.tiles}
                  data-track-label="tiles-footer"
                  className={jsHook('footer-tracking')}
                >
                  <Icon icon="tiles" />
                  Tiles
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.letterBoxed}
                  data-track-label="letter-boxed-footer"
                  className={jsHook('footer-tracking')}
                >
                  <Icon icon="letter-boxed" />
                  Letter Boxed
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.vertex}
                  data-track-label="vertex-footer"
                  className={jsHook('footer-tracking')}
                >
                  <Icon icon="vertex" />
                  Vertex
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.sudoku}
                  data-track-label="sudoku-footer"
                  className={jsHook('footer-tracking')}
                >
                  <Icon icon="sudoku" />
                  Sudoku
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.hub}
                  data-track-label="all-games-footer"
                  className={jsHook('footer-tracking')}
                >
                  All Games
                </a>
              </li>
            </ul>
          </section>

          <section className="pz-footer__section pz-footer__section-link-col">
            {/* Crosswords */}
            <h4 className="pz-footer__section-header">Crosswords</h4>
            <ul className="pz-footer__list">
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.archive}
                  data-track-label="archive-footer"
                  className={jsHook('footer-tracking')}
                >
                  Crossword Archives
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.stats}
                  data-track-label="stats-footer"
                  className={jsHook('footer-tracking')}
                >
                  Statistics
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.leaderboards}
                  data-track-label="leaderboards-footer"
                  className={jsHook('footer-tracking')}
                >
                  Leaderboards
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.submission}
                  data-track-label="submit-crosswords-footer"
                  className={jsHook('footer-tracking')}
                >
                  Submit a Crossword
                </a>
              </li>
            </ul>

            {/* Community */}
            <h4 className="pz-footer__section-header">Community</h4>
            <ul className="pz-footer__list">
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.wordplay}
                  data-track-label="wordplay-footer"
                  className={jsHook('footer-tracking')}
                >
                  Gameplay Stories
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.sbForum}
                  data-track-label="sb-forum-footer"
                  className={jsHook('footer-tracking')}
                >
                  Spelling Bee Forum
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.twitter}
                  data-track-label="twitter-footer"
                  className={jsHook('footer-tracking')}
                >
                  Games Twitter
                </a>
              </li>
            </ul>
          </section>

          <section className="pz-footer__section pz-footer__section-link-col">
            {/* Learn More */}
            <h4 className="pz-footer__section-header">Learn More</h4>
            <ul className="pz-footer__list">
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.faq}
                  data-track-label="faq-footer"
                  className={jsHook('footer-tracking')}
                >
                  FAQs
                </a>
              </li>
              <li className="pz-footer__link pz-hide-ios">
                <a
                  href={navigationLinks.gift}
                  data-track-label="gift-subscription-footer"
                  className={jsHook('footer-tracking')}
                >
                  Gift Subscriptions
                </a>
              </li>
              <li className="pz-footer__link games-collection">
                <a
                  data-medium="footer"
                  data-source="nytimes-games"
                  href={`${navigationLinks.shop}?utm_campaign=games_collection&utm_content=footer&utm_medium=referral&utm_source=nyt_games`}
                  data-track-label="times-store-footer"
                  className={jsHook('footer-tracking')}
                >
                  Shop the Games Collection
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.apps}
                  data-track-label="download-app-footer"
                  className={jsHook('footer-tracking')}
                >
                  Download the App
                </a>
              </li>
              <li className="pz-footer__link">
                <a
                  href={navigationLinks.feedback}
                  id={jsHook('feedback-link')}
                  target="__blank"
                  rel="external"
                  data-track-label="contact-us-footer"
                  className={jsHook('footer-tracking')}
                >
                  Contact Us
                </a>
              </li>
            </ul>
          </section>

          {/* Legal */}
          <section className="pz-footer__section pz-footer__legal pz-footer__section-link-col">
            <ul className="pz-footer__legal-links">
              <li className="pz-footer__legal-link">
                <a
                  className="pz-footer__legal-co"
                  href={navigationLinks.company}
                >
                  © {new Date().getFullYear()} The New York Times
                  Company
                </a>
              </li>
              <li className="pz-footer__legal-link">
                <a href={navigationLinks.home}>NYTimes.com</a>
              </li>
              <li className="pz-footer__legal-link">
                <a href={navigationLinks.sitemap}>Sitemap</a>
              </li>
              <li className="pz-footer__legal-link">
                <a href={navigationLinks.privacy}>Privacy Policy</a>
              </li>
              <li className="pz-footer__legal-link">
                <a href={navigationLinks.termsOfService}>
                  Terms of Service
                </a>
              </li>

              {/**
               *  PURR Elements
               *  List items are rendered then hidden or shown by CSS based on PURR directives
               */}

              {/* CCPA Privacy Choices Link */}
              <li className="pz-footer__legal-link ccpa-opt-out">
                <a
                  className="ccpa-link"
                  href="https://www.nytimes.com/privacy/your-privacy-choices"
                  data-region="footer"
                  data-track="linkOptOut"
                >
                  <div className="ccpa-icon" />
                  Your Privacy Choices
                </a>
              </li>

              {/* CALIFORNIA NOTICES  */}
              <li className="pz-footer__legal-link ccpa-california-notice">
                <a
                  className="ccpa-link"
                  target="_blank"
                  rel="noopener noreferrer"
                  href="https://www.nytimes.com/privacy/privacy-policy#california-notice"
                  data-region="footer"
                  data-track="linkCANotice"
                >
                  California Notices
                </a>
              </li>

              {/* FIDES */}
              <li
                className="pz-footer__legal-link default-hidden"
                id={jsHook('privacy-preferences-link')}
              >
                <a
                  target="_blank"
                  rel="noopener noreferrer"
                  href={`${origin}/privacy/manage-settings`}
                >
                  Manage Privacy Preferences
                </a>
              </li>
            </ul>
          </section>
        </div>
      </footer>
    )
  },
)

export default CacheSafeFooter
