import React from 'react'
import cn from 'classnames'

import { withServerData } from './withServerData'
import CacheSafeHead from './CacheSafeHead'
import CacheSafeScripts from './CacheSafeScripts'
import CacheSafeNav from './CacheSafeNav'
import CacheSafeFooter from './CacheSafeFooter'
import CacheSafeUniversalTopBanner, {
  hasGamesSaleBanner,
  hasTopSaleBanner,
} from './Marketing/CacheSafeUniversalTopBanner'

export const CacheSafePage = withServerData((props) => {
  return (
    <html lang="en-US">
      <CacheSafeHead {...props} />
      <body
        className={cn('pz-page pz-loading', {
          'pz-use-intercept': props.includeScreenIntercept,
          'pz-sale-banner': hasTopSaleBanner(props.url),
        })}
      >
        <header
          className={cn('pz-header pz-hide-loading', {
            'pz-game-header':
              props.navProps && props.navProps.isGamePage,
            'pz-has-messaging': props.hasMessaging,
          })}
        >
          <CacheSafeUniversalTopBanner
            {...props}
            subscribeUrl={props.navigationLinks.subscribe.default}
          />
          <CacheSafeNav
            {...props.navProps}
            isTopSaleBanner={hasTopSaleBanner(props.url)}
            hasMessaging={props.hasMessaging}
            isGamesSale={hasGamesSaleBanner(props.url)}
          />
        </header>
        {props.includeScreenIntercept && (
          <div className="pz-intercept" />
        )}
        <div
          className={cn(
            'pz-content pz-hide-loading',
            props.contentClassName,
          )}
        >
          {props.children}
        </div>
        <CacheSafeFooter
          suppressFooterOnMobile={props.suppressFooterOnMobile}
        />
        <CacheSafeScripts />
      </body>
    </html>
  )
})

export default CacheSafePage
