/* eslint-disable react/no-danger */
import React from 'react'

import { withServerData } from './withServerData'
import { InlineVar } from './InlineVar'
import { HybridConfigContainer } from './HybridConfigContainer'

export const CacheSafeScripts = withServerData(
  ({
    env,
    assets,
    pageName,
    abraConfig,
    adUnitPath,
    featureFlags,
    sentryDSN,
    sentrySampleRate,
    commitHash,
    navigationLinks,
    purrDirectiveFormat,
    adManagerCode,
    abraCode,
  }) => (
    <>
      {/*
      Expose page name, used for things like tracking
    */}
      {pageName && <InlineVar name="pageName" value={pageName} />}
      {/*
      Expose runtime environment variables
    */}
      <InlineVar name="env" value={env} />
      {/*
      Expose abra configuration
    */}
      <InlineVar
        name="abra"
        value={{ config: abraConfig, tests: {} }}
      />
      {/*
      Expose runtime environment variables
    */}
      <InlineVar name="adUnitPath" value={adUnitPath} />
      {/*
      Expose navigation links variables
    */}
      <InlineVar name="navigationLinks" value={navigationLinks} />
      {/*
      Expose feature flags variables
    */}
      <InlineVar name="featureFlags" value={featureFlags} />
      {/*
      Expose Sentry DSN to the front end
    */}
      <InlineVar
        name="sentryConfig"
        value={{
          dsn: sentryDSN,
          release: commitHash,
          sampleRate: sentrySampleRate,
          environment: env.name,
        }}
      />
      {/*
      CCPA to the front end
     */}
      <InlineVar
        name="purrDirectiveFormat"
        value={purrDirectiveFormat}
      />
      {/*
      Inform responsive.js that this is a cache safe render
     */}
      {/* eslint-disable-next-line react/jsx-boolean-value */}
      <InlineVar name="isCacheSafe" value={true} />

      {/*
      Create nodes for responsive hook
    */}
      <div id="ratio-hook" />
      <div id="width-hook" />
      {/*
      Insert our javascripts (inlining where desired)
    */}
      {assets.scripts.map((script, i) => {
        if (script.src) {
          return (
            <script
              key={i}
              defer
              type="text/javascript"
              src={script.src}
            />
          )
        }

        if (script.inline) {
          return (
            <script
              key={i}
              id={script.id}
              defer
              type="text/javascript"
              dangerouslySetInnerHTML={{
                __html: script.inline,
              }}
            />
          )
        }
        throw new Error(`bad script config ${JSON.stringify(script)}`)
      })}
      {/*
      Insert inlined ad manager
    */}
      <script
        type="text/javascript"
        dangerouslySetInnerHTML={{
          __html: adManagerCode,
        }}
      />
      {/*
      Insert inlined abra code
    */}
      <script
        type="text/javascript"
        dangerouslySetInnerHTML={{
          __html: abraCode,
        }}
      />
      {/*
      Render the Android hybrid config script tag server side in case this is a hybrid webview.
      This is a no-op if we are in desktop or non hybrid environments as it's an empty script tag
    */}
      <HybridConfigContainer />
    </>
  ),
)

export default CacheSafeScripts
