import React from 'react'
import pt from 'prop-types'

import { InlineVar } from './InlineVar'

export const GameContainer = ({
  id,
  gameData,
  renderHeader,
  renderToolbar,
  renderBody,
}) => {
  return (
    <div className="pz-section" id={id}>
      {renderHeader ? (
        <div className="pz-row pz-game-title-bar xwd__hide-when-no-data">
          <div className="pz-module" id="portal-game-header">
            {renderHeader()}
          </div>
        </div>
      ) : (
        <div id="portal-client-side-header" />
      )}
      <div className="pz-game-wrapper" id="js-hook-game-wrapper">
        <div id="portal-game-moments">
          {/* game moments are injected here */}
        </div>
        <div id="portal-sb-modals">
          {/* spelling bee's modals are injected here */}
        </div>
        <div id="portal-sb-tooltip">
          {/* spelling bee's tooltip is injected here */}
        </div>
        <div id="portal-modal-system">
          {/* new modal system portals are injected new */}
        </div>
        <div id="portal-toast-system">
          {/* new toast system portals are injected new */}
        </div>
        <div className="pz-game-screen" id="js-hook-pz-moment__game">
          <div className="pz-game-toolbar xwd__hide-when-no-data">
            <div className="pz-row">
              <div
                className="pz-module pz-flex-row pz-game-toolbar-content"
                id="portal-game-toolbar"
              >
                {/* Toolbar items are injected here */}
                {renderToolbar && renderToolbar()}
              </div>
            </div>
          </div>
          <div id="portal-game-modals">
            {/* game modals are injected here */}
          </div>
          <div className="pz-game-field" id="pz-game-root">
            {renderBody && renderBody()}
            <noscript>This game requires javascript</noscript>
          </div>
          <InlineVar name="gameData" value={gameData} />
        </div>
        <div id="portal-editorial-content">
          {/* editorial content for crossword is injected here */}
        </div>
      </div>
    </div>
  )
}

GameContainer.propTypes = {
  id: pt.string,
  gameData: pt.oneOfType([pt.shape({}).isRequired, pt.string]),
  renderHeader: pt.func,
  renderToolbar: pt.func,
  renderBody: pt.func,
}

export default GameContainer
