import React from 'react'
import pt from 'prop-types'

import TopSaleBanner from './Sale/TopSaleBanner'
import { CacheSafeGameSalesBanner } from './Sale/GameSalesBanners'
import { isAASaleActive, isGamesSaleActive } from './Sale/functions'

export const hasTopSaleBanner = (url) => isAASaleActive(url)
export const hasGamesSaleBanner = (url) => isGamesSaleActive(url)

/**
 * Contains the logic for determining which banners to show at the top of cached pages
 * - AA Sale Banner
 * - Games Sale Banner
 */
const CacheSafeUniversalTopBanner = ({
  url,
  subscribeUrl,
  navigationLinks,
}) => {
  const canShowDeltaBanner =
    !hasTopSaleBanner(url) && !hasGamesSaleBanner(url)

  return (
    <>
      {canShowDeltaBanner && <div id="delta-banner-portal" />}
      {hasTopSaleBanner(url) && (
        <TopSaleBanner url={url} navLinks={navigationLinks} />
      )}
      {hasGamesSaleBanner(url) && (
        <CacheSafeGameSalesBanner
          url={url}
          subscribeUrl={subscribeUrl}
        />
      )}
    </>
  )
}

CacheSafeUniversalTopBanner.propTypes = {
  url: pt.string,
  subscribeUrl: pt.string,
  navigationLinks: pt.shape({
    login: pt.string,
  }),
}

export default CacheSafeUniversalTopBanner
