import React from 'react'
import { mount } from 'enzyme'

import CacheSafeUniversalTopBanner from './CacheSafeUniversalTopBanner'

describe('SERVER COMPONENTS: UNIVERSAL TOP BANNER', () => {
  window.navigationLinks = window.navigationLinks || {}
  window.navigationLinks.login = ''

  /**
   * When the next AA sale occurs, modify these date ranges to test it
   */
  const dateWithinAASale = '03/01/2023'
  const dateOutsideAASale = '04/10/2023'

  /**
   * When the next Games sale occurs, modify these date ranges to test it
   */
  const dateWithinGamesSale = '12/15/2023'
  const dateOutsideGamesSale = '12/31/2023'

  describe('All Access Sale: 02/27/2023 - 04/01/2023', () => {
    it('should render the all-access sale banner within the all-acces date range', () => {
      const url = `https://www.nytimes.com/crosswords?date-override=${dateWithinAASale}`
      const saleBanner = mount(
        <CacheSafeUniversalTopBanner url={url} />,
      )

      expect(saleBanner.find('#top-sale-banner')).toHaveLength(1)
    })

    it('should NOT render the all-access sale banner within the all-acces date range', () => {
      const url = `https://www.nytimes.com/crosswords?date-override=${dateOutsideAASale}`
      const saleBanner = mount(
        <CacheSafeUniversalTopBanner url={url} />,
      )

      expect(saleBanner.find('#top-sale-banner')).toHaveLength(0)
    })
  })

  describe('Games Sale: 12/14/2023 - 12/29/2023', () => {
    it('should render the all-access sale banner within the all-acces date range', () => {
      const url = `https://www.nytimes.com/crosswords?date-override=${dateWithinGamesSale}`
      const saleBanner = mount(
        <CacheSafeUniversalTopBanner url={url} />,
      )

      expect(saleBanner.find('.games-sale-banner')).toHaveLength(1)
    })

    it('should NOT render the all-access sale banner within the all-acces date range', () => {
      const url = `https://www.nytimes.com/crosswords?date-override=${dateOutsideGamesSale}`
      const saleBanner = mount(
        <CacheSafeUniversalTopBanner url={url} />,
      )

      expect(saleBanner.find('.games-sale-banner')).toHaveLength(0)
    })
  })
})
