import React from 'react'
import pt from 'prop-types'
import moment from 'moment'

import { MessagingBanner } from '../Messaging/MessagingBanner'
import OUR_GAMES from '../../../../../shared/hub/constants/ourGames'

const FreeGameBanner = ({
  isSubscriber,
  referrer,
  game,
  expiration,
}) => {
  const endPromo = expiration * 1000

  if (
    Date.now() > endPromo ||
    isSubscriber ||
    referrer !== '/crosswords'
  ) {
    return null
  }

  const gameData = OUR_GAMES.find((g) => g.id === game)
  const formattedDate = moment(endPromo).format('MMMM Do')

  return (
    <MessagingBanner
      containerClassNames={['position-top', 'centered']}
      bannerClassName={gameData.id}
      featuredLink={{
        text: gameData.name,
        link: gameData.url,
      }}
      bannerText={`is free to play until ${formattedDate}.`}
    />
  )
}

FreeGameBanner.propTypes = {
  isSubscriber: pt.bool.isRequired,
  referrer: pt.string.isRequired,
  game: pt.oneOf(OUR_GAMES.map((g) => g.id)),
  expiration: pt.number,
}

export default FreeGameBanner
