import React from 'react'
import pt from 'prop-types'

import ourGames from 'hub/constants/ourGames'

import FreeGameBannerComponent from './FreeGameBanner'

const FreeGameBannerTemplate = ({ expiration, ...args }) => {
  // need to convert expiration date to seconds
  return (
    <FreeGameBannerComponent
      expiration={expiration / 1000}
      {...args}
    />
  )
}

const numOfMillisecondsInDay = 86400 * 1000
export const FreeGameBanner = FreeGameBannerTemplate.bind({})
FreeGameBanner.args = {
  expiration: new Date().getTime() + numOfMillisecondsInDay,
  containerHeight: 600,
}

export default {
  title: 'Design System/Banners/Free Game Banner',
  component: FreeGameBanner,
  parameters: {
    docs: {
      prepareForInline: (storyFn) => (
        <div
          style={{
            transform: 'translateZ(0)',
            height: '10vh',
            overflow: 'auto',
          }}
        >
          {storyFn()}
        </div>
      ),
    },
  },
  args: {
    isSubscriber: false,
    referrer: '/crosswords',
    game: 'letter-boxed',
    expiration: 1656614376000,
  },
  argTypes: {
    game: {
      options: ourGames.map((g) => g.id),
      control: {
        type: 'select',
      },
    },
    expiration: {
      control: {
        type: 'date',
      },
    },
    referrer: {
      table: {
        disable: true,
      },
    },
  },
}

FreeGameBanner.propTypes = {
  expiration: pt.number,
}
