import React from 'react'
import { mount } from 'enzyme'

import FreeGameBanner from './FreeGameBanner'

describe('FreeGameBanner', () => {
  let args

  beforeEach(() => {
    args = {
      isSubscriber: true,
      link: '/puzzles/letter-boxed',
      referrer: '/crosswords',
      game: 'letter-boxed',
      expiration: 5696850802, // July 11th, 2150
    }
  })

  it('should not show banner if user is subscribed', () => {
    const banner = mount(<FreeGameBanner {...args} />)
    expect(banner.isEmptyRender()).toBe(true)
  })

  it('should show banner if user is not subscribed, the promo period is active, and the user is on the hub', () => {
    args.isSubscriber = false

    const banner = mount(<FreeGameBanner {...args} />)
    expect(banner.text()).toEqual(
      'Letter Boxed is free to play until July 11th.',
    )
    const link = banner
      .find('.messaging-banner__featured-link')
      .props().href
    expect(link).toBe('/puzzles/letter-boxed')
    const icon = banner.find('span.pz-icon')
    expect(icon.props().className).toContain('letter-boxed')
  })

  it('should not show banner if the promo period is not active', () => {
    args.expiration = 0
    const banner = mount(<FreeGameBanner {...args} />)
    expect(banner.isEmptyRender()).toBe(true)
  })

  it('should not show banner if user is not on the hub', () => {
    args.referrer = '/puzzles/tiles'
    const banner = mount(<FreeGameBanner {...args} />)
    expect(banner.isEmptyRender()).toBe(true)
  })
})
