import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

export const MessagingBanner = ({
  bannerHeadline,
  bannerText,
  bannerClassName,
  containerClassNames,
  callToAction,
  featuredLink,
  clickHandler,
}) => (
  <div className={cn('messaging-banner', containerClassNames)}>
    <div className="messaging-banner__left">
      <span className={`pz-icon pz-icon-${bannerClassName}`} />
    </div>
    <p className="messaging-banner__right">
      {bannerHeadline && (
        <span className="messaging-banner__headline">
          {bannerHeadline}
        </span>
      )}
      {featuredLink && (
        <span>
          <a
            onClick={clickHandler}
            className="messaging-banner__featured-link"
            href={featuredLink.link}
          >
            {featuredLink.text}
          </a>{' '}
        </span>
      )}
      <span className="messaging-banner__text">{bannerText}</span>
      {callToAction && (
        <span>
          {' '}
          <a
            onClick={clickHandler}
            className="messaging-banner__action"
            href={callToAction.link}
          >
            {callToAction.text}
          </a>
        </span>
      )}
    </p>
  </div>
)

MessagingBanner.propTypes = {
  bannerHeadline: pt.string,
  bannerText: pt.oneOfType([pt.string, pt.element]).isRequired,
  containerClassNames: pt.arrayOf(pt.string),
  bannerClassName: pt.string,
  callToAction: pt.shape({
    link: pt.string.isRequired,
    text: pt.string.isRequired,
  }),
  featuredLink: pt.shape({
    link: pt.string.isRequired,
    text: pt.string.isRequired,
  }),
  clickHandler: pt.func,
}
