import React from 'react'

import { MessagingBanner } from './MessagingBanner'

export default {
  component: MessagingBanner,
  title: 'Design System/Banners/MessagingBanner',
  parameters: {
    docs: {
      prepareForInline: (storyFn) => (
        <div
          style={{
            transform: 'translateZ(0)',
            height: '10vh',
            overflow: 'auto',
          }}
        >
          {storyFn()}
        </div>
      ),
    },
  },
  args: {
    bannerText: 'Play up to 8 times with a free account.',
  },
  argTypes: {
    bannerClassName: {
      control: {
        type: 'select',
        options: [
          'tiles',
          'letter-boxed',
          'vertex',
          'spelling-bee',
          'daily',
          'mini',
          'sudoku',
        ],
      },
    },
    containerClassNames: {
      control: {
        type: 'multi-select',
        options: [
          'slide-down',
          'mobile-column',
          'headline',
          'centered',
          'position-top',
        ],
      },
    },
  },
}

const Template = (args) => <MessagingBanner {...args} />

export const Main = Template.bind({})

export const WithCTA = Template.bind({})

WithCTA.args = {
  callToAction: { link: '', text: 'Register now.' },
  bannerClassName: 'tiles',
  containerClassNames: ['mobile-column'],
}

WithCTA.argTypes = {
  bannerHeadline: {
    controls: false,
  },
}

export const WithHeadline = Template.bind({})

WithHeadline.args = {
  bannerHeadline: 'STARTING JULY 1',
  bannerText:
    "We're no longer supporting KenKen®. You can still play in our print edition or at",
  callToAction: {
    text: 'kenkenpuzzle.com.',
    link: 'https://www.kenkenpuzzle.com/nydaily',
  },
  containerClassNames: ['headline'],
  bannerClassName: 'alert',
}
