import React from 'react'
import { shallow } from 'enzyme'

import { MessagingBanner } from './MessagingBanner'

describe('SERVER COMPONENTS: MESSAGING BANNER', () => {
  it('should render the respective component with passed values', () => {
    const bannerConfig = {
      bannerText: 'Read this!',
      bannerClassName: 'letter-boxed',
    }

    const messagingBanner = shallow(
      <MessagingBanner {...bannerConfig} />,
    )
    expect(messagingBanner.find('.messaging-banner').exists()).toBe(
      true,
    )
    expect(
      messagingBanner
        .find('.messaging-banner__text')
        .text()
        .includes(bannerConfig.bannerText),
    ).toBe(true)
    expect(
      messagingBanner.find('.pz-icon-letter-boxed').exists(),
    ).toBe(true)
    expect(
      messagingBanner.find('.messaging-banner__action').exists(),
    ).toBe(false)
    expect(
      messagingBanner.find('.messaging-banner__headline').exists(),
    ).toBe(false)
  })

  it('should render call to action when one is passed in', () => {
    const bannerConfig = {
      bannerText: 'Read this!',
      bannerClassName: 'letter-boxed',
      callToAction: {
        link: 'tonowhere',
        text: 'Click here!',
      },
    }

    const messagingBanner = shallow(
      <MessagingBanner {...bannerConfig} />,
    )
    const cta = messagingBanner.find('.messaging-banner__action')
    expect(cta.exists()).toBe(true)
    expect(cta.prop('href')).toBe(bannerConfig.callToAction.link)
    expect(cta.text()).toBe(bannerConfig.callToAction.text)
  })

  it('should render headline layout when headline is passed in', () => {
    const bannerConfig = {
      bannerHeadline: 'Look here',
      bannerText: 'Things are changing',
      bannerClassName: 'headline',
      callToAction: {
        link: 'tonowhere',
        text: 'Click here!',
      },
    }

    const messagingBanner = shallow(
      <MessagingBanner {...bannerConfig} />,
    )

    const headline = messagingBanner.find(
      '.messaging-banner__headline',
    )
    const logo = messagingBanner.find('.messaging-banner__logo')
    const leftColumn = messagingBanner.find('.messaging-banner__left')
    const rightColumn = messagingBanner.find(
      '.messaging-banner__right',
    )
    const cta = messagingBanner.find('.messaging-banner__action')

    expect(headline.exists()).toBe(true)
    expect(logo.exists()).toBe(false)
    expect(leftColumn.exists()).toBe(true)
    expect(rightColumn.exists()).toBe(true)
    expect(cta.prop('href')).toBe(bannerConfig.callToAction.link)
    expect(cta.text()).toBe(bannerConfig.callToAction.text)
  })
})
