import React from 'react'
import cn from 'classnames'
import pt from 'prop-types'

import { getGamesSaleBannerUrgency, isSub } from './functions'

const upgradeCopy = 'Save on all of The Times, including Games.'
const acquisitionCopy = '50% off your first year of Games.'
const shortAcquisitionCopy = '50% off your first year.'

const whiteCaret =
  'https://www.nytimes.com/vi-assets/static-assets/images/MessageComponentLibrary/Chevron-Right-White.svg'

const blackCaret =
  'https://www.nytimes.com/vi-assets/static-assets/images/MessageComponentLibrary/Chevron-Right-Black.svg'

export const GameSalesBanner = (props) => {
  const { url, userType, subscribeUrl } = props

  const bannerConfig = getGamesSaleBannerUrgency(url)

  return (
    <>
      <a
        href={subscribeUrl}
        rel="noreferrer"
        className="pz-hide-loading pz-hide-ada pz-hide-games-app pz-hide-sub"
        id="games-sale-banner-a"
      >
        <div
          className={cn(
            `top-sale-banner games-sale-banner ${bannerConfig.bannerColor}`,
          )}
        >
          <div className={cn('top-sale-banner__copy ')}>
            <span
              className={cn('top-sale-banner__urgency hide-on-xs')}
              dangerouslySetInnerHTML={{
                __html: `${bannerConfig.urgencyMessage}: `,
              }}
            />
            <span
              className={cn('top-sale-banner__urgency show-on-xs')}
              dangerouslySetInnerHTML={{
                __html: `${bannerConfig.shortUrgencyMessage}: `,
              }}
            />
            <span className={cn('hide-on-xs')}>
              {acquisitionCopy}
              {/* Dec '23 Games sale renders acquisition copy. Clean-up task to reinstate upgrade messaging: https://jira.nyt.net/browse/MWD-837 */}
              {/* {isSub(userType.entitlement)
                ? upgradeCopy
                : acquisitionCopy} */}
            </span>
            <span className={cn('show-on-xs')}>
              {shortAcquisitionCopy}
              {/* Dec '23 Games sale renders acquisition copy. Clean-up task to reinstate upgrade messaging: https://jira.nyt.net/browse/MWD-837 */}
              {/* {isSub(userType.entitlement)
                ? upgradeCopy
                : acquisitionCopy} */}
            </span>
          </div>

          <div className="top-sale-banner__iconwrapper">
            {bannerConfig.bannerColor === 'black' ? (
              <img
                className="top-sale-banner__icon"
                src={whiteCaret}
                alt="open banner"
              />
            ) : (
              <img
                className="top-sale-banner__icon"
                src={blackCaret}
                alt="open banner"
              />
            )}
          </div>
        </div>
      </a>
    </>
  )
}

GameSalesBanner.propTypes = {
  userType: pt.object,
  url: pt.string,
  subscribeUrl: pt.string,
}

export const CacheSafeGameSalesBanner = (props) => {
  const { url, subscribeUrl } = props

  const bannerConfig = getGamesSaleBannerUrgency(url)

  return (
    <>
      <a
        href={subscribeUrl}
        rel="noreferrer"
        className="pz-hide-loading pz-hide-ada pz-hide-sub"
        id="cache-safe-games-sale-banner-a"
      >
        <div
          className={cn(
            `top-sale-banner games-sale-banner ${bannerConfig.bannerColor}`,
          )}
        >
          <div className={cn('top-sale-banner__copy ')}>
            <span
              className={cn('top-sale-banner__urgency hide-on-xs')}
              dangerouslySetInnerHTML={{
                __html: `${bannerConfig.urgencyMessage}: `,
              }}
            />
            <span
              className={cn('top-sale-banner__urgency show-on-xs')}
              dangerouslySetInnerHTML={{
                __html: `${bannerConfig.shortUrgencyMessage}: `,
              }}
            />
            {/* Clean-up task to reinstate upgrade messaging: https://jira.nyt.net/browse/MWD-837 */}
            {/* Show for all users seeing banner, as Dec '23 sale isn't goaled for upgrades. */}
            <span className="pz-hide-loading hide-on-xs">
              {acquisitionCopy}
            </span>
            <span className="pz-hide-loading show-on-xs">
              {shortAcquisitionCopy}
            </span>
            {/* Hide for all users seeing banner, as Dec '23 sale only renders acquisition messaging. */}
            <span className="pz-hide-loading pz-hide-regi pz-hide-anon pz-hide-sub pz-hide-digi">
              {upgradeCopy}
            </span>
          </div>
          <div className="top-sale-banner__iconwrapper">
            {bannerConfig.bannerColor === 'black' ? (
              <img
                className="top-sale-banner__icon"
                src={whiteCaret}
                alt="open banner"
              />
            ) : (
              <img
                className="top-sale-banner__icon"
                src={blackCaret}
                alt="open banner"
              />
            )}
          </div>
        </div>
      </a>
    </>
  )
}

CacheSafeGameSalesBanner.propTypes = {
  url: pt.string,
  subscribeUrl: pt.string,
}
