import React from 'react'
import cn from 'classnames'
import pt from 'prop-types'

import { appendSupportedParams } from 'views/util'

import { getAASaleUrgencyMessage } from './functions'

const TopSaleBanner = ({ url, isDelta, navLinks }) => {
  // even though this component is defined on the server, it is used
  // on both server and client. For navigation links, the server
  // will provide them via props, and the client will make them
  // accessible on the window
  const links =
    typeof window === 'undefined' ? navLinks : window.navigationLinks

  const loginUrl = appendSupportedParams(
    links.login,
    '&asset=delta-mini-banner',
  )

  const bannerLink = isDelta
    ? loginUrl
    : 'https://www.nytimes.com/subscription/games?campaignId=89RW9'

  const bannerText = isDelta
    ? 'Track your stats and streaks.'
    : 'Save on all of The Times, including Games.'

  return (
    <a
      id="top-sale-banner"
      href={bannerLink}
      rel="noreferrer"
      className="pz-hide-loading pz-hide-newsreader pz-hide-games-app pz-hide-ada"
    >
      <div className={cn('top-sale-banner')}>
        <div className={cn('top-sale-banner__copy')}>
          <span className={cn('top-sale-banner__urgency')}>
            {isDelta
              ? 'Create an account or log in.'
              : getAASaleUrgencyMessage(url)}
          </span>
          <span className="top-sale-banner__text">{bannerText}</span>
        </div>
        <img
          className="top-sale-banner__icon"
          src="https://mwcm.nyt.com/dam/LP/games/banner/chevron-right.svg"
          alt="open banner"
        />
      </div>
    </a>
  )
}

TopSaleBanner.propTypes = {
  url: pt.string,
  isDelta: pt.bool,
  navLinks: pt.shape({
    login: pt.string,
  }),
}

export default TopSaleBanner
