import {
  getDateOverride,
  getAASaleUrgencyMessage,
  isAASaleActive,
  isGamesSaleActive,
  getGamesSaleBannerUrgency,
  getButtonText,
} from './functions'

describe('Marketing: Sale Functions', () => {
  it('should be able to parse the date-override parameter', () => {
    const location = {
      search: () => 0,
      substring: () => 'date-override=05/03/2023',
    }

    expect(getDateOverride(location)).toBe('05/03/2023')
  })

  /**
   * When the next AA sale occurs, modify the date ranges to test it
   */
  describe('All Access Sale: 02/27/2023 - 04/01/2023', () => {
    it('should detect when the sale is active', () => {
      const activeDate = '02/28/2023'

      const location = {
        search: () => 0,
        substring: () => `date-override=${activeDate}`,
      }

      expect(isAASaleActive(location)).toBe(true)
    })

    it('should detect when the sale is inactive', () => {
      const inactiveDate = '05/01/2023'

      const location = {
        search: () => 0,
        substring: () => `date-override=${inactiveDate}`,
      }

      expect(isAASaleActive(location)).toBe(false)
    })

    it('should change urgency messaging based on date', () => {
      const firstDate = '02/28/2023'
      const secondDate = '03/14/2023'

      const location = {
        search: () => 0,
        substring: () => `date-override=${firstDate}`,
      }

      const firstDateMessaging = getAASaleUrgencyMessage(location)
      expect(firstDateMessaging).toBe('The All Access Sale.')

      location.substring = () => `date-override=${secondDate}`
      const secondDateMessaging = getAASaleUrgencyMessage(location)
      expect(secondDateMessaging).toBe(
        'The All Access Sale Ends Soon.',
      )
    })
  })

  /**
   * When the next Games sale occurs, modify the date ranges to test it
   */
  describe('Games Sale: 12/14/2023 - 12/29/2023', () => {
    it('should detect when the sale is active', () => {
      const activeDate = '12/15/2023'

      const location = {
        search: () => 0,
        substring: () => `date-override=${activeDate}`,
      }

      expect(isGamesSaleActive(location)).toBe(true)
    })

    it('should detect when the sale is inactive', () => {
      const inactiveDate = '12/31/2023'

      const location = {
        search: () => 0,
        substring: () => `date-override=${inactiveDate}`,
      }

      expect(isGamesSaleActive(location)).toBe(false)
    })

    it('should change urgency messaging based on date', () => {
      const firstDate = '12/15/2023'
      const secondDate = '12/23/2023'

      const location = {
        search: () => 0,
        substring: () => `date-override=${firstDate}`,
      }

      const { urgencyMessage: firstDateMessaging } =
        getGamesSaleBannerUrgency(location)
      expect(firstDateMessaging).toBe('Limited Time Offer')

      location.substring = () => `date-override=${secondDate}`
      const { urgencyMessage: secondDateMessaging } =
        getGamesSaleBannerUrgency(location)
      expect(secondDateMessaging).toBe('Ends Soon')
    })

    it('shows different messaging for subs and regis', () => {
      expect(getButtonText()).toBe('Subscribe for 50% off')
      expect(getButtonText('sub')).toBe('Upgrade and save')
    })
  })
})
