import React from 'react'
import { mount } from 'enzyme'

import UniversalTopBanner from './UniversalTopBanner'

describe('SERVER COMPONENTS: UNIVERSAL TOP BANNER', () => {
  window.navigationLinks = window.navigationLinks || {}
  window.navigationLinks.login = ''

  /**
   * When the next AA sale occurs, modify these date ranges to test it
   */
  const dateWithinAASale = '03/01/2023'
  const dateOutsideAASale = '04/10/2023'

  /**
   * When the next Games sale occurs, modify these date ranges to test it
   */
  const dateWithinGamesSale = '12/15/2023'
  const dateOutsideGamesSale = '12/31/2023'

  const props = {
    url: '',
    hubPuzzles: {},
    deviceType: {
      gamesAppPlatform: '',
      newsreaderAppPlatform: '',
    },
    userType: {},
    messaging: {
      bannerText: 'Read this!',
      bannerClassName: 'letter-boxed',
    },
  }

  const digiUserType = {
    isLoggedIn: true,
    hasDigi: true,
    hasXwd: false,
  }

  const anonUserType = {
    isLoggedIn: false,
    hasDigi: false,
    hasXwd: false,
  }

  const regiUserType = {
    isLoggedIn: true,
    hasDigi: false,
    hasXwd: false,
  }

  const desktop = {
    gamesAppPlatform: '',
    newsreaderAppPlatform: '',
  }

  const apps = {
    gamesAppPlatform: 'ios',
    newsreaderAppPlatform: 'ios',
  }

  describe('All Access Sale: 02/27/2023 - 04/01/2023', () => {
    it('should render the all-access sale banner for anons within the all-acces date range on desktop', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinAASale}`
      props.userType = { ...anonUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#top-sale-banner')).toHaveLength(1)
    })

    it('should render the all-access sale banner for regis within the all-acces date range on desktop', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinAASale}`
      props.userType = { ...regiUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#top-sale-banner')).toHaveLength(1)
    })

    it('should render the all-access sale banner for subs within the all-acces date range on desktop', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinAASale}`
      props.userType = { ...digiUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#top-sale-banner')).toHaveLength(1)
    })

    it('should NOT render the all-access sale banner for anons within the all-acces date range on apps', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinAASale}`
      props.userType = { ...anonUserType }
      props.deviceType = { ...apps }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#top-sale-banner')).toHaveLength(0)
    })

    it('should NOT render the all-access sale banner for regis within the all-acces date range on apps', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinAASale}`
      props.userType = { ...regiUserType }
      props.deviceType = { ...apps }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#top-sale-banner')).toHaveLength(0)
    })

    it('should NOT render the all-access sale banner for subs within the all-acces date range on apps', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinAASale}`
      props.userType = { ...digiUserType }
      props.deviceType = { ...apps }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#top-sale-banner')).toHaveLength(0)
    })

    it('should NOT render the all-access sale banner for anons outside of the all-acces date range', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateOutsideAASale}`
      props.userType = { ...anonUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#top-sale-banner')).toHaveLength(0)
    })

    it('should NOT render the all-access sale banner for regis outside of the all-acces date range', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateOutsideAASale}`
      props.userType = { ...regiUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#top-sale-banner')).toHaveLength(0)
    })

    it('should NOT render the all-access sale banner for subs outside of the all-acces date range', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateOutsideAASale}`
      props.userType = { ...digiUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#top-sale-banner')).toHaveLength(0)
    })
  })

  describe('Games Sale: 12/14/2023 - 12/29/2023', () => {
    it('should render the games sale banner for anons within the games sale date range on desktop', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinGamesSale}`
      props.userType = { ...anonUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('.games-sale-banner')).toHaveLength(1)
    })

    it('should render the games sale banner for regis within the games sale date range on desktop', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinGamesSale}`
      props.userType = { ...regiUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('.games-sale-banner')).toHaveLength(1)
    })

    it('should render the games sale banner for subs within the games sale date range on desktop', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinGamesSale}`
      props.userType = { ...digiUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('.games-sale-banner')).toHaveLength(1)
    })

    it('should render the games sale banner for anons within the games sale date range on apps with hidden css classes', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinGamesSale}`
      props.userType = { ...anonUserType }
      props.deviceType = { ...apps }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(
        saleBanner.find('.pz-hide-ada.pz-hide-games-app'),
      ).toHaveLength(1)
    })

    it('should render the games sale banner for regis within the games sale date range on apps with hidden css classes', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinGamesSale}`
      props.userType = { ...regiUserType }
      props.deviceType = { ...apps }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(
        saleBanner.find('.pz-hide-ada.pz-hide-games-app'),
      ).toHaveLength(1)
    })

    it('should render the games sale banner for subs within the games sale date range on apps with hidden css classes', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinGamesSale}`
      props.userType = { ...digiUserType }
      props.deviceType = { ...apps }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(
        saleBanner.find('.pz-hide-ada.pz-hide-games-app'),
      ).toHaveLength(1)
    })

    it('shout not render the games sale banner for anons outside of the games sale date range and expect to be hidden', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateOutsideGamesSale}`
      props.userType = { ...anonUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('.games-sale-banner')).toHaveLength(0)
    })

    it('should not render the games sale banner for regis outside of the games sale date range and expect to be hidden', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateOutsideGamesSale}`
      props.userType = { ...regiUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('.games-sale-banner')).toHaveLength(0)
    })

    it('should not render the games sale banner for subs outside of the games sale date range and expect to be hidden', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateOutsideGamesSale}`
      props.userType = { ...digiUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('.games-sale-banner')).toHaveLength(0)
    })
  })

  describe('Delta Banner Messaging', () => {
    it('should NOT render the Delta banner for anons when the games sale is active', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinGamesSale}`
      props.userType = { ...anonUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#delta-banner-portal')).toHaveLength(0)
    })
    it('should NOT render the Delta banner for regis when the games sale is active', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinGamesSale}`
      props.userType = { ...regiUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#delta-banner-portal')).toHaveLength(0)
    })
    it('should NOT render the Delta banner for subs when the games sale is active', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinGamesSale}`
      props.userType = { ...digiUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#delta-banner-portal')).toHaveLength(0)
    })
    it('should NOT render the Delta banner for anons when the AA sale is active', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinAASale}`
      props.userType = { ...anonUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#delta-banner-portal')).toHaveLength(0)
    })
    it('should NOT render the Delta banner for regis when the AA sale is active', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinAASale}`
      props.userType = { ...regiUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#delta-banner-portal')).toHaveLength(0)
    })
    it('should NOT render the Delta banner for subs when the AA sale is active', () => {
      props.url = `https://www.nytimes.com/crosswords?date-override=${dateWithinAASale}`
      props.userType = { ...digiUserType }
      props.deviceType = { ...desktop }
      const saleBanner = mount(<UniversalTopBanner {...props} />)

      expect(saleBanner.find('#delta-banner-portal')).toHaveLength(0)
    })
  })
})
