import React from 'react'
import cn from 'classnames'

import { withServerData } from './withServerData'
import { Head } from './Head'
import { Scripts } from './Scripts'
import { Nav } from './Nav'
import { Footer } from './Footer'
import UniversalTopBanner, {
  getSaleBodyClasses,
  determineTopSaleBanner,
} from './Marketing/UniversalTopBanner'

export const Page = withServerData((props) => {
  let lang
  if (typeof window !== 'undefined') {
    lang = window.navigator.language
  } else {
    lang = 'en-US'
  }

  const saleBodyClasses = getSaleBodyClasses(props)

  return (
    <html lang={lang}>
      <Head {...props} />
      <body
        // NOTE: Some of these classes are re-written client-side
        // to make them cache-safe. See responsive/index.ts
        className={cn('pz-page', {
          'pz-mobile': props.deviceType.isMobile,
          'pz-desktop': !props.deviceType.isMobile,
          'pz-use-intercept': props.includeScreenIntercept,
          'pz-hybrid': props.isHybridWebView,
          'pz-games-app': props.deviceType.gamesAppPlatform,
          'pz-newsreader': !!props.deviceType.newsreaderAppPlatform,
          'pz-play-tab': !!props.isPlayTab,
          'pz-ios': props.deviceType.newsreaderAppPlatform === 'ios',
          ...saleBodyClasses,
        })}
      >
        <header
          className={cn('pz-header', {
            'pz-game-header':
              props.navProps && props.navProps.isGamePage,
            'pz-has-messaging': props.hasMessaging,
          })}
        >
          <UniversalTopBanner
            {...props}
            subscribeUrl={props.navigationLinks.subscribe.default}
          />
          <Nav
            {...props.navProps}
            hasMessaging={props.hasMessaging}
            isTopSaleBanner={determineTopSaleBanner(props)}
          />
        </header>
        {props.includeScreenIntercept && (
          <div className="pz-intercept" />
        )}
        <div className={cn('pz-content', props.contentClassName)}>
          {props.children}
        </div>
        {(props.deviceType.isMobile &&
          props.suppressFooterOnMobile) || <Footer />}
        <Scripts />
      </body>
    </html>
  )
})

export default Page
