import React from 'react'

import { withServerData } from './withServerData'
import { InlineVar } from './InlineVar'
import { HybridConfigContainer } from './HybridConfigContainer'

export const Scripts = withServerData((props) => (
  <>
    {/*
      Expose page name, used for things like tracking
    */}
    {props.pageName && (
      <InlineVar name="pageName" value={props.pageName} />
    )}
    {/*
      Expose cachable user type for use in JS
    */}
    <InlineVar name="userType" value={props.userType} />
    {/*
      Expose runtime environment variables
    */}
    <InlineVar name="env" value={props.env} />
    {/*
      Expose abra configuration
    */}
    <InlineVar
      name="abra"
      value={{ config: props.abraConfig, tests: {} }}
    />
    {/*
      Expose runtime environment variables
    */}
    <InlineVar name="adUnitPath" value={props.adUnitPath} />
    {/*
      Expose navigation links variables
    */}
    <InlineVar name="navigationLinks" value={props.navigationLinks} />
    {/*
      Expose feature flags variables
    */}
    <InlineVar name="featureFlags" value={props.featureFlags} />
    {/*
      Expose Play Tab boolean
    */}
    <InlineVar name="isPlayTab" value={props.isPlayTab} />
    {/*
      Expose Sentry DSN to the front end
    */}
    <InlineVar
      name="sentryConfig"
      value={{
        dsn: props.sentryDSN,
        release: props.commitHash,
        sampleRate: props.sentrySampleRate,
        environment: props.env.name,
      }}
    />
    {/*
      CCPA to the front end
     */}
    <InlineVar
      name="purrDirectiveFormat"
      value={props.purrDirectiveFormat}
    />

    {/*
      Create nodes for responsive hook
    */}
    <div id="ratio-hook" />
    <div id="width-hook" />
    {/*
      Insert our javascripts (inlining where desired)
    */}
    {props.assets.scripts.map((script, i) => {
      if (script.src) {
        return (
          <script
            key={i}
            defer
            type="text/javascript"
            src={script.src}
          />
        )
      }

      if (script.inline) {
        return (
          <script
            key={i}
            id={script.id}
            defer
            type="text/javascript"
            dangerouslySetInnerHTML={{
              __html: script.inline,
            }}
          />
        )
      }
      throw new Error(`bad script config ${JSON.stringify(script)}`)
    })}
    {/*
      Insert inlined ad manager
    */}
    {props.compliance.ads && !props.deviceType.mobile && (
      <script
        type="text/javascript"
        dangerouslySetInnerHTML={{
          __html: props.adManagerCode,
        }}
      />
    )}
    {/*
      Insert inlined abra code
    */}
    <script
      type="text/javascript"
      dangerouslySetInnerHTML={{
        __html: props.abraCode,
      }}
    />
    {/*
      Insert Hybrid Webview Detection
    */}
    <InlineVar name="isHybridWebView" value={props.isHybridWebView} />
    <InlineVar
      name="newsreaderAppPlatform"
      value={props.deviceType.newsreaderAppPlatform}
    />
    <InlineVar
      name="gamesAppPlatform"
      value={props.deviceType.gamesAppPlatform}
    />
    <InlineVar
      name="newsreaderAppVersion"
      value={props.deviceType.newsreaderAppVersion}
    />
    <InlineVar
      name="gamesAppVersion"
      value={props.deviceType.gamesAppVersion}
    />
    {/*
      Provide Android hybrid config script tag container
    */}
    {props.isHybridWebView && <HybridConfigContainer />}
    {/*
      Load ET. Ideally, this could be done via @nyt/eventtracker-js and call init with expected values.
    */}
    {!props.isHybridWebView && (
      <script type="text/javascript" src={props.env.gtm} />
    )}
  </>
))

export default Scripts
