import React from 'react'
import pt from 'prop-types'

// provide serverData should be the top level compoenent
// in the server render, so that and decendant can use
// withServerData() to access the res.locals object
export class ProvideServerData extends React.Component {
  getChildContext() {
    return {
      serverData: this.props,
    }
  }

  render() {
    const { children } = this.props
    return children
  }
}

ProvideServerData.defaultProps = {
  children: null,
}

ProvideServerData.propTypes = {
  children: pt.element,
}

ProvideServerData.childContextTypes = {
  serverData: pt.shape({}),
}

// withServerData
// is a HOC that ensures the Component
// will recieve the requestData
export const withServerData = (Component) => {
  const Wrapped = (props, context) => {
    const { serverData } = context
    return <Component {...serverData} {...props} />
  }

  Wrapped.contextTypes = {
    serverData: pt.shape({}),
  }

  return Wrapped
}
