import React from 'react'

import { CacheSafePage, withServerData } from '../components/index'
import { InlineVar } from '../components/InlineVar'

const errorPageTitles = {
  401: 'Subscription Required',
  404: 'Page Not Found',
}

export const ErrorPage = withServerData(
  ({ error, subscriptionCampaign, liraAsset }) => {
    return (
      <CacheSafePage
        titleOverride={
          errorPageTitles[error.status] ||
          'Oops! Something went wrong.'
        }
        suppressFooterOnMobile
      >
        {/* have to send error properties specifically rather than
        the whole error object becuase properties get stripped
        during the stringify process */}
        <InlineVar name="errorStackTrace" value={error.stack} />
        <InlineVar name="errorStatus" value={error.status} />
        <InlineVar
          name="subscriptionCampaign"
          value={subscriptionCampaign}
        />
        <InlineVar name="liraAsset" value={liraAsset} />
        <div id="error-page-root" />
      </CacheSafePage>
    )
  },
)

export default ErrorPage
