import React from 'react'
import cn from 'classnames'

import { appendSupportedParams } from 'views/util'
import { getSaleBodyClasses } from 'views/components/Marketing/UniversalTopBanner'

import {
  CacheSafePage,
  InlineVar,
  withServerData,
} from '../components/index'

export const Leaderboard = withServerData(
  ({
    error,
    view,
    data,
    navigationLinks,
    userType,
    url,
    userGeo,
    abraConfig,
    deviceType,
  }) => {
    const liraAsset = `&asset=leaderboard`
    const loginUrl = appendSupportedParams(
      navigationLinks.login,
      liraAsset,
    )

    const registerUrl = appendSupportedParams(
      navigationLinks.register,
      liraAsset,
    )

    const layoutProps = {
      view,
      error,
      login: loginUrl,
      register: registerUrl,
      ...data,
    }

    const backgroundClass = layoutProps.error ? 'blue' : 'none'

    const saleBodyClasses = getSaleBodyClasses(
      userType,
      url,
      userGeo,
      abraConfig,
      deviceType,
    )

    return (
      <CacheSafePage
        contentClassName={cn('lbd-background', backgroundClass, {
          ...saleBodyClasses,
        })}
      >
        <div id="lbd-root" />
        <InlineVar name="data" value={layoutProps} />
      </CacheSafePage>
    )
  },
)

export default Leaderboard
