import React from 'react'
import PT from 'prop-types'

import { appendSupportedParams } from 'views/util'

import {
  withServerData,
  GameContainer,
  CacheSafePage,
  CacheSafeAdsFrame,
} from '../components/index'
import getTotalCredits from '../../../games/tiles/js/tilesCredits/getTotalCredits'

export const TilesBase = ({ gameData, navigationLinks }) => {
  // Navigation Links
  const lireAsset = `&asset=tiles`
  const registerUrl = appendSupportedParams(
    navigationLinks.register,
    lireAsset,
  )

  const links = {
    login: navigationLinks.login,
    register: registerUrl,
    subscribe: 'https://www.nytimes.com/subscription/games',
  }

  return (
    <CacheSafePage
      navProps={{ isGamePage: true }}
      suppressFooterOnMobile
    >
      <CacheSafeAdsFrame>
        <div
          dangerouslySetInnerHTML={{ __html: gameData.iconsSVG }}
        />
        <GameContainer
          id="tiles-container"
          gameData={{ ...gameData, links }}
          renderHeader={() => (
            <h2>
              <em className="pz-game-title">Tiles</em>
            </h2>
          )}
        />
      </CacheSafeAdsFrame>
    </CacheSafePage>
  )
}

TilesBase.propTypes = {
  gameData: PT.object,
  navigationLinks: PT.object,
}

export const Tiles = withServerData(TilesBase)
