import React from 'react'

import { wordleInitialDarkMode } from '../../util/wordleInitialDarkMode'
import { CacheSafeScripts, withServerData } from '../components/index'

export const Wordle = withServerData(
  ({ assets, metadata, userQueryCode }) => {
    return (
      <html lang="en">
        <head>
          <meta charSet="UTF-8" />
          <meta
            name="viewport"
            content="width=device-width, initial-scale=1.0"
          />
          <meta name="theme-color" content="#000000" />

          <title>{metadata.title}</title>

          {metadata.linkTags.map((linkProps, idx) => (
            <link key={idx} {...linkProps} />
          ))}

          {metadata.metaTags.map((tagProps, idx) => (
            <meta key={idx} {...tagProps} />
          ))}

          <link
            rel="canonical"
            href="https://www.nytimes.com/games/wordle/index.html"
          />

          {assets.styles.map((css, i) => {
            if (css.src) {
              return (
                <link
                  key={i}
                  rel="stylesheet"
                  type="text/css"
                  href={css.src}
                />
              )
            }

            return null
          })}

          <script
            type="text/javascript"
            /* eslint-disable-next-line react/no-danger */
            dangerouslySetInnerHTML={{
              __html: `(function(){${userQueryCode}})();`,
            }}
          />
        </head>
        <body>
          <script
            type="text/javascript"
            // eslint-disable-next-line react/no-danger
            dangerouslySetInnerHTML={{
              __html: `(${wordleInitialDarkMode.toString()})();`,
            }}
          />
          <CacheSafeScripts />
        </body>
      </html>
    )
  },
)

export default Wordle
