import React from 'react'
import { mount } from 'enzyme'

import { ErrorPage } from '../ErrorPage'
import { InlineVar } from '../../components/InlineVar'

type CacheSafePageProps = {
  children: React.ReactNode
}

jest.mock('../../components/index', () => ({
  CacheSafePage: ({ children }: CacheSafePageProps) => (
    <div>{children}</div>
  ),
  withServerData: (_: any) => _,
}))

type InlineVarProps = {
  name: string
  value: string | boolean | number
}

jest.mock('../../components/InlineVar', () => ({
  InlineVar: ({ name, value }: InlineVarProps) => (
    <div>
      {name} {value}
    </div>
  ),
}))

describe('SERVER PAGES: ERROR', () => {
  it('renders 401 error page correctly', () => {
    const props = {
      error: {
        stack: 'Unauthorized',
        status: 401,
      },
      liraAsset: 'error-page',
      subscriptionCampaign: 'SSSS',
    }

    const wrapper = mount(<ErrorPage {...props} />)

    const errorStackTrace = wrapper.find(InlineVar).find({
      name: 'errorStackTrace',
      value: 'Unauthorized',
    })

    const errorStatus = wrapper.find(InlineVar).find({
      name: 'errorStatus',
      value: 401,
    })

    const liraAsset = wrapper.find(InlineVar).find({
      name: 'liraAsset',
      value: 'error-page',
    })

    const subscriptionCampaign = wrapper.find(InlineVar).find({
      name: 'subscriptionCampaign',
      value: 'SSSS',
    })

    expect(errorStackTrace.length).toBe(1)
    expect(errorStatus.length).toBe(1)
    expect(liraAsset.length).toBe(1)
    expect(subscriptionCampaign.length).toBe(1)
  })

  it('renders a 404 page correctly', () => {
    const props = {
      error: {
        stack: 'Not Found',
        status: 404,
      },
      liraAsset: 'error-page',
      subscriptionCampaign: 'SSSS',
    }

    const wrapper = mount(<ErrorPage {...props} />)

    const errorStackTrace = wrapper.find(InlineVar).find({
      name: 'errorStackTrace',
      value: 'Not Found',
    })

    const errorStatus = wrapper.find(InlineVar).find({
      name: 'errorStatus',
      value: 404,
    })

    const liraAsset = wrapper.find(InlineVar).find({
      name: 'liraAsset',
      value: 'error-page',
    })

    const subscriptionCampaign = wrapper.find(InlineVar).find({
      name: 'subscriptionCampaign',
      value: 'SSSS',
    })

    expect(errorStackTrace.length).toBe(1)
    expect(errorStatus.length).toBe(1)
    expect(liraAsset.length).toBe(1)
    expect(subscriptionCampaign.length).toBe(1)
  })

  it('renders a 500 page correctly', () => {
    const props = {
      error: {
        stack: 'Server Error',
        status: 500,
      },
      liraAsset: 'error-page',
      subscriptionCampaign: 'SSSS',
    }

    const wrapper = mount(<ErrorPage {...props} />)

    const errorStackTrace = wrapper.find(InlineVar).find({
      name: 'errorStackTrace',
      value: 'Server Error',
    })

    const errorStatus = wrapper.find(InlineVar).find({
      name: 'errorStatus',
      value: 500,
    })

    const liraAsset = wrapper.find(InlineVar).find({
      name: 'liraAsset',
      value: 'error-page',
    })

    const subscriptionCampaign = wrapper.find(InlineVar).find({
      name: 'subscriptionCampaign',
      value: 'SSSS',
    })

    expect(errorStackTrace.length).toBe(1)
    expect(errorStatus.length).toBe(1)
    expect(liraAsset.length).toBe(1)
    expect(subscriptionCampaign.length).toBe(1)
  })
})
