import React from 'react'
import { render, screen } from '@testing-library/react'

import { Leaderboard } from '../Leaderboard'

/* eslint-disable */
jest.mock('../../components/index', () => ({
  CacheSafePage: ({ children, contentClassName }) => (
    <div className={contentClassName}>{children}</div>
  ),
  InlineVar: (props) => {
    return (
      <div>
        <p>{props.value.login}</p>
        <p>{props.value.register}</p>
        <p>{props.value.foo}</p>
        <p>{props.value.view}</p>
      </div>
    )
  },
  withServerData: (_) => _,
}))

/* eslint-enable */

describe('SERVER PAGES: LEADERBOARD', () => {
  const props = {
    navigationLinks: {
      login: '/login',
      register: '/auth/register',
    },
    userType: {},
    data: {
      foo: 'bar',
    },
  }

  it('inlines correct props', () => {
    props.data.view = 'invite'

    render(<Leaderboard {...props} />)

    expect(screen.getByText('/login&asset=leaderboard')).toBeTruthy()
    expect(
      screen.getByText('/auth/register&asset=leaderboard'),
    ).toBeTruthy()
    expect(screen.getByText('bar')).toBeTruthy()
    expect(screen.getByText('invite')).toBeTruthy()
  })

  it('supports a view prop', () => {
    props.data.view = 'other'

    render(<Leaderboard {...props} />)
    expect(screen.getByText('other')).toBeTruthy()
  })

  it('renders blue for other errors', () => {
    props.error = {}
    props.data.view = 'invite'

    render(<Leaderboard {...props} />)
    expect(document.getElementsByClassName('blue')[0]).toBeTruthy()
  })
})
