import React from 'react'
import { shallow } from 'enzyme'

import { Sudoku } from '../Sudoku'
import {
  CacheSafePage,
  CacheSafeAdsFrame,
  GameContainer,
} from '../../components/index'

/* eslint-disable */
jest.mock('../../components/index', () => ({
  withServerData: (_) => _,
  CacheSafePage: ({ children }) => <div>{children}</div>,
  CacheSafeAdsFrame: ({ children }) => <div>{children}</div>,
  GameContainer: ({ children }) => <div>{children}</div>,
}))
/* eslint-enable */

describe('SERVER PAGES: SUDOKU', () => {
  test('renders page with ads and game component', () => {
    const page = shallow(<Sudoku />)
    const adFrame = page.find(CacheSafeAdsFrame)
    const game = adFrame.find(GameContainer)
    expect(game.exists()).toBe(true)
  })

  test('renders page as game page', () => {
    const page = shallow(<Sudoku />).find(CacheSafePage)
    expect(page.prop('navProps')).toEqual({
      isGamePage: true,
    })
  })

  test('renders game data', () => {
    const gameData = {}
    const game = shallow(<Sudoku gameData={gameData} />).find(
      GameContainer,
    )
    expect(game.prop('gameData')).toBe(gameData)
  })

  test('renders game header with date', () => {
    const game = shallow(
      <Sudoku gameData={{ displayDate: 'today!' }} />,
    ).find(GameContainer)
    const header = shallow(game.prop('renderHeader')())
    expect(header.find('.pz-game-title').text()).toBe('Sudoku')
    expect(header.find('.pz-game-date').text()).toBe('today!')
  })
})
