import moment from 'moment'

// NOTE: must stay in sync with foundation/util.js:jsHook
export const jsHook = (ID_OR_CLASSNAME) => `js-${ID_OR_CLASSNAME}`

// NOTE: must stay in sync with foundation/util.js:URLS_WITHOUT_PARAM_SUPPORT
const URLS_WITHOUT_PARAM_SUPPORT = [
  'nytimes://login',
  'nytimes://createAccount',
]

// NOTE: must stay in sync with foundation/util.js:appendSupportedParams
/**
 * Add query params to links that have query param support.
 * All web links have query param support, but
 * in the case of ios deeplinks, some urls do not support
 * unhandled params, so we need to use the original navigation
 * deeplinks as-is to prevent errors.
 *
 * @param {String} link navigation link
 * @param {String} params params to add, if supported
 */
export const appendSupportedParams = (link, params) => {
  const useOriginalLink = URLS_WITHOUT_PARAM_SUPPORT.some((url) =>
    link.startsWith(url),
  )

  return useOriginalLink ? link : `${link}${params}`
}

const abraConfig = {
  shared: 'TEST_sharedPhoenix_0930',
}

export const getAbraServerVariant = (test, abraData) => {
  const testName = abraConfig[test]
  try {
    return abraData[testName].variant
  } catch (err) {
    console.error('error retrieving abra server variant', err)
    return ''
  }
}

const NYT_TOKEN_RE = /(\w*)\{nyt-(\w+)\}(\w*)/g
const NYT_TIME_FORMATS = {
  m: (timestamp) => {
    const fullMonth = timestamp.format('MMMM')
    const threeLetterMonth =
      fullMonth === 'September' ? 'Sept' : fullMonth.substring(0, 3)

    return fullMonth.length > 4 ? `${threeLetterMonth}.` : fullMonth
  },
}

const getNYTTimeTokens = (timestamp, fmt) =>
  fmt.replace(NYT_TOKEN_RE, (a, b, nytFormat) => {
    const formatter = NYT_TIME_FORMATS[nytFormat]

    if (!formatter) {
      throw new Error(`Unrecognized NYT time: "${nytFormat}"`)
    }

    return `[${formatter(timestamp)}]`
  })

export const formatDate = (date, fmt) => {
  if (!date) return ''

  const timestamp = moment(date)
  const specialFormat = getNYTTimeTokens(timestamp, fmt)

  return timestamp.format(specialFormat)
}

export const capitalize = (string) =>
  string && string.length > 1
    ? string[0].toUpperCase() + string.slice(1)
    : ''

export default { jsHook }
