import React, { useState, useEffect, useMemo } from 'react'

import { abra } from 'foundation'
import type { UserType } from 'foundation'

import AbraContext from './AbraContext'

const AbraProvider = ({
  children,
  userType,
}: {
  children: React.ReactNode
  userType?: UserType
}) => {
  const [tests, setTests] = useState<{
    [key: string]: string | null
  }>({ ...abra.getTests() })
  const [hasAbraLoaded, setLoaded] = useState(false)

  useEffect(() => {
    abra.init(userType)
    setTests({ ...abra.getTests() })
    setLoaded(true)
  }, [userType])

  const value = useMemo(() => {
    const getVariant = (test: string) => tests[test]
    const reportExposure = (test: string) => abra.reportExposure(test)
    return { tests, getVariant, reportExposure, hasAbraLoaded }
  }, [tests, hasAbraLoaded])

  return (
    <AbraContext.Provider value={value}>
      {children}
    </AbraContext.Provider>
  )
}

export default AbraProvider
