export const checkVersion = (
  appVersion: string,
  minVersionMajor: number,
  minVersionMinor: number,
) => {
  const [major, minor] = (appVersion || '').split('.').map(Number)
  if (
    major < minVersionMajor ||
    (major === minVersionMajor && minor < minVersionMinor)
  ) {
    return false
  }

  return true
}

// returns true if the Spelling Bee past puzzles feature should be available
export const usePastPuzzles = () => {
  // never enable server-side
  if (typeof window === 'undefined') {
    return false
  }

  // disable on iOS games app < 4.47
  if (window.gamesAppPlatform === 'ios') {
    return checkVersion(window.gamesAppVersion, 4, 47)
  }

  // disable on android games app < 4.47
  if (window.gamesAppPlatform === 'android') {
    return checkVersion(window.gamesAppVersion, 4, 47)
  }

  // TODO: verify
  // disable on android news app < 10.12
  if (window.newsreaderAppPlatform === 'android') {
    return checkVersion(window.newsreaderAppVersion, 10, 12)
  }

  return true
}
