import { useEffect, useState } from 'react'
import { PUB_EVENTS } from '@nyt/ad-slot'

import {
  AdSlotPubSubReturnType,
  EventData,
} from '../../foundation/js/ads/adTracking/constants'

const useAdEvents = () => {
  const [hasIntAd, setHasIntAd] = useState<undefined | boolean>(
    undefined,
  )
  const [hasAdLoaded, setHasAdLoaded] = useState(false)
  const [hasAdRendered, setHasAdRendered] = useState(false)
  const [hasIntAdError, setHasIntAdError] = useState(false)
  const [isFluid, setIsFluid] = useState(false)

  useEffect(() => {
    const onAdFailure =
      (failureType: number) => (param: EventData) => {
        const { slot, id, type, isEmpty } = param
        if (failureType === 0 || isEmpty) {
          setHasIntAd(false)
          setHasIntAdError(true)
        }
      }

    const onEvent = (evt: string) => (param: EventData) => {
      const { slot, id, size } = param
      if (id || slot) {
        setHasIntAd(evt !== 'AdEmpty')
      }

      if (evt === PUB_EVENTS.AD_LOADED) {
        setHasAdLoaded(true)
      }

      if (evt === PUB_EVENTS.AD_RENDERED) {
        setHasAdRendered(true)
      }

      if (evt === 'AdRendered' && size && size[1] === 0) {
        setIsFluid(true)
      }
    }

    let subs: (AdSlotPubSubReturnType | undefined)[] = []
    if (window.AdSlot4) {
      window.AdSlot4.cmd.push(() => {
        const PubSub = window.AdSlot4?.events
        subs = [
          PubSub?.subscribe({
            name: 'script_loader_error',
            callback: onAdFailure(0),
            scope: 'all',
          }),
          PubSub?.subscribe({
            name: 'BidderError',
            callback: onAdFailure(0),
            scope: 'all',
          }),
          PubSub?.subscribe({
            name: 'AdEmpty',
            callback: onAdFailure(1),
            scope: 'all',
          }),
          PubSub?.subscribe({
            name: 'AdRendered',
            callback: onEvent('AdRendered'),
            scope: 'all',
          }),
          PubSub?.subscribe({
            name: PUB_EVENTS.AD_LOADED,
            callback: onEvent(PUB_EVENTS.AD_LOADED),
            scope: 'all',
          }),
        ]
      })
    }

    return () => {
      while (subs.length) {
        subs.pop()?.remove()
      }
    }
  }, [])
  return {
    hasIntAd,
    hasIntAdError,
    isFluid,
    isAdReady: hasAdRendered && hasAdLoaded,
  }
}
export default useAdEvents
