import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import { appendSupportedParams } from '../../../server/views/util'
import { getButtonText } from '../../../server/views/components/Marketing/Sale/functions'

const Error = ({
  error,
  navigationLinks,
  subscriptionCampaign,
  iconError,
  iconSubscribe,
  liraAsset,
  userType,
  documentTitle,
}) => {
  let body

  const loginUrl = appendSupportedParams(
    navigationLinks.login,
    `&asset=${liraAsset}`,
  )

  if (documentTitle) {
    document.title = documentTitle
  }

  switch (error.status) {
    case 401:
    case 403:
      body = (
        <div className="pz-error__message">
          {iconSubscribe && (
            <i className={cn('pz-error__icon', iconSubscribe)} />
          )}
          <h1>Subscribe to play.</h1>
          <p>
            Get full access to The Crossword, created daily by Times
            experts, with a New York Times Games subscription.
          </p>
          <a
            className="pz-error__button default"
            href={navigationLinks.subscribe[subscriptionCampaign]}
          >
            Subscribe
          </a>
          <a
            className="pz-error__button sale"
            href={navigationLinks.subscribe[subscriptionCampaign]}
          >
            {getButtonText(userType?.entitlement || '')}
          </a>
          <br />
          {userType?.isLoggedIn ? null : (
            <p>
              <a className="pz-error__link" href={loginUrl}>
                Log in
              </a>
            </p>
          )}
        </div>
      )
      break

    case 404:
      body = (
        <div className="pz-error__message">
          {iconError && (
            <i className={cn('pz-error__icon', iconError)} />
          )}
          <h1>This page no longer exists.</h1>
          <a className="pz-error__button" href="/crosswords">
            Explore Our Games
          </a>
        </div>
      )
      break

    default:
      body = (
        <div className="pz-error__message">
          {iconError && (
            <i className={cn('pz-error__icon', iconError)} />
          )}
          <h1>
            Our site is <br />
            playing games with us.{' '}
          </h1>
          <p>
            We’re working to solve an issue with our server. Try
            refreshing the page or check back soon. In the meantime,
            explore the Mini Crossword and more.
          </p>
          <a className="pz-error__button" href="/crosswords">
            Play Games
          </a>
        </div>
      )
  }

  return (
    <div className="pz-error">
      {body}
      {error.status === 404 ? (
        <div className="pz-error-img-1" alt="" />
      ) : (
        <div className="pz-error-img" alt="" />
      )}
    </div>
  )
}

Error.propTypes = {
  error: pt.shape({
    status: pt.number,
    stack: pt.string,
  }).isRequired,
  navigationLinks: pt.shape({
    login: pt.string,
    subscribe: pt.shape({}),
  }),
  liraAsset: pt.string,
  subscriptionCampaign: pt.string,
  iconError: pt.string,
  iconSubscribe: pt.string,
  userType: pt.shape({
    isLoggedIn: pt.bool,
    entitlement: pt.string,
  }),
  documentTitle: pt.string,
}

Error.defaultProps = {
  liraAsset: 'puzzle-paywall',
  subscriptionCampaign: 'default',
}

export default Error
