# foundation

Foundation contains the basic scripts and styles to stand up a page, such as Ads and Navigation.

It exposes some helpful utilities for other bundles to use.

### JavaScript

#### Environment

You can access information about the environment from foundation like so:

```javascript
import { env } from 'foundation'
```

which includes the following low-level information:

```JavaScript
{
  version: "vX.X.X",
  api: "http://edge.games.nyti.nyt.net",
  name: "prod"
}
```

#### Feature Flags

You can access the feature flags configured in the environment from foundation like so:

```javascript
import { featureFlags } from 'foundation'
```

which will include any feature flags:

```JavaScript
{
  myFeatureFlag: true,
  myOtherFeatureFlag: false,
}
```

### User

You can access the current user from foundation like so:

```JavaScript
import { user, userType } from 'foundation'
```

The user type contains cacheable information about the user:

```JavaScript
{
  entitlement: "sub,cr"
  hasDigi: true
  hasHd: false
  hasXwd: true
  inShortzMode: true
  isLoggedIn: true
}
```

and the user allows you to fetch the unique info

```JavaScript
user.get().then(u => {
  // now you have the regi id!
})
```

### Feedback Links

Generating the feedback link is a bit tricky since it uses un-cacheable data
about the users device that would require a bulky library on the front-end to compute.

So foundation exports an async helper for this

```javascript
import { getFeedbackLink } from 'foundation'

getFeedbackLink('My Subject Line').then((mailtoLink) => {
  // now you have a mailto link with fanciness!
})
```

### Tracking

You can access basic tracking

```javascript
import { track } from 'foundation'

track(eventName, eventConfig)
```

The tricky part is how to setup the config, so we wrapped this for games in `createGameTracker.js`

### XHR

Foundation also includes a very rudimentary ajax helper for talking to our API.
It is no where near the robustness of popular libraries, but it is very small and we've gotten through a few games with it.

Here is an example of how we tend to use it:

```javascript
import { env, xhr } from 'foundation'

const API_URL = `${env.api}/svc/crosswords/v6/leaderboard`

export const createProfile = (profileName) => {
  return xhr
    .post(`${API_URL}/profile.json`, { name: profileName })
    .then(...)
    .catch(...)
}
```
