import detectFeatures from './js/browserFeatureDetector'
import { disableAdsCookie, isRobot } from './js/util'
import {
  loadBidders,
  initializeAds,
  getBaseTargeting,
  areAdsDisabled,
} from './js/ads'
import loadALS from './js/ads/loadALS'
import { initializeFooter } from './js/footer'
import { initializeNav } from './js/navigation'
import { initializeGdpr } from './js/gdpr'
import { user, userType } from './js/user'
import { device, ipadCheck } from './js/device'
import { setupTracking, reportWebVitals } from './js/tracking'
import { win } from './js/aliases'
import ccpa from './js/ccpa'
import initSentry from './js/sentry'
import initBridgeAndConfig from './js/hybrid'
import { abra } from './js/abra'
import getAdUnitPath from './js/ads/getAdUnitPath'

initBridgeAndConfig()
reportWebVitals()
initSentry(win.sentryConfig)
detectFeatures()
abra.init()

if (!win.isHybridWebView && win.pageName !== 'wordle') {
  // this information comes from the bridge in hybrid, and we don't need it for wordle
  user.initialize()
  device.initialize()
}

initializeNav()
initializeFooter()

ipadCheck()

const blockAds =
  // @ts-ignore
  __DISABLE_ADS__ || (userType?.inShortzMode && disableAdsCookie)

if (!blockAds) {
  const disableAds = areAdsDisabled()
  if (!disableAds) {
    loadBidders() // do this ASAP to give bidders time to load
    loadALS(abra, getBaseTargeting())
  }

  win.addEventListener('load', () => {
    ccpa()
    if (!disableAds) {
      initializeAds(getAdUnitPath(win), abra.getTests())
    }
    setupTracking()
  })
} else {
  win.dataLayer = []
}

export type {
  UserType,
  UserEntitlement,
  AbraTests,
  AbraGetVariantFn,
  AbraExposeFn,
} from './window'
export {
  env,
  featureFlags,
  agentIdCookie,
  nytGeoCookie,
  appendSupportedParams,
  jsHook,
  getQueryParams,
} from './js/util'
export { device } from './js/device'
export { user, userType } from './js/user'
export { getFeedbackLink } from './js/footer'
export {
  mobileNavTools,
  globalNavId,
  mobileToolbarId,
  showToolbarClass,
} from './js/navigation'
export {
  track,
  trackPageUpdate,
  trackClick,
  reportWebVitals,
  trackInteraction,
  trackImpression,
  trackModuleInteraction,
} from './js/tracking'
export { SEND_EMAIL_TYPE } from './js/hybrid'
export { ccpa } from './js/ccpa'
export { parsePurrCookieValue } from './js/parsePurrCookieValue'
export { xhr } from './js/xhr'
export { abra } from './js/abra'
export type { AbraLimitedAudienceTests } from './js/abra/limitedAudienceTests'
export { refreshAds } from './js/ads' // TODO: a virtual page view should be exposed which calls this
export {
  captureSentryError,
  setSentryData,
  setSentryUser,
} from './js/sentry/index'
export { isRobot } from './js/util'
// just a convenient way to obscure its globalness and help with unit testing
export const getGameData = () => win.gameData
