describe('foundation ads.ts', () => {
  describe('loadBidders', () => {
    afterEach(() => {
      jest.restoreAllMocks()
    })
    it('passes expected AdSlot parameter to loadBiddingScripts', () => {
      const expectedAdSlot = {
        cmd: [],
        init: () => null,
        events: { subscribe: () => ({ remove: () => {} }) },
        refreshAds: () => null,
      }
      // @ts-ignore
      jest.spyOn(global, 'window', 'get').mockReturnValue({
        ...window,
        AdSlot4: expectedAdSlot,
      })
      const loadBiddingScriptsMock = jest
        .spyOn(require('../ads/loadBiddingScripts'), 'default')
        .mockImplementation()

      require('../ads').loadBidders()

      expect(loadBiddingScriptsMock).toHaveBeenCalledWith(
        expectedAdSlot,
        expect.any(String),
        expect.any(Object),
      )
    })
    it('passes expected page name parameter to loadBiddingScripts', () => {
      const expectedPageName = 'TEST_PAGE_NAME'
      jest
        .spyOn(require('../util'), 'getPageName')
        .mockReturnValue(expectedPageName)
      const loadBiddingScriptsMock = jest
        .spyOn(require('../ads/loadBiddingScripts'), 'default')
        .mockImplementation()

      require('../ads').loadBidders()

      expect(loadBiddingScriptsMock).toHaveBeenCalledWith(
        expect.any(Object),
        expectedPageName,
        expect.any(Object),
      )
    })
    it('passes expected bidders parameter to loadBiddingScripts', () => {
      const expectedBidders = ['bidder1', 'bidder2', 'bidder3']
      jest
        .spyOn(require('../ads/getActiveBidders'), 'default')
        .mockReturnValue(expectedBidders)
      const loadBiddingScriptsMock = jest
        .spyOn(require('../ads/loadBiddingScripts'), 'default')
        .mockImplementation()

      require('../ads').loadBidders()

      expect(loadBiddingScriptsMock).toHaveBeenCalledWith(
        expect.any(Object),
        expect.any(String),
        expectedBidders,
      )
    })
  })

  describe('getBaseTargeting', () => {
    afterEach(() => {
      jest.restoreAllMocks()
    })

    it('returns expected data', () => {
      const sov = require('../ads/kvps/sov').default
      jest
        .spyOn(require('../ads/kvps/plat'), 'default')
        .mockReturnValue('mweb')
      jest
        .spyOn(require('../ads/kvps/prop'), 'default')
        .mockReturnValue('mnyt')
      jest
        .spyOn(require('../ads/kvps/vp'), 'default')
        .mockReturnValue('small')

      expect(require('../ads').getBaseTargeting()).toEqual({
        plat: 'mweb',
        prop: 'mnyt',
        typ: 'games',
        sov,
        vp: 'small',
      })
    })
  })
})
