import React from 'react'
import { render, screen } from '@testing-library/react'

import { addFidesLink } from '../footer'
import { Footer } from '../../../../server/views/components/Footer'
import CacheSafeFooter from '../../../../server/views/components/CacheSafeFooter'
import createNavLinks from '../../../../server/util/createNavigationLinks'
import { abra } from '../abra'

jest.mock('../abra', () => ({
  abra: {
    getVariant: jest.fn(),
  },
}))

const navigationLinks = createNavLinks(
  {},
  {
    locals: {
      userType: { hasDigi: true },
      deviceType: {
        newsreaderAppPlatform: '',
        newsreaderAppVersion: '',
      },
    },
  },
)

describe('addFidesLink utility - Footer.js', () => {
  let props: any

  beforeEach(() => {
    props = {
      compliance: { optOut: false },
      navigationLinks,
      deviceType: { newsreaderAppPlatform: '' },
      userType: { hasXwd: false },
      env: { name: 'stg' },
    }
  })

  it('does not add a class to Manage Preferences link when appropriate', () => {
    render(<Footer {...props} />)
    expect(document.querySelector('.fides-tcf-manage')).toBeNull
  })

  it('adds a class to the Manage Preferences link when appropriate', () => {
    // @ts-ignore
    abra.getVariant.mockReturnValue('1_Enabled')

    render(<Footer {...props} />)
    addFidesLink()

    expect(document.querySelector('.fides-tcf-manage')).toBeTruthy
  })
})

describe('addFidesLink utility - CacheSafeFooter.js', () => {
  let props: any

  beforeEach(() => {
    props = {
      compliance: { optOut: false },
      navigationLinks,
      deviceType: { newsreaderAppPlatform: '' },
      userType: { hasXwd: false },
      env: { name: 'stg' },
    }
  })

  it('does not add a class to the Manage Preferences link when appropriate', () => {
    render(<CacheSafeFooter {...props} />)
    expect(document.querySelector('.fides-tcf-manage')).toBeNull
  })

  it('adds a class to the Manage Preferences link when appropriate', () => {
    // @ts-ignore
    abra.getVariant.mockReturnValue('1_Enabled')

    render(<CacheSafeFooter {...props} />)
    addFidesLink()

    expect(document.querySelector('.fides-tcf-manage')).toBeTruthy
  })
})
