import {
  findPurrCookieValue,
  parsePurrCookieValue,
  searchToObject,
} from '../parsePurrCookieValue'
import { PURR_DIRECTIVE_FORMAT } from '../../../../server/util/parsePurrDirectiveHeader'

jest.mock('foundation', () => ({
  env: { version: 'test' },
  ccpa: jest.fn(),
}))

const defaultPurrValue = 'sssssssssssssxxss'

Object.defineProperty(window.document, 'cookie', {
  writable: true,
  // s means "show" for whatever index
  value: `nyt-purr=${defaultPurrValue}`,
})

Object.defineProperty(window, 'location', {
  writable: true,
  value: {
    search: '?query=this',
  },
})

// @ts-ignore
window.purrDirectiveFormat = PURR_DIRECTIVE_FORMAT

describe('parsing values', () => {
  it('finds the purr cookie value', () => {
    const cookieValue = findPurrCookieValue()
    expect(cookieValue).toBe(defaultPurrValue)
  })

  it('finds the query value', () => {
    const query = searchToObject()
    expect(query).toStrictEqual({ query: 'this' })
  })

  it('parses cookie value', () => {
    const parsedCookieValue = parsePurrCookieValue()
    expect(parsedCookieValue).toStrictEqual({
      PURR_AdConfiguration_v3: 'adluce-socrates',
      PURR_CaliforniaNoticesUI: 'show',
      PURR_DataSaleOptOutUI_v2: 'show',
      PURR_LimitSensitivePI: 'show',
      PURR_TOSBlocker_v1: 'show',
      PURR_FidesTCF: 'show',
    })
  })
})
