import { formatExposureData, abra } from '.'

jest.mock('../util', () => ({
  env: { name: 'prod' },
}))

jest.mock('../sentry', () => ({
  captureSentryError: jest.fn(),
}))

Object.defineProperty(window, 'isHybridWebview', {
  writable: true,
  value: false,
})

Object.defineProperty(window, 'abra', {
  writable: true,
  value: {
    tests: {
      GAMES_test_1234: '0_control',
      '.ver': '0',
    },
  },
})

Object.defineProperty(window, 'gamesAppPlatform', {
  writable: true,
  value: '',
})

describe('abra tracking', () => {
  it('formats the correct ab expose data for desktop', () => {
    const { data, eventName } = formatExposureData('GAMES_test_1234')
    expect(eventName).toBe('ab-expose')
    expect(data).toEqual({
      abtest: {
        test: 'GAMES_test_1234',
        variant: '0_control',
        config_ver: '0',
        integration: `games-prd`,
      },
    })
  })

  it('formats the correct ab expose data for hybrid ios XWD app', () => {
    window.isHybridWebView = true
    window.gamesAppPlatform = 'ios'

    const { data, eventName } = formatExposureData('GAMES_test_1234')
    expect(eventName).toBe('ab_expose')
    expect(data).toEqual({
      test: 'GAMES_test_1234',
      variant: '0_control',
      config_ver: '0',
      integration: `games-prd`,
    })
  })

  it('formats the correct ab expose data for newsreader app', () => {
    window.isHybridWebView = true
    window.gamesAppPlatform = ''

    const { data, eventName } = formatExposureData('GAMES_test_1234')
    expect(eventName).toBe('ab-expose')
    expect(data).toEqual({
      abtest: {
        test: 'GAMES_test_1234',
        variant: '0_control',
        config_ver: '0',
        integration: `games-prd`,
      },
    })
  })

  it('formats the correct ab expose data for android xwd app', () => {
    window.isHybridWebView = true
    window.gamesAppPlatform = 'android'

    const { data, eventName } = formatExposureData('GAMES_test_1234')
    expect(eventName).toBe('ab_expose')
    expect(data).toEqual({
      test: 'GAMES_test_1234',
      variant: '0_control',
      config_ver: '0',
      integration: `games-prd`,
    })
  })
})
