/**
 * For Abra experiments that require specific user, device, or time duration restrictions
 * How to use:
 *  1. Make sure you have an Abra experiment set up in the Abra UI
 *  2. Add the name of your Abra experiment as a key in the test testConfigs object
 *  3. Add your restrictions as the value to your experiment name key. All fields are optional
 *  4. Additionally you can provide css classes that will be added to the body for each variant
 *
 *    GAMES_sampleTest_0123: {
 *      startDate: new Date('01/05/2023 10:00:000-0400'),
 *      endDate: new Date('04/30/2023 11:00:000-0400'),
 *      audience: {
 *        users: ['anon', 'regi'],
 *        platforms: ['games-ios', 'games-android'],
 *      },
 *      classNames: {
 *        '0_control': 'abra-sample-test-control',
 *        '1_variant': 'abra-sample-test-show-variant',
 *      }
 *    },
 */

type AbraExperimentName = string

export type AbraUserType = 'anon' | 'regi' | 'sub' | 'ada' | 'digi'

export type AbraPlatformType =
  | 'web'
  | 'mobile-web'
  | 'desktop'
  | 'games-ios'
  | 'games-android'
  | 'newsreader-ios'
  | 'newsreader-android'
  | 'hybrid'

export type AbraAudience = {
  users?: AbraUserType[]
  platforms?: AbraPlatformType[]
}

export type AbraBodyClasses = {
  [key in string]: string
}

export type AbraTestRestriction = {
  startDate?: Date
  endDate?: Date
  audience?: AbraAudience
  classNames?: AbraBodyClasses
}

export type AbraLimitedAudienceTests = Record<
  AbraExperimentName,
  AbraTestRestriction
>

const testConfigs: AbraLimitedAudienceTests = {
  MWD_phoenix_games_sale_banner: {
    startDate: new Date('12/14/2023 10:00:000-0500'),
    endDate: new Date('12/29/2023 12:00:000-0500'),
    audience: {
      users: ['anon', 'regi', 'digi'],
      platforms: [
        'newsreader-ios',
        'newsreader-android',
        'games-ios',
        'games-android',
      ],
    },
    classNames: {
      '1_Show': 'pz-games-sale-banner',
    },
  },
  GAMES_saleButtonCopy_0421: {
    startDate: new Date('05/22/2023 06:00:000-0400'),
    endDate: new Date('06/30/2023 12:00:000-0400'),
    audience: {
      users: ['anon', 'regi', 'digi'],
      platforms: ['web'],
    },
  },
  GAMES_meterIntegration_0228: {
    audience: {
      platforms: ['web'],
    },
  },
  GAMES_xwdMeterIntegration_0927: {
    audience: {
      platforms: ['web'],
    },
  },
  GAMES_xwdMeterEnforcement_0927: {
    audience: {
      platforms: ['web'],
    },
  },
  MWD_phoenix_games_sale_cta: {
    startDate: new Date('12/14/2023 10:00:000-0500'),
    endDate: new Date('12/29/2023 12:00:000-0500'),
    audience: {
      users: ['anon', 'regi', 'digi'],
      platforms: [
        'newsreader-ios',
        'newsreader-android',
        'games-ios',
        'games-android',
      ],
    },
    classNames: {
      '1_Show': 'pz-games-sale-cta',
    },
  },
  GAMES_wordleWebStatsRegiWall_1023: {
    audience: {
      platforms: ['web'],
    },
  },
}

export default testConfigs
