import als from '../als'

describe('als', () => {
  afterEach(() => {
    jest.restoreAllMocks()
  })
  it('should catch as expected if setAdSlotKVPsFromLocalStorage rejects', (done) => {
    const expectedError = new Error('FOO ERROR')
    jest
      .spyOn(require('../als/setAdSlotKVPsFromApi'), 'default')
      .mockResolvedValue({})
    jest
      .spyOn(
        require('../als/setAdSlotKVPsFromLocalStorage'),
        'default',
      )
      .mockRejectedValue(expectedError)
    jest
      .spyOn(window.console, 'warn')
      .mockImplementationOnce((err) => {
        try {
          expect(err).toEqual(expectedError)
          done()
        } catch (error) {
          done(error)
        }
      })

    als({ prop: 'fooProp', plat: 'fooPlat', typ: 'bartyp' })
  })
  it('should set adslot kvps from local storage', () => {
    jest
      .spyOn(require('../als/setAdSlotKVPsFromApi'), 'default')
      .mockResolvedValue({})
    const testSpy = jest
      .spyOn(
        require('../als/setAdSlotKVPsFromLocalStorage'),
        'default',
      )
      .mockResolvedValue({})

    als({ prop: 'fooProp', plat: 'fooPlat', typ: 'bartyp' })

    expect(testSpy).toHaveBeenCalled()
  })
  it('should catch as expected if setAdSlotKVPsFromApi rejects', (done) => {
    const expectedError = new Error('FOO ERROR')
    jest
      .spyOn(require('../als/setAdSlotKVPsFromApi'), 'default')
      .mockRejectedValue(expectedError)
    jest
      .spyOn(
        require('../als/setAdSlotKVPsFromLocalStorage'),
        'default',
      )
      .mockResolvedValue({})
    jest
      .spyOn(window.console, 'warn')
      .mockImplementationOnce((err) => {
        try {
          expect(err).toEqual(expectedError)
          done()
        } catch (error) {
          done(error)
        }
      })

    als({ prop: 'fooProp', plat: 'fooPlat', typ: 'bartyp' })
  })
  it('should set adslot kvps from api', () => {
    const testSpy = jest
      .spyOn(require('../als/setAdSlotKVPsFromApi'), 'default')
      .mockResolvedValue({})
    jest
      .spyOn(
        require('../als/setAdSlotKVPsFromLocalStorage'),
        'default',
      )
      .mockResolvedValue({})

    als({ prop: 'fooProp', plat: 'fooPlat', typ: 'bartyp' })

    expect(testSpy).toHaveBeenCalled()
  })
  it('should pass expected params to setAdSlotKVPsFromApi from getServiceUrl', () => {
    const expectedValue = 'FOO_BAR_URL'

    const expectedUriParam = 'http://foo.bar'

    jest
      .spyOn(require('../als/getServiceUrl'), 'getParams')
      .mockReturnValue({
        uri: expectedUriParam,
      })
    const testSpy = jest
      .spyOn(require('../als/setAdSlotKVPsFromApi'), 'default')
      .mockResolvedValue({})
    jest
      .spyOn(
        require('../als/setAdSlotKVPsFromLocalStorage'),
        'default',
      )
      .mockResolvedValue({})
    jest
      .spyOn(require('../als/getServiceUrl'), 'default')
      .mockReturnValue(expectedValue)

    als({ prop: 'fooProp', plat: 'fooPlat', typ: 'bartyp' })

    expect(testSpy).toHaveBeenCalledWith(
      expectedValue,
      expectedUriParam,
    )
  })
  it('should pass expected params to getServiceUrl', () => {
    const expectedHost = 'TEST_HOST'
    const expectedParams = {
      foo: 'foo',
      bar: 'bar',
    }

    jest.spyOn(global, 'window', 'get').mockReturnValue({
      // @ts-ignore
      location: {
        host: expectedHost,
      },
    })

    jest
      .spyOn(require('../als/setAdSlotKVPsFromApi'), 'default')
      .mockResolvedValue({})
    jest
      .spyOn(
        require('../als/setAdSlotKVPsFromLocalStorage'),
        'default',
      )
      .mockResolvedValue({})
    const getServiceUrlSpy = jest
      .spyOn(require('../als/getServiceUrl'), 'default')
      .mockImplementation(jest.fn())
    jest
      .spyOn(require('../als/getServiceUrl'), 'getParams')
      .mockReturnValue(expectedParams)

    als({ prop: 'fooProp', plat: 'fooPlat', typ: 'bartyp' })

    expect(getServiceUrlSpy).toHaveBeenCalledWith(
      expectedHost,
      expectedParams,
    )
  })
  it('should pass expected params to getParams', () => {
    const prop = 'fooProp'
    const plat = 'barPlat'
    const typ = 'fooBarTyp'
    const origin = 'TEST_ORIGIN'
    const pathname = 'TEST_PATHNAME'
    const search = 'TEST_SEARCH'

    const expectedParams = {
      foo: 'foo',
      bar: 'bar',
    }

    jest.spyOn(global, 'window', 'get').mockReturnValue({
      // @ts-ignore
      location: {
        origin,
        pathname,
        search,
      },
    })

    jest
      .spyOn(require('../als/setAdSlotKVPsFromApi'), 'default')
      .mockResolvedValue({})
    jest
      .spyOn(
        require('../als/setAdSlotKVPsFromLocalStorage'),
        'default',
      )
      .mockResolvedValue({})
    const getParamsSpy = jest
      .spyOn(require('../als/getServiceUrl'), 'getParams')
      .mockReturnValue(expectedParams)

    als({ prop, plat, typ })

    expect(getParamsSpy).toHaveBeenCalledWith(
      expect.objectContaining({
        prop,
        plat,
        typ,
        origin,
        pathname,
        search,
      }),
    )
  })
})
