import getAbraDFPTests from '../getAbraDFPTests'

describe('getAbraDFPTests', () => {
  it('should return expected filtered list', () => {
    const tests = {
      GAMES_TEST_Thing: '1_test',
      DFP_GAMES_tester: '0_control',
      DIFFERENT_TEST: '0_control',
      DFP_SOME_OTHER_TEST: '1_tester',
      SOMETHING_TO_DO_WITH_DFP: '0_control',
    }
    const testString = getAbraDFPTests(tests)
    expect(testString).toContain('dfp_games_tester_0_control')
    expect(testString).toContain('dfp_some_other_test_1_tester')
    expect(testString).toContain('something_to_do_with_dfp_0_control')
  })
  it('should add additional values from existing string list', () => {
    const tests = {
      GAMES_TEST_Thing: '1_test',
      DFP_GAMES_tester: '0_control',
      DIFFERENT_TEST: '0_control',
      DFP_SOME_OTHER_TEST: '1_tester',
      SOMETHING_TO_DO_WITH_DFP: '0_control',
    }
    const dfp1 = 'dfp_tester'
    const dfp2 = 'dfp_second_tester'
    const existingList = `${dfp1},${dfp2}`
    const testString = getAbraDFPTests(tests, existingList)
    expect(testString).toContain(dfp1)
    expect(testString).toContain(dfp2)
  })
  it('should not duplicate values from existing list', () => {
    const dfpDupeTesterKey = 'dfp_some_other_test'
    const dfpDupeTesterValue = '1_tester'
    const tests = {
      GAMES_TEST_Thing: '1_test',
      DFP_GAMES_tester: '0_control',
      DIFFERENT_TEST: '0_control',
      [dfpDupeTesterKey]: dfpDupeTesterValue,
      SOMETHING_TO_DO_WITH_DFP: '0_control',
    }
    const dfpDupeTesterBuilt = `${dfpDupeTesterKey}_${dfpDupeTesterValue}`
    const existingList = `${dfpDupeTesterBuilt},dfp_other_tester`
    const testString = getAbraDFPTests(tests, existingList)
    const regexp = new RegExp(dfpDupeTesterBuilt, 'g')
    const unique = [...testString.matchAll(regexp)]
    expect(unique).toHaveLength(1)
  })
})
