import getAdSizes, {
  DEFAULT_SIZES,
  MOBILE_INTERSTITIAL_SIZES,
  MOBILE_INTERSTITIAL_SIZES_SHORT,
} from '../getSizeMappings'

describe('getAdSizes', () => {
  it('returns default sizes when no path is provided', () => {
    const result = getAdSizes().default
    expect(result).toEqual(DEFAULT_SIZES)
  })

  it('returns mobile interstitial sizes when path is "wordle" and ad type is "intsl"', () => {
    // @ts-ignore
    const { intsl } = getAdSizes('wordle')
    expect(intsl).toEqual(MOBILE_INTERSTITIAL_SIZES)
  })

  it('returns default sizes when path is "wordle" and ad type is not specified', () => {
    const result = getAdSizes('wordle').default
    expect(result).toEqual(DEFAULT_SIZES)
  })

  it('returns default sizes when an unknown path is provided', () => {
    const result = getAdSizes('unknown').default
    expect(result).toEqual(DEFAULT_SIZES)
  })

  it('returns mobile interstitial sizes when path is "wordle" and a tall height is specified', () => {
    const result = getAdSizes('wordle', 736)
    expect(result.intsl).toEqual(MOBILE_INTERSTITIAL_SIZES)
    expect(result.default).toEqual(DEFAULT_SIZES)
  })

  it('returns the appropriate wordle sizes on shorter screen heights', () => {
    const { intsl } = getAdSizes('wordle', 735)
    expect(intsl).toEqual(MOBILE_INTERSTITIAL_SIZES_SHORT)
  })

  it('returns the correct default sizes when path is "default" and screen height is given', () => {
    const resultTall = getAdSizes('default', 736)
    expect(resultTall.default).toEqual(DEFAULT_SIZES)

    const resultShort = getAdSizes('default', 735)
    expect(resultShort.default).toEqual(DEFAULT_SIZES)
  })
})
