import loadALS, {
  ALS_AA_TEST,
  ALS_AB_TEST,
  VARIANT,
} from '../loadALS'

describe('loadALS', () => {
  describe('AA TEST', () => {
    it('should not call reportExposure if AA test does not return truthy', () => {
      const reportExposureSpy = jest.fn()
      const abra = {
        getVariant: (test: string) => {
          if (['NO TEST'].includes(test)) return true

          return null
        },
        reportExposure: reportExposureSpy,
        getTests: jest.fn(),
      }
      loadALS(abra, { plat: 'foo', prop: 'bar' })
      expect(reportExposureSpy).not.toHaveBeenCalledWith(ALS_AA_TEST)
    })
    it('should call reportExposure if AA test returns truthy', () => {
      const reportExposureSpy = jest.fn()
      const abra = {
        getVariant: (test: string) => {
          if ([ALS_AA_TEST].includes(test)) return true

          return null
        },
        reportExposure: reportExposureSpy,
        getTests: jest.fn(),
      }
      loadALS(abra, { plat: 'foo', prop: 'bar' })
      expect(reportExposureSpy).toHaveBeenCalledWith(ALS_AA_TEST)
    })
  })
  describe('AB TEST', () => {
    it('should not call reportExposure if AB test does not return truthy', () => {
      const reportExposureSpy = jest.fn()
      const abra = {
        getVariant: (test: string) => {
          if (['NO TEST'].includes(test)) return true

          return null
        },
        reportExposure: reportExposureSpy,
        getTests: jest.fn(),
      }
      loadALS(abra, { plat: 'foo', prop: 'bar' })
      expect(reportExposureSpy).not.toHaveBeenCalledWith(ALS_AB_TEST)
    })
    it('should call reportExposure if AB test returns truthy', () => {
      const reportExposureSpy = jest.fn()
      const abra = {
        getVariant: (test: string) => {
          if ([ALS_AB_TEST].includes(test)) return true

          return null
        },
        reportExposure: reportExposureSpy,
        getTests: jest.fn(),
      }
      loadALS(abra, { plat: 'foo', prop: 'bar' })
      expect(reportExposureSpy).toHaveBeenCalledWith(ALS_AB_TEST)
    })
    it('should call als if AB test returns variant', () => {
      const alsSpy = jest
        .spyOn(require('../als'), 'default')
        .mockImplementation(jest.fn())
      const reportExposureSpy = jest.fn()
      const abra = {
        getVariant: (test: string) => {
          if ([ALS_AB_TEST].includes(test)) return VARIANT

          return null
        },
        reportExposure: reportExposureSpy,
        getTests: jest.fn(),
      }
      loadALS(abra, { plat: 'foo', prop: 'bar' })
      expect(alsSpy).toHaveBeenCalled()
    })
    it('should pass expected targeting to als if AB test returns variant', () => {
      const expectedTargeting = {
        plat: 'foo',
        prop: 'bar',
        typ: 'TEST_TYP',
        sov: 'TEST_SOV',
        vp: 'TESTER_VP',
      }

      const alsSpy = jest
        .spyOn(require('../als'), 'default')
        .mockImplementation(jest.fn())
      const reportExposureSpy = jest.fn()
      const abra = {
        getVariant: (test: string) => {
          if ([ALS_AB_TEST].includes(test)) return VARIANT

          return null
        },
        reportExposure: reportExposureSpy,
        getTests: jest.fn(),
      }
      loadALS(abra, expectedTargeting)
      expect(alsSpy).toHaveBeenCalledWith(expectedTargeting)
    })
  })
})
