import { PAGE_TYPE, SECTION } from '../constants'

describe('loadBiddingScripts', () => {
  afterEach(() => {
    jest.restoreAllMocks()
  })
  it('should call AdSlot4.loadScripts if it exists', () => {
    const loadScriptsSpy = jest.fn()
    require('../loadBiddingScripts').default({
      loadScripts: loadScriptsSpy,
    })
    expect(loadScriptsSpy).toHaveBeenCalled()
  })
  it('should pass expected static values', () => {
    const loadScriptsSpy = jest.fn()
    require('../loadBiddingScripts').default({
      loadScripts: loadScriptsSpy,
    })
    expect(loadScriptsSpy).toHaveBeenCalledWith(
      expect.objectContaining({
        pageType: PAGE_TYPE,
        section: SECTION,
      }),
    )
  })
  it('should pass expected value from shouldLoadPrebid', () => {
    const shouldLoadPrebidMock = 'TESTING_SHOULD_LOAD'
    jest
      .spyOn(require('../shouldLoadPrebid'), 'default')
      .mockReturnValue(shouldLoadPrebidMock)
    const loadScriptsSpy = jest.fn()
    require('../loadBiddingScripts').default({
      loadScripts: loadScriptsSpy,
    })
    expect(loadScriptsSpy).toHaveBeenCalledWith(
      expect.objectContaining({
        loadPrebid: shouldLoadPrebidMock,
      }),
    )
  })
  it('should pass second param to shouldLoadPrebid', () => {
    const shouldLoadPrebidMock = 'TESTING_SHOULD_LOAD'
    const pageName = 'TEST_PAGE_NAME'
    const shouldLoadPrebidSpy = jest
      .spyOn(require('../shouldLoadPrebid'), 'default')
      .mockReturnValue(shouldLoadPrebidMock)
    const loadScriptsSpy = jest.fn()
    require('../loadBiddingScripts').default(
      {
        loadScripts: loadScriptsSpy,
      },
      pageName,
    )
    expect(shouldLoadPrebidSpy).toHaveBeenCalledWith(pageName)
  })
})
