import { PUB_EVENTS } from '@nyt/ad-slot'

import { track } from 'foundation'

import {
  DEFAULT_EVENT,
  DEFAULT_TYPE,
  DEFAULT_TRIGGER,
  ETEventData,
  EventData,
} from './constants'
import getCreativeId from './utils/getCreativeId'
import getLineItemId from './utils/getLineItemId'
import hasImportantTargetingKeysEtSchema from './utils/hasImportantTargetingKeysEtSchema'

export const trackAdImpression = ({
  event = DEFAULT_EVENT,
  type = DEFAULT_TYPE,
  data: ad,
}: {
  event?: string
  type?: string
  data: ETEventData
}) => {
  const eventData = {
    type,
    trigger: DEFAULT_TRIGGER,
  }
  track(event, {
    eventData,
    ad,
  })
}

const mapTrackingData = (data: EventData): ETEventData => {
  const {
    slot,
    id: slotId,
    pos,
    position: posit,
    adSlotEventName,
    ...adData
  } = data

  // Take out a few data points to save on bandwidth
  const {
    sizes,
    creativeId,
    sourceAgnosticCreativeId,
    lineItemId,
    sourceAgnosticLineItemId,
    ...rest
  } = adData

  const slotData = slot?.getResponseInformation() || {}
  const pageType = window.adUnitPath ?? 'notfound'

  const returnData: ETEventData = {
    ...rest,
    adSlotEventName,
    creativeId: getCreativeId(slotData),
    lineItemId: getLineItemId(slotData),
    position: pos || posit,
    slotId,
    pageType,
    ...hasImportantTargetingKeysEtSchema(adSlotEventName, slot),
  }

  return returnData
}

export const subscribeCallBack = (
  adSlotEventName: string,
): ((e: EventData) => void) => {
  return (e: EventData) => {
    if (
      !(
        adSlotEventName === PUB_EVENTS.AD_EMPTY &&
        e.type === PUB_EVENTS.AD_BLOCK_ON
      )
    ) {
      const data = mapTrackingData({
        ...e,
        adSlotEventName,
      })
      trackAdImpression({ data })
    }
  }
}
