import { PUB_EVENTS } from '@nyt/ad-slot'

import { AdSizeMapping } from '../getSizeMappings'

export const DEFAULT_EVENT = 'impression'
export const DEFAULT_TYPE = 'impression'
export const DEFAULT_TRIGGER = 'ad'

// GPT targeting keys
export const TYP_KEY = 'typ'
export const POS_KEY = 'pos'
export const VER_KEY = 'ver'
export const PROP_KEY = 'prop'
export const PLAT_KEY = 'plat'
export const VP_KEY = 'vp'
export const BT_KEY = 'bt'
export const ALICE_CLIENTSIDE_KEY = 'als_test_clientside'

// Critical KVPs we want to check for on ad requests
export const CRITICAL_KEYS = [
  TYP_KEY,
  POS_KEY,
  VER_KEY,
  PROP_KEY,
  PLAT_KEY,
  VP_KEY,
]

export const adLifeCycleEventsToTrack = [
  PUB_EVENTS.AD_SLOT_READY,
  PUB_EVENTS.AD_DEFINED,
  PUB_EVENTS.AD_CALLED,
  PUB_EVENTS.AD_REQUEST_SENT,
  PUB_EVENTS.AD_RESPONSE,
  PUB_EVENTS.AD_RENDERED,
  PUB_EVENTS.AD_LOADED,
  PUB_EVENTS.AD_VIEWABLE,
  PUB_EVENTS.AD_EMPTY,
]

export interface AdSlotInstanceType {
  getSlotElementId: () => string
  getResponseInformation: () => {
    advertiserId: string
    campaignId: string
    creativeId: string
    sourceAgnosticCreativeId?: string
    creativeTemplateId: string
    lineItemId: string
    sourceAgnosticLineItemId?: string
  }
  getTargetingKeys: () => string[]
}

export interface AdSlotPubSubReturnType {
  remove: () => void
}

export interface AdSlotPubSubType {
  subscribe: (arg: {
    name: string
    scope: string
    callback: (arg: EventData) => void
  }) => AdSlotPubSubReturnType
}

export interface EventData {
  adSlotEventName: string
  pageType: string
  slotId: string | undefined
  position: string
  lineItemId?: string
  sourceAgnosticLineItemId?: string
  creativeId?: string
  sourceAgnosticCreativeId?: string
  timeDefined?: string
  timeCalled?: string
  timeCallSent?: number
  timeRendered?: number
  timeLoaded?: number
  timeViewed?: number
  isEmpty?: boolean
  type?: string
  pos?: string
  slot?: AdSlotInstanceType
  id?: string | undefined
  size?: number[]
  sizes?: AdSizeMapping[]
}

export type ETEventData = Pick<
  EventData,
  | 'adSlotEventName'
  | 'pageType'
  | 'slotId'
  | 'position'
  | 'timeDefined'
  | 'timeCalled'
  | 'timeCallSent'
  | 'timeRendered'
  | 'timeLoaded'
  | 'timeViewed'
  | 'lineItemId'
  | 'creativeId'
  | 'isEmpty'
> & {
  has_bt?: boolean
  has_als_test_clientside?: boolean
  has_critical_kvps?: boolean
  is_alice_cache?: boolean
  is_bt_empty?: boolean
}
