import {
  ALICE_CLIENTSIDE_KEY,
  BT_KEY,
  CRITICAL_KEYS,
} from '../../constants'
import hasImportantTargetingKeys from '../hasImportantTargetingKeys'

import {
  mockAdSlotInstance,
  mockPubAdsService,
} from './utils-test-mocks'

describe('hasImportantTargetingKeys', () => {
  beforeEach(() => {
    jest
      .spyOn(mockPubAdsService, 'getTargetingKeys')
      .mockReturnValue([''])
  })
  afterEach(() => {
    jest.restoreAllMocks()
  })
  it('should return "true"s if all the right keys are present', () => {
    jest
      .spyOn(mockAdSlotInstance, 'getTargetingKeys')
      .mockReturnValue([
        ...CRITICAL_KEYS,
        BT_KEY,
        ALICE_CLIENTSIDE_KEY,
      ])
    expect(
      hasImportantTargetingKeys(
        mockAdSlotInstance,
        mockPubAdsService,
      ),
    ).toEqual({
      has_bt: true,
      has_als_test_clientside: true,
      has_critical_kvps: true,
    })
  })

  it('should return false if bt_key is missing', () => {
    jest
      .spyOn(mockAdSlotInstance, 'getTargetingKeys')
      .mockReturnValue([...CRITICAL_KEYS, ALICE_CLIENTSIDE_KEY])
    expect(
      hasImportantTargetingKeys(
        mockAdSlotInstance,
        mockPubAdsService,
      ),
    ).toEqual({
      has_bt: false,
      has_als_test_clientside: true,
      has_critical_kvps: true,
    })
  })

  it('should return false if alice key is missing', () => {
    jest
      .spyOn(mockAdSlotInstance, 'getTargetingKeys')
      .mockReturnValue([...CRITICAL_KEYS, BT_KEY])
    expect(
      hasImportantTargetingKeys(
        mockAdSlotInstance,
        mockPubAdsService,
      ),
    ).toEqual({
      has_bt: true,
      has_als_test_clientside: false,
      has_critical_kvps: true,
    })
  })

  it('should return false if any critical key is missing', () => {
    jest
      .spyOn(mockAdSlotInstance, 'getTargetingKeys')
      .mockReturnValue([
        ...CRITICAL_KEYS.slice(1),
        BT_KEY,
        ALICE_CLIENTSIDE_KEY,
      ])
    expect(
      hasImportantTargetingKeys(
        mockAdSlotInstance,
        mockPubAdsService,
      ),
    ).toEqual({
      has_bt: true,
      has_als_test_clientside: true,
      has_critical_kvps: false,
    })
  })
})
