import { PUB_EVENTS } from '@nyt/ad-slot'

import hasImportantTargetingKeysEtSchema from '../hasImportantTargetingKeysEtSchema'
import * as getGptService from '../getGptService'
import * as hasImportantTargetingKeys from '../hasImportantTargetingKeys'
import * as getIsAliceFromLocalStorage from '../getIsAliceFromLocalStorage'
import * as getIsBtEmpty from '../getIsBtEmpty'

import { mockPubAdsService } from './utils-test-mocks'

describe('hasImportantTargetingKeysEtSchema', () => {
  beforeEach(() => {
    jest
      .spyOn(getGptService, 'default')
      .mockReturnValue(mockPubAdsService)
  })
  afterEach(() => {
    jest.restoreAllMocks()
  })
  it('should return an empty object for some events', () => {
    expect(
      hasImportantTargetingKeysEtSchema(PUB_EVENTS.AD_EMPTY),
    ).toEqual({})
  })

  it('should return an object with "true" values if dependent functions return true', () => {
    jest.spyOn(hasImportantTargetingKeys, 'default').mockReturnValue({
      has_bt: true,
      has_als_test_clientside: true,
      has_critical_kvps: true,
    })
    jest
      .spyOn(getIsAliceFromLocalStorage, 'default')
      .mockReturnValue(true)
    jest.spyOn(getIsBtEmpty, 'default').mockReturnValue(true)
    expect(
      hasImportantTargetingKeysEtSchema(PUB_EVENTS.AD_DEFINED),
    ).toEqual({
      has_bt: true,
      has_als_test_clientside: true,
      has_critical_kvps: true,
      is_alice_cache: true,
      is_bt_empty: true,
    })
  })

  it('should return an object with "false" values if dependent functions return false', () => {
    jest.spyOn(hasImportantTargetingKeys, 'default').mockReturnValue({
      has_bt: false,
      has_als_test_clientside: false,
      has_critical_kvps: false,
    })
    jest
      .spyOn(getIsAliceFromLocalStorage, 'default')
      .mockReturnValue(false)
    jest.spyOn(getIsBtEmpty, 'default').mockReturnValue(false)
  })
})
