describe('awaitAdSlot', () => {
  afterEach(() => {
    jest.restoreAllMocks()
    jest.resetModules()
  })
  it('should resolve with expected data when AdSlot.cmd has already been initialized', () => {
    const expectedObj = {
      test: 'FOO',
      testOther: 'BAR',
    }

    const cmdPush = (fn: Function) => {
      fn()
    }
    jest.spyOn(global, 'window', 'get').mockReturnValue({
      // @ts-ignore
      AdSlot4: {
        cmd: {
          // @ts-ignore
          push: cmdPush,
        },
      },
    })
    const awaitAdSlot = jest.requireActual('../awaitAdSlot').default
    return expect(awaitAdSlot(expectedObj)).resolves.toEqual(
      expectedObj,
    )
  })
  it('should resolve with expected data when AdSlot.cmd is initialized within the AWAIT TIME', () => {
    const expectedObj = {
      test: 'FOO',
      testOther: 'BAR',
    }

    const awaitAdSlotPkg = jest.requireActual('../awaitAdSlot')
    const { default: awaitAdSlot, AWAIT_TIME } = awaitAdSlotPkg

    const emulateAdSlotCreation = () => {
      const oldAdSlot = window.AdSlot4
      const AdSlot4 = window.AdSlot4 || { cmd: [] }
      AdSlot4.cmd.forEach((fn) => {
        fn()
      })
      window.AdSlot4 = oldAdSlot
    }
    // set our run time to be 1 ms before timeout error would occur
    setTimeout(emulateAdSlotCreation, AWAIT_TIME / 2)

    return expect(awaitAdSlot(expectedObj)).resolves.toEqual(
      expectedObj,
    )
  })
  it('should time out after expected time if AdSlot.cmd does not run', () => {
    const awaitAdSlotPkg = jest.requireActual('../awaitAdSlot')
    const { default: awaitAdSlot, TIMEOUT_ERROR } = awaitAdSlotPkg

    return expect(awaitAdSlot({})).rejects.toEqual(TIMEOUT_ERROR)
  })
})
