import {
  TEST_CLIENTSIDE_KEY,
  TEST_CLIENTSIDE_DEFAULT_KEY,
  MKTG_KEY,
  MKTG_DEFAULT_KEY,
  BT_KEY,
  BT_DEFAULT_KEY,
  SUB_KEY,
  SUB_DEFAULT_KEY,
} from '../constants'
import getLocalStorageValues from '../getLocalStorageValues'

describe('getLocalStorageValues', () => {
  beforeEach(() => {
    jest.restoreAllMocks()
  })
  it('returns expected value for TEST_CLIENTSIDE_KEY', () => {
    const expectedValue = 'EXPECTED TEST VALUE'
    const getItem = (val: string) => {
      return {
        [TEST_CLIENTSIDE_KEY]: expectedValue,
      }[val]
    }

    return expect(
      getLocalStorageValues({ getItem }),
    ).resolves.toMatchObject(
      expect.objectContaining({
        [TEST_CLIENTSIDE_KEY]: expectedValue,
      }),
    )
  })
  it('returns expected value for MKTG_KEY', () => {
    const expectedValue = 'EXPECTED TEST VALUE'
    const getItem = (val: string) => {
      return {
        [MKTG_KEY]: expectedValue,
      }[val]
    }

    return expect(
      getLocalStorageValues({ getItem }),
    ).resolves.toMatchObject(
      expect.objectContaining({
        [MKTG_KEY]: expectedValue,
      }),
    )
  })
  it('returns expected value for BT_KEY', () => {
    const expectedValue = 'EXPECTED TEST VALUE'
    const getItem = (val: string) => {
      return {
        [BT_KEY]: expectedValue,
      }[val]
    }

    return expect(
      getLocalStorageValues({ getItem }),
    ).resolves.toMatchObject(
      expect.objectContaining({
        [BT_KEY]: expectedValue,
      }),
    )
  })
  it('returns expected value for SUB_KEY', () => {
    const expectedValue = 'EXPECTED TEST VALUE'
    const getItem = (val: string) => {
      return {
        [SUB_KEY]: expectedValue,
      }[val]
    }

    return expect(
      getLocalStorageValues({ getItem }),
    ).resolves.toMatchObject(
      expect.objectContaining({
        [SUB_KEY]: expectedValue,
      }),
    )
  })
  it('should return expected defaults', () => {
    const getItem = (val: string) => {
      return {}[val]
    }

    return expect(
      getLocalStorageValues({ getItem }),
    ).resolves.toMatchObject(
      expect.objectContaining({
        [TEST_CLIENTSIDE_KEY]: TEST_CLIENTSIDE_DEFAULT_KEY,
        [MKTG_KEY]: MKTG_DEFAULT_KEY,
        [BT_KEY]: BT_DEFAULT_KEY,
        [SUB_KEY]: SUB_DEFAULT_KEY,
      }),
    )
  })
  it('should reject with expected error if localStorage.getItem throws', () => {
    const expectedError = new Error('Error: FooBar')
    const getItem = () => {
      throw expectedError
    }

    return expect(getLocalStorageValues({ getItem })).rejects.toEqual(
      expectedError,
    )
  })
})
