import getService, { DEFAULT_OPTS } from '../getService'

describe('getService', () => {
  beforeEach(() => {
    jest.restoreAllMocks()
  })
  it('should pass expected url to xhr', () => {
    const getSpy = jest.fn()
    jest
      .spyOn(jest.requireActual('foundation'), 'xhr', 'get')
      .mockReturnValue({
        get: getSpy,
      })
    const expectedUrl = 'https://foo.com'
    getService(expectedUrl)
    expect(getSpy).toHaveBeenCalledWith(
      expectedUrl,
      expect.any(Object),
    )
  })
  it('should pass expected default option to xhr to prevent cors issues', () => {
    const getSpy = jest.fn()
    jest
      .spyOn(jest.requireActual('foundation'), 'xhr', 'get')
      .mockReturnValue({
        get: getSpy,
      })
    getService('https://foo.com')
    expect(getSpy).toHaveBeenCalledWith(
      expect.any(String),
      DEFAULT_OPTS,
    )
  })
  it('should pass expected options to xhr', () => {
    const getSpy = jest.fn()
    jest
      .spyOn(jest.requireActual('foundation'), 'xhr', 'get')
      .mockReturnValue({
        get: getSpy,
      })
    const expectedOptions = { foo: 'test_foo', bar: 'test_bar' }
    getService('https://foo.com', expectedOptions)
    expect(getSpy).toHaveBeenCalledWith(
      expect.any(String),
      expectedOptions,
    )
  })
})
