import getServiceUrl, { getParams } from '../getServiceUrl'
import { DEV_HOST, PRD_HOST } from '../constants'

describe('getServiceUrl', () => {
  it('should return expected url if location host is not www.nytimes.com', () => {
    expect(getServiceUrl('www.test.com')).toEqual(DEV_HOST)
  })
  it('should return expected url if location is not provided', () => {
    expect(getServiceUrl()).toEqual(DEV_HOST)
  })
  it('should return expected url if location host is www.nytimes.com', () => {
    expect(getServiceUrl('www.nytimes.com')).toEqual(PRD_HOST)
  })
  it('should return expected search params if params object is passed', () => {
    const expectedAlsRulesTest = 'expectedAlsRulesTest'
    const expectedUri = 'expectedUri'
    const expectedProp = 'expectedProp'
    const expectedPlat = 'expectedPlat'
    const expectedTyp = 'expectedTyp'
    const serviceUrlParams = {
      alice_rules_test: expectedAlsRulesTest,
      uri: expectedUri,
      prop: expectedProp,
      plat: expectedPlat,
      typ: expectedTyp,
    }

    const serviceUrl = getServiceUrl('www.test.com', serviceUrlParams)
    const testUrl = new URL(serviceUrl)
    const testSearch = Object.fromEntries(
      testUrl.searchParams.entries(),
    )
    expect(testSearch).toMatchObject(
      expect.objectContaining(serviceUrlParams),
    )
  })
  describe('getParams', () => {
    it('should return expected value if params are empty', () => {
      expect(getParams({})).toEqual({
        alice_rules_test: null,
        plat: '',
        prop: '',
        typ: '',
        uri: '',
      })
    })
    it('should return expected alice_rules_test search param', () => {
      const expectedParam = 'ALICE_FOO_RULES_BAR_TEST'
      const props = {
        search: `?alice_rules_test=${expectedParam}`,
      }
      expect(getParams(props)).toEqual(
        expect.objectContaining({
          alice_rules_test: expectedParam,
        }),
      )
    })
    it('should join origin and pathname as expected', () => {
      const props = {
        origin: 'FOO',
        pathname: '_BAR',
      }
      expect(getParams(props)).toEqual(
        expect.objectContaining({
          uri: props.origin + props.pathname,
        }),
      )
    })
    it('should pass prop, plat, and typ as expected', () => {
      const props = {
        prop: 'TEST_PROP',
        plat: 'TEST_PLAT',
        typ: 'TEST_TYP',
      }
      expect(getParams(props)).toEqual(
        expect.objectContaining({
          prop: props.prop,
          plat: props.plat,
          typ: props.typ,
        }),
      )
    })
  })
})
