import setAdSlotKVPsFromApi from '../setAdSlotKVPsFromApi'

describe('setAdSlotKVPsFromApi', () => {
  afterEach(() => {
    jest.restoreAllMocks()
  })
  it('should catch as expected if getService rejects', async () => {
    const expectedError = 'TEST_REQUEST_FAILURE_INFO'
    jest
      .spyOn(
        jest.requireActual('../trackImpression'),
        'getRequestFailure',
      )
      .mockReturnValue(expectedError)
    jest
      .spyOn(jest.requireActual('../getService'), 'default')
      .mockRejectedValue(expectedError)

    const trackImpressionSpy = jest
      .spyOn(jest.requireActual('../trackImpression'), 'default')
      .mockImplementation(jest.fn())
    await setAdSlotKVPsFromApi('', '')

    expect(trackImpressionSpy).toHaveBeenCalledWith(expectedError)
  })
  it('should catch as expected if awaitAdSlot rejects', async () => {
    const expectedUri = 'https://foo.bar'

    const expectedValue = jest
      .requireActual('../trackImpression')
      .getRequestFailure(expectedUri)
    jest
      .spyOn(jest.requireActual('../getService'), 'default')
      .mockResolvedValue({})
    jest
      .spyOn(jest.requireActual('../trackResponse'), 'default')
      .mockResolvedValue({})

    jest
      .spyOn(jest.requireActual('../awaitAdSlot'), 'default')
      .mockRejectedValue({})

    const trackImpressionSpy = jest
      .spyOn(jest.requireActual('../trackImpression'), 'default')
      .mockImplementation(jest.fn())
    await setAdSlotKVPsFromApi('', expectedUri)

    expect(trackImpressionSpy).toHaveBeenCalledWith(expectedValue)
  })
  it('should set KVPValues even if local storage fails', async () => {
    const expectedError = new Error('FOO_TEST_BAR_ERROR')
    jest
      .spyOn(jest.requireActual('../getService'), 'default')
      .mockResolvedValue({})
    jest
      .spyOn(jest.requireActual('../awaitAdSlot'), 'default')
      .mockResolvedValue({})
    const setKVPvaluesSpy = jest
      .spyOn(jest.requireActual('../setKVPvalues'), 'default')
      .mockResolvedValue({})
    jest
      .spyOn(
        jest.requireActual('../setLocalStorageValues'),
        'default',
      )
      .mockImplementation(() => {
        return () => Promise.reject(expectedError)
      })

    jest
      .spyOn(jest.requireActual('../trackImpression'), 'default')
      .mockImplementation(jest.fn())
    await setAdSlotKVPsFromApi('', '')

    expect(setKVPvaluesSpy).toHaveBeenCalled()
  })
})
