import setKVPvalues from '../setKVPvalues'
import {
  BT_KEY,
  MKTG_KEY,
  SUB_KEY,
  TEST_CLIENTSIDE_KEY,
} from '../constants'

describe('setKVPValues', () => {
  beforeEach(() => {
    jest.restoreAllMocks()
  })
  it('still resolves with expected data if pubads does not exist', () => {
    // @ts-ignore
    jest.spyOn(global, 'window', 'get').mockReturnValue({
      // @ts-ignore
      AdSlot4: {},
    })
    const data = {
      [BT_KEY]: 'TEST VALUE',
    }

    return expect(setKVPvalues(data)).resolves.toEqual(data)
  })
  it('does not return modified data from data passed in when a valid key exists', () => {
    const updateAdReqSpy = jest.fn()
    // @ts-ignore
    jest.spyOn(global, 'window', 'get').mockReturnValue({
      // @ts-ignore
      AdSlot4: {
        // @ts-ignore
        updateAdReq: updateAdReqSpy,
      },
    })
    const data = {
      [BT_KEY]: 'TEST VALUE',
    }

    return expect(setKVPvalues(data)).resolves.toEqual(data)
  })
  it('set bt targeting on pubads', async () => {
    const updateAdReqSpy = jest.fn()
    // @ts-ignore
    jest.spyOn(global, 'window', 'get').mockReturnValue({
      // @ts-ignore
      AdSlot4: {
        // @ts-ignore
        updateAdReq: updateAdReqSpy,
      },
    })
    const expectedValue = 'TEST_VALUE'
    const data = {
      [BT_KEY]: expectedValue,
    }

    await setKVPvalues(data)
    expect(updateAdReqSpy).toHaveBeenCalledWith(data)
  })
  it('set mktg targeting on pubads', async () => {
    const updateAdReqSpy = jest.fn()
    // @ts-ignore
    jest.spyOn(global, 'window', 'get').mockReturnValue({
      // @ts-ignore
      AdSlot4: {
        // @ts-ignore
        updateAdReq: updateAdReqSpy,
      },
    })
    const expectedValue = 'TEST_VALUE'
    const data = {
      [MKTG_KEY]: expectedValue,
    }

    await setKVPvalues(data)
    expect(updateAdReqSpy).toHaveBeenCalledWith(data)
  })
  it('set sub targeting on pubads', async () => {
    const updateAdReqSpy = jest.fn()
    // @ts-ignore
    jest.spyOn(global, 'window', 'get').mockReturnValue({
      // @ts-ignore
      AdSlot4: {
        // @ts-ignore
        updateAdReq: updateAdReqSpy,
      },
    })
    const expectedValue = 'TEST_VALUE'
    const data = {
      [SUB_KEY]: expectedValue,
    }

    await setKVPvalues(data)
    expect(updateAdReqSpy).toHaveBeenCalledWith(data)
  })
  it('set als_clientside targeting on pubads', async () => {
    const updateAdReqSpy = jest.fn()
    // @ts-ignore
    jest.spyOn(global, 'window', 'get').mockReturnValue({
      // @ts-ignore
      AdSlot4: {
        // @ts-ignore
        updateAdReq: updateAdReqSpy,
      },
    })
    const expectedValue = 'TEST_VALUE'
    const data = {
      [TEST_CLIENTSIDE_KEY]: expectedValue,
    }

    await setKVPvalues(data)
    expect(updateAdReqSpy).toHaveBeenCalledWith(data)
  })
})
