import trackImpression, {
  getBaseTracking,
  getEmptyKeyTracking,
  getMissingKeyTracking,
  getRequestFailure,
} from '../trackImpression'

describe('trackImpression', () => {
  afterEach(() => {
    jest.restoreAllMocks()
  })
  describe('getBaseTracking', () => {
    it('should return expected default values', () => {
      expect(getBaseTracking()).toEqual(
        expect.objectContaining({
          name: 'alice-timing',
          context: 'script-load',
          label: '',
        }),
      )
    })
    it('should return expected values with label', () => {
      const expectedLabel = 'FOO_BAR'
      expect(getBaseTracking({ label: expectedLabel })).toEqual(
        expect.objectContaining({
          name: 'alice-timing',
          context: 'script-load',
          label: expectedLabel,
        }),
      )
    })
  })
  describe('getEmptyKeyTracking', () => {
    it('should return expected label from key param', () => {
      const key = 'FOO'
      const expectedLabel = `alice-error-${key}-undefined`
      expect(getEmptyKeyTracking(key)).toEqual(
        expect.objectContaining({
          name: 'alice-timing',
          context: 'script-load',
          label: expectedLabel,
        }),
      )
    })
    it('should return expected value if no key param', () => {
      expect(getEmptyKeyTracking()).toEqual(undefined)
    })
  })
  describe('getMissingKeyTracking', () => {
    it('should return expected label from key param', () => {
      const key = 'FOO'
      const expectedLabel = `alice-error-${key}-missing`
      expect(getMissingKeyTracking(key)).toEqual(
        expect.objectContaining({
          name: 'alice-timing',
          context: 'script-load',
          label: expectedLabel,
        }),
      )
    })
    it('should return expected value if no key param', () => {
      expect(getMissingKeyTracking()).toEqual(undefined)
    })
  })
  describe('getRequestFailure', () => {
    it('should return expected label from url param', () => {
      const url = 'FOO'
      const expectedLabel = `alice-error-reqfail-${url}`
      expect(getRequestFailure(url)).toEqual(
        expect.objectContaining({
          name: 'alice-timing',
          context: 'script-load',
          label: expectedLabel,
        }),
      )
    })
    it('should return expected value if no key param', () => {
      expect(getRequestFailure()).toEqual(undefined)
    })
  })
  it('should call trackImpression with expected params', () => {
    const expectedName = 'EXPECTED_NAME'
    const expectedContext = 'EXPECTED_NAME'
    const expectedLabel = 'EXPECTED_NAME'

    const foundation = jest.requireActual('foundation')
    const trackSpy = jest
      .spyOn(foundation, 'trackImpression')
      .mockImplementation(jest.fn())

    trackImpression({
      name: expectedName,
      label: expectedLabel,
      context: expectedContext,
    })
    expect(trackSpy).toHaveBeenCalledWith(
      expectedName,
      '',
      expectedLabel,
      expectedContext,
    )
  })
})
