import trackResponse, {
  loopThroughValues,
  trackEmptyValue,
} from '../trackResponse'
import {
  getEmptyKeyTracking,
  getMissingKeyTracking,
} from '../trackImpression'

describe('trackResponse', () => {
  afterEach(() => {
    jest.restoreAllMocks()
  })
  describe('loopThroughValues', () => {
    it('should call cb param if item in obj is not object', () => {
      const testObj = {
        als_test_clientside: '',
      }
      const cbSpy = jest.fn()
      loopThroughValues(testObj, cbSpy as Function)
      expect(cbSpy).toHaveBeenCalledTimes(1)
    })
    it('should return false if obj param is not object', () => {
      const result = loopThroughValues(
        // @ts-ignore
        '',
        jest.fn(),
      )
      expect(result).toEqual(false)
    })
    it('should not call cb param if obj param is not object', () => {
      const cbSpy = jest.fn()
      // @ts-ignore
      loopThroughValues('', cbSpy)
      expect(cbSpy).not.toHaveBeenCalled()
    })
  })
  describe('trackEmptyValue', () => {
    it('should not call trackImpression if value param is truthy', () => {
      const trackImpression = jest.requireActual('../trackImpression')
      const trackSpy = jest.spyOn(trackImpression, 'default')
      trackEmptyValue('foo', 'true')
      expect(trackSpy).not.toHaveBeenCalled()
    })
    it('should not call trackImpression if value param is null', () => {
      const trackImpression = jest.requireActual('../trackImpression')
      const trackSpy = jest.spyOn(trackImpression, 'default')
      trackEmptyValue('foo', null)
      expect(trackSpy).not.toHaveBeenCalled()
    })
    it('should not call trackImpression if value param is undefined', () => {
      const trackImpression = jest.requireActual('../trackImpression')
      const trackSpy = jest.spyOn(trackImpression, 'default')
      trackEmptyValue('foo')
      expect(trackSpy).not.toHaveBeenCalled()
    })
    it('should call trackImpression if value param is empty string', () => {
      const trackImpression = jest.requireActual('../trackImpression')
      const trackSpy = jest.spyOn(trackImpression, 'default')
      trackEmptyValue('foo', '')
      expect(trackSpy).toHaveBeenCalled()
    })
  })
  it('should call trackImpression with expected value if data is missing Asset value', async () => {
    const expectedTrackValue = getMissingKeyTracking('Asset')

    const trackImpression = jest.requireActual('../trackImpression')
    const trackSpy = jest.spyOn(trackImpression, 'default')

    const data = {
      User: {},
    }
    await trackResponse(data)
    expect(trackSpy).toHaveBeenCalledWith(expectedTrackValue)
  })
  it('should call trackImpression with expected value if data is missing User value', async () => {
    const expectedTrackValue = getMissingKeyTracking('User')

    const trackImpression = jest.requireActual('../trackImpression')
    const trackSpy = jest.spyOn(trackImpression, 'default')

    const data = {
      Asset: {},
    }
    await trackResponse(data)
    expect(trackSpy).toHaveBeenCalledWith(expectedTrackValue)
  })
  it('should call trackImpression with expected value if data is missing bt value', async () => {
    const expectedTrackValue = getMissingKeyTracking('bt')

    const trackImpression = jest.requireActual('../trackImpression')
    const trackSpy = jest.spyOn(trackImpression, 'default')

    const data = {
      User: {},
    }
    await trackResponse(data)
    expect(trackSpy).toHaveBeenCalledWith(expectedTrackValue)
  })
  it('should not call trackImpression missing key tracking value if data bt value is empty string', async () => {
    const expectedTrackValue = getMissingKeyTracking('bt')

    const trackImpression = jest.requireActual('../trackImpression')
    const trackSpy = jest.spyOn(trackImpression, 'default')

    const data = {
      User: {
        bt: '',
      },
    }

    await trackResponse(data)
    expect(trackSpy).not.toHaveBeenCalledWith(expectedTrackValue)
  })
  it('should resolve with data initially passed in', () => {
    const data = {
      als_test_clientside: 'FOO',
      Asset: {},
      User: {},
    }

    return expect(trackResponse(data)).resolves.toEqual(data)
  })
})
