import { trackImpression } from 'foundation'

import { isObject } from './utils'

type TrackingData = {
  name: string
  label?: string[] | string | null
  context?: string
}
export const getBaseTracking = (
  { label }: { label: string } | undefined = { label: '' },
): TrackingData => ({
  name: 'alice-timing',
  context: 'script-load',
  label,
})
export const getMissingKeyTracking = (
  key?: string,
): TrackingData | undefined =>
  key
    ? getBaseTracking({ label: `alice-error-${key}-missing` })
    : undefined
export const getEmptyKeyTracking = (
  key?: string,
): TrackingData | undefined =>
  key
    ? getBaseTracking({ label: `alice-error-${key}-undefined` })
    : undefined
export const getRequestFailure = (
  url?: string,
): TrackingData | undefined =>
  url
    ? getBaseTracking({ label: `alice-error-reqfail-${url}` })
    : undefined

export default (obj?: TrackingData) => {
  if (obj && isObject(obj)) {
    const { name, context, label } = obj
    trackImpression(name, '', label, context)
  } else {
    return false
  }
}
