import { ALSData } from './constants'
import trackImpression, {
  getEmptyKeyTracking,
  getMissingKeyTracking,
} from './trackImpression'
import { isObject } from './utils'

export const loopThroughValues = (
  obj: ALSData,
  cb: Function,
): void | boolean => {
  if (!isObject(obj)) return false
  Object.entries(obj).forEach(([key, value]) => {
    if (isObject(value)) {
      loopThroughValues(value, cb)
    } else {
      cb(key, value)
    }
  })
}

export const trackEmptyValue = (
  key: string,
  value?: string | null,
) => {
  if (value === '') {
    trackImpression(getEmptyKeyTracking(key))
  }
}

export default (data: ALSData): Promise<ALSData> => {
  const { Asset, User } = data

  if (!Asset) {
    trackImpression(getMissingKeyTracking('Asset'))
  }

  if (!User) {
    trackImpression(getMissingKeyTracking('User'))
  } else {
    const { bt } = User
    if (bt == null) {
      trackImpression(getMissingKeyTracking('bt'))
    }
  }

  loopThroughValues(data, trackEmptyValue)

  return Promise.resolve(data)
}
