import sov from './kvps/sov'
import getAbraDFPTests from './getAbraDFPTests'

const getAbra = () => window.abra || {}

export function formatCustParams(params) {
  const validKeyList = Object.keys(params).filter(
    (key) => !!params[key],
  )

  const validParamList = validKeyList.map(
    (key) => `${key}%3D${params[key]}`,
  )

  return validParamList.join('%26')
}

const DEFAULT_PARAM_VALUE = 'DEFAULT_VALUE'

const dynamicBaseParams = {
  url: DEFAULT_PARAM_VALUE,
}

const baseParams = {
  output: 'xml_vast4',
  gdfp_req: 1,
  sz: '480x360|480x361|640x480',
  slotname: '29390238/nyt/games',
  env: 'vp',
  cmsid: '1958',
  video_doc_id: '100000008266794',
  vpos: 'preroll',
  ...dynamicBaseParams,
}

const dynamicBaseCustParams = {
  plat: DEFAULT_PARAM_VALUE,
  prop: DEFAULT_PARAM_VALUE,
  // adv: DEFAULT_PARAM_VALUE,
  abra_dfp: DEFAULT_PARAM_VALUE,
  sub: DEFAULT_PARAM_VALUE,
  uap: DEFAULT_PARAM_VALUE,
  vp: DEFAULT_PARAM_VALUE,
  sov: DEFAULT_PARAM_VALUE,
  purr: DEFAULT_PARAM_VALUE,
  // npa: DEFAULT_PARAM_VALUE,
  // rdp: DEFAULT_PARAM_VALUE,
  page_view_id: DEFAULT_PARAM_VALUE,
}

const baseCustParams = {
  autoplay: 'no',
  pos: 'vidh',
  typ: 'games',
  viddur: 'medium',
  videoser: '',
  viddes: '',
  ...dynamicBaseCustParams,
}

const checkForDefaults = (
  obj,
  warningMessagingPrefix = '',
  suppressWarning = false,
) => {
  if (!suppressWarning) {
    Object.entries(obj).forEach((entry) => {
      if (entry[1] === DEFAULT_PARAM_VALUE) {
        console.warn(
          `${warningMessagingPrefix} :: ADTARGETING WARNING :: ${entry[0]} IS NOT SET`,
        )
      }
    })
  }

  return obj
}

const populateAdTargetingData = ({
  cust_params = {},
  ...targeting
} = {}) => {
  const baseObj = checkForDefaults({
    ...baseParams,
    ...targeting,
  })

  const custParams = checkForDefaults({
    ...baseCustParams,
    ...cust_params,
    sov,
    abra_dfp: getAbraDFPTests(getAbra().tests, cust_params.abra_dfp),
  })

  return {
    ...baseObj,
    cust_params: formatCustParams(custParams),
  }
}

export default (targetingParams) => {
  return populateAdTargetingData(targetingParams)
}
