export type AdSize = 'fluid' | [number, number]
export type AdSizeMapping = [number, AdSize[]]
const FLUID_SIZE = 'fluid'

export const MOBILE_INTERSTITIAL_SIZES: AdSizeMapping[] = [
  [0, [FLUID_SIZE, [300, 250], [300, 600]]],
]

export const MOBILE_INTERSTITIAL_SIZES_SHORT: AdSizeMapping[] = [
  [0, [FLUID_SIZE, [300, 250]]],
]

// 600px for the creative height, 76px for the continue button, 36px for
// ad slug top, 24px for ad slug bottom
const SHORT_SCREEN_CUTOFF = 735

export const DEFAULT_SIZES: AdSizeMapping[] = [
  [990, [FLUID_SIZE, [728, 90], [970, 90], [970, 250], [1605, 300]]],
  [750, [FLUID_SIZE, [728, 90], [1605, 300]]],
  [0, [FLUID_SIZE, [300, 250], [300, 420]]],
]

export default (
  path: string = 'default',
  viewportHeight: number = 736,
): Record<string, AdSizeMapping[]> => {
  // check if we have anything based on our path, otherwise we'll use the default
  if (path === 'wordle') {
    return {
      default: DEFAULT_SIZES,
      intsl:
        viewportHeight > SHORT_SCREEN_CUTOFF
          ? MOBILE_INTERSTITIAL_SIZES
          : MOBILE_INTERSTITIAL_SIZES_SHORT,
    }
  }

  return {
    default: DEFAULT_SIZES,
  }
}
