import { env } from './util'
import inView from './inView'
import { xhr } from './xhr'
import {
  trackComplianceClick,
  trackComplianceImpression,
} from './ccpa.utils' // CCPA Privacy compliance

const PURR_API =
  env.name === 'prod'
    ? 'https://purr.nytimes.com'
    : 'https://purr.dev.nytimes.com'

// Make a call to the PURR cache on every pageview.
xhr.get(`${PURR_API}/v1/purr-cache`)

export const ccpa = () => {
  if (window.ccpa) {
    return
  }

  let ccpaLinks: HTMLElement[]

  /**
   * Many Wordle players are playing on iOS devices too old
   * to support spread operators on objects
   */
  try {
    ccpaLinks = [
      ...document.querySelectorAll('.ccpa-link'),
    ] as HTMLElement[]
  } catch (e) {
    return
  }

  ccpaLinks.forEach((el) => {
    el.addEventListener('click', trackComplianceClick)
    inView(el, trackComplianceImpression)
  })

  window.ccpa = true
}

export default ccpa
