import { track } from './tracking'

const modules: Record<string, string> = {
  linkCANotice: 'california notices link',
  linkOptOut: 'DNSS opt-out link',
}

const exposed: Record<string, boolean> = {}

export const trackComplianceClick = (e: Event) => {
  const domElement = e.target as HTMLAnchorElement
  const region = domElement.getAttribute('data-region') || ''
  const name = domElement.getAttribute('data-track') || ''
  const label =
    domElement.getAttribute('data-label') || domElement.textContent

  track('moduleInteraction', {
    eventData: {
      pagetype: 'game',
      trigger: 'module',
      type: 'click',
    },
    module: {
      name: modules[name],
      label,
      region,
    },
  })
}

export const trackComplianceImpression = (
  e: IntersectionObserverEntry,
) => {
  const region = e.target.getAttribute('data-region') || ''
  const name = e.target.getAttribute('data-track') || ''
  const label = e.target.textContent

  if (!exposed[`${region}-${name}`]) {
    track('impression', {
      module: {
        name: modules[name],
        label,
        region,
      },
    })

    exposed[`${region}-${name}`] = true
  }
}
