import { isMobile } from 'responsive'

import { makeAsyncValue } from './util'
import { localStore, win, doc } from './aliases'
import { xhr } from './xhr'

const globalNavigator = win.navigator

export const device = makeAsyncValue<{ feedback: string }>(
  () => xhr.get('/puzzles/device'), // initialize by fetching from web app
  localStore, // store this in local storage
  'pz-device', // use this key
  globalNavigator.userAgent, // invalidate if this value changes (ie emulating a device)
)

// With the introduction of iOS 13, iPads have "Always request desktop site"
// turned on by default, which breaks MobileDetect. This is a temporary
// workaround.

// Edit 12/08/23: This temporary workaround is four years old, and it seems all games are accustomed to this
// behavior. The long-term solution is to move games to cache safe components that do detection client side.
// That will remove the need for this.
export const ipadCheck = () => {
  if (
    !win.isCacheSafe && // For cache safe games that are not vertex, skip this logic
    !isMobile &&
    (/iPad/.test(globalNavigator.platform) ||
      (globalNavigator.platform === 'MacIntel' &&
        globalNavigator.maxTouchPoints > 1))
  ) {
    doc.cookie = 'inferredIpad=true;domain=nytimes.com;'
    win.location.reload()
  }
}
