import { doc } from './aliases'

export interface HTMLElementWithEvents extends HTMLElement {
  events: { [key: string]: string }
}

// @see http://youmightnotneedjquery.com/
// im going out on a limb and guessing we
// will be fine without the ie9 tricks
// but they are split out so we can add it in
// (and for mangling)
export function addClass(
  elm: HTMLElement | Element,
  className: string,
) {
  if (elm === null) {
    return
  }
  elm.classList.add(className)
}

export function removeClass(elm: HTMLElement, className: string) {
  if (elm === null) {
    return
  }
  elm.classList.remove(className)
}

export function toggleClass(elm: HTMLElement, className: string) {
  elm.classList.toggle(className)
}

export function getAttribute(elm: HTMLElement, attr: string) {
  return elm.getAttribute(attr)
}

export function setAttribute(
  elm: HTMLElement,
  attr: string,
  value: string,
) {
  elm.setAttribute(attr, value)
}

export function addEventListener(
  elm: HTMLElement | Element | Window,
  eventName: string,
  listener: EventListenerOrEventListenerObject,
  passiveOptions?: boolean | AddEventListenerOptions | undefined,
) {
  elm.addEventListener(eventName, listener, passiveOptions)
}

export function setInnerHtml(elm: HTMLElement, innerHtml: string) {
  elm.innerHTML = innerHtml
}

export function getElementById(id: string) {
  return doc.getElementById(id)
}

export function querySelector(query: string) {
  return doc.querySelector(query)
}

export function appendChild(
  parent: HTMLElement,
  child: HTMLElement | Text,
) {
  parent.appendChild(child)
}

export function removeChildren(node: HTMLElement) {
  while (node.children.length) {
    node.removeChild(node.children[0])
  }
}

export function mountNode(
  parentNode: HTMLElement,
  childNode: HTMLElement,
) {
  removeChildren(parentNode)
  appendChild(parentNode, childNode)
}

export function mountNodeList(
  parentNode: HTMLElement,
  childNodes: HTMLElement[],
) {
  removeChildren(parentNode)
  childNodes.forEach((childNode) => {
    appendChild(parentNode, childNode)
  })
}

// createNode
// a sort of super dumb version of node creation
// that does not assume you want to update or do any vdom stuff
// that ignores edge cases such as svg
// if we want to do more, I think we should consider including hyperapp
// as it is only 1k (also some of the tricks here come from hyperapp source)

// NOTE: many pieces of this come from https://github.com/hyperapp/hyperapp/blob/master/src/index.js

function eventListener(event: Event) {
  // @ts-ignore not worth it making the complex recursive type, here
  return event.currentTarget?.events[event.type](event)
}

export function createNode(
  nodeName: string,
  attributes: Record<string, any>,
  innerText?: string,
) {
  const element = doc.createElement(nodeName) as HTMLElementWithEvents

  if (innerText) appendChild(element, doc.createTextNode(innerText))

  Object.keys(attributes).forEach((name) => {
    const value = attributes[name]
    if (name[0] === 'o' && name[1] === 'n') {
      const newName = name.slice(2).toLowerCase()

      if (!element.events) element.events = {}
      element.events[newName] = value

      addEventListener(element, newName, eventListener)
    } else if (value != null && value !== false) {
      element.setAttribute(name, value)
    }
  })

  return element
}
