import { getFidesSnippet } from '@nyt/fides'

import { parsePurrCookieValue } from './parsePurrCookieValue'
import { win } from './aliases'
import { abra } from './abra'

const appendFidesScript = (src: string) => {
  const script = document.createElement('script')
  script.type = 'text/javascript'
  script.innerHTML = src

  document.body.appendChild(script)
}

// taken from ClientSideScripts/index.js
const appendGdprScript = (src: string) => {
  const script = document.createElement('script')

  script.src = src
  script.async = true

  document.body.appendChild(script)
}

export const initializeGdpr = () => {
  const fidesVariant = 'GAMES_fidesIntegration_1109'
  const fidesAbraEnabled =
    abra.getVariant(fidesVariant) === '1_Enabled'

  const directives = parsePurrCookieValue()
  const fidesPurrEnabled = directives.PURR_FidesTCF === 'show'

  const fidesEnabled =
    !win.isHybridWebView && fidesAbraEnabled && fidesPurrEnabled

  if (fidesEnabled) {
    appendFidesScript(getFidesSnippet())
  } else if (!win.isHybridWebView) {
    appendGdprScript(
      'https://www.nytimes.com/games-assets/gdpr/cookie-notice-v2.1.4.min.js',
    )
  }
}
