import { meetsMinimumVersion } from '../detection'

describe('HYBRID: Detection', () => {
  describe('meetsMinimumVersion', () => {
    it('returns true if the app version is equal to the minimum requirement', () => {
      expect(meetsMinimumVersion('4.23.1', '4.23.1')).toBe(true)
    })

    it('returns true if the app version has a greater minor version than the minimum requirement', () => {
      expect(meetsMinimumVersion('4.24.1', '4.23.19')).toBe(true)
    })

    it('returns true if the app version has a greater major version than the minimum requirement', () => {
      expect(meetsMinimumVersion('5.0.9', '4.23.1')).toBe(true)
    })

    it('returns false if the app version has a lesser minor version than the minimum requirement', () => {
      expect(meetsMinimumVersion('4.21.13', '4.23.21')).toBe(false)
    })

    it('returns false if the app version has a lesser major version than the minimum requirement', () => {
      expect(meetsMinimumVersion('3.51.13', '4.23.21')).toBe(false)
    })

    it('returns false if the app version is an empty string', () => {
      expect(meetsMinimumVersion('', '4.23')).toBe(false)
    })

    it('returns false if the app version does not supply both major and minor versions', () => {
      expect(meetsMinimumVersion('4', '4.23')).toBe(false)
    })

    it('returns true if the app version does not supply both major and minor versions, but the major version is higher', () => {
      expect(meetsMinimumVersion('5', '4.23')).toBe(true)
    })

    it('returns false if the app version is an empty string', () => {
      expect(meetsMinimumVersion('', '4.23')).toBe(false)
    })

    it('returns false if the app version has no numbers but can be split by a .', () => {
      expect(meetsMinimumVersion('.', '4.23')).toBe(false)
    })

    it('returns false if the app version is just nonsense', () => {
      expect(
        meetsMinimumVersion(
          'the quick brown fox jumps over the lazy invalid version',
          '4.23',
        ),
      ).toBe(false)
    })
  })
})
