import initBridge from '../initBridge'
import { bridgeCommands, COMMAND_BACK_TO_HUB } from '../commands'

const mockConfig = {
  foo: 'bar',
}

jest.mock('@nyt/native-bridge', () => ({
  initNativeBridge: jest.fn(() => ({
    callNativeBridgeCommand: jest.fn((command) => {
      return Promise.resolve()
    }),
  })),
}))

describe('NATIVE BRIDGE: Bridge Initialization', () => {
  window.navigator = {}
  window.newsreaderAppPlatform = 'android'

  initBridge()

  it('defines the list of bridge commands on the window', () => {
    expect(
      Object.keys(window.navigator.native.bridgeCommands).sort(),
    ).toEqual(bridgeCommands.sort())
  })

  it('enables all of the bridge commands', () => {
    // eslint-disable-next-line
    for (const key in window.navigator.native.bridgeCommands) {
      expect(
        window.navigator.native.bridgeCommands[key].enabled,
      ).toBe(true)
    }
  })

  it('implements the list of bridge commands on the NativeBridge object', () => {
    // eslint-disable-next-line
    bridgeCommands.forEach((command) => {
      expect(window.NativeBridge[command]).toBeDefined()
    })
  })

  it('NativeBridge commands dispatch to the @nyt/native-bridge command function', () => {
    window.NativeBridge.gamesBackToHub()
    expect(
      window.NativeBridge.callNativeBridgeCommand,
    ).toBeCalledWith(COMMAND_BACK_TO_HUB)
  })
})
