/**
 * Provides a function which adds debug statements to an array on the window.
 * This enables developers to see what happened before the Safari dev tools
 * were enabled. MAX_DEBUG_SIZE prevents memory leak.
 */
const createDebugger = function () {
  window.hybridDebug = window.hybridDebug || []

  const MAX_DEBUG_SIZE = 30

  return (message: string, args?: any[], response?: any) => {
    if (window.hybridDebug.length > MAX_DEBUG_SIZE) {
      window.hybridDebug.pop()
    }
    window.hybridDebug.unshift({ message, args, response })
  }
}

export default createDebugger()
