import { win } from './aliases'

const VIEWER_KEY = '__viewers__'

// from: https://github.com/w3c/IntersectionObserver/blob/master/polyfill/intersection-observer.js
if (
  'IntersectionObserver' in win &&
  'IntersectionObserverEntry' in win &&
  'intersectionRatio' in win.IntersectionObserverEntry.prototype
) {
  // Minimal polyfill for Edge 15's lack of `isIntersecting`
  // See: https://github.com/w3c/IntersectionObserver/issues/211
  if (
    !('isIntersecting' in win.IntersectionObserverEntry.prototype)
  ) {
    Object.defineProperty(
      win.IntersectionObserverEntry.prototype,
      'isIntersecting',
      {
        get() {
          return this.intersectionRatio > 0
        },
      },
    )
  }

  win.__observeInView__ = true
}

type IntersectionObserverCallback = (
  entry: IntersectionObserverEntry,
) => void
type ElementWithViewers = Element & {
  [VIEWER_KEY]?: Array<IntersectionObserverCallback>
}

/**
 * Setup a Intersection observer to track all elements
 */
let observer: IntersectionObserver
const setupObserver = () => {
  observer = new win.IntersectionObserver(
    (entries) => {
      entries.forEach((entry) => {
        if (entry.isIntersecting) {
          (entry.target as ElementWithViewers)[VIEWER_KEY]?.forEach(
            (cb) => cb(entry),
          )
        }
      })
    },
    {
      threshold: 0.4,
    },
  )
}

const inView = (
  elm: ElementWithViewers,
  cb: IntersectionObserverCallback,
) => {
  if (window.__observeInView__) {
    if (!observer) setupObserver()

    if (elm[VIEWER_KEY]) {
      elm[VIEWER_KEY]?.push(cb)
    } else {
      elm[VIEWER_KEY] = [cb]
      observer.observe(elm)
    }
  }
}

export default inView
