export type PurrDirectiveHeader = {
  PURR_DataSaleOptOutUI_v2: {
    index: 7
    values: {
      h: 'hide'
      s: 'show'
      o: 'show-opted-out'
    }
    default: 'hide'
    queryParam: 'opt-out'
  }
  PURR_CaliforniaNoticesUI: {
    index: 8
    values: {
      h: 'hide'
      s: 'show'
    }
    default: 'hide'
    queryParam: 'california-notices'
  }
  PURR_AdConfiguration_v3: {
    index: 11
    values: {
      f: 'full'
      r: 'rdp'
      n: 'npa'
      s: 'adluce-socrates'
      l: 'ltd'
    }
    default: 'full'
    queryParam: 'ad-config'
  }
  PURR_LimitSensitivePI: {
    index: 12
    values: {
      h: 'hide'
      s: 'show'
    }
    default: 'hide'
    queryParam: 'limit-sensitive-information'
  }
  PURR_TOSBlocker_v1: {
    index: 15
    values: {
      h: 'hide'
      s: 'show'
    }
    default: 'hide'
    queryParam: 'tos-blocker'
  }
  PURR_FidesTCF: {
    index: 16
    values: {
      h: 'hide'
      s: 'show'
    }
    default: 'hide'
    queryParam: 'fides-tcf'
  }
}

export const findPurrCookieValue = () => {
  let purrCookieValue
  if (document.cookie.indexOf('nyt-purr') > -1) {
    purrCookieValue = document.cookie
      .split('; ')
      .find((row) => row.startsWith('nyt-purr='))
      ?.split('=')[1]
  }

  return purrCookieValue
}

export const searchToObject = () => {
  const pairs = window.location.search.substring(1).split('&')

  // eslint-disable-next-line prefer-const
  let obj: { [key: string]: string } = {}
  let pair

  pairs.forEach((pairs) => {
    pair = pairs.split('=')
    obj[decodeURIComponent(pair[0])] = decodeURIComponent(
      pair[1] || '',
    )
  })

  return obj
}

type PurrDirectiveHeaderValues =
  | { h: 'hide'; s: 'show'; o: 'show-opted-out' }
  | { h: 'hide'; s: 'show' }
  | { f: 'full'; r: 'rdp'; n: 'npa'; s: 'adluce-socrates'; l: 'ltd' }

export const parsePurrCookieValue = () => {
  const header = findPurrCookieValue()
  window.purrDirectives = {}
  return Object.keys(window.purrDirectiveFormat).reduce(
    (ds, key) => {
      const directive =
        window.purrDirectiveFormat[key as keyof PurrDirectiveHeader]

      try {
        const query = searchToObject()

        const value =
          query[directive.queryParam] ||
          directive.values[
            // @ts-ignore
            header[directive.index] as keyof PurrDirectiveHeaderValues
          ]

        if (window.purrDirectives) window.purrDirectives[key] = value

        return {
          ...ds,
          [key]: value,
        }
      } catch (e) {
        if (window.purrDirectives) {
          window.purrDirectives[key] = directive.default
        }

        return {
          ...ds,
          [key]: directive.default,
        }
      }
    },
    {
      PURR_DataSaleOptOutUI_v2: 'hide',
      PURR_CaliforniaNoticesUI: 'hide',
      PURR_AdConfiguration_v3: 'full',
      PURR_LimitSensitivePI: 'hide',
      PURR_TOSBlocker_v1: 'hide',
      PURR_FidesTCF: 'hide',
    },
  )
}
