/**
 * SENTRY OUTBOUND FILTER
 *
 * This file contains the filter applied to all Sentry events *before* they are transmitted.
 *
 * When a noisy issue has been identified, please add the error message to the ignoreErrors
 * array. This helps keep our Sentry usage down and minimizes the network calls our users make
 * during gameplay.
 */

/**
 * An array containing strings which are used by the Sentry SDK outbound filter. An includes() is
 * performed with these values which means *these strings are case sensitive*
 *
 * Add a portion of an error message string here if you wish for it to be filtered before being sent to Sentry.
 */
export const ignoreErrors: (string | RegExp)[] = [
  /**
   * AD AND TRACKING RELATED ERRORS
   * These words are commonly found in noisy errors related to ads or tracking
   */
  'amazon-adsystem',
  'ads-us',
  'amp4ads',
  'pubads',
  'prebid',
  '2mdn',
  'ampproject',
  'chartbeat',
  'gsi',
  'bk_addPageCtx',
  'yimg',
  'BOOMR',
  'boomerang',
  'gtm',
  'google_tag_manager',
  'scorecardresearch',
  "('video')[0].childNodes",
  'webkitExitFullScreen',
  'ORA',
  'Event Tracker',
  'ceCurrentVideo.currentTime',
  '_pageTimings',
  "Unexpected token '<'",
  'Options is missing a key',
  "reading 'campaign'",
  'setConfig is not a function', // jkidd
  'kdmw', // moat
  'sourceAgnosticCreativeId', // doubleclick
  'slot.getResponseInformation', // something from gpt.js

  /**
   * BROWSER EXTENSTIONS
   * Occasionally users play our games with browser extensions that can sometimes be noisy
   */
  'safari-extension',
  'safari-web-extension',
  'moz-extension',
  'chrome-extension',

  /**
   * LIBRARY ERRORS
   * Errors thrown from libraries we use
   */
  'promiseReactionJob',
  'setIOSParameters',
  'onInitNativeAds',
  'adsDisabled',
  'messageHandlers',
  'isNil',
  'Object.fromEntries is not a function',
  'SymBrowser_ModifyWindowOpenWithTarget',
  'unknownParameters',
  'safari.pushNotification',

  /**
   * NETWORK ERRORS
   * Errors related to intermittent connections during gameplay or temporarily down endpoints.
   */
  'bad req',
  'No Internet',
  'Failed to fetch',
  'Load failed',
  'timed out',
  'Something went wrong',
  // These will usually get picked up by Datadog first, so no need to duplicate alerting
  'failed to process puzzle', // LetterBoxed and Vertex puzzles endpoint are down
  'SUDOKU FAILED', // Sudoku puzzle data failed to fetch

  /**
   * OTHER ERRORS
   * Things that are noisy that seem unrelated or we just need to temporarily mute.
   */
  'Illegal invocation', // Noisy.
  'No root config found',
  'webkit-masked-url',
  /share/i, // When users cancel sharing their Wordle and Connections scores
  'feature toggles accessed before being set',
  'Non-Error promise rejection captured',
  'QuotaExceededError', // Local storage full or corrupted
  /database/i, // Crossword local saves with indexeddb sometimes fail
]

/**
 * Tells Sentry to only transmit errors that originate from scrpts with this url pattern
 */
export const allowUrls: (string | RegExp)[] = [
  /^https:\/\/(www|local)\.(stg\.)?nytimes\.com/,
]
