import * as Sentry from '@sentry/react'

import { SentryConfig } from '../../window'

import { ignoreErrors, allowUrls } from './filter'
import {
  HybridMetaData,
  NoiseFilter,
  OfflineLogger,
  RouteSampler,
} from './integrations'

/**
 * Initialize Sentry on the client side
 *
 * @param {object} config
 * @param {string} config.dsn The DSN for games-phoenix project in Sentry
 * @param {string} config.release The commit hash of this build.
 * @param {number} config.sampleRate The rate of events to send to Sentry (0-1)
 * @param {string} config.environment The environment tag for the events this session
 */
const initSentry = (config: SentryConfig) => {
  const { dsn, release, environment, sampleRate } = config

  if (sampleRate) {
    Sentry.init({
      dsn,
      release,
      environment,
      ignoreErrors,
      allowUrls,
      maxBreadcrumbs: 70,
      sampleRate,
      tracesSampleRate: sampleRate,
      integrations: [
        new Sentry.BrowserTracing(),
        new NoiseFilter(),
        new HybridMetaData(),
        new OfflineLogger(),
        new RouteSampler({ sampleRate, environment }),
      ],
    })
  }
}

export default initSentry
export * from './filter'
export * from './utils'
