import * as Sentry from '@sentry/react'
import type { Integration } from '@sentry/types'

/**
 * A Sentry custom integration that sets context and tag data for the session.
 * This data is necessary to determine which errors are affecting specific apps
 * and platforms.
 */
export class HybridMetaData implements Integration {
  static id = 'HybridMetaData'

  name = 'HybridMetaData'

  setupOnce = () => {
    // Add hybrid data about the user
    Sentry.setContext('hybrid', {
      isHybridWebView: window.isHybridWebView,
      newsreaderAppPlatform: window.newsreaderAppPlatform,
      gamesAppPlatform: window.gamesAppPlatform,
      isPlayTab: window.isPlayTab,
    })

    // Set hybrid tags to allow easy filtering of hybrid-only events
    if (window.isHybridWebView) {
      Sentry.setTag('hybrid', true)
    }

    // Set app tag if the user is in an app
    if (window.newsreaderAppPlatform || window.gamesAppPlatform) {
      const app = window.newsreaderAppPlatform
        ? `newsreader-${window.newsreaderAppPlatform}`
        : `games-${window.gamesAppPlatform}`
      Sentry.setTag('app', app)
    } else {
      Sentry.setTag('app', 'web')
    }
  }
}
