import * as Sentry from '@sentry/react'
import type { Integration } from '@sentry/types'

/**
 * A Sentry custom integration that applies breadcrumbs to the session
 * whenever a user loses and regains their internet connection. This additional
 * metadata helps engineers determine which errors may be caused by intermittent
 * connections.
 */
export class OfflineLogger implements Integration {
  static id = 'OfflineLogger'

  name = 'OfflineLogger'

  setupOnce = () => {
    // Send a Sentry breadcrumb if the user loses connection
    window.addEventListener('offline', () => {
      Sentry.addBreadcrumb({
        message: 'The user has gone offline',
        level: 'warning',
      })
    })

    // Send a Sentry breadcrumb if the user loses connection
    window.addEventListener('online', () => {
      Sentry.addBreadcrumb({
        message: 'The user has returned online',
        level: 'warning',
      })
    })
  }
}
