import { AdSlotPubSubType } from './js/ads/adTracking/constants'
import { AdSizeMapping } from './js/ads/getSizeMappings'
import { GamesNativeBridge } from './js/hybrid/commands'
import { PurrDirectiveHeader } from './js/parsePurrCookieValue'

export type SentryConfig = {
  dsn?: string
  release: string
  sampleRate?: number
  environment: string
}

export type UserEntitlement =
  | 'anon' // logged out user
  | 'sub' // news subscriber (digital subscription but no games access)
  | 'cr' // crossword subscriber
  | 'reg' // registered, unsubscribed user
  | 'sub,cr' // all digital access subscriber
  | 'anon,sub' // anonymous subscriber (signed up via app)

export type UserType = {
  isLoggedIn: boolean
  hasXwd: boolean
  hasDigi: boolean
  hasHd: boolean
  inShortzMode: boolean
  entitlement: UserEntitlement
  regiId: string | null
  isFreeTrial?: boolean // Only available for app users
}

export type AbraRules = Record<
  string,
  number | Record<string, Array<AbraRules | string | number>>
>

export type AbraParams = {
  regi_id?: string | null
  agent_id?: string | null
  geo_country?: string | null
}

export type AbraTests = {
  [key: string]: string | null
}

export type AbraGetVariantFn = (test: string) => string | null

export type AbraExposeFn = (test: string) => void

export type HybridConfig = {
  OS: string
  AbraConfig: AbraTests
  userInfo: {
    agentID: string
    entitlements?: string[]
    regiId?: string
  }
}

export type GamesGetUserDetailsResponse = {
  id: string
  success: boolean
  values: {
    gamesGetUserDetails: {
      isUserLoggedIn: boolean
      isSubscribed: boolean
      regiID: string
      nytsCookie?: string
      isFreeTrial?: boolean
    }
  }
  error?: string
}

declare global {
  interface Window {
    __REDUX_DEVTOOLS_EXTENSION__?: any
    __observeInView__?: boolean
    Abra: (
      rules: AbraRules,
      params: AbraParams,
      overrides?: AbraTests,
    ) => AbraGetVariantFn
    abra: {
      config?: AbraRules
      getVariant?: AbraGetVariantFn
      tests: AbraTests
    }
    AdSlot4?: {
      props?: {
        adUnitPath?: string
      }
      cmd: Array<() => void>
      loadScripts?: (opts: {
        pageType: string
        section: string
        loadAmazon?: boolean
        loadPrebid?: boolean
        setFastFetch?: boolean
      }) => void
      initializeAd?: (
        element: HTMLDivElement,
        params: { id: string; position: string; adUnitPath?: string },
      ) => void
      updateAdReq?: (adReq: object, id?: string) => void
      getAdReq?: () => object
      init: (opts: {
        adTargeting: { [key: string]: string }
        adUnitPath: string
        sizeMapping: Record<string, AdSizeMapping[]>
      }) => void
      events: AdSlotPubSubType
      refreshAds: () => void
    }
    adUnitPath?: string
    asset?: { uri: string }
    cheat?: (limit?: number) => void
    config?: HybridConfig
    dataLayer: Array<{
      event: string
      eventData?: {
        trigger: string
        type: string
      }
      'gtm.start'?: number
      abtest?: {
        test: string
        variant: string | null
        config_ver: string | null
        integration: string
      }
      module?: {
        context: any
        name: [string] | string
        element: {
          label: string
          name: string
        }
      }
    }>
    DocumentTouch?: any
    env: {
      account: string
      api: string
      edge: string
      moogle: string
      gtm: string
      hostname: string
      meter: string
      name: string
      tagx: string
      version: string
      samizdat: {
        host: string
        appType: string
        appVersion: string
        token: string
      }
    }
    featureFlags: { [key: string]: boolean }
    gameData?: any
    hybridConfig?: HybridConfig
    isAndroidDevice?: boolean
    isHybridWebView?: boolean
    isMobileDevice?: boolean
    isIOSDevice?: boolean
    isPlayTab?: boolean
    isCacheSafe?: boolean
    navigationLinks: {
      subscribe: { [key: string]: any }
      login: string
      [key: string]: any
    }
    newsreaderAppPlatform: 'ios' | 'android' | ''
    newsreaderAppVersion: string
    nyt_et?: (event: {
      [key: string]: string | { [key: string]: any }
    }) => void
    gamesAppPlatform: 'ios' | 'android' | ''
    gamesAppVersion: string
    NativeBridge?: GamesNativeBridge
    NYTG: {
      enqueue: (command: string) => void
      onCommandResult: <T>(result: T) => void
    }
    opera?: {}
    pageName?: string
    purrDirectives?: {
      [key: string]: string
    }
    // @ts-ignore:next-line
    requestIdleCallback: (callback: () => void, options?: any) => void
    reset?: () => void
    resetProgressComplete?: boolean
    safari?: {
      pushNotification: any
    }
    sentryConfig: SentryConfig
    SIMULATE_OFFLINE?: boolean
    userQueryXHR: XMLHttpRequest | null
    anonEntitlementXHR: XMLHttpRequest | null
    userType: UserType
    purrDirectiveFormat: PurrDirectiveHeader
    hybridDebug: any[]
    ccpa: boolean
  }

  interface Navigator {
    native: {
      bridgeCommands: Record<string, { enabled: boolean }>
    }
    // @ts-ignore
    canShare: (msg: { text: string }) => boolean
  }
}
