import React from 'react'
import pt from 'prop-types'
import { connect } from 'react-redux'
import cn from 'classnames'

import SponsoredCard from 'hub/SponsoredCard/SponsoredCard'
import PromoCard from 'hub/PromoCard/PromoCard'
import SecondaryCard from 'hub/SecondaryCard'
import { getIsMoarGamesVariant } from 'hub/store/selectors'
import { MONTHLY_BONUS } from 'hub/track/constants'

const Titled = ({ title, children, isMoarGamesVariant }) => (
  <div
    className={cn('alternate-card-phone', {
      'moar-games-variant': isMoarGamesVariant,
    })}
  >
    <h2 className="hub-welcome__title">{title}</h2>
    {children}
  </div>
)

const AlternateCardPhone = ({
  sponsorship,
  user,
  isMoarGamesVariant,
}) => {
  if (sponsorship) {
    return (
      <Titled
        title="Sponsored Puzzle"
        isMoarGamesVariant={isMoarGamesVariant}
      >
        <SponsoredCard
          puzzleCollection="promoPuzzle"
          sponsorship={sponsorship}
        />
      </Titled>
    )
  }

  if (user.hasXwd) {
    return (
      <Titled
        title="Monthly Bonus"
        isMoarGamesVariant={isMoarGamesVariant}
      >
        <div
          className="js-hub-tracker"
          data-track-hub={MONTHLY_BONUS}
          role="button"
          tabIndex={0}
        >
          <SecondaryCard puzzleCollection="bonusPuzzle" />
        </div>
      </Titled>
    )
  }

  return (
    <Titled
      title="More Games"
      isMoarGamesVariant={isMoarGamesVariant}
    >
      <PromoCard />
    </Titled>
  )
}

Titled.propTypes = {
  title: pt.string,
  children: pt.node,
  isMoarGamesVariant: pt.bool,
}

AlternateCardPhone.propTypes = {
  user: pt.shape({
    hasXwd: pt.bool,
  }),
  sponsorship: pt.shape({}),
  isMoarGamesVariant: pt.bool,
}

const mapStateToProps = (state) => ({
  user: state.user,
  sponsorship: state.sponsorship,
  subscribeLinks: state.subscribeLinks,
  isMoarGamesVariant: getIsMoarGamesVariant(state),
})

export default connect(mapStateToProps)(AlternateCardPhone)
