import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import TrackInView from 'hub/TrackInView/TrackInView'

const GameCard = ({
  id,
  name,
  description,
  url,
  subscribe,
  upsell,
  alwaysPlayable,
}) => {
  const needsSubscription = subscribe && !alwaysPlayable

  return (
    <TrackInView
      event={`hub-${id}`}
      tagName="a"
      className={cn('hub-game-card', id, {
        subscribe: needsSubscription,
      })}
      href={needsSubscription ? subscribe : url}
    >
      <div
        role="button"
        tabIndex={0}
        className="js-hub-tracker"
        data-track-hub={name}
        data-track-hub-context={id}
      >
        <div className="hub-game-card__cover">
          <div className="hub-game-card__illustration" />
          <h4 className="hub-game-card__name">{name}</h4>
        </div>
        <div className="hub-game-card__content">
          <p className="hub-game-card__description">
            {needsSubscription ? upsell : description}
          </p>
          <div className="hub-game-card__button">
            {needsSubscription ? 'Subscribe' : 'Play'}
          </div>
        </div>
      </div>
    </TrackInView>
  )
}

GameCard.propTypes = {
  id: pt.string,
  url: pt.string,
  name: pt.string,
  upsell: pt.string,
  subscribe: pt.string,
  description: pt.string,
  alwaysPlayable: pt.bool,
}

GameCard.defaultProps = {
  upsell: 'Challenge yourself with a new puzzle every day.',
}

export default GameCard
