import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import TrackInView from 'hub/TrackInView/TrackInView'

const GameCardMultiLink = ({
  id,
  name,
  url,
  subscribe,
  alwaysPlayable,
}) => {
  const needsSubscription = subscribe && !alwaysPlayable
  const trackPastPuzzleClick = () => {
    if (!window.foundationTrack) {
      return
    }

    window.foundationTrack('moduleInteraction', {
      module: {
        type: 'click',
        element: {
          name: 'hub',
          label: 'spelling-bee-hub',
        },
      },
    })
  }

  return (
    <div
      className={cn(
        'hub-game-card',
        'hub-dual-link',
        'js-hub-tracker',
        id,
        {
          subscribe: needsSubscription,
        },
      )}
    >
      <div data-track-hub={name} data-track-hub-context={id}>
        <div className="hub-game-card__cover">
          <div className="hub-game-card__illustration" />
          <h4 className="hub-game-card__name">{name}</h4>
        </div>
        <div className="hub-game-card__content">
          <TrackInView
            event={`hub-${id}`}
            tagName="a"
            href={needsSubscription ? subscribe : url}
            className={cn(
              'hub-game-card',
              'hub-game-card__button',
              id,
              {
                subscribe: needsSubscription,
              },
            )}
          >
            {needsSubscription ? 'Subscribe' : 'Play'}
          </TrackInView>
          <TrackInView
            event={`hub-past-puzzles-${id}`}
            tagName="a"
            href="/puzzles/spelling-bee/hub"
            className={cn(
              'hub-game-card',
              'hub-game-card__button',
              `past-puzzles-hub-${id}`,
              {
                subscribe: needsSubscription,
              },
            )}
            onClick={trackPastPuzzleClick}
          >
            Past Puzzles
          </TrackInView>
        </div>
      </div>
    </div>
  )
}

GameCardMultiLink.propTypes = {
  id: pt.string,
  url: pt.string,
  name: pt.string,
  subscribe: pt.string,
  alwaysPlayable: pt.bool,
}

export default GameCardMultiLink
