import React from 'react'
import pt from 'prop-types'
import { connect } from 'react-redux'

import {
  getIsMoarGamesVariant,
  getGamesSection,
} from 'hub/store/selectors'
import Section from 'hub/shared/Section/Section'

import { usePastPuzzles } from '../../abra/usePastPuzzles'

import GameCard from './GameCard'
import GameCardMultiLink from './GameCardMultiLink'

const GamesSection = ({ ourGames, isMoarGamesVariant }) => {
  const isPastPuzzleFeature = usePastPuzzles()

  return (
    <Section className="hub-our-games">
      <div className="hub-our-games__container">
        {!isMoarGamesVariant && (
          <h3 className="section__header">More Games</h3>
        )}
        <div className="hub-our-games__content">
          {ourGames.map((game) =>
            isPastPuzzleFeature && game.isMultiLink ? (
              <GameCardMultiLink key={game.id} {...game} />
            ) : (
              <GameCard key={game.id} {...game} />
            ),
          )}
        </div>
      </div>
    </Section>
  )
}

GamesSection.propTypes = {
  ourGames: pt.arrayOf(pt.shape({})),
  isMoarGamesVariant: pt.bool,
}

export default connect((state) => ({
  ourGames: getGamesSection(state),
  isMoarGamesVariant: getIsMoarGamesVariant(state),
}))(GamesSection)
