import React from 'react'
import { shallow } from 'enzyme'

import TrackInView from '../../TrackInView/TrackInView'
import GameCard from '../GameCard'

describe('HUB: GAME CARD', () => {
  it('should render play card', () => {
    const game = {
      id: 'test-game',
      name: 'Test Gabe',
      description: 'about...',
      url: 'puzzle/',
      subscribe: null,
    }

    const card = shallow(<GameCard {...game} />)
      .find(TrackInView)
      .dive()

    expect(card.find(`a.hub-game-card.${game.id}`).prop('href')).toBe(
      game.url,
    )
    expect(card.find('.hub-game-card__name').text()).toBe(game.name)
    expect(card.find('.hub-game-card__description').text()).toBe(
      game.description,
    )
    expect(card.find('.hub-game-card__button').text()).toBe('Play')
  })

  it('should render subscribe cards', () => {
    const game = {
      id: 'test-game',
      name: 'Test Gabe',
      description: 'about...',
      url: 'puzzle/',
      subscribe: '/subscribe',
      upsell: 'sell it...',
    }

    const card = shallow(<GameCard {...game} />)
      .find(TrackInView)
      .dive()

    expect(
      card.find(`a.hub-game-card.subscribe.${game.id}`).prop('href'),
    ).toBe(game.subscribe)
    expect(card.find('.hub-game-card__name').text()).toBe(game.name)
    expect(card.find('.hub-game-card__description').text()).toBe(
      game.upsell,
    )
    expect(card.find('.hub-game-card__button').text()).toBe(
      'Subscribe',
    )
  })

  it('should render alwaysPlayable card', () => {
    const game = {
      id: 'test-game',
      name: 'Test Gabe',
      description: 'about...',
      url: 'puzzle/',
      subscribe: '/subscribe',
      upsell: 'sell it...',
      alwaysPlayable: true,
    }

    const card = shallow(<GameCard {...game} />)
      .find(TrackInView)
      .dive()

    expect(card.find(`a.hub-game-card.${game.id}`).prop('href')).toBe(
      game.url,
    )
    expect(card.find('.hub-game-card__name').text()).toBe(game.name)
    expect(card.find('.hub-game-card__description').text()).toBe(
      game.description,
    )
    expect(card.find('.hub-game-card__button').text()).toBe('Play')
  })
})
