import React from 'react'
import { Provider } from 'react-redux'
import { createStore } from 'redux'
import { mount } from 'enzyme'

import GamesSection from '../GamesSection'
import GameCard from '../GameCard'

jest.mock('../GameCard', () => () => null)
jest.mock(
  '../../shared/Section/Section',
  () =>
    /* eslint-disable */
    function S({ children }) {
      return <div>{children}</div>
    },
  /* eslint-enable */
)
jest.mock('../../store/selectors', () => ({
  getGamesSection: (s) => s.ourGames,
  getIsMoarGamesVariant: () => false,
}))

const getRender = (initialState) => {
  const games = mount(
    <Provider store={createStore((_) => _, initialState)}>
      <GamesSection />
    </Provider>,
  )

  return games
}

describe('HUB: MORE GAMES', () => {
  it('renders games', () => {
    const state = {
      ourGames: [
        { id: 'letter-boxed', foo: true },
        { id: 'spelling-bee', foo: false },
      ],
    }

    const games = getRender(state)

    expect(games.find('.section__header').text()).toBe('More Games')

    const cards = games.find(GameCard)

    expect(cards).toHaveLength(state.ourGames.length)

    cards.forEach((c, i) => {
      expect(c.props()).toMatchObject(state.ourGames[i])
    })
  })
})
