import React from 'react'
import propTypes from 'prop-types'
import cn from 'classnames'

import { FEATURED_ARTICLE } from 'hub/track/constants'

import Section from '../shared/Section/Section'
import TrackInView from '../TrackInView/TrackInView'

const PromoSection = ({ children, className, title }) => (
  <Section backgroundColor="white">
    <div className={cn('hub-guide-promo-section', className)}>
      <h3 className="hub-section-header">{title}</h3>
      <div className="hub-guide-promo-content">{children}</div>
    </div>
  </Section>
)

PromoSection.propTypes = {
  className: propTypes.string,
  children: propTypes.oneOfType([
    propTypes.element,
    propTypes.arrayOf(propTypes.element),
  ]),
  title: propTypes.string,
}

export const PromoCard = ({ children, link }) => (
  <a
    className="hub-guide-promo-card js-hub-tracker"
    href={link}
    data-track-hub={FEATURED_ARTICLE}
  >
    <div className="hub-guide-promo-card-illustration" />
    <div className="hub-guide-promo-card-content">{children}</div>
  </a>
)

PromoCard.propTypes = {
  children: propTypes.element,
  link: propTypes.string,
}

const GUIDE_URL =
  'https://www.nytimes.com/guides/crosswords/how-to-solve-a-crossword-puzzle'

const GuidePromo = () => (
  <PromoSection title="Featured Article">
    <PromoCard link={GUIDE_URL}>
      <TrackInView tagName="div" event="hub-featured-article">
        <h2>
          How to Solve <br />
          The New York Times Crossword
        </h2>
        <p>A Guide by DEB AMLEN</p>
        <p>
          With patience and practice anyone can learn to solve
          crosswords.{' '}
          <span className="hub-guide-promo-link">Read More</span>
        </p>
      </TrackInView>
    </PromoCard>
  </PromoSection>
)

export default GuidePromo
