import React from 'react'
import cn from 'classnames'

import './LoadingCard.scss'

export type LoadingCardProps = {
  cardType: 'primary' | 'secondary' | 'tertiary' | 'bonus' | 'day'
}

type LineProps = {
  width: 'short' | 'mlong' | 'long' | 'xlong' | 'xshort' | 'xxshort'
  height?: 'thin' | 'thick' | 'medium' | 'small'
}

function Line({ width, height }: LineProps) {
  return <div className={cn('loadingText', width, height)} />
}

function Icon() {
  return <div className="icon primary progressIcon" />
}

function SecondaryCard() {
  return (
    <div className="featured standard">
      <Icon />
      <Line width="short" height="thick" />
      <Line width="xlong" />
      <Line width="xlong" height="thin" />
      <Line width="short" height="small" />
    </div>
  )
}

function PrimaryCard() {
  return (
    <div className="featured primary padding">
      <Icon />
      <Line width="xlong" height="thick" />
      <Line width="short" height="small" />
      <Line width="long" height="thin" />
      <Line width="xlong" height="thick" />
    </div>
  )
}

function TertiaryCard() {
  return (
    <div className="featured standard tertiary">
      <Line width="xshort" height="thick" />
      <Line width="xlong" height="thin" />
      <Line width="long" height="thick" />
      <Line width="xlong" height="thick" />
      <Line width="long" height="thick" />

      <Line width="xshort" height="thick" />
      <Line width="long" height="thin" />
      <Line width="xlong" height="thick" />
      <Line width="long" height="thick" />

      <Line width="long" height="thin" />
      <Line width="xshort" height="thick" />
    </div>
  )
}

function BonusCard() {
  return (
    <div className="island standard center">
      <Line width="mlong" height="thick" />
      <Line width="mlong" height="thick" />
      <Line width="xshort" height="small" />
      <Line width="long" height="thin" />
      <Icon />
      <Line width="long" height="small" />
    </div>
  )
}

function DayCard() {
  return (
    <div className="thumb standard island center">
      <Line width="xxshort" height="medium" />
      <Icon />
      <Line width="xxshort" height="medium" />
    </div>
  )
}

export default function LoadingCard({ cardType }: LoadingCardProps) {
  const cardMap = {
    primary: <PrimaryCard />,
    secondary: <SecondaryCard />,
    tertiary: <TertiaryCard />,
    bonus: <BonusCard />,
    day: <DayCard />,
  }

  return cardMap[cardType]
}
