import React from 'react'
import { shallow } from 'enzyme'

import { MobileStatsCard } from '../MobileStatsCard'

describe('MOBILE STATS CARD', () => {
  let props

  beforeEach(() => {
    props = {
      user: {
        hasXwd: true,
      },
      statsAndStreaks: {
        miniStats: {
          bestDate: '2017-06-05',
          bestTime: 5,
          todaysDate: '2020-05-28',
          todaysTime: 0,
        },
        stats: {
          longestAvgTime: 1268,
          longestLatestTime: 310,
          puzzlesAttempted: 153,
          puzzlesSolved: 36,
          solveRate: 0.235,
          statsByDay: [
            {
              avgDenominator: 0,
              avgTime: 0,
              bestDate: '',
              bestTime: 0,
              label: 'Monday',
              latestDate: '',
              latestTime: 0,
              thisWeeksTime: 0,
            },
          ],
        },
        streaks: {
          currentStreak: 0,
          dateEnd: '2020-05-25',
          dateStart: '2014-01-01',
          dates: [['2017-02-23', '2017-02-24'], ['2017-04-28']],
          longestStreak: 2,
          verticalStreaks: [
            {
              length: 0,
              nextDate: '',
            },
          ],
        },
      },
    }
  })

  describe('when a user does not have any streak information', () => {
    it('renders the NoSubsCard', () => {
      const unSubbedUser = {
        user: { ...props.user },
        statsAndStreaks: {
          miniStats: { ...props.statsAndStreaks.miniStats },
          stats: { ...props.statsAndStreaks.stats },
        },
      }

      const mobileStats = shallow(
        <MobileStatsCard {...unSubbedUser} />,
      )
      const noSubs = mobileStats.find('NoSubsCard')

      expect(noSubs.exists()).toBe(true)
    })
  })

  describe('when a user is not a xwd subscriber', () => {
    it('renders the NoSubsCard', () => {
      const unSubbedUser = {
        user: {
          hasXwd: false,
        },
        statsAndStreaks: {
          ...props.statsAndStreaks,
        },
      }

      const mobileStats = shallow(
        <MobileStatsCard {...unSubbedUser} />,
      )
      const noSubs = mobileStats.find('NoSubsCard')

      expect(noSubs.exists()).toBe(true)
    })
  })

  describe('when a subbed user has no mini stats', () => {
    it('renders a No Stats component', () => {
      const mobileStats = shallow(<MobileStatsCard {...props} />)
      const noStats = mobileStats.find('.hub-mobile-stats__no-stats')

      expect(noStats.exists()).toBe(true)
    })
  })

  describe('when a subbed user has no daily stats', () => {
    it('renders a No Stats component', () => {
      const mobileStats = shallow(<MobileStatsCard {...props} />)
      const noStats = mobileStats.find('.hub-mobile-stats__no-stats')

      expect(noStats.exists()).toBe(true)
    })
  })

  describe('when a user has mini stats', () => {
    it('renders the bestMiniBar', () => {
      const hasMiniStats = {
        user: { ...props.user },
        statsAndStreaks: {
          stats: { ...props.statsAndStreaks.stats },
          streaks: { ...props.statsAndStreaks.streaks },
          miniStats: {
            todaysDate: '2020-05-28',
            todaysTime: 0,
            bestTime: 10,
            bestDate: '',
          },
        },
      }

      const mobileStats = shallow(
        <MobileStatsCard {...hasMiniStats} />,
      )

      const bestStats = mobileStats.find(
        '.hub-mobile-stats__best.mini',
      )

      expect(bestStats.exists()).toBe(true)
    })
  })

  describe('when a user has daily stats', () => {
    it('renders the bestDailyBar', () => {
      const hasDailyStats = {
        user: { ...props.user },
        statsAndStreaks: {
          ...props.statsAndStreaks,
          stats: {
            ...props.statsAndStreaks.stats,
            statsByDay: [
              {
                avgDenominator: 1,
                avgTime: 1000,
                bestDate: '2020-03-24',
                bestTime: 1000,
                label: 'Monday',
                latestDate: '2020-03-24',
                latestTime: 1000,
                thisWeeksTime: 1000,
              },
            ],
          },
          streaks: { ...props.statsAndStreaks.streaks },
        },
      }

      const mobileStats = shallow(
        <MobileStatsCard {...hasDailyStats} />,
      )

      const bestStats = mobileStats.find(
        '.hub-mobile-stats__best.daily',
      )

      expect(bestStats.exists()).toBe(true)
    })
  })

  describe('when a user has some (not all) daily stats', () => {
    it('renders the bestDailyBar', () => {
      const hasDailyStats = {
        user: { ...props.user },
        statsAndStreaks: {
          ...props.statsAndStreaks,
          stats: {
            ...props.statsAndStreaks.stats,
            statsByDay: [
              {
                avgDenominator: 1,
                avgTime: 0,
                bestDate: '',
                bestTime: 0,
                label: 'Monday',
                latestDate: '',
                latestTime: 0,
                thisWeeksTime: 1000,
              },
            ],
          },
          streaks: { ...props.statsAndStreaks.streaks },
        },
      }

      const mobileStats = shallow(
        <MobileStatsCard {...hasDailyStats} />,
      )

      const bestStats = mobileStats.find(
        '.hub-mobile-stats__best.daily',
      )

      const dailyStats = mobileStats.find(
        '.hub-mobile-stats__today.daily',
      )

      const noData = mobileStats.find(
        '.hub-mobile-stats__no-stats-block',
      )

      expect(bestStats.exists()).toBe(false)
      expect(dailyStats.exists()).toBe(true)
      expect(noData.exists()).toBe(false)
    })
  })
})
