import React, { useEffect, useRef, useState } from 'react'
import pt from 'prop-types'
import { connect } from 'react-redux'

import createModalSystem from '../../../games/helpers/createModalSystem'
import PrintModal from '../PrintModal/PrintModal'
import * as printOptions from '../PrintModal/printOptions'

import { ModalContext } from './ModalContext'

export const modals = [
  {
    name: 'print',
    Content: PrintModal,
    closeByEx: true,
    closeByBgClick: true,
  },
]

const ModalSystemProvider = ({ children, id, printUrl }) => {
  const [context, setContext] = useState()
  const urlRef = useRef(printUrl)

  useEffect(() => {
    urlRef.current = printUrl
  })

  const handlePrint = (event) => {
    if (event.key === 'Enter' || event.key === 'NumpadEnter') {
      event.preventDefault()
      window.open(urlRef.current)
    }
  }

  useEffect(() => {
    setContext(
      createModalSystem({
        root: document.getElementById(id),
        modals,
        onOpen() {
          document.addEventListener('keydown', handlePrint)
        },
        onClose() {
          document.removeEventListener('keydown', handlePrint)
        },
      }),
    )
  }, [])

  if (!context) {
    return children
  }

  return (
    <ModalContext.Provider value={context}>
      {children}
    </ModalContext.Provider>
  )
}

const mapStateToProps = (state) => ({
  printUrl: printOptions.getPrintUrl(state),
})

ModalSystemProvider.propTypes = {
  children: pt.node,
  id: pt.string,
  printUrl: pt.string,
}

export default connect(mapStateToProps)(ModalSystemProvider)
