import React from 'react'
import { Provider } from 'react-redux'
import pt from 'prop-types'

import PrimaryCardComponent from './index'

import setUpStore from '../store/store'

const puzzles = {
  daily: [
    {
      puzzle_id: 19177,
      format_type: 'Normal',
      publish_type: 'Daily',
      print_date: '2021-04-20',
      author: 'Adam Wagner',
      editor: 'Will Shortz',
    },
  ],
  daily_longer_author: [
    {
      puzzle_id: 19180,
      format_type: 'Normal',
      publish_type: 'Daily',
      print_date: '2021-04-18',
      author: 'John Halpern and Friends',
      editor: 'Will Shortz',
    },
  ],
}

const defaultStoreArgs = {
  deviceType: {},
  subscribeLinks: { default: '/' },
  hubPuzzles: puzzles,
}

const Template = ({ puzzleType, store }) => (
  <Provider store={store}>
    <PrimaryCardComponent puzzleCollection={puzzleType} />
  </Provider>
)

Template.propTypes = {
  puzzleType: pt.string,
  store: pt.shape({}),
}

const subscriberStore = setUpStore({
  userType: {
    isLoggedIn: true,
    hasXwd: true,
  },
  ...defaultStoreArgs,
})
export const Subscriber = Template.bind({})
Subscriber.args = {
  puzzleType: 'daily',
  store: subscriberStore,
}

const nonSubcriberStore = setUpStore({
  userType: {
    isLoggedIn: false,
    hasXwd: false,
  },
  ...defaultStoreArgs,
})
export const NonSubscriber = Template.bind({})
NonSubscriber.args = {
  puzzleType: 'daily',
  store: nonSubcriberStore,
}

export default {
  component: Subscriber,
  title: 'Hub/Top/Primary Card',
  argTypes: {
    puzzleType: {
      control: {
        type: 'select',
        options: ['daily', 'dailyLongerAuthor'],
      },
    },
    store: { control: { disable: true } },
  },
  parameters: {
    layout: 'centered',
    backgrounds: {
      default: 'welcomeBlue',
      values: [
        {
          name: 'welcomeBlue',
          value: '#4d88f9',
        },
      ],
    },
  },
}
