import React from 'react'
import pt from 'prop-types'
import { Provider } from 'react-redux'

import setUpStore from '../store/store'

import Progress from './Progress'

const bonusPuzzle = [
  {
    puzzle_id: 19127,
    title: 'National Bookmobile Day',
    format_type: 'Normal',
    publish_type: 'Bonus',
    print_date: '2021-04-01',
    author: 'Fred Piscop',
    editor: '',
  },
]

const weeklyPuzzles = [
  {
    puzzle_id: 19191,
    title: '',
    format_type: 'Normal',
    publish_type: 'Daily',
    print_date: '2021-04-30',
    author: 'Kate Hawkins',
    editor: 'Will Shortz',
  },
  {
    puzzle_id: 19187,
    title: '',
    format_type: 'Normal',
    publish_type: 'Daily',
    print_date: '2021-04-29',
    author: 'Adam Wagner',
    editor: 'Will Shortz',
  },
  {
    puzzle_id: 19186,
    title: '',
    format_type: 'Normal',
    publish_type: 'Daily',
    print_date: '2021-04-28',
    author: 'Hal Moore',
    editor: 'Will Shortz',
  },
  {
    puzzle_id: 19188,
    title: '',
    format_type: 'Normal',
    publish_type: 'Daily',
    print_date: '2021-04-27',
    author: 'Jeff McDermott',
    editor: 'Will Shortz',
  },
  {
    puzzle_id: 19192,
    title: '',
    format_type: 'Normal',
    publish_type: 'Daily',
    print_date: '2021-04-26',
    author: 'Eric and Lori Bornstein',
    editor: 'Will Shortz',
  },
  {
    puzzle_id: 16506,
    title: 'STRETCHING EXERCISES',
    format_type: 'Normal',
    publish_type: 'Daily',
    print_date: '2021-04-25',
    author: 'Jeremy Newton',
    editor: 'Will Shortz',
  },
  {
    puzzle_id: 19176,
    title: 'Stretching Exercises',
    format_type: 'Normal',
    publish_type: 'Daily',
    print_date: '2021-04-24',
    author: 'Jeremy Newton',
    editor: 'Will Shortz',
  },
  {
    puzzle_id: 19172,
    title: '',
    format_type: 'Normal',
    publish_type: 'Daily',
    print_date: '2021-04-24',
    author: 'Kristian House and Mike Dockins',
    editor: 'Will Shortz',
  },
]

/**
 * NOTE: This array comes from the progress.json API call and populates the 'Last 7 Days' tab
 */
const progress = [
  {
    puzzle_id: 19191,
    print_date: '2021-04-30',
    publish_type: 'Daily',
    last_modified: '2021-05-02 10:42:36',
    solved: false,
    percent_filled: 50,
    star: '',
  },
  {
    puzzle_id: 19187,
    print_date: '2021-04-29',
    publish_type: 'Daily',
    last_modified: '2021-04-29 14:13:59',
    solved: false,
    percent_filled: 10,
    star: '',
  },
  {
    puzzle_id: 19186,
    print_date: '2021-04-28',
    publish_type: 'Daily',
    last_modified: '2021-05-02 10:43:03',
    solved: false,
    percent_filled: 25,
    star: '',
  },
  {
    puzzle_id: 19192,
    print_date: '2021-04-26',
    publish_type: 'Daily',
    last_modified: '2021-04-26 15:20:42',
    solved: false,
    percent_filled: 75,
    star: '',
  },
]

/**
 * NOTE: This array comes from the recent.json API call and populates the 'In Progress' tab
 */
const recent = [
  {
    puzzle_id: 19191,
    print_date: '2021-04-30',
    publish_type: 'Daily',
    last_modified: '2021-05-02 10:42:36',
    solved: false,
    percent_filled: 50,
    star: '',
  },
  {
    puzzle_id: 19187,
    print_date: '2021-04-29',
    publish_type: 'Daily',
    last_modified: '2021-04-29 14:13:59',
    solved: false,
    percent_filled: 10,
    star: '',
  },
  {
    puzzle_id: 19189,
    print_date: '2021-04-28',
    publish_type: 'Daily',
    last_modified: '2021-05-02 10:43:03',
    solved: false,
    percent_filled: 25,
    star: '',
  },
  {
    puzzle_id: 19192,
    print_date: '2021-04-26',
    publish_type: 'Daily',
    last_modified: '2021-04-26 15:20:42',
    solved: false,
    percent_filled: 75,
    star: '',
  },
]

const defaultStore = {
  userType: {
    isLoggedIn: true,
    hasXwd: true,
    id: 1234567,
  },
  hubPuzzles: {
    bonus_puzzle: bonusPuzzle,
    weekly_puzzles: weeklyPuzzles,
    recent_puzzles: [],
  },
}

export const hubPuzzles = {
  bonus_puzzle: bonusPuzzle,
  weekly_puzzles: weeklyPuzzles,
  recent_puzzles: recent,
  progress,
}

const progressStore = {
  userType: {
    isLoggedIn: true,
    hasXwd: true,
    id: 1234567,
  },
  hubPuzzles,
}

const Template = ({ store }) => {
  const api = {
    fetchRecentPuzzles: () => Promise.resolve(),
  }

  return (
    <Provider store={store}>
      <Progress api={api} />
    </Provider>
  )
}

Template.propTypes = {
  args: pt.shape({}),
  store: pt.shape({}),
}

export const Default = Template.bind({})

Default.args = {
  store: setUpStore(defaultStore),
}

export const InProgress = Template.bind({})

InProgress.args = {
  store: setUpStore(progressStore),
}

export default {
  title: 'Hub/Middle/Progress Section',
  component: Default,
  argTypes: {
    store: { control: { disable: true } },
  },
}
