import React from 'react'
import pt from 'prop-types'

import createUrls from '../utils/createUrls'

const Print = ({ puzzle, pdfLinkOnly, printAction, section }) => {
  const urls = createUrls(puzzle)
  const printUrl = urls.newspaper.puzzle || urls.generated.puzzle

  const suppressModal = pdfLinkOnly // because Home Delivery subscriber

  /** allow parent to make this just a pdf link */
  const handlePrint = suppressModal
    ? () => {}
    : (event) => {
        event.preventDefault()
        printAction(puzzle)

        if (!window.foundationTrack) {
          return
        }

        window.foundationTrack('moduleInteraction', {
          module: {
            type: 'ob_click',
            element: {
              name: 'hub',
              label: 'print-puzzle',
            },
            context: `${puzzle.puzzleId}`,
            label: section,
          },
        })
      }

  /** if something cannot be printed, do not render */
  if (!printUrl) return null

  return (
    <div className="printTool">
      <a
        className="hub-print-link"
        href={printUrl}
        onClick={handlePrint}
      >
        <div className="print" />
      </a>
    </div>
  )
}

Print.propTypes = {
  puzzle: pt.shape({
    formatType: pt.string,
    puzzleId: pt.number,
  }),
  pdfLinkOnly: pt.bool,
  printAction: pt.func,
  section: pt.string,
}

export default Print
