import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import {
  cardActions,
  SUBSCRIBE,
  VIEW_NEWSPAPER,
} from './cardConstants'

const convertPercentageToFraction = (percentage = 0, subdivisions) =>
  Math.ceil((percentage * subdivisions) / 100)

const ProgressIcon = ({
  iconType,
  hasGoldStar,
  isSolved,
  percentFilled,
  action,
  hasStreakAfter,
  hasStreakBefore,
  isBrandNew,
  isFake,
  isStatic,
}) => {
  const getProgressValue = () => {
    if (isFake) return 'Unavailable'

    if (isBrandNew) return 'Newest'

    if (action === VIEW_NEWSPAPER || isStatic) return '0'

    if (action === SUBSCRIBE) return 'Unavailable'

    if (hasGoldStar && iconType !== 'mini') return 'GoldStar'

    if (isSolved) return 'BlueStar'

    const subdivisions = iconType === 'mini' ? 4 : 16
    return convertPercentageToFraction(percentFilled, subdivisions)
  }

  const progressIconClassName = `${iconType}Progress${getProgressValue()}`

  const iconClasses = cn(
    'progressIconContent',
    progressIconClassName,
    {
      streakBefore: hasStreakBefore,
      streakAfter: hasStreakAfter,
    },
  )

  return <div data-star={hasGoldStar} className={iconClasses} />
}

ProgressIcon.propTypes = {
  action: pt.oneOf(cardActions).isRequired,
  percentFilled: pt.number,
  isSolved: pt.bool,
  hasGoldStar: pt.bool,
  hasStreakAfter: pt.bool,
  hasStreakBefore: pt.bool,
  iconType: pt.oneOf(['mini', 'puzzle']),
  isBrandNew: pt.bool,
  isFake: pt.bool,
  isStatic: pt.bool,
}

export default ProgressIcon
