import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import {
  PLAY,
  PRINT,
  SUBSCRIBE,
  VIEW_NEWSPAPER,
  cardActions,
} from './cardConstants'

const getRibbonText = {
  [VIEW_NEWSPAPER]: () => 'Print',
  [SUBSCRIBE]: () => 'Subscribe',
  [PRINT]: () => 'Print',
  [PLAY]: (percentFilled, isSolved, isBrandNew) => {
    if (isSolved) return 'Review'

    if (percentFilled) return 'Resume'

    if (isBrandNew) return 'New'

    return 'Play'
  },
}

const ProgressBanner = ({
  action,
  percentFilled,
  isSolved,
  isBrandNew,
}) => {
  const text = getRibbonText[action](
    percentFilled,
    isSolved,
    isBrandNew,
  )

  return (
    <div className={cn('cardRibbon', { brandNew: isBrandNew })}>
      <span>{text}</span>
    </div>
  )
}

ProgressBanner.propTypes = {
  action: pt.oneOf(cardActions).isRequired,
  percentFilled: pt.number,
  isSolved: pt.bool,
  isBrandNew: pt.bool,
}

export default ProgressBanner
