import React from 'react'
import { shallow } from 'enzyme'

import PuzzleIcon from '../PuzzleIcon'

jest.mock('../cardConstants', () => ({
  cardActions: ['foo', 'VIEW_NEWSPAPER', 'SUBSCRIBE'],
  VIEW_NEWSPAPER: 'VIEW_NEWSPAPER',
  SUBSCRIBE: 'SUBSCRIBE',
}))

describe('PUZZLE ICON', () => {
  let defaultProps
  let icon

  beforeEach(() => {
    jest.resetAllMocks()

    defaultProps = {
      action: 'foo',
      hasStreakAfter: false,
      hasStreakBefore: false,
      isBrandNew: false,
      isFake: false,
      hasGoldStar: false,
      isStatic: false,
    }
  })

  // MINI classnames
  test('mini at 25 percent complete gets `miniProgress1` in its classname', () => {
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={25}
        iconType="mini"
      />,
    )
    expect(icon.hasClass('miniProgress1')).toBe(true)
  })
  test('mini at 50 percent complete gets `miniProgress2` in its classname', () => {
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={50}
        iconType="mini"
      />,
    )
    expect(icon.hasClass('miniProgress2')).toBe(true)
  })
  test('mini at 75 percent complete gets `miniProgress3` in its classname', () => {
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={75}
        iconType="mini"
      />,
    )
    expect(icon.hasClass('miniProgress3')).toBe(true)
  })
  test('mini at 99 percent complete gets `miniProgress4` in its classname', () => {
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={99}
        iconType="mini"
      />,
    )
    expect(icon.hasClass('miniProgress4')).toBe(true)
  })

  // DAILY classnames
  test('daily at 49 percent complete gets `puzzleProgress8` in its classname', () => {
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={49}
        iconType="puzzle"
      />,
    )
    expect(icon.hasClass('puzzleProgress8')).toBe(true)
  })
  test('daily at 75 percent complete gets `puzzleProgress12` in its classname', () => {
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={75}
        iconType="puzzle"
      />,
    )
    expect(icon.hasClass('puzzleProgress12')).toBe(true)
  })
  test('daily at 99 percent complete gets `puzzleProgress16` in its classname', () => {
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={99}
        iconType="puzzle"
      />,
    )
    expect(icon.hasClass('puzzleProgress16')).toBe(true)
  })

  // OTHER classnames
  test('unavailable daily gets `puzzleProgressUnavailable` in its classname', () => {
    defaultProps.isFake = true
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={99}
        iconType="puzzle"
      />,
    )
    expect(icon.hasClass('puzzleProgressUnavailable')).toBe(true)
  })
  test('brand new daily gets `puzzleProgressNewest` in its classname', () => {
    defaultProps.isBrandNew = true
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={99}
        iconType="puzzle"
      />,
    )
    expect(icon.hasClass('puzzleProgressNewest')).toBe(true)
  })
  test('puzzle with VIEW_NEWSPAPER action gets `puzzleProgress0` in its classname', () => {
    defaultProps.action = 'VIEW_NEWSPAPER'
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={99}
        iconType="puzzle"
      />,
    )
    expect(icon.hasClass('puzzleProgress0')).toBe(true)
  })
  test('static daily puzzle gets `puzzleProgress0` in its classname', () => {
    defaultProps.isStatic = true
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={99}
        iconType="puzzle"
      />,
    )
    expect(icon.hasClass('puzzleProgress0')).toBe(true)
  })
  test('daily with subscribe action gets `puzzleProgressUnavailable` in its classname', () => {
    defaultProps.action = 'SUBSCRIBE'
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={99}
        iconType="puzzle"
      />,
    )
    expect(icon.hasClass('puzzleProgressUnavailable')).toBe(true)
  })
  test('daily with gold star flag gets `puzzleProgressGoldStar` in its classname', () => {
    defaultProps.hasGoldStar = true
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved={false}
        percentFilled={99}
        iconType="puzzle"
      />,
    )
    expect(icon.hasClass('puzzleProgressGoldStar')).toBe(true)
  })
  test('solved mini gets `miniProgressBlueStar` in its classname', () => {
    defaultProps.hasGoldStar = true
    icon = shallow(
      <PuzzleIcon
        {...defaultProps}
        isSolved
        percentFilled={99}
        iconType="mini"
      />,
    )
    expect(icon.hasClass('miniProgressBlueStar')).toBe(true)
  })
})
