import React from 'react'
import pt from 'prop-types'

import { cardActions } from '../cardConstants'
import PuzzleIconComponent from '../PuzzleIcon'
import ProgressBanner from '../PuzzleRibbon'

export const PuzzleCardIcon = ({
  iconType = 'mini',
  action = cardActions[0],
  ...args
}) => (
  <div className="progressIcon">
    <PuzzleIconComponent
      iconType={iconType}
      action={action}
      {...args}
    />
    <ProgressBanner iconType={iconType} action={action} {...args} />
  </div>
)

export default {
  title: 'Hub/Bottom/Puzzle Card Components/Puzzle Card Icon',
  component: PuzzleCardIcon,
  parameters: {
    layout: 'centered',
  },
  args: {
    action: cardActions[0],
    percentFilled: 0,
    isSolved: false,
    hasGoldStar: false,
    hasStreakAfter: false,
    hasStreakBefore: false,
    iconType: 'mini',
    isBrandNew: false,
    isFake: false,
    isStatic: false,
  },
  argTypes: {
    action: {
      type: 'select',
      options: cardActions,
    },
    iconType: {
      type: 'select',
      options: ['mini', 'puzzle'],
    },
  },
}

PuzzleCardIcon.propTypes = {
  action: pt.oneOf(cardActions),
  percentFilled: pt.number,
  isSolved: pt.bool,
  hasGoldStar: pt.bool,
  hasStreakAfter: pt.bool,
  hasStreakBefore: pt.bool,
  iconType: pt.oneOf(['mini', 'puzzle']),
  isBrandNew: pt.bool,
  isFake: pt.bool,
  isStatic: pt.bool,
}
