import React from 'react'
import pt from 'prop-types'
import { compose } from 'redux'
import { connect } from 'react-redux'

import Section from '../shared/Section/Section'
import PuzzleCard from '../PuzzleCard/PuzzleCard'
import TrackInView from '../TrackInView/TrackInView'
import withPuzzleCollection from '../withPuzzleCollection'

const PuzzleGroup = ({
  user,
  track,
  title,
  isFree,
  puzzles,
  moreLink,
  subscribeLinks,
  puzzleCollection,
}) => (
  <Section backgroundColor="white">
    <TrackInView
      event={track}
      tagName="section"
      className="hub-puzzle-group"
    >
      <h2 className="hub-section-header">{title}</h2>
      <div className="hub-expand-to-row">
        {puzzles.map((puzzle) => (
          <PuzzleCard
            user={user}
            type="Island"
            puzzle={puzzle}
            isFree={isFree}
            key={puzzle.puzzle_id}
            collection={puzzleCollection}
            subscribeLinks={subscribeLinks}
            section="variety-puzzles"
          />
        ))}
      </div>
      {moreLink && (
        <div className="hub-puzzle-group__more-link">
          <a href={moreLink}>MORE</a>
        </div>
      )}
    </TrackInView>
  </Section>
)

PuzzleGroup.propTypes = {
  isFree: pt.bool,
  title: pt.string,
  track: pt.string,
  user: pt.shape({}),
  moreLink: pt.string,
  puzzleCollection: pt.string,
  subscribeLinks: pt.shape({}),
  puzzles: pt.arrayOf(pt.shape({})),
}

const mapStateToProps = ({ user, subscribeLinks }) => ({
  user,
  subscribeLinks,
})

export default compose(
  withPuzzleCollection,
  connect(mapStateToProps),
)(PuzzleGroup)
