import React from 'react'
import { Provider } from 'react-redux'
import pt from 'prop-types'

import SecondaryCardComponent from './index'

import setUpStore from '../store/store'

const puzzles = {
  mini: [
    {
      puzzle_id: 19169,
      format_type: 'Normal',
      publish_type: 'Mini',
      print_date: '2021-04-19',
      author: 'Jane Doe',
      editor: '',
      title: '',
    },
  ],
  mini_multi_line_title: [
    {
      puzzle_id: 9506,
      title: 'Tips & Tricks',
      format_type: 'Normal',
      publish_type: 'Mini',
      print_date: '2013-10-17',
      author: 'Cecilia Maverick',
      editor: '',
    },
  ],
  daily: [
    {
      puzzle_id: 19177,
      title: 'Short Title',
      format_type: 'Normal',
      publish_type: 'Daily',
      print_date: '2021-04-20',
      author: 'Adam Wagner',
      editor: 'Will Shortz',
    },
  ],
  daily_multi_line_title: [
    {
      puzzle_id: 19180,
      title: 'Cryptic Crossword',
      format_type: 'Normal',
      publish_type: 'Daily',
      print_date: '2021-04-18',
      author: 'John Halpern and Friends',
      editor: 'Will Shortz',
    },
  ],
}

const defaultStoreArgs = {
  deviceType: {},
  subscribeLinks: { default: '/' },
  hubPuzzles: puzzles,
}

const subscriberStore = setUpStore({
  userType: {
    isLoggedIn: true,
    hasXwd: true,
  },
  ...defaultStoreArgs,
})

const Template = ({ puzzleType, store }) => (
  <Provider store={store}>
    <SecondaryCardComponent puzzleCollection={puzzleType} />
  </Provider>
)

Template.propTypes = {
  puzzleType: pt.string,
  store: pt.shape({}),
}

export const Subscriber = Template.bind({})
Subscriber.args = {
  puzzleType: 'mini',
  store: subscriberStore,
}

const nonSubscriberStore = setUpStore({
  userType: {
    isLoggedIn: true,
    hasXwd: false,
  },
  ...defaultStoreArgs,
})
export const NonSubscriber = Template.bind({})
NonSubscriber.args = {
  puzzleType: 'mini',
  store: nonSubscriberStore,
}

const snakeToCamel = (str) =>
  str.replace(/([-_][a-z])/g, (group) =>
    group.toUpperCase().replace('-', '').replace('_', ''),
  )
const puzzleNames = Object.keys(puzzles).map(snakeToCamel)

export default {
  component: Subscriber,
  title: 'Hub/Top/Secondary Card',
  argTypes: {
    puzzleType: {
      control: {
        type: 'select',
        options: puzzleNames,
      },
    },
    store: { control: { disable: true } },
  },
  parameters: {
    layout: 'centered',
    backgrounds: {
      default: 'welcomeBlue',
      values: [
        {
          name: 'welcomeBlue',
          value: '#4d88f9',
        },
      ],
    },
  },
}
