import React from 'react'
import propTypes from 'prop-types'

import PuzzleIcon from '../PuzzleCard/PuzzleIcon'
import PuzzleRibbon from '../PuzzleCard/PuzzleRibbon'
import withPuzzleCollection from '../withPuzzleCollection'
import { camelizeKeysDeep } from '../utils/miscellany'

import { SPONSORED_PUZZLE_LINK } from './linkConfig'

export const PuzzleIconAndRibbon = ({ puzzle = {} }) => {
  const adaptedPuzzle = {
    action: 'PLAY',
    iconType: 'puzzle',
    ...camelizeKeysDeep(puzzle),
    isSolved: puzzle.solved,
  }

  return (
    <div className="progressIcon">
      <PuzzleIcon {...adaptedPuzzle} />
      <PuzzleRibbon {...adaptedPuzzle} />
    </div>
  )
}

PuzzleIconAndRibbon.propTypes = {
  puzzle: propTypes.shape({}).isRequired,
}

const SponsoredCard = withPuzzleCollection(
  ({ puzzles: [puzz = {}], sponsorship }) => (
    <div className="featured standard puzzleInfo">
      <a href={SPONSORED_PUZZLE_LINK} className="puzzleAction">
        <div className="puzzleInfoContent">
          <PuzzleIconAndRibbon puzzle={puzz} />
          <h3 className="hub-sponsored-card__title">{puzz.title}</h3>
          <div className="byline">
            By&nbsp;
            <span className="hub-sponsored-card__all-caps">
              {puzz.author}
            </span>
          </div>
        </div>
      </a>
      <div className="hub-sponsored-card__supported-by">
        Supported by
        <a
          href={sponsorship.link}
          target="_blank"
          rel="noopener noreferrer"
        >
          <div
            className="hub-sponsored-card__sponsor"
            style={{
              backgroundImage: `url(${sponsorship.cardImage})`,
            }}
          />
        </a>
      </div>
    </div>
  ),
)

export default SponsoredCard
