import React from 'react'
import { Provider } from 'react-redux'
import pt from 'prop-types'

import setUpStore from '../store/store'
import { GET_STATS_AND_STREAKS } from '../store/constants'

import StatsCardComponent from './StatsCard'

const streakStats = {
  dailyStats: {
    statsByDay: [
      {
        avg_denominator: 81,
        avgTime: 833,
        bestTime: 360,
        label: 'Monday',
        latestDate: '2021-04-19',
        latestTime: 763,
        thisWeeksTime: 763,
      },
      {
        avg_denominator: 38,
        avgTime: 1298,
        bestTime: 580,
        label: 'Tuesday',
        latestDate: '2021-04-13',
        latestTime: 689,
        thisWeeksTime: 0,
      },
    ],
  },
  streaks: {
    currentStreak: 2,
    dateEnd: '2021-04-20',
    dateStart: '2014-01-01',
    dates: [],
    longestStreak: 55,
  },
}

const noRecordsStats = {
  type: GET_STATS_AND_STREAKS,
  payload: {
    dailyStats: {
      statsByDay: [{}, {}],
    },
    streaks: {
      dateEnd: '2021-04-20',
      dateStart: '2014-01-01',
      verticalStreaks: [
        {
          length: 0,
          nextDate: '',
        },
      ],
    },
  },
}

const defaultStoreArgs = {
  userType: {
    isLoggedIn: false,
    hasXwd: false,
  },
  deviceType: {},
  subscribeLinks: { default: '/' },
}

const store = setUpStore(defaultStoreArgs)

const Template = ({ stats }) => {
  store.dispatch({
    type: GET_STATS_AND_STREAKS,
    payload: stats,
  })

  return (
    <Provider store={store}>
      <StatsCardComponent />
    </Provider>
  )
}

Template.propTypes = {
  stats: pt.shape({}),
}

export const Default = Template.bind({})
Default.args = {
  stats: streakStats,
}

const noStreaksStore = setUpStore(defaultStoreArgs)
export const NoStreaks = () => (
  <Provider store={noStreaksStore}>
    <StatsCardComponent />
  </Provider>
)

const noRecordsStore = setUpStore(defaultStoreArgs)
noRecordsStore.dispatch(noRecordsStats)
export const NoRecords = () => (
  <Provider store={noRecordsStore}>
    <StatsCardComponent />
  </Provider>
)

export default {
  component: Default,
  title: 'Hub/Top/Stats Card',
  parameters: {
    layout: 'centered',
    backgrounds: {
      default: 'welcomeBlue',
      values: [
        {
          name: 'welcomeBlue',
          value: '#4d88f9',
        },
      ],
    },
  },
}
