import React from 'react'
import { shallow } from 'enzyme'

import { StatsCard } from './StatsCard'

jest.mock('../TrackInView/TrackInView', () => () => 'TrackInView')

const noStats = {
  thisWeeksTime: 0,
  avgTime: 0,
  bestDate: '',
  bestTime: 0,
  latestTime: 0,
  label: 'Monday',
  latestDate: '',
}

const noStreaks = {
  currentStreak: 0,
  longestStreak: 0,
  dateEnd: '2020-05-28',
  dateStart: '2020-05-28',
}

const avgAndBestStats = {
  thisWeeksTime: 0,
  avgDenominator: 1,
  avgTime: 200,
  bestDate: '2020-05-28',
  bestTime: 200,
  latestTime: 0,
  label: 'Monday',
  latestDate: '',
}

const todaysStats = {
  thisWeeksTime: 0,
  avgDenominator: 0,
  avgTime: 0,
  bestDate: '',
  bestTime: 0,
  latestTime: 0,
  label: 'Monday',
  latestDate: '2020-05-28',
}

const streaks = {
  currentStreak: 2,
  longestStreak: 10,
  dateEnd: '2020-05-28',
  dateStart: '2020-05-28',
}

const noStatsAndStreaks = {
  statsAndStreaks: {
    streaks: noStreaks,
    stats: {
      statsByDay: [
        noStats,
        noStats,
        noStats,
        noStats,
        noStats,
        noStats,
        noStats,
      ],
    },
  },
}

const avgAndBestStatsAndStreaks = {
  statsAndStreaks: {
    streaks,
    stats: {
      statsByDay: [
        avgAndBestStats,
        avgAndBestStats,
        avgAndBestStats,
        avgAndBestStats,
        avgAndBestStats,
        avgAndBestStats,
        avgAndBestStats,
      ],
    },
  },
}

const todaysStatsAndStreaks = {
  statsAndStreaks: {
    streaks,
    stats: {
      statsByDay: [
        todaysStats,
        todaysStats,
        todaysStats,
        todaysStats,
        todaysStats,
        todaysStats,
        todaysStats,
      ],
    },
  },
}

describe('HUB: STATS CARD', () => {
  afterEach(() => {
    jest.resetAllMocks()
  })

  it('should render general placeholder', () => {
    const noData = { statsAndStreaks: {} }
    const wrapper = shallow(<StatsCard {...noData} />)
    const myAverage = wrapper.find('.hub-stats-card__title')
    const chartBlock = wrapper.find('.hub-stats-card__chart-block')
    expect(myAverage.text()).toBe('My Average')
    expect(chartBlock.length).toBe(0)
  })

  it('should render no stats placeholder', () => {
    const wrapper = shallow(<StatsCard {...noStatsAndStreaks} />)
    const noStatsEls = wrapper.find('.hub-stats-card__no-stats')
    const noStatsPlaceholder = noStatsEls.first()
    expect(noStatsPlaceholder.text()).toBe(
      'Solve today’s crossword to see some more stats!',
    )
  })

  it('should render no stats and streaks placeholders', () => {
    const wrapper = shallow(<StatsCard {...noStatsAndStreaks} />)
    const noStatsEls = wrapper.find('.hub-stats-card__no-stats')
    const noStatsPlaceholder = noStatsEls.first()
    const noStreaksPlaceholder = noStatsEls.last()
    expect(noStatsPlaceholder.text()).toBe(
      'Solve today’s crossword to see some more stats!',
    )
    expect(noStreaksPlaceholder.text()).toBe('No current streak')
  })

  it('should render best and average stats bars', () => {
    const wrapper = shallow(
      <StatsCard {...avgAndBestStatsAndStreaks} />,
    )
    const avgBar = wrapper.find('.hub-stats-card__bar.avg')
    const bestBar = wrapper.find('.hub-stats-card__bar.best')
    const todaysBar = wrapper.find('.hub-stats-card__bar.today')
    expect(avgBar).toHaveLength(1)
    expect(bestBar).toHaveLength(1)
    expect(todaysBar).toHaveLength(0)
  })

  it('should render todays time bar', () => {
    const wrapper = shallow(<StatsCard {...todaysStatsAndStreaks} />)
    const todaysBar = wrapper.find('.hub-stats-card__bar.today')
    expect(todaysBar).toHaveLength(1)
  })

  it('should render streak info', () => {
    const wrapper = shallow(<StatsCard {...todaysStatsAndStreaks} />)
    const currentStreak = wrapper
      .find('.hub-stats-card__streak-info')
      .first()

    const longestStreak = wrapper
      .find('.hub-stats-card__streak-info')
      .last()
    expect(currentStreak.text()).toContain(
      streaks.currentStreak.toString(),
    )
    expect(longestStreak.text()).toContain(
      streaks.longestStreak.toString(),
    )
  })
})
