import React from 'react'
import pt from 'prop-types'
import { connect } from 'react-redux'

import {
  getTodaysDate,
  getTodaysDayIdx,
  getStreakLength,
  getLastStreakDate,
  getVerticalStreakLength,
  getVerticalStreakNextDate,
} from '../store/selectors'

import getArticleForNumber from './getArticleForNumber'
import shouldShowGoldStreak from './shouldShowGoldStreak'
import getDayOfWeek from './getDayOfWeek'

const StreakEncouragement = ({
  todaysDate,
  streakLength,
  todaysDayIdx,
  lastStreakDate,
  verticalStreakLength,
  verticalStreakNextDate,
}) => {
  if (!streakLength && !verticalStreakLength) return null

  let msg
  let showLink

  if (shouldShowGoldStreak(streakLength, verticalStreakLength)) {
    msg = `You’re on ${getArticleForNumber(
      streakLength,
    )} ${streakLength} day streak!`
    showLink = todaysDate !== lastStreakDate
  } else {
    msg =
      verticalStreakLength > 1
        ? `You’ve solved ${verticalStreakLength} ${getDayOfWeek(
            todaysDayIdx,
          )}s in a row!`
        : `You solved last ${getDayOfWeek(todaysDayIdx)}!`
    showLink = todaysDate === verticalStreakNextDate
  }

  const content = (
    <>
      <span>{msg}</span>
      {showLink && <strong>KEEP IT GOING</strong>}
    </>
  )

  const encouragement = showLink ? (
    <a
      className="hub-streak-encouragement"
      href="/crosswords/game/daily"
    >
      {content}
    </a>
  ) : (
    <span className="hub-streak-encouragement">{content}</span>
  )

  return <div className="hub-wrap-message">{encouragement}</div>
}

StreakEncouragement.propTypes = {
  todaysDate: pt.string,
  todaysDayIdx: pt.number,
  streakLength: pt.number,
  lastStreakDate: pt.string,
  verticalStreakLength: pt.number,
  verticalStreakNextDate: pt.string,
}

export default connect((state) => ({
  todaysDate: getTodaysDate(state),
  todaysDayIdx: getTodaysDayIdx(state),
  streakLength: getStreakLength(state),
  lastStreakDate: getLastStreakDate(state),
  verticalStreakLength: getVerticalStreakLength(state),
  verticalStreakNextDate: getVerticalStreakNextDate(state),
}))(StreakEncouragement)
