import React from 'react'
import { Provider } from 'react-redux'
import pt from 'prop-types'

import setUpStore from '../store/store'
import { GET_STATS_AND_STREAKS } from '../store/constants'

import StreakEncouragementComponent from './StreakEncouragement'

const getVerticalStreaks = (streakLength, keepItGoing) => {
  const nextDate = keepItGoing ? '2021-04-20' : '2021-04-19'
  return [
    undefined,
    undefined,
    {
      length: streakLength,
      nextDate,
    },
  ]
}

const streaks = {
  currentStreak: 0,
  longest_streak: 5,
}

const storeArgs = {
  userType: {
    isLoggedIn: false,
    hasXwd: false,
  },
  subscribeLinks: { default: '/' },
  hubPuzzles: {
    daily_puzzle: [
      {
        puzzle_id: 19177,
        title: '',
        format_type: 'Normal',
        publish_type: 'Daily',
        print_date: '2021-04-20',
        author: 'Adam Wagner',
        editor: 'Will Shortz',
      },
    ],
  },
}

const streakStore = setUpStore(storeArgs)

const StreakTemplate = ({ streakLength, keepItGoing }) => {
  const verticalStreaks = getVerticalStreaks(
    streakLength,
    keepItGoing,
  )

  const updatedStats = {
    streaks: {
      ...streaks,
      verticalStreaks,
    },
  }

  streakStore.dispatch({
    type: GET_STATS_AND_STREAKS,
    payload: updatedStats,
  })

  return (
    <Provider store={streakStore}>
      <StreakEncouragementComponent puzzleCollection="miniPuzzle" />
    </Provider>
  )
}

StreakTemplate.propTypes = {
  streakLength: pt.number,
  keepItGoing: pt.bool,
}

export const Default = StreakTemplate.bind()
Default.args = {
  streakLength: 5,
  keepItGoing: false,
}

const goldStore = setUpStore(storeArgs)

const goldStreaks = {
  currentStreak: 8,
  dates: [['2021-04-19']],
  longest_streak: 5,
  vertical_streaks: [
    {
      length: 0,
      next_date: '',
    },
  ],
}

const GoldTemplate = ({ currentStreak, keepItGoing }) => {
  const dates = keepItGoing ? [['2021-04-19']] : [['2021-04-20']]
  const updatedStats = {
    streaks: { ...goldStreaks, currentStreak, dates },
  }
  goldStore.dispatch({
    type: GET_STATS_AND_STREAKS,
    payload: updatedStats,
  })

  return (
    <Provider store={goldStore}>
      <StreakEncouragementComponent puzzleCollection="miniPuzzle" />
    </Provider>
  )
}

GoldTemplate.propTypes = {
  currentStreak: pt.number,
  keepItGoing: pt.bool,
}

export const Gold = GoldTemplate.bind()
Gold.args = {
  currentStreak: 8,
  keepItGoing: true,
}

export default {
  component: Default,
  title: 'Hub/Top/Streak Encouragement',
  parameters: {
    layout: 'centered',
    backgrounds: {
      default: 'welcomeBlue',
      values: [
        {
          name: 'welcomeBlue',
          value: '#4d88f9',
        },
      ],
    },
  },
}
