import React from 'react'
import pt from 'prop-types'

import { trackImpression } from '../track/track'

import inView from './inView'

const propTypes = {
  tagName: pt.string,
  event: pt.string.isRequired,
  eventRegion: pt.string,
  eventLabel: pt.string,
  onClick: pt.func,
}

/**
 * Keep track of what impressions have fired already
 */
const EXPOSED = {}

class TrackInView extends React.PureComponent {
  constructor(props) {
    super(props)
    this.wrapper = React.createRef()
  }

  componentDidMount() {
    if (this.wrapper.current) {
      inView(this.wrapper.current, () => {
        const { event, eventRegion, eventLabel } = this.props
        const key = event + eventRegion
        if (!EXPOSED[key]) {
          trackImpression(event, eventRegion, eventLabel)
          EXPOSED[key] = true
        }
      })
    }
  }

  render() {
    const { tagName, onClick } = this.props
    const Tag = tagName
    const childProps = {}
    Object.entries(this.props).forEach(([prop, val]) => {
      if (!propTypes[prop]) childProps[prop] = val
    })
    return (
      <Tag {...childProps} ref={this.wrapper} onClick={onClick} />
    )
  }
}

TrackInView.propTypes = propTypes
TrackInView.defaultProps = {
  tagName: 'div',
  eventRegion: 'scroll-to',
  eventLabel: '',
  onClick: () => {},
}

export default TrackInView
