import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

const Welcome = ({
  isMoarGamesVariant,
  user,
  renderMini,
  renderDaily,
  renderGamesSection,
  renderAlternate,
  renderDownloadApp,
  renderPromotedLinks,
  renderAlternatePhone,
}) => {
  return (
    <div
      className={cn('hub-welcome', {
        'promote-daily': user.hasXwd || user.hasHd,
        'moar-games-variant': isMoarGamesVariant,
      })}
    >
      <div className="hub-welcome__title today">Today’s Puzzles</div>
      <div className="hub-welcome-sections">
        <div className="hub-welcome__section daily">
          {renderDaily()}
        </div>
        <div className="hub-welcome__section promoted-links">
          {renderPromotedLinks()}
        </div>
        {isMoarGamesVariant && (
          <div className="hub-welcome__section games-section">
            {renderGamesSection()}
          </div>
        )}
        <div className="hub-welcome__section mini">
          {renderMini()}
        </div>
        <div className="hub-welcome__section alternate">
          {renderAlternate()}
        </div>
        <div className="hub-welcome__section alternate-phone">
          {renderAlternatePhone()}
        </div>
      </div>
      {renderDownloadApp && (
        <div className="hub-welcome__section download-app">
          {renderDownloadApp()}
        </div>
      )}
    </div>
  )
}

Welcome.propTypes = {
  isMoarGamesVariant: pt.bool,
  user: pt.shape({
    hasXwd: pt.bool.isRequired,
    hasHd: pt.bool.isRequired,
  }).isRequired,
  renderMini: pt.func.isRequired,
  renderDaily: pt.func.isRequired,
  renderGamesSection: pt.func.isRequired,
  renderAlternate: pt.func.isRequired,
  renderDownloadApp: pt.func,
  renderPromotedLinks: pt.func.isRequired,
  renderAlternatePhone: pt.func.isRequired,
}

export default Welcome
