import React from 'react'
import { shallow } from 'enzyme'

import Welcome from '../Welcome'

describe('HUB: WELCOME', () => {
  const props = {
    user: {
      hasXwd: false,
      hasHd: false,
      isMoarGamesVariant: false,
    },
    renderDaily: () => <span>Daily</span>,
    renderMini: () => <span>Mini</span>,
    renderPromotedLinks: () => <span>Promoted Links</span>,
    renderAlternate: () => <span>Alternate</span>,
    renderAlternatePhone: () => <span>Alternate Phone</span>,
    renderDownloadApp: () => <span>Download App</span>,
  }

  it('should render all welcome sections', () => {
    const wrapper = shallow(<Welcome {...props} />)
    const daily = wrapper.find('.hub-welcome__section.daily')
    const mini = wrapper.find('.hub-welcome__section.mini')
    const promotedLinks = wrapper.find(
      '.hub-welcome__section.promoted-links',
    )
    const alternate = wrapper.find('.hub-welcome__section.alternate')
    const alternatePhone = wrapper.find(
      '.hub-welcome__section.alternate-phone',
    )

    const downloadApp = wrapper.find(
      '.hub-welcome__section.download-app',
    )
    expect(daily.text()).toBe('Daily')
    expect(mini.text()).toBe('Mini')
    expect(promotedLinks.text()).toBe('Promoted Links')
    expect(alternate.text()).toBe('Alternate')
    expect(alternatePhone.text()).toBe('Alternate Phone')
    expect(downloadApp.text()).toBe('Download App')
  })

  it('should not promote daily', () => {
    const wrapper = shallow(<Welcome {...props} />)
    const welcomeContainer = wrapper.find('.hub-welcome')
    expect(welcomeContainer.hasClass('promote-daily')).toBe(false)
  })

  it('should promote daily if user has xwd sub', () => {
    props.user.hasXwd = true
    const wrapper = shallow(<Welcome {...props} />)
    const welcomeContainer = wrapper.find('.hub-welcome')
    expect(welcomeContainer.hasClass('promote-daily')).toBe(true)
  })

  it('should promote daily if user has home delivery sub', () => {
    props.user.hasHd = true
    const wrapper = shallow(<Welcome {...props} />)
    const welcomeContainer = wrapper.find('.hub-welcome')
    expect(welcomeContainer.hasClass('promote-daily')).toBe(true)
  })

  it('should not render downloadApp', () => {
    props.renderDownloadApp = null
    const wrapper = shallow(<Welcome {...props} />)
    const downloadApp = wrapper.find(
      '.hub-welcome__section.download-app',
    )
    expect(downloadApp).toHaveLength(0)
  })

  describe('when using the more games variant', () => {
    it('displays the daily crossword', () => {
      props.user.isMoarGamesVariant = true

      const wrapper = shallow(<Welcome {...props} />)

      const daily = wrapper.find('.hub-welcome__section.daily')
      expect(daily.text()).toBe('Daily')
    })

    it('displays the mini', () => {
      props.user.isMoarGamesVariant = true

      const wrapper = shallow(<Welcome {...props} />)

      const mini = wrapper.find('.hub-welcome__section.mini')
      expect(mini.text()).toBe('Mini')
    })
  })
})
