import React from 'react'
import pt from 'prop-types'
import { connect } from 'react-redux'

import AlternateCard from 'hub/AlternateCard'
import AlternateCardPhone from 'hub/AlternateCardPhone'
import PrimaryCard from 'hub/PrimaryCard'
import SecondaryCard from 'hub/SecondaryCard'
import DownloadApp from 'hub/DownloadApp/DownloadApp'
import WordplayLink from 'hub/WordplayLink/WordplayLink'
import GamesSection from 'hub/GamesSection/GamesSection'
import StreakEncouragement from 'hub/StreakEncouragement/StreakEncouragement'
import { getIsMoarGamesVariant } from 'hub/store/selectors'

import Welcome from './Welcome'

const SmartWelcome = ({ isMoarGamesVariant, user, device }) => {
  const renderDownloadApp = device.os
    ? () => <DownloadApp os={device.os} />
    : undefined

  return (
    <Welcome
      isMoarGamesVariant={isMoarGamesVariant}
      user={user}
      renderDownloadApp={renderDownloadApp}
      renderMini={() => (
        <SecondaryCard
          puzzleCollection="miniPuzzle"
          link="/crosswords/game/mini"
        />
      )}
      renderGamesSection={() => <GamesSection />}
      renderDaily={() => (
        <PrimaryCard puzzleCollection="dailyPuzzle" section="triptych"/>
      )}
      renderPromotedLinks={() => (
        <>
          <StreakEncouragement />
          <WordplayLink
            puzzleCollection="dailyPuzzle"
            isMoarGamesVariant={isMoarGamesVariant}
          />
        </>
      )}
      renderAlternate={() => <AlternateCard />}
      renderAlternatePhone={() =>
        isMoarGamesVariant ? null : <AlternateCardPhone />
      }
    />
  )
}

SmartWelcome.propTypes = {
  isMoarGamesVariant: pt.bool,
  user: pt.shape({
    hasXwd: pt.bool,
  }),
  device: pt.shape({
    os: pt.string,
  }),
}

const mapStateToProps = (state) => ({
  user: state.user,
  device: state.device,
  isMoarGamesVariant: getIsMoarGamesVariant(state),
})

export default connect(mapStateToProps)(SmartWelcome)
