import { env, xhr } from 'foundation'

import logger from '../../../games/shared/utils/clientLogger'
import { camelizeKeysDeep } from '../utils/miscellany'

import fallback from './fallback'

export const fetchStatsAndStreaks = (userId) => {
  const url = `${env.api}/svc/crosswords/v3/${userId}/stats-and-streaks.json?date_start=2014-01-01&start_on_monday=true`

  return xhr
    .get(url)
    .then((response) =>
      camelizeKeysDeep({
        dailyStats: response.results.stats,
        streaks: response.results.streaks,
      }),
    )
    .catch((error) => {
      console.error(
        'Failed to fetch stats and streaks. Falling back to mock data.',
        error,
      )
      return camelizeKeysDeep({
        dailyStats: fallback.dailyStats,
        streaks: fallback.streaks,
      })
    })
}

const fetchMiniStats = (userId) => {
  const url = `${env.api}/svc/crosswords/v3/${userId}/mini-stats.json?date_start=2014-01-01&start_on_monday=true`

  return xhr
    .get(url)
    .then((response) =>
      camelizeKeysDeep({
        miniStats: response.results,
      }),
    )
    .catch((error) => {
      console.error(
        'Failed to fetch mini stats. Falling back to mock data.',
        error,
      )
      return camelizeKeysDeep({
        miniStats: fallback.miniStats,
      })
    })
}

export const fetchAllStats = (userId) =>
  Promise.all([
    fetchMiniStats(userId),
    fetchStatsAndStreaks(userId),
  ]).then((results) =>
    results.reduce((final, v) => Object.assign(final, v), {}),
  )

export const fetchRecentPuzzles = (userId) => {
  const url = `${env.api}/svc/crosswords/v3/${userId}/recent.json`

  return xhr
    .get(url)
    .then((response) => response.results)
    .catch((error) => {
      logger.error(
        'Failed to fetch recent puzzle json. Falling back to mock data',
        error,
      )
      return fallback.recent
    })
}

export const fetchPuzzleProgress = (userId, puzzleIds) => {
  const queryParam = `?puzzle_ids=${puzzleIds.join()}`
  const url = `${env.api}/svc/crosswords/v3/${userId}/progress.json${queryParam}`

  return xhr
    .get(url)
    .then((response) =>
      response.results.reduce(
        (map, item) =>
          Object.assign(map, {
            [item.puzzle_id]: item,
          }),
        {},
      ),
    )
    .catch((error) => {
      logger.error(
        'Failed to fetch puzzle json. Falling back to mock data',
        error,
      )
      return fallback.progress
    })
}
