import { xhr } from 'foundation'

import { fetchAllStats } from './api'

jest.mock('foundation', () => ({
  env: {
    api: 'host',
  },
  xhr: {
    get: jest.fn(),
  },
}))

describe('HUB: FETCH USER STATS', () => {
  it('should fetch stats and streaks', () => {
    expect.assertions(2)

    xhr.get.mockImplementation((url) =>
      Promise.resolve(
        url.includes('mini-stats')
          ? { results: { mini_stat: 100 } }
          : {
              results: {
                stats: { daily_stat: 123 },
                streaks: { streak_stuff: true },
              },
            },
      ),
    )

    const promise = fetchAllStats(13)

    /** assert correct args for xhr */
    expect(xhr.get.mock.calls).toEqual([
      [
        'host/svc/crosswords/v3/13/mini-stats.json?date_start=2014-01-01&start_on_monday=true',
      ],
      [
        'host/svc/crosswords/v3/13/stats-and-streaks.json?date_start=2014-01-01&start_on_monday=true',
      ],
    ])

    /** assert proper value comes back */
    return promise.then((stats) => {
      expect(stats).toMatchObject({
        miniStats: { miniStat: 100 },
        dailyStats: { dailyStat: 123 },
        streaks: { streakStuff: true },
      })
    })
  })
})
