import '../shared-styles'
import '../shared-scripts'

import React from 'react'
import ReactDOM from 'react-dom'
import { Provider } from 'react-redux'

import { user, device } from 'foundation'
import { UserProvider } from 'user'
import ClientSideScripts from 'shared/components/ClientSideScripts'

import { FeatureFlagProvider } from '../abra/FeatureFlagProvider'

import AbraWrapper from './AbraWrapper'
import setUpStore from './store/store'
import * as api from './api/api'
import HubContainer from './HubContainer/HubContainer'
import { getUserId, getDeviceOs } from './store/actionCreators'

import './index.scss'

/* eslint-disable-next-line no-underscore-dangle */
const hubProps = window.__HUB_PROPS__
/* eslint-disable-next-line no-underscore-dangle */
delete window.__HUB_PROPS__

const {
  hubVariant,
  userType,
  hubPuzzles,
  deviceType,
  compliance,
  sponsorship,
  navigationLinks,
} = hubProps

// Set up store
const store = setUpStore({
  hubVariant,
  userType,
  hubPuzzles,
  deviceType,
  compliance,
  sponsorship,
  subscribeLinks: navigationLinks.subscribe,
})

store.dispatch(getUserId(user))
store.dispatch(getDeviceOs(device))

ReactDOM.render(
  <>
    <ClientSideScripts />
    <UserProvider>
      <Provider store={store}>
        <AbraWrapper>
          <FeatureFlagProvider>
            <HubContainer
              {...hubProps}
              api={api}
              user={user}
              device={device}
            />
          </FeatureFlagProvider>
        </AbraWrapper>
      </Provider>
    </UserProvider>
  </>,
  document.getElementById('hub-root'),
)
