import React, { Component } from 'react'
import propTypes from 'prop-types'
import cn from 'classnames'

class Drawer extends Component {
  constructor(props) {
    super(props)
    this.state = {
      isOpen: props.startOpen || false,
      hasBeenCalled: false,
    }
  }

  componentDidMount = this.onView

  componentDidUpdate = this.onView

  shouldComponentUpdate(nextProps, nextState) {
    const { isOpen } = this.state
    return isOpen !== nextState.isOpen
  }

  onView() {
    const { onView } = this.props
    const { hasBeenCalled, isOpen } = this.state
    const isFirstCall = !hasBeenCalled
    if (typeof onView === 'function' && isOpen) {
      onView(isFirstCall)
      if (isFirstCall) {
        this.setState({ hasBeenCalled: true })
      }
    }
  }

  toggle() {
    this.setState((prevState) => ({
      isOpen: !prevState.isOpen,
    }))
  }

  render() {
    const { title, children } = this.props
    const { isOpen } = this.state

    return (
      <div
        className={cn('accordion__drawer', {
          isOpen,
          isClosed: !isOpen,
        })}
      >
        {/* eslint-disable-next-line jsx-a11y/no-noninteractive-element-interactions */}
        <h6
          className="accordion__drawerTitle"
          onClick={() => this.toggle()}
        >
          {title}
        </h6>
        <div className="accordion__drawerContent">{children}</div>
      </div>
    )
  }
}

Drawer.propTypes = {
  startOpen: propTypes.bool,
  onView: propTypes.func,
  children: propTypes.element,
  title: propTypes.string,
}

Drawer.defaultProps = {
  startOpen: false,
  onView: () => {},
  children: null,
  title: '',
}

export default Drawer
