import React from 'react'
import { shallow } from 'enzyme'

import ButtonTab from './ButtonTab'

describe('COMPONENT: LINKTAB', () => {
  const defaultProps = {
    isCurrentTab: false,
    title: 'test title',
  }

  it('returns a button', () => {
    const wrapper = shallow(<ButtonTab {...defaultProps} />)
    expect(wrapper.find('button')).toHaveLength(1)
  })

  it('uses the provided tab title', () => {
    const wrapper = shallow(<ButtonTab {...defaultProps} />)
    expect(
      wrapper
        .find('span')
        .first()
        .text(),
    ).toEqual('test title')
  })

  it('applies the correct class for a selected tab', () => {
    const wrapper = shallow(
      <ButtonTab {...defaultProps} isCurrentTab />,
    )
    expect(wrapper.find('.active')).toHaveLength(1)
  })

  it('does not apply additional styling for unselected tabs', () => {
    const wrapper = shallow(<ButtonTab {...defaultProps} />)
    expect(wrapper.find('.active')).toHaveLength(0)
  })
})
