import React from 'react'
import PT from 'prop-types'
import { Link as ReactRouterLink } from 'react-router-dom'

/**
 * NOTE: When using TabGroup with LinkTab, to ensure proper routing,
 * be sure to match your React Router paramater handling
 * to your tab object formatting.
 *
 * Example:
 * A route handler of /crosswords/archive/:param (e.g. /crosswords/archive/mini)
 * Should correspond to a tab object like
 * {
 *   Tab: <LinkTab>mini</LinkTab>,
 *   param: 'mini',
 *   key: 'mini',
 * }
 */
const LinkTab = ({ isCurrentTab, title, ...props }) => (
  <ReactRouterLink {...props}>
    <span>{title}</span>
    {isCurrentTab && (
      <div className="active">
        <span>{title}</span>
      </div>
    )}
  </ReactRouterLink>
)

LinkTab.propTypes = {
  isCurrentTab: PT.bool,
  title: PT.string.isRequired,
}

export default LinkTab
