import React from 'react'
import { shallow } from 'enzyme'
import { Link as ReactRouterLink } from 'react-router-dom'

import LinkTab from './LinkTab'

describe('COMPONENT: LINKTAB', () => {
  const defaultProps = {
    isCurrentTab: false,
    title: 'test title',
    to: '/a-test-tab/',
  }

  it('returns a react router link', () => {
    const wrapper = shallow(<LinkTab {...defaultProps} />)
    expect(wrapper.find(ReactRouterLink)).toHaveLength(1)
  })

  it('uses the provided tab title', () => {
    const wrapper = shallow(<LinkTab {...defaultProps} />)
    expect(
      wrapper
        .find('span')
        .first()
        .text(),
    ).toEqual('test title')
  })

  it('applies the correct class for a selected tab', () => {
    const wrapper = shallow(
      <LinkTab {...defaultProps} isCurrentTab />,
    )
    expect(wrapper.find('.active')).toHaveLength(1)
  })

  it('does not apply additional styling for unselected tabs', () => {
    const wrapper = shallow(<LinkTab {...defaultProps} />)
    expect(wrapper.find('.active')).toHaveLength(0)
  })
})
