import React from 'react'
import { mount, shallow } from 'enzyme'

import Tabs from '../Tabs/Tabs'
import ButtonTab from '../ButtonTab/ButtonTab'

import TabGroup from './TabGroup'

describe('COMPONENT: TabGroup', () => {
  const defaultProps = {
    onChange: () => {},
    initialTab: 0,
    tabs: [
      {
        Tab: <ButtonTab title="aTab" />,
        content: <div id="some-tab-info" />,
        key: 'aTab',
      },
      {
        Tab: <ButtonTab title="anotherTab" />,
        content: <div id="tab-info" />,
        key: 'tabInfo',
      },
    ],
  }

  const defaultSetup = (customProps) => {
    return shallow(<TabGroup {...defaultProps} {...customProps} />)
  }

  it('Renders Tabs', () => {
    const wrapper = defaultSetup()
    expect(wrapper.find(Tabs)).toHaveLength(1)
  })

  it('has built-in tab selection and state management', () => {
    const wrapper = mount(<TabGroup {...defaultProps} />)

    // We start with the first tab (default) selected
    expect(wrapper.find('#some-tab-info')).toHaveLength(1)
    expect(wrapper.find('#tab-info')).toHaveLength(0)

    // Click on the second tab
    const tab2 = wrapper.find('button').at(1)
    tab2.simulate('click')

    // Now, the second tab body is present
    expect(wrapper.find('#some-tab-info')).toHaveLength(0)
    expect(wrapper.find('#tab-info')).toHaveLength(1)
  })
})
