import React from 'react'
import propTypes from 'prop-types'

import { tabsPropTypes } from '../../../sharedPropTypes'
import TabContents from '../TabContents/TabContents'

const Tabs = ({ currentTab, tabs, updateTab }) => {
  const selectedTab = tabs[currentTab] || {}

  return (
    <div className="tab__tabGroup">
      <nav className="tab__tabNav">
        <ul className="tab__tabNavItems">
          {tabs &&
            tabs.map(({ Tab, key }, idx) => {
              return React.cloneElement(Tab, {
                key,
                className: 'tab__tab',
                style: { width: `${(1 / tabs.length) * 100}%` },
                onClick: () => updateTab(idx),
                isCurrentTab: idx === currentTab,
              })
            })}
        </ul>
      </nav>
      {selectedTab && <TabContents tab={selectedTab} />}
    </div>
  )
}

Tabs.propTypes = {
  currentTab: propTypes.number,
  tabs: tabsPropTypes.isRequired,
  updateTab: propTypes.func,
}

Tabs.defaultProps = {
  updateTab: () => {},
}

export default Tabs
