import React from 'react'
import { shallow } from 'enzyme'

import ButtonTab from '../ButtonTab/ButtonTab'
import LinkTab from '../LinkTab/LinkTab'
import TabContents from '../TabContents/TabContents'

import Tabs from './Tabs'

const buttonTabs = [
  {
    Tab: <ButtonTab title="aTab" />,
    content: <div id="some-tab-info" />,
    key: 'aTab',
  },
  {
    Tab: <ButtonTab title="anotherTab" />,
    content: <div id="tab-info" />,
    key: 'anotherTab',
  },
]

const linkTabs = [
  {
    Tab: <LinkTab title="aTab" to="/daily-tab" />,
    content: <div id="some-tab-info" />,
    key: 'some-tab-info',
  },
  {
    Tab: <LinkTab title="anotherTab" to="/mini-tab" />,
    content: <div id="tab-info" />,
    key: 'tab-info',
  },
]

describe('COMPONENT: Tabs', () => {
  const defaultProps = {
    currentTab: 0,
    updateTab: jest.fn(),
    tabs: buttonTabs,
  }

  it('renders the Tab component provided', () => {
    const buttonTabWrapper = shallow(<Tabs {...defaultProps} />)
    const linkTabWrapper = shallow(
      <Tabs {...defaultProps} tabs={linkTabs} />,
    )

    expect(buttonTabWrapper.find(ButtonTab)).toHaveLength(2)
    expect(linkTabWrapper.find(LinkTab)).toHaveLength(2)
  })

  it('renders a TabContent component with the selected tab content', () => {
    const wrapper = shallow(<Tabs {...defaultProps} />)

    expect(wrapper.find(TabContents)).toHaveLength(1)
  })
})
