import React from 'react'
import propTypes from 'prop-types'
import cn from 'classnames'

/**
 * EXAMPLE USAGE
 * <HideOn mobile></HideOn>
 * <HideOn mobile desktop></HideOn>
 * <ShowOn mobile desktop tablet></HideOn>
 */

const validDeviceKeys = ['phone', 'tablet', 'desktop', 'smallDevice']

const getClasses = (props) =>
  Object.keys(props).reduce((classes, propName) => {
    if (validDeviceKeys.includes(propName)) {
      if (props[propName]) classes.push(propName)
    } else {
      throw new Error(
        `Visibility expected one of ${validDeviceKeys.join()}`,
      )
    }

    return classes
  }, [])

/* eslint-disable react/no-unused-prop-types */
const visibilityProps = {
  children: propTypes.oneOfType([
    propTypes.element,
    propTypes.string,
    propTypes.arrayOf(propTypes.element),
  ]),
  phone: propTypes.bool,
  tablet: propTypes.bool,
  desktop: propTypes.bool,
  smallDevice: propTypes.bool,
}
/* eslint-enable react/no-unused-prop-types */

export const HideOn = ({ children, ...props }) => (
  <div className={cn('hideOn', ...getClasses(props))}>{children}</div>
)

export const ShowOn = ({ children, ...props }) => (
  <div className={cn('showOn', ...getClasses(props))}>{children}</div>
)

HideOn.propTypes = visibilityProps
ShowOn.propTypes = visibilityProps
