import { combineReducers } from 'redux'

import convertToV6 from '../utils/convertToV6'

import {
  CHANGE_PRINT_OPTION,
  GET_USER_ID,
  GET_DEVICE_OS,
  SET_HUB_VARIANT,
  GET_STATS_AND_STREAKS,
  GET_PUZZLE_COLLECTIONS,
  SELECT_PUZZLE,
  UPDATE_PUZZLES_PROGRESS,
  LOAD_PRINT_PREFS,
  CHANGE_BLOCK_OPACITY,
  CHANGE_PRINT_LAYOUT,
} from './constants'

/*
 * Useful when we compose nested reducers, and
 * some of the top level keys should simply accept whatever
 * state is passed to them, regardless of the action
 */
const createIdentityReducer = (initial) => (state = initial) => state

/** temporary collection reducer while integrating cards and hub page */
const collectionsReducer = (state = {}, { type, payload }) => {
  switch (type) {
    case GET_PUZZLE_COLLECTIONS:
      return { ...payload.collections, ...state }
    default:
      return state
  }
}

const puzzlesReducer = (state = {}, { type, payload }) => {
  switch (type) {
    case GET_PUZZLE_COLLECTIONS:
      return { ...payload.puzzles, ...state }
    case UPDATE_PUZZLES_PROGRESS:
      return Object.entries(state).reduce(
        (newState, [id, val]) =>
          Object.assign(newState, {
            [id]: { ...val, ...payload[id] },
          }),
        {},
      )
    default:
      return state
  }
}

const statsReducer = (state = {}, { type, payload }) => {
  switch (type) {
    case GET_STATS_AND_STREAKS:
      return { ...state, ...payload }
    default:
      return state
  }
}

const userReducer = (state = {}, { type, payload }) => {
  switch (type) {
    case GET_USER_ID:
      return { ...state, id: payload }
    default:
      return state
  }
}

const deviceReducer = (state = {}, { type, payload }) => {
  switch (type) {
    case GET_DEVICE_OS:
      return { ...state, os: payload }
    default:
      return state
  }
}

const hubVariantReducer = (state = '', { type, payload }) => {
  switch (type) {
    case SET_HUB_VARIANT:
      return payload
    default:
      return state
  }
}

export const defaultOptions = {
  selectedPuzzle: {},
  isGeneratable: false,
  version: 'puzzle',
  showBlack: false,
  showSpoiler: true,
}

// For now, add (don't replace) v6 key/value pairs to v2 data format since other parts of the app reference v2 keys
const printOptionsReducer = (state = defaultOptions, action) => {
  const { payload, type } = action
  switch (type) {
    case SELECT_PUZZLE:
      return {
        ...convertToV6(state, action.payload),
        version: 'puzzle', // default to puzzle for each newly selected puzzle
      }
    case CHANGE_PRINT_OPTION:
      return {
        ...state,
        ...payload,
      }
    default:
      return state
  }
}

const defaultPrintPrefs = {
  opacity: 100,
  layout: 'standard', // standard | southpaw | large_print
}

const printPrefsReducer = (state = defaultPrintPrefs, action) => {
  const { type, payload } = action
  switch (type) {
    case LOAD_PRINT_PREFS:
      return payload || state
    case CHANGE_PRINT_LAYOUT:
    case CHANGE_BLOCK_OPACITY: {
      return {
        ...state,
        ...payload,
      }
    }
    default:
      return state
  }
}

export default combineReducers({
  user: userReducer,
  stats: statsReducer,
  device: deviceReducer,
  hubVariant: hubVariantReducer,
  puzzles: puzzlesReducer,
  collections: collectionsReducer,
  ourGames: createIdentityReducer([]),
  compliance: createIdentityReducer({}),
  sponsorship: createIdentityReducer({}),
  subscribeLinks: createIdentityReducer({}),
  printOptions: printOptionsReducer,
  printPrefs: printPrefsReducer,
})
