import { createSelector } from 'reselect'
import moment from 'moment'

import { HUB_VARIANT_MOAR_GAMES } from './constants'

/**
 * Determine if we should render the Moar Games hub variant.
 *
 * @param {Object} state The store's state object
 * @returns {Bool}
 */
export const getIsMoarGamesVariant = ({ hubVariant }) =>
  hubVariant === HUB_VARIANT_MOAR_GAMES

/** collections */
export const getCollections = (state) => state.collections
export const getPuzzles = (state) => state.puzzles
export const getGamesSection = (state) => state.ourGames

/** today's date */
export const getTodaysDate = createSelector(
  [getCollections, getPuzzles],
  (collections, puzzles) => {
    const todaysId =
      collections.dailyPuzzle && collections.dailyPuzzle[0]
    const todaysPuzzle = puzzles[todaysId]
    return todaysPuzzle && todaysPuzzle.print_date
  },
)

export const getTodaysDayIdx = createSelector(
  getTodaysDate,
  (today) => (today ? new Date(today).getUTCDay() : undefined),
)

/** streaks */
export const getStreaks = (state) =>
  state.stats && state.stats.streaks

export const getStreakLength = createSelector(
  getStreaks,
  (streaks) => (streaks && streaks.currentStreak) || 0,
)

export const getLastStreakDate = createSelector(
  getStreaks,
  (streaks) => {
    if (!streaks || !streaks.dates) return undefined
    const newest = streaks.dates[streaks.dates.length - 1] || []
    return newest[newest.length - 1]
  },
)

export const getVerticalStreak = createSelector(
  [getStreaks, getTodaysDayIdx],
  (streaks, todaysIdx) =>
    (streaks &&
      streaks.verticalStreaks &&
      streaks.verticalStreaks[todaysIdx]) ||
    {},
)

export const getVerticalStreakLength = createSelector(
  getVerticalStreak,
  (verticalStreak) => verticalStreak.length || 0,
)

export const getVerticalStreakNextDate = createSelector(
  getVerticalStreak,
  (verticalStreak) => verticalStreak.nextDate || undefined,
)

const selectedPuzzle = (state) => state.printOptions.selectedPuzzle

export const formatDate = createSelector(selectedPuzzle, (puzzle) => {
  const fullMonth = moment(puzzle.printDate).format('MMMM')
  const year = moment(puzzle.printDate).format('YYYY')
  const dayOfMonth = moment(puzzle.printDate).format('D')

  return `${fullMonth} ${dayOfMonth}, ${year}`
})

export const getCurrentPuzzle = (state) => state.gamePageData || {}
