import thunk from 'redux-thunk'
import { createStore, compose, applyMiddleware } from 'redux'

import createGamesSectionData from '../utils/createGamesSectionData'
import normalizeCollections from '../utils/normalizeCollections'

import { persistPreferences } from './middleware'
import reducer from './reducer'
import { initialState } from './constants'

/* ------------
  STORE SETUP
------------- */

const setUpStore = ({
  hubVariant,
  userType,
  compliance,
  deviceType,
  sponsorship,
  subscribeLinks,
  hubPuzzles = {},
}) => {
  const middleware = [applyMiddleware(thunk, persistPreferences)]

  if (
    typeof window !== 'undefined' &&
    window.__REDUX_DEVTOOLS_EXTENSION__
  ) {
    middleware.push(window.__REDUX_DEVTOOLS_EXTENSION__())
  }

  const store = createStore(
    reducer,
    {
      ...initialState,
      hubVariant,
      compliance,
      sponsorship,
      user: userType,
      subscribeLinks,
      device: deviceType,
      ...normalizeCollections(hubPuzzles),
      ourGames: createGamesSectionData(
        hubPuzzles,
        userType,
        subscribeLinks,
      ),
    },
    compose(...middleware),
  )

  return store
}

export default setUpStore
