import moment from 'moment'

import createGamesSectionData from '../createGamesSectionData'

jest.mock('../../constants/ourGames', () => [
  {
    id: 'game-one',
    name: 'Game One',
    url: '/puzzles/game-one',
    subscriptionCampaign: 'gameOneCard',
    description: 'Description of Game One',
  },
  {
    id: 'game-two',
    name: 'Game Two',
    url: '/puzzles/game-two',
    subscriptionCampaign: 'gameTwoCard',
    description: 'Description of Game Two',
  },
])

const subscribeLinks = {
  gameOneCard: 'subscribe/gameOne',
  gameTwoCard: 'subscribe/gameTwo',
}

describe('UTIL: CREATE GAMES SECTION STATE', () => {
  it('should handle missing free products', () => {
    const data = {}
    const user = { hasXwd: false }
    const newGames = createGamesSectionData(
      data,
      user,
      subscribeLinks,
    )
    expect(newGames).toEqual([
      {
        freeUntil: null,
        id: 'game-one',
        name: 'Game One',
        url: '/puzzles/game-one',
        description: 'Description of Game One',
        subscribe: 'subscribe/gameOne',
      },
      {
        freeUntil: null,
        id: 'game-two',
        name: 'Game Two',
        url: '/puzzles/game-two',
        description: 'Description of Game Two',
        subscribe: 'subscribe/gameTwo',
      },
    ])
  })

  it('should handle xwd users', () => {
    const data = {}
    const user = { hasXwd: true }
    const newGames = createGamesSectionData(
      data,
      user,
      subscribeLinks,
    )
    expect(newGames).toEqual([
      {
        freeUntil: null,
        id: 'game-one',
        name: 'Game One',
        url: '/puzzles/game-one',
        description: 'Description of Game One',
      },
      {
        freeUntil: null,
        id: 'game-two',
        name: 'Game Two',
        url: '/puzzles/game-two',
        description: 'Description of Game Two',
      },
    ])
  })

  it('should handle free games', () => {
    const expiration = moment('2100-12-25')
    const data = {
      free_products: [
        { name: 'game-one', expiration: expiration.unix() },
      ],
    }
    const user = { hasXwd: false }
    const newGames = createGamesSectionData(
      data,
      user,
      subscribeLinks,
    )

    expect(newGames).toEqual([
      {
        freeUntil: 'December 25th',
        id: 'game-one',
        name: 'Game One',
        url: '/puzzles/game-one',
        description: 'Description of Game One',
      },
      {
        freeUntil: null,
        id: 'game-two',
        name: 'Game Two',
        url: '/puzzles/game-two',
        description: 'Description of Game Two',
        subscribe: 'subscribe/gameTwo',
      },
    ])
  })

  it('should check that the promo hasn’t expired', () => {
    const expiration = moment('2100-12-01')
    const data = {
      free_products: [
        {
          name: 'game-one',
          expiration: moment()
            .subtract(1, 'seconds')
            .unix(),
        },
        { name: 'game-two', expiration: expiration.unix() },
      ],
    }
    const user = { hasXwd: false }
    const newGames = createGamesSectionData(
      data,
      user,
      subscribeLinks,
    )

    expect(newGames).toEqual([
      {
        freeUntil: null,
        id: 'game-one',
        name: 'Game One',
        url: '/puzzles/game-one',
        description: 'Description of Game One',
        subscribe: 'subscribe/gameOne',
      },
      {
        freeUntil: 'December 1st',
        id: 'game-two',
        name: 'Game Two',
        url: '/puzzles/game-two',
        description: 'Description of Game Two',
      },
    ])
  })
})
