import * as urls from '../createUrls'

jest.mock('../time', () => ({
  formatDate: (date, format) => `${date}-${format}`,
}))

describe('UTIL / CREATE URLS', () => {
  describe('create pdf url', () => {
    test('for daily puzzle', () => {
      const puzzle = { publishType: 'Daily', printDate: 'today' }
      expect(urls.createPDFUrl(puzzle)).toEqual(
        '/svc/crosswords/v2/puzzle/print/today-MMMDDYY.pdf',
      )
      expect(urls.createPDFUrl(puzzle, true)).toEqual(
        '/svc/crosswords/v2/puzzle/print/today-MMMDDYY.ans.pdf',
      )
    })
    test('for any other puzzle', () => {
      const puzzle = { publishType: 'Other', printDate: 'today' }
      expect(urls.createPDFUrl(puzzle)).toEqual(undefined)
      expect(urls.createPDFUrl(puzzle, true)).toEqual(undefined)
    })
  })

  describe('create generated urls', () => {
    test('for a downloadable puzzle', () => {
      const puzzle = {
        puzzleId: 123,
        formatType: 'Normal',
      }
      expect(urls.createGeneratedUrls(puzzle)).toEqual({
        puzzle: '/svc/crosswords/v2/puzzle/123.pdf',
        solution: '/svc/crosswords/v2/puzzle/123.ans.pdf',
      })
    })

    test('for a non-downloadable puzzle', () => {
      const puzzle = {
        puzzleId: 123,
        formatType: 'Other',
      }
      expect(urls.createGeneratedUrls(puzzle)).toEqual({})
    })
  })

  describe('create play url', () => {
    test('for pdf-only puzzle', () => {
      const puzzle = { formatType: 'PDF', printDate: 'today' }
      expect(urls.createPlayUrl(puzzle)).toEqual(undefined)
    })
    test('for standard puzzle', () => {
      const puzzle = {
        publishType: 'Daily',
        printDate: 'today',
        formatType: 'Normal',
      }
      expect(urls.createPlayUrl(puzzle)).toEqual(
        '/crosswords/game/daily/today-YYYY/MM/DD',
      )
    })
    test('for bonus puzzle', () => {
      const puzzle = {
        publishType: 'Bonus',
        printDate: 'today',
        formatType: 'Normal',
      }
      expect(urls.createPlayUrl(puzzle)).toEqual(
        '/crosswords/game/bonus/today-YYYY/MM',
      )
    })
  })
})
