import finesseHubCollections from '../finesseHubCollections'

describe('UTILS: FINESSE HUB COLLECTIONS', () => {
  it('should return all collection keys', () => {
    const collections = {
      daily_puzzle: [],
      bonus_puzzle: [],
      entitlement: 'basic',
    }

    const expected = {
      daily_puzzle: [],
      bonus_puzzle: [],
      entitlement: 'basic',
    }

    expect(finesseHubCollections(collections)).toEqual(expected)
  })
  it('should mark the mini_puzzle as isFree', () => {
    const collections = {
      mini_puzzle: [
        {
          puzzle_id: 12345,
          title: '',
        },
      ],
    }

    expect(
      finesseHubCollections(collections).mini_puzzle[0],
    ).toHaveProperty('isFree', true)
  })

  it('should combine free_puzzles and free_mini_from_archive and mark all as free', () => {
    const collections = {
      free_puzzles: [{ puzzle_id: 12345 }, { puzzle_id: 23456 }],
      free_mini_from_archive: [{ puzzle_id: 34567 }],
    }

    const finessedCollections = finesseHubCollections(collections)

    expect(finessedCollections.free_puzzles).toHaveLength(3)
    expect(finessedCollections).not.toHaveProperty(
      'free_mini_from_archive',
    )
    finessedCollections.free_puzzles.forEach((freePuzzle) => {
      expect(freePuzzle).toHaveProperty('isFree', true)
    })
  })

  it('should delete free_products', () => {
    const collections = {
      daily_puzzle: [],
      free_products: [],
    }

    expect(finesseHubCollections(collections)).not.toHaveProperty(
      'free_products',
    )
  })
})
