const freeCollections = [
  'mini_puzzle',
  'tips_and_tricks_mini_puzzles',
  'free_mini_from_archive',
  'free_puzzles',
]

const markFree = (puzzle) => ({ ...puzzle, isFree: true })

/**
 * Finesse some of the collections we get from the /puzzles endpoint.
 * We do things like marking relevant collections as free, combining collections,
 * and removing unneeded collections.
 * We'll return basically a similarly structured collections object.
 *
 * @param {Object} collections An object of collections from the API
 * @returns {Object}           A finessed version of the collections from the API
 */
export default (collections) => {
  const markedFree = Object.entries(collections).reduce(
    (finessed, [collection, puzzles]) => ({
      ...finessed,
      ...{
        [collection]: freeCollections.includes(collection)
          ? (puzzles || []).map(markFree)
          : puzzles || [],
      },
    }),
    {},
  )

  /** combine two collections so it is not a problem down stream :( */
  if (markedFree.free_puzzles && markedFree.free_mini_from_archive) {
    markedFree.free_puzzles = [
      ...markedFree.free_puzzles,
      ...markedFree.free_mini_from_archive,
    ]
    delete markedFree.free_mini_from_archive
  }

  delete markedFree.free_products

  return markedFree
}
