import finesseHubCollections from './finesseHubCollections'
import { convertSnakeToCamel } from './miscellany'

/**
 * Normalize and clean a puzzle collection response from the API
 * before passing along to our UI for rendering.
 *
 * In:
 *  {
 *    mini_puzzle: [
 *      { puzzle_id: 18650, ... },
 *      ...
 *    ],
 *    tips_and_tricks_mini_puzzles: [...],
 *    free_mini_from_archive: [...],
 *    free_puzzles: [
 *      { puzzle_id: 5685, ... },
 *      ...
 *    ],
 *    weekly_puzzles: [...],
 *    variety_puzzles: [...],
 *    daily_puzzle: [
 *      { puzzle_id: 18639, ... }
 *    ],
 *    bonus_puzzle: [],
 *    free_products: [],
 *    entitlement: 'basic',
 *  }
 *
 * Out:
 * {
 *   puzzles: {
 *     '5685': {...},
 *     '9506': {...},
 *     '18636': {...},
 *     '18639': {...},
 *     '18650': {...},
 *     ...
 *   },
 *   collections: {
 *     miniPuzzle: [18650],
 *     tipsAndTricksMiniPuzzles: [9506, ...],
 *     freePuzzles: [5685, ...],
 *     weeklyPuzzles: [18636, ...],
 *     varietyPuzzles: [...],
 *     dailyPuzzle: [18639],
 *     promoPuzzle: [...],
 *     bonusPuzzle: [],
 *   },
 * }
 *
 * @param {Object} collections An object of collections from the API
 * @returns {Object)           A normalized representation of the puzzles and collections
 */
const normalizeCollections = (collections) =>
  Object.entries(finesseHubCollections(collections)).reduce(
    (final, [key, values]) => {
      /** there is an odd key at the end of the collection */
      if (!Array.isArray(values)) return final

      const camelizedKey = convertSnakeToCamel(key)
      final.collections[camelizedKey] = []
      values.forEach((puzz) => {
        final.collections[camelizedKey].push(puzz.puzzle_id)
        final.puzzles[puzz.puzzle_id] = puzz
      })
      return final
    },
    { puzzles: {}, collections: {} },
  )

export default normalizeCollections
