/**
 * withPuzzle()
 * is a higher order component to help make components that
 * accept a collection key prop and recieve puzzles from redux
 * the reason for the complexity is that using reselect
 * with props, across multiple components is tricky!
 * see here: https://github.com/reactjs/reselect#sharing-selectors-with-props-across-multiple-components
 *
 * Example use:
 * const MyComponent = ({ puzzle }) => <div>{JSON.stringify(puzzle)}</div>
 * const Connected = withPuzzle(MyComponent)
 * <Connected puzzleId='123' />
 */
import { connect } from 'react-redux'
import { createSelector } from 'reselect'

const getPuzzle = (state, props) => state.puzzles[props.puzzleId]

const withPuzzle = (Component) =>
  connect(() => {
    /** we must make the selector for each instance, because it depends on props */
    const get = createSelector([getPuzzle], (puzzle) => puzzle)

    /** create the mapper for each instance */
    return (state, props) => ({
      puzzleData: get(state, props), // NOTE: temporary until new PuzzleCard is ready
      puzzle: get(state, props),
    })
  })(Component)

export default withPuzzle
