import React from 'react'
import pt from 'prop-types'

import Button from './Button'

class AsyncButton extends React.Component {
  constructor(props) {
    super(props)

    this.state = {
      isPending: false,
    }
  }

  handle = () => {
    this.setState({ isPending: true })
    const { action, onThen, onCatch } = this.props
    return action()
      .then((result) => {
        this.setState({ isPending: false }, () => {
          onThen(result)
        })
      })
      .catch((err) => {
        this.setState({ isPending: false }, () => {
          onCatch(err)
        })
      })
  }

  render() {
    const { pending, children } = this.props
    const { isPending } = this.state

    return (
      <Button
        {...this.props}
        action={this.handle}
        isDisabled={isPending}
      >
        {isPending ? pending : children}
      </Button>
    )
  }
}

AsyncButton.propTypes = {
  action: pt.func.isRequired,
  onThen: pt.func,
  onCatch: pt.func,
  pending: pt.string,
  children: pt.node.isRequired,
}

AsyncButton.defaultProps = {
  onThen: () => {},
  onCatch: () => {},
  pending: '...',
}

export default AsyncButton
