import React from 'react'
import { shallow } from 'enzyme'

import AsyncButton from './AsyncButton'
import Button from './Button'

jest.mock('./Button', () => () => '')

describe('LEADERBOARD: ASYNC BUTTON', () => {
  it('handles an async action that succeeds', () => {
    expect.assertions(6)

    const action = jest.fn()
    const onComplete = jest.fn()
    const onError = jest.fn()

    let complete

    action.mockReturnValue(
      /* eslint-disable-next-line no-unused-vars */
      new Promise((resolve, reject) => {
        complete = resolve
      }),
    )

    const button = shallow(
      <AsyncButton
        action={action}
        onThen={onComplete}
        onCatch={onError}
        pending="waiting..."
      >
        Push Me
      </AsyncButton>,
    )

    expect(button.find(Button).prop('children')).toBe('Push Me')

    const promise = button.find(Button).prop('action')()

    expect(action).toHaveBeenCalled()
    expect(onComplete).not.toHaveBeenCalled()
    expect(button.find(Button).prop('children')).toBe('waiting...')

    complete('result')

    return promise.then(() => {
      expect(button.find(Button).prop('children')).toBe('Push Me')
      expect(onComplete).toHaveBeenCalledWith('result')
    })
  })

  it('handles an async action that fails', () => {
    expect.assertions(5)

    const action = jest.fn()
    const onComplete = jest.fn()
    const onError = jest.fn()
    const testError = new Error('test')

    let fail

    action.mockReturnValue(
      new Promise((resolve, reject) => {
        fail = reject
      }),
    )

    const button = shallow(
      <AsyncButton
        action={action}
        onThen={onComplete}
        onCatch={onError}
        pending="waiting..."
      >
        Push Me
      </AsyncButton>,
    )

    const promise = button.find(Button).prop('action')()

    expect(action).toHaveBeenCalled()
    expect(onError).not.toHaveBeenCalled()
    expect(button.find(Button).prop('children')).toBe('waiting...')

    fail(testError)

    return promise.then(() => {
      expect(button.find(Button).prop('children')).toBe('Push Me')
      expect(onError).toHaveBeenCalledWith(testError)
    })
  })
})
