import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import { trackEvent } from '../track/track'

const Button = ({
  action,
  type,
  children,
  href,
  isDisabled,
  className,
  id,
  target,
  track,
}) => {
  const Tag = href ? 'a' : 'button'

  const clickHandler = (e) => {
    if (action) action(e)

    if (track) trackEvent(track)
  }

  return (
    <Tag
      href={href}
      disabled={isDisabled}
      target={target}
      id={id}
      className={cn('lbd-button', type, className)}
      onClick={clickHandler}
    >
      {children}
    </Tag>
  )
}

Button.propTypes = {
  id: pt.string,
  href: pt.string,
  target: pt.string,
  className: pt.string,
  isDisabled: pt.bool,
  action: pt.func,
  type: pt.oneOf(['black', 'white']).isRequired,
  children: pt.string.isRequired,
  track: pt.string,
}

export default Button
