import React from 'react'
import { shallow } from 'enzyme'

import { trackEvent } from '../track/track'

import Button from './Button'

jest.mock('../track/track', () => ({
  trackEvent: jest.fn(),
}))

describe('LEADERBOARD: BUTTONS', () => {
  it('class name matches prop type', () => {
    const button = shallow(<Button type="black">hey</Button>)
    expect(button.find('button.lbd-button').hasClass('black')).toBe(
      true,
    )
  })

  it('includes click handler for action', () => {
    const action = jest.fn()
    const button = shallow(
      <Button action={action} type="black">
        hey
      </Button>,
    )
    button.find('button.lbd-button').simulate('click')
    expect(action).toHaveBeenCalled()
  })

  it('supports tracking an event', () => {
    const action = jest.fn()
    const button = shallow(
      <Button action={action} type="black" track="eventName">
        hey
      </Button>,
    )
    button.find('button.lbd-button').simulate('click')
    expect(action).toHaveBeenCalled()
    expect(trackEvent).toHaveBeenCalledWith('eventName')
  })

  it('should render content', () => {
    const button = shallow(<Button type="black">Some Content</Button>)
    expect(button.find('button.lbd-button').text()).toBe(
      'Some Content',
    )
  })

  it('should render link if passed href', () => {
    const action = jest.fn()
    const button = shallow(
      <Button href="link" action={action} type="black">
        Some Content
      </Button>,
    )
    expect(button.find('a.lbd-button').prop('href')).toBe('link')
  })

  it('should be disabled if passed isDisabled', () => {
    const button = shallow(
      <Button isDisabled type="black">
        Some Content
      </Button>,
    )
    expect(button.find('button.lbd-button').prop('disabled')).toEqual(
      true,
    )
  })

  it('should not be disabled if not passed isDisabled', () => {
    const button = shallow(<Button type="black">Some Content</Button>)
    expect(button.find('button.lbd-button').prop('disabled')).toEqual(
      undefined,
    )
  })
})
