import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'
import ClipboardJS from 'clipboard'

import { trackEvent } from '../track/track'

class CopyToClipboard extends React.Component {
  constructor(props) {
    super(props)

    this.state = {
      copied: false,
    }

    this.trigger = React.createRef()
  }

  componentDidMount() {
    const { content } = this.props

    this.clipboard = this.setClipboard(content)

    this.clipboard.on('success', () => {
      trackEvent('INVITE_COPY')
      this.setState({
        copied: true,
      })
    })
  }

  componentDidUpdate(prevProps) {
    const { content } = this.props
    if (content !== prevProps.content) {
      this.clipboard = this.setClipboard(content)
      this.setState({
        copied: false,
      })
    }
  }

  componentWillUnmount() {
    this.clipboard.destroy()
  }

  setClipboard(content) {
    return new ClipboardJS(this.trigger.current, {
      text: () => {
        return content
      },
    })
  }

  render() {
    const {
      isDisabled,
      id,
      className,
      type,
      successText,
      children,
    } = this.props

    const { copied } = this.state

    return (
      <button
        type="button"
        ref={this.trigger}
        disabled={isDisabled}
        id={id}
        className={cn('lbd-button', type, className)}
      >
        {copied ? successText : children}
      </button>
    )
  }
}

CopyToClipboard.defaultProps = {
  children: '',
}

CopyToClipboard.propTypes = {
  content: pt.string,
  children: pt.string,
  successText: pt.string,
  isDisabled: pt.bool,
  id: pt.string,
  className: pt.string,
  type: pt.string,
}

CopyToClipboard.defaultProps = {
  content: '',
  successText: 'Copied!',
  isDisabled: false,
  id: '',
  className: '',
  type: '',
}

export default CopyToClipboard
