import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import Button from '../Button/Button'
import AsyncButton from '../Button/AsyncButton'
import CopyToClipboard from '../Button/CopyToClipboard'
import APIContext from '../api/APIContext'
import Modals from '../Modals/Modals'

export class StepOne extends React.Component {
  constructor(props) {
    super(props)
    const { shareURL } = this.props

    this.state = {
      shareURL,
      isOpen: false,
      linkError: null,
      fromOnboarding: false,
    }
  }

  componentDidMount = () => {
    if (window.location.search.match(/\?onboarding=true/)) {
      this.setState({ fromOnboarding: true })
    }
  }

  createShareLink = () => {
    const { shareURL } = this.state

    const subject = `Join my Crossword Leaderboard`
    const body = `\r\n${[
      `Add me to your New York Times Crossword leaderboard! We’ll be able to see each other’s Mini Crossword times.`,
      shareURL,
    ].join('\r\n\r\n')}`

    return `mailto:?subject=${encodeURIComponent(
      subject,
    )}&body=${encodeURIComponent(body)}`
  }

  showError = (err) => {
    this.setState({ linkError: err })
  }

  toggleModal = () => {
    const { isOpen } = this.state

    this.setState({
      linkError: null,
      isOpen: !isOpen,
    })
  }

  resetInvite = (newShareURL) => {
    this.setState({
      linkError: null,
      isOpen: false,
      shareURL: newShareURL,
    })
  }

  regenerateLink = () => {
    const { name, regenerateLink } = this.props

    return regenerateLink(name)
  }

  render() {
    const { fromOnboarding, shareURL, isOpen, linkError } = this.state

    return (
      <>
        {fromOnboarding ? (
          ''
        ) : (
          <div className="lbd-invite__links">
            <a
              href="/puzzles/leaderboards"
              className="lbd-type__text-link"
            >
              ‹
              {'  '}
              Leaderboards
            </a>
          </div>
        )}
        <div
          className={cn('lbd-invite', 'lbd-container-cols', {
            'lbd-invite-fromOnboarding': fromOnboarding,
          })}
        >
          <div className="lbd-invite__col">
            <div className="lbd-invite__friends lbd-invite__one" />
          </div>
          <div className="lbd-col">
            <h1 className="lbd-type__heading-md">
              Add friends to your leaderboard.
            </h1>
            <p className="lbd-type__text-mb-small">
              Send this link to your friends and they can add you.
            </p>
            <input
              className={cn(
                'lbd-invite__link',
                'lbd-type__link-text',
              )}
              type="text"
              onChange={() => {}}
              value={shareURL}
              ref={this.linkInput}
            />
            <div className="lbd-actions__block">
              <CopyToClipboard
                className="lbd-invite__action"
                type="black"
                content={shareURL}
              >
                Copy Link
              </CopyToClipboard>
              <Button
                className="lbd-invite__action"
                href={this.createShareLink()}
                target="_blank"
                type="white"
                track="INVITE_EMAIL"
              >
                Email
              </Button>
            </div>
            {fromOnboarding ? (
              <p className="lbd-type__text">
                Check out
                {' '}
                <a
                  href="/puzzles/leaderboards"
                  className="lbd-type__text-link"
                >
                  your leaderboard!
                </a>
              </p>
            ) : (
              <p className="lbd-type__text">
                If you want, you can
                {' '}
                <button
                  type="button"
                  onClick={this.toggleModal}
                  className="lbd-regenerate-button"
                >
                  disable your previous link
                </button>
                .
              </p>
            )}
          </div>
        </div>
        <Modals
          isOpen={isOpen}
          onClose={this.toggleModal}
          showClose
          className="lbd-modals"
        >
          {linkError ? (
            <>
              <p className="lbd-type__heading-sm">
                We couldn’t create your link
              </p>
              <p className="lbd-type__text">
                Your old link is still active. Please try again later.
              </p>
              <div className="lbd-actions__block">
                <Button
                  type="black"
                  action={this.toggleModal}
                  className="lbd-action-button-ok"
                >
                  OK
                </Button>
              </div>
            </>
          ) : (
            <>
              <p className="lbd-type__heading-sm">
                Want to create a new link?
              </p>
              <p className="lbd-type__text">
                If you do, your old link will stop working. Friends
                who have that link can no longer request to join your
                leaderboard. They’ll need your new link.
              </p>
              <div className="lbd-actions__block">
                <Button
                  type="white"
                  action={this.toggleModal}
                  className="lbd-action-button-nevermind"
                >
                  Never Mind
                </Button>
                <AsyncButton
                  type="black"
                  pending="Regenerating..."
                  action={this.regenerateLink}
                  onThen={this.resetInvite}
                  onCatch={this.showError}
                  track="INVITE_REGENERATE"
                >
                  New Link
                </AsyncButton>
              </div>
            </>
          )}
        </Modals>
      </>
    )
  }
}

StepOne.propTypes = {
  shareURL: pt.string.isRequired,
  regenerateLink: pt.func.isRequired,
  name: pt.string.isRequired,
}

const ConnectedSetupInvite = (props) => (
  <APIContext.Consumer>
    {(api) => <StepOne {...api} {...props} />}
  </APIContext.Consumer>
)

export default ConnectedSetupInvite
