import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import ErrorModal from '../Modals/ErrorModal'
import APIContext from '../api/APIContext'
import AsyncButton from '../Button/AsyncButton'

const capitalize = (string) => {
  return string.charAt(0).toUpperCase() + string.slice(1)
}

const imageVariants = ['image1', 'image2', 'image3']

const RANDOM_IMAGE_CLASS =
  typeof window === 'undefined'
    ? ''
    : `lbd-invite__friends--${
        imageVariants[
          Math.floor(Math.random() * imageVariants.length)
        ]
      }`

export class StepTwo extends React.Component {
  constructor(props) {
    super(props)

    this.state = {
      isSent: false,
      error: null,
    }
  }

  onSuccess = () => {
    this.setState({ isSent: true })
  }

  onFailure = (e) => {
    this.setState({ error: e })
  }

  dismissError = () => {
    this.setState({ error: null })
  }

  request = () => {
    const { requestToJoin, shareCode } = this.props
    const { isSent } = this.state
    if (isSent) return Promise.resolve()

    return requestToJoin(shareCode)
  }

  render() {
    const { name } = this.props
    const { isSent, error } = this.state
    const formattedName = capitalize(name)

    return (
      <>
        <div
          className={cn(
            'lbd-invite',
            'lbd-invite__two',
            'lbd-container-cols',
          )}
        >
          <div className="lbd-invite__col">
            <div
              className={cn(
                'lbd-invite__friends',
                RANDOM_IMAGE_CLASS,
              )}
            />
          </div>
          <div className="lbd-col">
            <h1 className="lbd-type__heading-md">
              Add 
              {' '}
              <span className="lbd-type__blue">{name}</span>
              {' '}
              to
              your leaderboard.
            </h1>
            <p className="lbd-type__text">
              You’ll see 
              {' '}
              {name}
              ’s Mini Crossword times on your leaderboard.
              {' '}
              {formattedName}
              {' '}
              will see your times as well.
            </p>
            <div className={cn('lbd-actions__block', 'single')}>
              <AsyncButton
                type="black"
                className={cn({
                  checked: isSent,
                })}
                action={this.request}
                onThen={this.onSuccess}
                onCatch={this.onFailure}
                track="REQUEST_JOIN"
                pending="Sending..."
              >
                {isSent ? 'Added' : 'Add'}
              </AsyncButton>
            </div>
            {isSent && (
              <p className="lbd-type__text lbd-invite__redirect">
                Check out your friend on
                {' '}
                <a href="/puzzles/leaderboards">your leaderboard</a>
                !
              </p>
            )}
          </div>
        </div>
        <ErrorModal
          isOpen={!!error}
          error={error}
          onClose={this.dismissError}
        />
      </>
    )
  }
}

StepTwo.propTypes = {
  name: pt.string.isRequired,
  shareCode: pt.string.isRequired,
  requestToJoin: pt.func,
}

StepTwo.defaultProps = {
  requestToJoin: () => {},
}

const ConnectedSetupInvite = (props) => (
  <APIContext.Consumer>
    {(api) => <StepTwo {...api} {...props} />}
  </APIContext.Consumer>
)

export default ConnectedSetupInvite
