import React from 'react'
import pt from 'prop-types'
import { Provider } from 'react-redux'

import Onboarding from '../Onboarding/Onboarding'
import Leaderboard from '../Leaderboard/Leaderboard'
import ManageFriendsContainer from '../ManageFriends/ManageFriends'
import ConfirmFriendsContainer from '../ManageFriends/ConfirmFriends'
import InviteStepOne from '../Invite/StepOne'
import InviteStepTwo from '../Invite/StepTwo'
import InviteError from '../Invite/Error'
import SetupProfile from '../SetupProfile/SetupProfile'
import Store from '../Store/index'

const layouts = {
  onboarding: Onboarding, // /leaderboards - when user has not chosen a leaderboard name
  friends: ManageFriendsContainer, // /leaderboards/settings
  friendsConfirm: ConfirmFriendsContainer, // /leaderboards/confirm
  profile: SetupProfile, // /leaderboards/invite/:code - when visiting an invite link
  leaderboards: Leaderboard, //  /leaderboards - when user has chosen a leaderboard name
  inviteStepOne: InviteStepOne, // /leaderboards/invite
  inviteStepTwo: InviteStepTwo, // /leaderboards/invite/:code - when accepting an invite
  inviteError: InviteError, // /leaderboards/invite/:code - when invite code is invalid
}

const Layout = (props) => {
  const { view } = props
  const View = layouts[view]

  if (!View) return null

  return (
    <Provider store={Store(props)}>
      <View {...props} />
    </Provider>
  )
}

Layout.propTypes = {
  view: pt.oneOf(Object.keys(layouts)),
}

export default Layout
