import React from 'react'
import { shallow } from 'enzyme'

import Onboarding from '../Onboarding/Onboarding'
import ManageFriends from '../ManageFriends/ManageFriends'
import Leaderboard from '../Leaderboard/Leaderboard'

import Layout from './Layout'

jest.mock(
  '../Onboarding/Onboarding',
  () =>
    function Onboarding() {
      return <div />
    },
)
jest.mock(
  '../ManageFriends/ManageFriends',
  () =>
    function ManageFriends() {
      return <div />
    },
)
jest.mock(
  '../Leaderboard/Leaderboard',
  () =>
    function Leaderboard() {
      return <div />
    },
)
jest.mock(
  '../SetupProfile/SetupProfile',
  () =>
    function SetupProfile() {
      return <div />
    },
)
jest.mock(
  '../Invite/StepOne',
  () =>
    function StepOne() {
      return <div />
    },
)
jest.mock(
  '../Invite/StepTwo',
  () =>
    function StepTwo() {
      return <div />
    },
)

describe('LEADERBOARD: LAYOUT', () => {
  let props

  beforeEach(() => {
    props = {
      displayDate: '',
      login: '',
      name: '',
      printDate: '',
      scoreList: [],
      shareURL: '',
    }
  })

  test('it returns Onboarding page', () => {
    const page = shallow(<Layout {...props} view="onboarding" />)
    expect(page.find(Onboarding)).toHaveLength(1)
  })

  test('it returns Leaderboard page', () => {
    const page = shallow(<Layout {...props} view="leaderboards" />)
    expect(page.find(Leaderboard)).toHaveLength(1)
  })

  test('it returns ManageFriends page', () => {
    const page = shallow(<Layout {...props} view="friends" />)
    expect(page.find(ManageFriends)).toHaveLength(1)
  })

  test('handles bad view', () => {
    /* eslint-disable */
    const error = (console.error = jest.fn())
    expect(() => {
      shallow(<Layout {...props} view="bad" />)
    }).not.toThrow()
    console.error = error
    /* eslint-enable */
  })
})
