import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import LeaderboardItem from '../LeaderboardItem/LeaderboardItem'
import PendingRequests from '../PendingRequests/PendingRequests'
import Button from '../Button/Button'

const Leaderboard = ({
  scoreList,
  displayDate,
  puzzleLink,
  pendingRequests,
}) => (
  <div className={cn('lbd-board', 'lbd-container-md')}>
    <div className="lbd-board__header lbd-type__centered">
      <h2 className="lbd-type__subhead">The Mini Crossword</h2>
      <h1 className="lbd-type__heading lbd-your-leaderboard">
        Your Leaderboard
      </h1>
      <h3 className="lbd-type__date">{displayDate}</h3>
    </div>
    <div className="lbd-board__items">
      {scoreList.map((score, i) => (
        <LeaderboardItem key={i} {...score} puzzleLink={puzzleLink} />
      ))}
    </div>
    <div className="lbd-board__actions">
      <Button
        href="/puzzles/leaderboards/settings"
        type="white"
        track="LEADERBOARD_TO_FRIENDS"
      >
        Settings
      </Button>
      <Button
        href="/puzzles/leaderboards/invite"
        type="black"
        track="LEADERBOARD_TO_INVITE"
      >
        Add Friends
      </Button>
    </div>
    {scoreList.length === 1 && !pendingRequests && (
      <div className="lbd-board__tip">
        <p className="lbd-type__heading-md">Play together.</p>
        <p className="lbd-type__text">
          Invite friends to join your leaderboard. To participate,
          they’ll just need a nytimes.com account. They don’t need to
          be subscribers.
        </p>
        <p className="lbd-type__text">
          <strong>Only friends you invite can see your time.</strong>
        </p>
      </div>
    )}
    {pendingRequests > 0 && (
      <div className="lbd-board__pending">
        <PendingRequests pendingRequests={pendingRequests} />
      </div>
    )}
  </div>
)

Leaderboard.propTypes = {
  displayDate: pt.string,
  puzzleLink: pt.string,
  scoreList: pt.arrayOf(pt.shape({})),
  pendingRequests: pt.number,
}

export default Leaderboard
