import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

const LeaderboardItem = (props) => {
  const { isMe, finished, name, puzzleLink, solveTime, rank } = props

  if (isMe && !finished) {
    return (
      <div className="lbd-score">
        <p className="lbd-score__rank">•</p>
        <p className="lbd-score__name">
          {name} 
          {' '}
          <span className="lbd-score__you">(you)</span>
        </p>
        <a className="lbd-score__link" href={puzzleLink}>
          Play Puzzle
        </a>
      </div>
    )
  }

  return (
    <div
      className={cn('lbd-score', {
        'no-rank': !solveTime,
      })}
    >
      <p className="lbd-score__rank">{finished ? rank : '•'}</p>
      <p
        className={cn('lbd-score__name', {
          'lbd-score__self': isMe,
        })}
      >
        {name} 
        {' '}
        {isMe && <span className="lbd-score__you">(you)</span>}
      </p>
      <p className="lbd-score__time">{solveTime || '--'}</p>
    </div>
  )
}

LeaderboardItem.propTypes = {
  name: pt.string.isRequired,
  finished: pt.bool,
  rank: pt.string,
  isMe: pt.bool,
  solveTime: pt.string,
  puzzleLink: pt.string,
}

export default LeaderboardItem
