import React from 'react'
import { shallow } from 'enzyme'

import LeaderboardItem from './LeaderboardItem'

describe('LEADERBOARD: BOARD ITEM', () => {
  test('render a friend with a score', () => {
    const score = {
      name: 'greg',
      rank: '1',
      solveTime: '3:30',
      finished: true,
    }

    const item = shallow(<LeaderboardItem {...score} />)
    expect(item.find('.lbd-score').hasClass('no-rank')).toBe(false)
    expect(item.find('.lbd-score__rank').text()).toBe(score.rank)
    expect(
      item
        .find('.lbd-score__name')
        .text()
        .trim(),
    ).toBe(score.name)
    expect(item.find('.lbd-score__time').text()).toBe(score.solveTime)
  })

  test('render you', () => {
    const score = {
      name: 'greg',
      rank: '1',
      solveTime: '3:30',
      finished: true,
      isMe: true,
    }

    const item = shallow(<LeaderboardItem {...score} />)
    expect(item.find('.lbd-score__name').text()).toBe(
      `${score.name} (you)`,
    )
  })

  test('render you without a score', () => {
    const score = {
      name: 'greg',
      rank: '1',
      finished: false,
      isMe: true,
      puzzleLink: 'link',
    }

    const item = shallow(<LeaderboardItem {...score} />)

    expect(item.find('.lbd-score').hasClass('no-rank')).toBe(false)
    expect(item.find('.lbd-score__rank').text()).toBe('•')
    expect(item.find('.lbd-score__name').text()).toBe(
      `${score.name} (you)`,
    )
    expect(
      item
        .find('.lbd-score__link')
        .text()
        .trim(),
    ).toBe('Play Puzzle')
    expect(item.find('.lbd-score__link').prop('href')).toBe(
      score.puzzleLink,
    )
  })

  test('render a friend without a score', () => {
    const score = {
      name: 'greg',
      rank: null,
      solveTime: null,
      finished: false,
    }

    const item = shallow(<LeaderboardItem {...score} />)
    expect(item.find('.lbd-score').hasClass('no-rank')).toBe(true)
    expect(item.find('.lbd-score__rank').text()).toBe('•')
    expect(
      item
        .find('.lbd-score__name')
        .text()
        .trim(),
    ).toBe(score.name)
    expect(item.find('.lbd-score__time').text()).toBe('--')
  })

  test('render a friend a tie', () => {
    const score = {
      name: 'greg',
      rank: '',
      solveTime: '3:30',
      finished: true,
    }

    const item = shallow(<LeaderboardItem {...score} />)
    expect(item.find('.lbd-score').hasClass('no-rank')).toBe(false)
    expect(item.find('.lbd-score__rank').text()).toBe(score.rank)
    expect(
      item
        .find('.lbd-score__name')
        .text()
        .trim(),
    ).toBe(score.name)
    expect(item.find('.lbd-score__time').text()).toBe(score.solveTime)
  })
})
