import React from 'react'
import { connect } from 'react-redux'
import pt from 'prop-types'

import { unblock } from '../../Store/actions'

const BlockedFriend = ({ name, userID, unblock, confirm }) => {
  return (
    <li className="lbd-friend">
      <span className="lbd-friend__label">
        <span className="lbd-type__truncate">{name}</span>
      </span>
      <button
        type="button"
        className="lbd-friend__action"
        onClick={() =>
          confirm({
            title: `Unblock ${name}?`,
            track: 'FRIEND_MAYBE_UNBLOCK', // NOTE: this doesnt have a corresponding event for confirm
            body: `If you unblock someone, it won’t automatically make you friends, but you will be able to request each other again.`,
            actions: [
              {
                type: 'white',
                text: 'Never Mind',
              },
              {
                type: 'black',
                text: 'Unblock',
                track: 'FRIEND_UNBLOCK',
                action: () => unblock(userID),
              },
            ],
          })}
      >
        Unblock
      </button>
    </li>
  )
}

BlockedFriend.propTypes = {
  name: pt.string.isRequired,
  userID: pt.number.isRequired,
  confirm: pt.func,
  unblock: pt.func,
}

const mapStateToProps = () => ({})

const mapDispatchToProps = (dispatch) => ({
  unblock: (userID) => dispatch(unblock(userID)),
})

export default connect(
  mapStateToProps,
  mapDispatchToProps,
)(BlockedFriend)
