import React from 'react'
import { connect } from 'react-redux'
import pt from 'prop-types'

import { removeFriend, blockFriend } from '../../Store/actions'

const Friend = ({
  name,
  userID,
  removeFriend,
  blockFriend,
  confirm,
}) => {
  return (
    <li className="lbd-friend">
      <span className="lbd-friend__label">
        <span className="lbd-type__truncate">{name}</span>
      </span>
      <button
        type="button"
        className="lbd-friend__action"
        onClick={() =>
          confirm({
            title: `Remove ${name}?`,
            body: `Removing friends means you’ll no longer be on each other’s leaderboards. Friends will not receive a notification that they’ve been removed. If you know you’ll never want to connect again, you can block them.`,
            track: 'FRIEND_MAYBE_REMOVE',
            actions: [
              {
                type: 'white',
                text: 'Block',
                track: 'FRIEND_REMOVE_AND_BLOCK',
                action: () => blockFriend(userID),
              },
              {
                type: 'black',
                text: 'Remove',
                track: 'FRIEND_REMOVE',
                action: () => removeFriend(userID),
              },
            ],
          })}
      >
        Remove
      </button>
    </li>
  )
}

Friend.propTypes = {
  name: pt.string.isRequired,
  userID: pt.number.isRequired,
  removeFriend: pt.func,
  blockFriend: pt.func,
  confirm: pt.func,
}

const mapStateToProps = () => ({})

const mapDispatchToProps = (dispatch) => ({
  blockFriend: (userID) => dispatch(blockFriend(userID)),
  removeFriend: (userID) => dispatch(removeFriend(userID)),
})

export default connect(mapStateToProps, mapDispatchToProps)(Friend)
