import React from 'react'
import { connect } from 'react-redux'
import pt from 'prop-types'

import {
  confirmPending,
  rejectPending,
  blockFriend,
} from '../../Store/actions'
import { PENDING_STATES } from '../../Store/constants'
import { trackEvent } from '../../track/track'

export const PendingFriend = ({
  name,
  userID,
  blockFriend,
  pendingState,
  rejectPending,
  confirmPending,
  confirm,
  showError,
}) => {
  let action

  switch (pendingState) {
    case PENDING_STATES.AWAITING: {
      action = (
        <span className="lbd-pending__action">
          (Awaiting their confirmation)
        </span>
      )
      break
    }

    case PENDING_STATES.CONFIRMING: {
      action = (
        <span className="lbd-pending__action">Confirming...</span>
      )
      break
    }

    case PENDING_STATES.CONFIRMED: {
      action = (
        <span className="lbd-pending__action confirmed">
          Confirmed
        </span>
      )
      break
    }
    case PENDING_STATES.PENDING:
    default: {
      action = (
        <>
          <button
            type="button"
            className="lbd-friend__action"
            onClick={() =>
              confirm({
                title: `Reject ${name}?`,
                track: 'FRIEND_MAYBE_REJECT',
                body: `Rejecting friends means you won’t be connected. To connect again, one of you will have to send a new request. If you know you’ll never want to connect, you can block them.`,
                actions: [
                  {
                    type: 'white',
                    text: 'Block',
                    track: 'FRIEND_REJECT_AND_BLOCK',
                    action: () => blockFriend(userID),
                  },
                  {
                    type: 'black',
                    text: 'Reject',
                    track: 'FRIEND_REJECT',
                    action: () => rejectPending(userID),
                  },
                ],
              })}
          >
            Reject
          </button>
          <button
            type="button"
            className="lbd-friend__action blue"
            onClick={() => {
              trackEvent('FRIEND_CONFIRM')
              confirmPending(userID).catch(showError)
            }}
          >
            Confirm
          </button>
        </>
      )
      break
    }
  }

  return (
    <li className="lbd-friend">
      <span className="lbd-friend__label">
        <span className="lbd-type__truncate">{name}</span>
      </span>
      {action}
    </li>
  )
}

PendingFriend.propTypes = {
  name: pt.string.isRequired,
  userID: pt.number.isRequired,
  blockFriend: pt.func.isRequired,
  pendingState: pt.string,
  rejectPending: pt.func,
  confirmPending: pt.func,
  confirm: pt.func,
  showError: pt.func,
}

const mapStateToProps = () => ({})

const mapDispatchToProps = (dispatch) => ({
  blockFriend: (userID) => dispatch(blockFriend(userID)),
  rejectPending: (userID) => dispatch(rejectPending(userID)),
  confirmPending: (userID) => dispatch(confirmPending(userID)),
})

export default connect(
  mapStateToProps,
  mapDispatchToProps,
)(PendingFriend)
