import React from 'react'
import { connect } from 'react-redux'
import pt from 'prop-types'

import { getNameError } from '../../api/handleAPIError'
import {
  editSelf,
  editSelfEnter,
  editSelfLeave,
  editSelfUpdate,
} from '../../Store/actions'

const Self = ({
  name,
  error,
  pendingName,
  editName,
  isEditing,
  updateName,
  submitName,
  isSubmitting,
  dissmisName,
}) => {
  return (
    <li className="lbd-friend">
      {isEditing ? (
        <>
          <input
            className="lbd-type__input lbd-friend__label name-input"
            type="text"
            id="name"
            autoFocus
            placeholder="Your name or other handle"
            value={pendingName}
            disabled={isSubmitting}
            onChange={(e) => updateName(e.target.value)}
            onKeyUp={(e) => {
              if (e.key === 'Enter') {
                submitName(pendingName)
              }
            }}
          />
          {isSubmitting ? (
            <span className="lbd-pending__action">Saving...</span>
          ) : (
            <>
              <button
                type="button"
                className="lbd-friend__action"
                onClick={dissmisName}
              >
                Cancel
              </button>
              <button
                type="button"
                className="lbd-friend__action blue"
                onClick={() => submitName(pendingName)}
              >
                Save
              </button>
            </>
          )}
          {error && (
            <p className="lbd-friend__error">
              Error: 
              {' '}
              {getNameError(error)}
            </p>
          )}
        </>
      ) : (
        <>
          <span className="lbd-friend__label">
            <span className="lbd-type__truncate">{name}</span>
          </span>
          <button
            type="button"
            className="lbd-friend__action"
            onClick={editName}
          >
            Edit Display Name
          </button>
        </>
      )}
    </li>
  )
}

Self.propTypes = {
  error: pt.shape({}),
  name: pt.string.isRequired,
  pendingName: pt.string,
  editName: pt.func,
  isEditing: pt.bool,
  updateName: pt.func,
  submitName: pt.func,
  isSubmitting: pt.bool,
  dissmisName: pt.func,
}

Self.defaultProps = {
  error: {},
  pendingName: '',
  editName: () => {},
  isEditing: false,
  updateName: () => {},
  submitName: () => {},
  isSubmitting: false,
  dissmisName: () => {},
}

const mapStateToProps = (state) => {
  return state.connections.self[0]
}

const mapDispatchToProps = (dispatch) => {
  return {
    editName: () => dispatch(editSelfEnter()),
    dissmisName: () => dispatch(editSelfLeave()),
    updateName: (newName) => dispatch(editSelfUpdate(newName)),
    submitName: (newName) =>
      dispatch(editSelf(newName)).catch(() => {}),
  }
}

export default connect(mapStateToProps, mapDispatchToProps)(Self)
