import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'

import Blocked from '../Blocked'

const renderConnection = (props) => {
  const store = {
    getState: () => {},
    subscribe: jest.fn(),
    dispatch: jest.fn(),
  }

  return mount(
    <Provider store={store}>
      <Blocked {...props} />
    </Provider>,
  )
}

describe('LEADERBOARD: FRIENDS LIST / BLOCKED', () => {
  it('renders a name', () => {
    const connection = renderConnection({
      name: 'foo',
      userID: 1,
    })

    const name = connection.find('.lbd-friend__label').text()

    expect(name).toBe('foo')
  })

  it('shows button to remove a friend', () => {
    const connection = renderConnection({
      name: 'foo',
      userID: 1,
    })

    const stateText = connection.find('.lbd-friend__action').text()

    expect(stateText).toBe('Unblock')
  })

  it('fires confirmation upon clicking remove', () => {
    let confirmation = false
    const connection = renderConnection({
      name: 'foo',
      userID: 1,
      confirm: () => {
        confirmation = true
      },
    })

    const action = connection.find('.lbd-friend__action')
    action.simulate('click')

    expect(confirmation).toBe(true)
  })
})
