import React from 'react'
import cn from 'classnames'
import pt from 'prop-types'
import { connect } from 'react-redux'

import { trackEvent } from '../track/track'
import ErrorModal from '../Modals/ErrorModal'
import ActionModal from '../Modals/ActionModal'
import { CONNECTION_TYPES } from '../Store/constants'

import Connection from './Connection/index'

class FriendsList extends React.Component {
  constructor(props) {
    super(props)

    this.state = {
      isOpen: false,
      confirmation: undefined,
      error: undefined,
    }
  }

  toggle = () => {
    this.setState((s) => ({ isOpen: !s.isOpen }))
  }

  confirm = (options) => {
    this.setState({ confirmation: options })
    trackEvent(options.track)
  }

  dismissConfirm = () => {
    this.setState({ confirmation: undefined })
  }

  showError = (error) => {
    this.setState({ confirmation: undefined, error })
  }

  dismissError = () => {
    this.setState({ error: undefined })
  }

  render() {
    const { type, users, title, toggle, empty } = this.props
    const { isOpen, confirmation, error } = this.state

    if (type === CONNECTION_TYPES.PENDING && users.length === 0) {
      return ''
    }

    return (
      <div className="lbd-friends" id={`manage-${type}`}>
        <h4 className="lbd-friends__title">{title}</h4>
        {toggle && !!users.length && (
          <div className="lbd-friend">
            <span
              role="switch"
              onClick={this.toggle}
              className={cn('lbd-friend__action', 'toggle', {
                active: isOpen,
              })}
            >
              {isOpen ? 'Hide' : 'View'} 
              {' '}
              {toggle}
            </span>
          </div>
        )}
        {(!toggle || isOpen) && !!users.length && (
          <ul>
            {users.map((user, i) => (
              <Connection
                type={type}
                key={i}
                confirm={this.confirm}
                showError={this.showError}
                {...user}
              />
            ))}
          </ul>
        )}
        {!!users.length || (
          <ul className="lbd-friend empty">
            <li className="lbd-friend__label">{empty}</li>
          </ul>
        )}
        <ActionModal
          isOpen={!!confirmation}
          onClose={this.dismissConfirm}
          onFail={this.showError}
          {...confirmation}
        />
        <ErrorModal
          isOpen={!!error}
          onClose={this.dismissError}
          error={error}
        />
      </div>
    )
  }
}

FriendsList.propTypes = {
  type: pt.string,
  users: pt.arrayOf(pt.shape({})),
  title: pt.string,
  toggle: pt.string,
  empty: pt.string,
}

FriendsList.defaultProps = {
  type: '',
  users: {},
  title: '',
  toggle: '',
  empty: '',
}

const mapStateToProps = (state, ownProps) => {
  const users = state.connections[ownProps.type]

  return {
    users: ownProps.filter ? users.filter(ownProps.filter) : users,
  }
}

export default connect(mapStateToProps)(FriendsList)
