import React from 'react'
import { shallow } from 'enzyme'

import ManageFriends from './ManageFriends'
import FriendsList from './FriendsList'

jest.mock('./FriendsList', () => () => '')
jest.mock('../Store/constants', () => ({
  CONNECTION_TYPES: {
    SELF: 'SELF',
    FRIEND: 'FRIEND',
    PENDING: 'PENDING',
    BLOCKED: 'BLOCKED',
  },
}))

describe('LEADERBOARD: MANAGE FRIENDS', () => {
  test('renders title', () => {
    const manager = shallow(<ManageFriends />)
    const title = manager.find('.lbd-type__heading-sm')

    expect(title.text()).toBe('Leaderboards Settings')
  })

  test('renders the correct friend lists', () => {
    const manager = shallow(<ManageFriends />)
    const lists = manager.find(FriendsList)

    expect(lists.at(0).props()).toEqual({
      type: 'SELF',
      title: 'You',
    })

    const pendingProps = lists.at(1).props()
    expect(pendingProps.type).toEqual('PENDING')
    expect(pendingProps.title).toEqual('Pending Requests')
    expect(pendingProps.empty).toEqual('No pending requests.')

    expect(lists.at(2).props()).toEqual({
      type: 'FRIEND',
      title: 'Friends',
      empty: 'No friends yet!',
    })

    expect(lists.at(3).props()).toEqual({
      type: 'BLOCKED',
      title: 'Blocked',
      empty: 'No blocked friends.',
      toggle: 'Blocked List',
    })
  })
})
