import React from 'react'
import pt from 'prop-types'

import AsyncButton from '../Button/AsyncButton'

import Modal from './Modals'

const noopPromise = () => Promise.resolve()

const ActionModal = (props) => {
  const { title, body, onFail, onClose, actions } = props

  return (
    <Modal {...props} showClose>
      <p className="lbd-type__heading-sm">{title}</p>
      <p className="lbd-type__text">{body}</p>
      <div className="lbd-actions__block">
        {actions.map((action, i) => (
          <AsyncButton
            key={i}
            action={noopPromise}
            onThen={onClose}
            onCatch={onFail}
            pending={action.text}
            {...action}
          >
            {action.text}
          </AsyncButton>
        ))}
      </div>
    </Modal>
  )
}

ActionModal.propTypes = {
  title: pt.string,
  body: pt.string,
  onClose: pt.func,
  onFail: pt.func,
  actions: pt.arrayOf(pt.shape({})),
}

ActionModal.defaultProps = {
  actions: [],
}

export default ActionModal
