import React from 'react'
import { shallow } from 'enzyme'

import AsyncButton from '../Button/AsyncButton'

import ActionModal from './ActionModal'
import Modal from './Modals'

/* eslint-disable */
jest.mock('./Modals', () => ({ children }) => <div>{children}</div>)
jest.mock('../Button/AsyncButton', () => () => '')
/* eslint-enable */

describe('LEADERBOARDS: ACTION MODAL', () => {
  it('renders modal content correctly', () => {
    const props = {
      title: 'Action Title',
      body: 'Action Body',
      onClose: jest.fn(),
      onFail: jest.fn(),
      isOpen: true,
    }

    const action = shallow(<ActionModal {...props} />)
    const modal = action.find(Modal)

    expect(modal.prop('onClose')).toBe(props.onClose)
    expect(modal.prop('showClose')).toBe(true)
    expect(modal.prop('isOpen')).toBe(true)
    expect(action.find('.lbd-type__heading-sm').text()).toBe(
      props.title,
    )
    expect(action.find('.lbd-type__text').text()).toBe(props.body)
  })

  it('renders buttons for actions', async () => {
    const sampleAction = jest.fn()

    const props = {
      title: 'Action Title',
      body: 'Action Body',
      onClose: jest.fn(),
      onFail: jest.fn(),
      isOpen: true,
      actions: [
        {
          type: 'white',
          action: sampleAction,
          text: 'Action 1',
        },
        {
          type: 'black',
          text: 'Action 2',
          pending: '...',
        },
      ],
    }

    sampleAction.mockReturnValue(Promise.resolve(2))

    const action = shallow(<ActionModal {...props} />)
    const buttons = action.find(AsyncButton)
    const b1 = buttons.at(0)
    const b2 = buttons.at(1)
    const a1 = await b1.prop('action')()
    const a2 = await b2.prop('action')()

    expect(b1.prop('children')).toBe('Action 1')
    expect(b1.prop('pending')).toBe('Action 1')
    expect(a1).toBe(2)

    expect(b2.prop('children')).toBe('Action 2')
    expect(b2.prop('pending')).toBe('...')
    expect(a2).toBe(undefined)

    b1.prop('onThen')(1)
    b2.prop('onCatch')(2)

    expect(props.onClose).toHaveBeenCalledWith(1)
    expect(props.onFail).toHaveBeenCalledWith(2)
  })
})
