import React from 'react'
import pt from 'prop-types'

import Button from '../Button/Button'
import { getModalError, ERR } from '../api/handleAPIError'
import { trackImpression } from '../track/track'

import Modal from './Modals'

class ErrorModal extends React.Component {
  componentDidUpdate(prevProps) {
    const { isOpen } = this.props

    if (!prevProps.isOpen && isOpen) {
      const { error } = this.props

      let errorCode
      let trackingEvent

      if (error) {
        errorCode = error.code
      }

      if (errorCode === ERR.TOO_MANY_CONNECTIONS) {
        trackingEvent = 'leaderboard-accept-too-many'
      }

      if (errorCode === ERR.FRIEND_TOO_MANY_CONNECTIONS) {
        trackingEvent = 'leaderboard-confirm-too-many'
      }

      if (trackingEvent) {
        trackImpression(trackingEvent)
      }
    }
  }

  render() {
    const { error, onClose } = this.props

    let errorTitle
    let errorDescription

    if (error) {
      ;[errorTitle, errorDescription] = getModalError(error)
    }

    return (
      <Modal {...this.props} onClose={onClose} showClose>
        <p className="lbd-type__heading-sm">{errorTitle}</p>
        <p className="lbd-type__text">{errorDescription}</p>
        <div className="lbd-actions__block single">
          <Button type="black" action={onClose}>
            OK
          </Button>
        </div>
      </Modal>
    )
  }
}

ErrorModal.defaultProps = {
  isOpen: false,
  onClose: () => {},
  error: null,
}

ErrorModal.propTypes = {
  isOpen: pt.bool,
  onClose: pt.func,
  error: pt.shape({
    code: pt.string,
  }),
}

export default ErrorModal
