import React from 'react'
import { shallow } from 'enzyme'

import Button from '../Button/Button'
import { trackImpression } from '../track/track'

import ErrorModal from './ErrorModal'
import Modal from './Modals'

/* eslint-disable */
jest.mock('./Modals', () => ({ children }) => <div>{children}</div>)
jest.mock('../Button/Button', () => () => '')
jest.mock('../api/handleAPIError', () => ({
  getModalError: (e) => e && [e.title, e.message],
  ERR: {
    TOO_MANY_CONNECTIONS: 'TOO_MANY_CONNECTIONS',
    FRIEND_TOO_MANY_CONNECTIONS: 'FRIEND_TOO_MANY_CONNECTIONS',
  },
}))
jest.mock('../track/track', () => ({
  trackImpression: jest.fn(),
}))
/* eslint-enable */

describe('LEADERBOARDS: ERROR MODAL', () => {
  afterEach(() => {
    trackImpression.mockReset()
  })

  it('renders modal content correctly', () => {
    const props = {
      onClose: jest.fn(),
      isOpen: true,
      error: { title: 'title', message: 'body' },
    }

    const action = shallow(<ErrorModal {...props} />)
    const modal = action.find(Modal)
    const button = action.find(Button)

    expect(modal.prop('showClose')).toBe(true)
    expect(modal.prop('isOpen')).toBe(true)
    expect(action.find('.lbd-type__heading-sm').text()).toBe('title')
    expect(action.find('.lbd-type__text').text()).toBe('body')
    expect(button.prop('children')).toBe('OK')
  })

  it('dismisses', () => {
    const props = {
      onClose: jest.fn(),
      isOpen: true,
      error: new Error('title: body'),
    }

    const action = shallow(<ErrorModal {...props} />)

    const button = action.find(Button)

    button.prop('action')()

    expect(props.onClose).toHaveBeenCalled()
  })

  it('handles missing error', () => {
    const action = shallow(<ErrorModal />)

    expect(action.find('.lbd-type__heading-sm').text()).toBe('')
    expect(action.find('.lbd-type__text').text()).toBe('')
  })

  it('tracks when you have too many friends', () => {
    const e = new Error('title: body')

    e.code = 'TOO_MANY_CONNECTIONS'

    const props = {
      onClose: jest.fn(),
      isOpen: false,
      error: e,
    }

    const m = shallow(<ErrorModal {...props} />)

    m.setProps({ isOpen: true })

    expect(trackImpression).toHaveBeenCalledWith(
      'leaderboard-accept-too-many',
    )

    m.setProps({ foo: 3 })

    expect(trackImpression).toHaveBeenCalledTimes(1)
  })

  it('tracks when they have too many friends', () => {
    const e = new Error('title: body')

    e.code = 'FRIEND_TOO_MANY_CONNECTIONS'

    const props = {
      onClose: jest.fn(),
      isOpen: false,
      error: e,
    }

    const m = shallow(<ErrorModal {...props} />)

    m.setProps({ isOpen: true })

    expect(trackImpression).toHaveBeenCalledWith(
      'leaderboard-confirm-too-many',
    )

    m.setProps({ foo: 3 })

    expect(trackImpression).toHaveBeenCalledTimes(1)
  })
})
