import React from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import Button from '../Button/Button'
import SetupProfile from '../SetupProfile/SetupProfile'
import { trackImpression } from '../track/track'

const Onboarding = ({
  error,
  login = '',
  register = '',
  fromAuthPage = false,
}) => {
  const welcome = (
    <div className="lbd-onboarding__header">
      <div className="lbd-onboarding__cover" />
      <h1 className="lbd-type__heading lbd-type__centered">
        Welcome to Leaderboards!
      </h1>
      <p className="lbd-type__text lbd-type__centered ">
        Have friends who play the Mini? See how long it took them to
        complete today’s puzzle.
      </p>
    </div>
  )

  if (error.status === 401) {
    trackImpression('hardregiwall', 'leaderboard-welcome')

    return (
      <div className={cn('lbd-onboarding', 'lbd-container-sm')}>
        {welcome}
        {error.status === 404 || error.status === 428 ? (
          <SetupProfile />
        ) : (
          <div className="lbd-onboarding__actions">
            <Button
              href={register}
              type="white"
              track="ONBOARDING_CREATE"
            >
              Create Account
            </Button>
            <Button
              href={login}
              type="black"
              track="ONBOARDING_LOGIN"
            >
              Log In
            </Button>
          </div>
        )}
      </div>
    )
  }

  if (fromAuthPage) {
    return (
      <div className={cn('lbd-onboarding', 'lbd-container-sm')}>
        <div className={cn('lbd-onboarding__preview')} />
        <SetupProfile titled />
      </div>
    )
  }

  return (
    <div
      className={cn(
        'lbd-onboarding',
        'lbd-container-sm',
        'lbd-onboarding-nonauth',
      )}
    >
      {welcome}
      <SetupProfile />
    </div>
  )
}

Onboarding.propTypes = {
  login: pt.string,
  register: pt.string,
  error: pt.shape({
    status: pt.number,
  }).isRequired,
  fromAuthPage: pt.bool,
}

export default Onboarding
