import React from 'react'
import { shallow } from 'enzyme'

import { trackImpression } from '../track/track'
import Button from '../Button/Button'
import SetupProfile from '../SetupProfile/SetupProfile'

import Onboarding from './Onboarding'

jest.mock(
  '../Button/Button',
  () =>
    function Button() {
      return <button />
    },
)
jest.mock(
  '../SetupProfile/SetupProfile',
  () =>
    function SetupProfile() {
      return <div />
    },
)

jest.mock('../../../shared/leaderboard/track/track', () => ({
  trackImpression: jest.fn(),
}))

describe('LEADERBOARD: ONBOARDING', () => {
  test('should show welcome when logged out', () => {
    const loginLink = 'http://login'
    const registerLink = 'http://auth/register'
    const onboarding = shallow(
      <Onboarding
        error={{ status: 401 }}
        login={loginLink}
        register={registerLink}
      />,
    )

    const actions = onboarding.find('.lbd-onboarding__actions')
    const buttons = actions.find(Button)
    const createAccount = buttons.at(0)
    const login = buttons.at(1)

    expect(onboarding.find('.lbd-type__heading').text()).toBe(
      'Welcome to Leaderboards!',
    )

    expect(createAccount.prop('children')).toBe('Create Account')
    expect(createAccount.prop('type')).toBe('white')
    expect(createAccount.prop('href')).toBe(registerLink) // eventually passed in
    expect(createAccount.prop('track')).toBe('ONBOARDING_CREATE')

    expect(login.prop('children')).toBe('Log In')
    expect(login.prop('type')).toBe('black')
    expect(login.prop('href')).toBe(loginLink) // eventually passed in
    expect(login.prop('track')).toBe('ONBOARDING_LOGIN')

    expect(trackImpression).toHaveBeenCalledWith(
      'hardregiwall',
      'leaderboard-welcome',
    )

    expect(trackImpression).toHaveBeenCalledTimes(1)
  })

  test('should setup when bouncing back from auth', () => {
    const onboarding = shallow(
      <Onboarding error={{ status: 404 }} fromAuthPage />,
    )
    const setup = onboarding.find(SetupProfile)

    expect(
      onboarding.text().includes('Welcome to Leaderboards'),
    ).toBe(false)
    expect(setup.exists()).toBe(true)
    expect(setup.prop('titled')).toBe(true)
  })

  test('should show setup when precondition is missing', () => {
    const onboarding = shallow(
      <Onboarding error={{ status: 428 }} fromAuthPage />,
    )
    const setup = onboarding.find(SetupProfile)

    expect(
      onboarding.text().includes('Welcome to Leaderboards'),
    ).toBe(false)
    expect(setup.exists()).toBe(true)
    expect(setup.prop('titled')).toBe(true)
  })

  test('should show setup AND welcome if already logged without leaderboard profile', () => {
    const onboarding = shallow(<Onboarding error={{ status: 428 }} />)
    const setup = onboarding.find(SetupProfile)
    const title = onboarding.find('.lbd-type__heading')

    expect(title.text()).toBe('Welcome to Leaderboards!')
    expect(setup.exists()).toBe(true)
    expect(setup.prop('titled')).not.toBe(true)
  })
})
