const createConnectionMiddleware = (api) => (store) => (next) => (
  action,
) => {
  if (!action.api) {
    return next(action)
  }

  store.dispatch({
    type: `${action.type}/pending`,
    payload: action.payload,
  })

  return api.connection[action.type](action.payload)
    .then((response) => {
      store.dispatch({
        type: `${action.type}/success`,
        payload: { response, request: action.payload },
      })
    })
    .catch((error) => {
      store.dispatch({
        type: `${action.type}/error`,
        payload: { error, request: action.payload },
      })
      throw error // so that people handling the promise can also respond to the error
    })
}

export default createConnectionMiddleware
