import {
  SELF_EDIT,
  SELF_EDIT_ENTER,
  SELF_EDIT_LEAVE,
  SELF_EDIT_UPDATE,
  FRIEND_REMOVE,
  FRIEND_BLOCK,
  PENDING_CONFIRM,
  PENDING_CONFIRMING,
  PENDING_REJECT,
  BLOCKED_UNBLOCK,
  PENDING_STATES,
} from './constants'

export const initialState = {
  self: [{}],
  friends: [],
}

const updateSelf = (state, selfProps) => {
  return {
    ...state,
    self: [{ ...state.self[0], ...selfProps }],
  }
}

const friendsContainerReducer = (state = initialState, action) => {
  switch (action.type) {
    case SELF_EDIT_ENTER: {
      return updateSelf(state, {
        isEditing: true,
        error: null,
        pendingName: '',
      })
    }

    case SELF_EDIT_LEAVE: {
      return updateSelf(state, {
        isEditing: false,
        error: null,
        pendingName: '',
      })
    }

    case SELF_EDIT_UPDATE: {
      return updateSelf(state, {
        pendingName: action.payload,
        error: null,
      })
    }

    case `${SELF_EDIT}/pending`: {
      return updateSelf(state, {
        isSubmitting: true,
      })
    }

    case `${SELF_EDIT}/success`: {
      return updateSelf(state, {
        isSubmitting: false,
        isEditing: false,
        name: action.payload.request,
      })
    }

    case `${SELF_EDIT}/error`: {
      return updateSelf(state, {
        isSubmitting: false,
        error: action.payload.error,
      })
    }

    case `${FRIEND_BLOCK}/success`: {
      const targetId = action.payload.request
      const target = [...state.friends, ...state.pending].find(
        (connection) => connection.userID === targetId,
      )

      return {
        ...state,
        friends: state.friends.filter(
          (friend) => friend.userID !== targetId,
        ),
        pending: state.pending.filter(
          (friend) => friend.userID !== targetId,
        ),
        blocked: [target, ...state.blocked],
      }
    }

    case `${FRIEND_REMOVE}/success`: {
      const targetId = action.payload.request
      return {
        ...state,
        friends: state.friends.filter(
          (friend) => friend.userID !== targetId,
        ),
      }
    }

    case PENDING_CONFIRMING: {
      return {
        ...state,
        pending: state.pending.map((connection) => {
          if (connection.userID === action.payload) {
            connection.pendingState = PENDING_STATES.CONFIRMING
          }

          return connection
        }),
      }
    }

    case `${PENDING_CONFIRM}/success`: {
      const targetId = action.payload.request
      const target = state.pending.find(
        (connection) => connection.userID === targetId,
      )

      return {
        ...state,
        pending: state.pending.map((connection) => {
          if (connection.userID === targetId) {
            connection.pendingState = PENDING_STATES.CONFIRMED
          }

          return connection
        }),
        friends: [...state.friends, target],
      }
    }

    case `${PENDING_CONFIRM}/error`: {
      return {
        ...state,
        pending: state.pending.map((connection) => {
          if (connection.userID === action.payload.request) {
            delete connection.pendingState
          }

          return connection
        }),
      }
    }

    case `${PENDING_REJECT}/success`: {
      const targetId = action.payload.request
      return {
        ...state,
        pending: state.pending.filter(
          (pending) => pending.userID !== targetId,
        ),
      }
    }

    case `${BLOCKED_UNBLOCK}/success`: {
      const targetId = action.payload.request
      return {
        ...state,
        blocked: state.blocked.filter(
          (blocked) => blocked.userID !== targetId,
        ),
      }
    }
    default:
      return state
  }
}

export default friendsContainerReducer
