import { env, xhr } from 'foundation'

import * as constants from '../Store/constants'

import { handleAPIError } from './handleAPIError'
import forcePendingTime from './forcePendingTime'

const API_URL = `${env.api}/svc/crosswords/v6/leaderboard`

export const createProfile = (profileName) => {
  return xhr
    .post(`${API_URL}/profile.json`, { name: profileName })
    .then(handleAPIError)
}

export const regenerateLink = () => {
  const p = xhr
    .get(`${API_URL}/profile/code.json`)
    .then(handleAPIError)
    .then((r) => r.URL)

  return forcePendingTime(p)
}

export const getSuggestedName = () => {
  return xhr
    .get(`${API_URL}/profile/suggested.json`)
    .then(handleAPIError)
}

export const requestToJoin = (shareCode) => {
  const p = xhr
    .put(`${API_URL}/connection/request.json`, {
      code: shareCode,
    })
    .then(handleAPIError)

  return forcePendingTime(p)
}

const friendAction = (action, userID) => {
  return xhr
    .put(`${API_URL}/connection/${action}.json`, { userID })
    .then(handleAPIError)
}

export const connection = {}

connection[constants.FRIEND_REMOVE] = friendAction.bind(
  connection,
  'remove',
)
connection[constants.FRIEND_BLOCK] = friendAction.bind(
  connection,
  'block',
)
connection[constants.PENDING_CONFIRM] = friendAction.bind(
  connection,
  'approve',
)
connection[constants.PENDING_REJECT] = friendAction.bind(
  connection,
  'reject',
)
connection[constants.BLOCKED_UNBLOCK] = friendAction.bind(
  connection,
  'unblock',
)
connection[constants.SELF_EDIT] = (profileName) => {
  const p = xhr
    .put(`${API_URL}/profile.json`, { name: profileName })
    .then(handleAPIError)

  return forcePendingTime(p)
}
