import forcePendingTime from './forcePendingTime'

describe('LEADERBOARD: API FORCE PENDING TIME', () => {
  let now
  let times

  beforeEach(() => {
    now = Date.now
    jest.useFakeTimers()
    Date.now = jest.fn()
    Date.now.mockImplementation(() => times.shift())
  })

  afterEach(() => {
    jest.useRealTimers()
    Date.now = now
  })

  it('should slow down fast work', (done) => {
    expect.assertions(2)

    times = [1000, 1200] // before and after

    let result

    forcePendingTime(Promise.resolve({}), 400).then((val) => {
      result = val
    })

    Promise.resolve().then(() => {
      expect(result).toEqual(undefined)

      jest.advanceTimersByTime(201)

      process.nextTick(() => {
        expect(result).toBeDefined()
        done()
      })
    })
  })

  it('should default to 750', (done) => {
    expect.assertions(2)

    times = [1000, 1750] // before and after

    let result

    forcePendingTime(Promise.resolve({})).then((val) => {
      result = val
    })

    Promise.resolve().then(() => {
      expect(result).toEqual(undefined)

      jest.advanceTimersByTime(751)

      process.nextTick(() => {
        expect(result).toBeDefined()
        done()
      })
    })
  })

  it('should not slow down slow work', (done) => {
    expect.assertions(2)

    times = [1000, 1600] // before and after

    let result

    forcePendingTime(Promise.resolve({}), 400).then((val) => {
      result = val
    })

    Promise.resolve().then(() => {
      expect(result).toEqual(undefined)

      process.nextTick(() => {
        expect(result).toBeDefined()
        done()
      })
    })
  })
})
