// @see https://github.com/nytimes/games-leaderboards/blob/main/leaderboards.proto

export const handleAPIError = (res) => {
  if (res.errors) {
    const code = res.errorCode || 0
    const error = new Error(`API ERROR ${code}`)
    error.code = code
    throw error
  } else {
    return res
  }
}

export const ERR = {
  OFFLINE: -1,
  UNKNOWN: 0,
  NOT_FOUND: 1,
  INVALID_CODE: 2,
  ALREADY_CONNECTED: 3,
  TOO_MANY_CONNECTIONS: 4,
  FRIEND_TOO_MANY_CONNECTIONS: 5,
  PROFILE_NAME_TOO_LONG: 6,
  PROFILE_NAME_BAD_WORD: 7,
  PROFILE_NAME_REQUIRED: 8,
  CANNOT_CONNECT_SELF: 9,
  USER_AUTH_REQUIRED: 10,
}

export const errorToValue = (error, valueDefault, valueMap) => {
  if (!error) return

  const code = navigator.onLine ? error.code || 0 : ERR.OFFLINE

  return valueMap[code] || valueDefault
}

export const getModalError = (err) =>
  errorToValue(
    err,
    ['Oops, something went wrong.', 'Please try again later.'],
    {
      [ERR.OFFLINE]: ['You’re offline.', 'Connect to the internet.'],
      [ERR.NOT_FOUND]: [
        'This link has expired.',
        'The person who sent it to you generated a new one. Ask your friend for a new link.',
      ],
      [ERR.ALREADY_CONNECTED]: [
        `You’re already connected.`,
        `You’re ahead of the game. Your friend is on your leaderboard.`,
      ],
      [ERR.TOO_MANY_CONNECTIONS]: [
        `You’re popular!`,
        `You can’t add another friend because you’ve reached the maximum of 25 friends or pending connections. Try removing a friend or two.`,
      ],
      [ERR.FRIEND_TOO_MANY_CONNECTIONS]: [
        'Your friend is popular!',
        `The person you’re trying to add has reached the maximum of 25 friends or pending connections. Ask if they’ll remove a friend so you can join.`,
      ],
      [ERR.CANNOT_CONNECT_SELF]: [
        'Trying to add yourself?',
        `You can’t add yourself to your own leaderboard. Nice try.`,
      ],
    },
  )

export const getNameError = (err) =>
  errorToValue(err, 'Oops, something went wrong.', {
    [ERR.OFFLINE]: 'You’re offline.',
    [ERR.PROFILE_NAME_TOO_LONG]: 'Name is too long.',
    [ERR.PROFILE_NAME_BAD_WORD]: 'That name is not allowed.',
    [ERR.PROFILE_NAME_REQUIRED]: 'Name cannot be empty.',
  })
