import {
  ERR,
  errorToValue,
  getNameError,
  getModalError,
  handleAPIError,
} from './handleAPIError'

describe('LEADERBOARD: HANDLE API ERRORS', () => {
  it('should pass through if now error', () => {
    const res = { foo: true }
    expect(handleAPIError(res)).toBe(res)
  })

  it('should handle known error', () => {
    expect(() => {
      handleAPIError({ errors: [], errorCode: 1 })
    }).toThrow(`API ERROR ${1}`)
  })

  it('should handle an unknown error in API', () => {
    expect(() => {
      handleAPIError({ errors: [] })
    }).toThrow(`API ERROR ${0}`)
  })

  it('should be able to convert errors to values', () => {
    expect(
      errorToValue({}, 'default', {
        0: 'unknown',
        4: 'four',
      }),
    ).toBe('unknown')
    expect(errorToValue({ code: 4 }, 'default', { 4: 'four' })).toBe(
      'four',
    )
    expect(errorToValue({ code: 3 }, 'default', { 4: 'four' })).toBe(
      'default',
    )
    expect(errorToValue(undefined, 'default', { 4: 'four' })).toBe(
      undefined,
    )
  })

  it('should handle modal errors', () => {
    expect(getModalError({ code: ERR.ALREADY_CONNECTED })).toEqual([
      `You’re already connected.`,
      `You’re ahead of the game. Your friend is on your leaderboard.`,
    ])
  })

  it('should handle name errors', () => {
    expect(getNameError({ code: ERR.PROFILE_NAME_TOO_LONG })).toEqual(
      'Name is too long.',
    )
  })

  it('should handle offline', () => {
    const { onLine } = navigator

    Object.defineProperty(navigator, 'onLine', {
      writable: true,
      value: false,
    })

    expect(getNameError({ code: ERR.PROFILE_NAME_TOO_LONG })).toEqual(
      'You’re offline.',
    )

    Object.defineProperty(navigator, 'onLine', {
      writable: true,
      value: onLine,
    })
  })
})
