export const EVENT_TYPE = 'type'
export const WHERE_IT_HAPPENED = 'where'
export const WHAT_IT_DOES = 'what'
export const ADDITIONAL_INFO = 'extra'

/**
 * For event specs
 * @see https://docs.google.com/spreadsheets/d/1ia9nBlnUrVi_jkE-CYsCoKElSweGi8MWlcRJWSNFG0E/edit#gid=420489817
 */
const events = {
  ONBOARDING_CREATE: {
    // creates leaderboards account
    [WHERE_IT_HAPPENED]: 'leaderboard-welcome',
    [WHAT_IT_DOES]: 'create-account',
  },
  ONBOARDING_LOGIN: {
    // logs in at leaerboards welcome page
    [WHERE_IT_HAPPENED]: 'leaderboard-welcome',
    [WHAT_IT_DOES]: 'log-in',
  },
  ONBOARDING_NEXT: {
    // clicks through second page of leaderboards welcome process
    [WHERE_IT_HAPPENED]: 'leaderboard-welcome-next',
    [WHAT_IT_DOES]: 'next',
  },
  ONBOARDING_NAME: {
    // chooses display name for leaderboards and cicks next
    [WHERE_IT_HAPPENED]: 'leaderboard-display-name-pick',
    [WHAT_IT_DOES]: 'next',
  },
  LEADERBOARD_TO_INVITE: {
    // clicks 'add friends' on your leaderboard page
    [WHERE_IT_HAPPENED]: 'your-leaderboard',
    [WHAT_IT_DOES]: 'add-friends',
  },
  LEADERBOARD_TO_FRIENDS: {
    // clicks 'manage friends' on your leaderboard page
    [WHERE_IT_HAPPENED]: 'your-leaderboard',
    [WHAT_IT_DOES]: 'manage-friends',
  },
  INVITE_COPY: {
    // clicks copy link on leaderboards share link page
    [WHERE_IT_HAPPENED]: 'leaderboard-share-link',
    [WHAT_IT_DOES]: 'copy-link',
  },
  INVITE_EMAIL: {
    // clicks share-link on leaderboards share link page
    [WHERE_IT_HAPPENED]: 'leaderboard-share-link',
    [WHAT_IT_DOES]: 'share-link',
  },
  INVITE_REGENERATE: {
    // clicks generate new link on leaderboards share link page
    [WHERE_IT_HAPPENED]: 'leaderboard-share-link',
    [WHAT_IT_DOES]: 'generate-new-link',
  },
  REQUEST_JOIN: {
    // clicks accept request on leaderboard join page
    [WHERE_IT_HAPPENED]: 'join-friend-leaderboard',
    [WHAT_IT_DOES]: 'request-to-join',
  },
  REQUEST_IGNORE: {
    // clicks accept request on leaderboard join page (WE DONT HAVE THIS BUTTIN)
    [WHERE_IT_HAPPENED]: 'join-friend-leaderboard',
    [WHAT_IT_DOES]: 'ignore-request',
  },
  FRIEND_MAYBE_REMOVE: {
    // click remove from leaderboards manage friends page
    [WHERE_IT_HAPPENED]: 'leaderboard-manage-friends',
    [WHAT_IT_DOES]: 'remove',
  },
  FRIEND_MAYBE_REJECT: {
    // click reject from leaderboards manage friends page
    [WHERE_IT_HAPPENED]: 'leaderboard-manage-friends',
    [WHAT_IT_DOES]: 'reject',
  },
  FRIEND_MAYBE_UNBLOCK: {
    // click unblock from leaderboards manage friends page
    [WHERE_IT_HAPPENED]: 'leaderboard-manage-friends',
    [WHAT_IT_DOES]: 'unblock',
  },
  FRIEND_UNBLOCK: {
    // click unblock from leaderboards unblock page/modal
    [WHERE_IT_HAPPENED]: 'leaderboard-manage-friends',
    [WHAT_IT_DOES]: 'confirm-unblock',
  },
  FRIEND_CONFIRM: {
    // click confirm from leaderboards manage friends page
    [WHERE_IT_HAPPENED]: 'leaderboard-manage-friends',
    [WHAT_IT_DOES]: 'confirm',
  },
  FRIEND_REJECT: {
    // clicks reject from leaderboards reject modal
    [WHERE_IT_HAPPENED]: 'leaderboard-manage-friends',
    [WHAT_IT_DOES]: 'confirm-reject',
  },
  FRIEND_REJECT_AND_BLOCK: {
    // clicks reject and block from leaderboards reject modal
    [WHERE_IT_HAPPENED]: 'leaderboard-manage-friends',
    [WHAT_IT_DOES]: 'confirm-block',
  },
  FRIEND_REMOVE: {
    // clicks remove from leaderboards remove modal
    [WHERE_IT_HAPPENED]: 'leaderboard-manage-friends',
    [WHAT_IT_DOES]: 'confirm-remove',
  },
  FRIEND_REMOVE_AND_BLOCK: {
    // clicks remove and block from leaderboards remove modal
    [WHERE_IT_HAPPENED]: 'leaderboard-manage-friends',
    [WHAT_IT_DOES]: 'confirm-block',
  },
  YOU_TOO_MANY: {
    // clicks ok on accept too many friends modal
    [WHERE_IT_HAPPENED]: 'leaderboard-accept-too-many',
    [WHAT_IT_DOES]: '',
  },
  THEY_TOO_MANY: {
    // clicks ok on leaderboard confirm too many friends page
    [WHERE_IT_HAPPENED]: 'leaderboard-confirm-too-many',
    [WHAT_IT_DOES]: '',
  },
}

/**
 * NOTE: because leaderboards code runs on the server (unlike the games)
 * and we currently cannot import foundation on the server
 * we are grabbing it from the window
 */
export const track = (evt) => {
  if (typeof window === 'undefined' || !window.foundationTrack) {
    return
  }

  window.foundationTrack('moduleInteraction', {
    module: {
      name: evt[EVENT_TYPE],
      context: evt[ADDITIONAL_INFO],
      element: {
        name: evt[WHERE_IT_HAPPENED],
        label: evt[WHAT_IT_DOES],
      },
    },
    eventData: {
      pageType: 'game',
      type: evt[EVENT_TYPE],
      trigger: 'module',
      // important to leave an empty string for `status`
      // for the event to pass correctly to google analytics
      // consult with someone from tracking team before removing
      // and confirm that the events are still availably in big query
      status: '',
    },
  })
}

export const trackEvent = (name, extra) => {
  if (!events[name]) {
    // we dont throw here so that we dont crash other front-end code for tracking fail
    console.error(
      new Error(
        `unrecognized tracking event '${name}' in:\n${Object.keys(
          events,
        ).join(', ')}`,
      ),
    )
    return
  }

  const evt = {
    [EVENT_TYPE]: 'click',
    [ADDITIONAL_INFO]: extra,
    ...events[name],
  }

  track(evt)
}

export const trackImpression = (name, region, label, context) => {
  if (typeof window === 'undefined' || !window.foundationTrack) {
    return
  }

  window.foundationTrack('impression', {
    module: {
      name,
      region: region || '',
      label,
      context,
    },
  })
}
