import {
  track,
  trackEvent,
  EVENT_TYPE,
  WHERE_IT_HAPPENED,
  WHAT_IT_DOES,
  ADDITIONAL_INFO,
} from './track'

describe('LEADERBOARDS: TRACKING', () => {
  let foundationTrack

  beforeEach(() => {
    jest.spyOn(console, 'error')
    console.error.mockImplementation(() => {})

    foundationTrack = global.window.foundationTrack

    Object.defineProperty(window, 'foundationTrack', {
      writable: true,
      value: jest.fn(),
    })
  })

  afterEach(() => {
    console.error.mockRestore()

    Object.defineProperty(window, 'foundationTrack', {
      writable: true,
      value: foundationTrack,
    })
  })

  it('maps events to data layer', () => {
    track({
      [EVENT_TYPE]: 'EVENT_TYPE',
      [WHERE_IT_HAPPENED]: 'WHERE_IT_HAPPENED',
      [WHAT_IT_DOES]: 'WHAT_IT_DOES',
      [ADDITIONAL_INFO]: 'ADDITIONAL_INFO',
    })

    const [eventType, eventData] =
      window.foundationTrack.mock.calls[0]

    expect(eventType).toBe('moduleInteraction')
    expect(eventData).toEqual({
      module: {
        name: 'EVENT_TYPE',
        context: 'ADDITIONAL_INFO',
        element: {
          name: 'WHERE_IT_HAPPENED',
          label: 'WHAT_IT_DOES',
        },
      },
      eventData: {
        pageType: 'game',
        type: 'EVENT_TYPE',
        trigger: 'module',
        status: '',
      },
    })
  })

  it('tracks known events', () => {
    trackEvent('ONBOARDING_CREATE', 'extra')

    const [eventType, eventData] =
      window.foundationTrack.mock.calls[0]

    expect(eventType).toBe('moduleInteraction')
    expect(eventData).toEqual({
      module: {
        name: 'click',
        context: 'extra',
        element: {
          name: 'leaderboard-welcome',
          label: 'create-account',
        },
      },
      eventData: {
        pageType: 'game',
        type: 'click',
        trigger: 'module',
        status: '',
      },
    })
  })

  it('warns on unknown events', () => {
    trackEvent('unknown')
    expect(console.error.mock.calls[0][0].message).toMatch(
      "unrecognized tracking event 'unknown'",
    )
  })

  it('noop on server', () => {
    Object.defineProperty(window, 'Foundation', {
      writable: true,
      value: undefined,
    })

    track({
      [EVENT_TYPE]: 'EVENT_TYPE',
      [WHERE_IT_HAPPENED]: 'WHERE_IT_HAPPENED',
      [WHAT_IT_DOES]: 'WHAT_IT_DOES',
      [ADDITIONAL_INFO]: 'ADDITIONAL_INFO',
    })
  })
})
