import React from 'react'
import { render, screen } from '@testing-library/react'

import useCTA from './useCTA'

jest.mock('../abra/useFeatureFlag', () => ({
  __esModule: true,
  default: jest
    .fn()
    .mockReturnValueOnce(false)
    .mockReturnValueOnce(true)
    .mockReturnValueOnce(true)
    .mockReturnValueOnce(true),
}))

jest.mock('user', () => ({
  useUser: jest
    .fn()
    .mockReturnValueOnce({ userType: { entitlement: 'anon' } })
    .mockReturnValueOnce({ userType: { entitlement: 'regi' } })
    .mockReturnValueOnce({ userType: { entitlement: 'sub' } })
    .mockReturnValueOnce({ userType: { entitlement: 'digi' } }),
}))

const ComponentWithGamesSale = () => {
  const { getButtonText } = useCTA()

  return (
    <>
      <div className="button">{getButtonText()}</div>
    </>
  )
}

describe('HOOK: useCTA', () => {
  it('getButtonText returns default Subscribe text when not in the games sale', () => {
    render(<ComponentWithGamesSale />)

    const div = screen.getByText('Subscribe')
    expect(div).toBeTruthy()
  })

  it('getButtonText returns sale messaging for non-subs when the games sale is active', () => {
    render(<ComponentWithGamesSale />)

    const div = screen.getByText('Subscribe for 50% off')
    expect(div).toBeTruthy()
  })

  it('getButtonText returns acquisition messaging for subs when the games sale is active', () => {
    render(<ComponentWithGamesSale />)
    const div = screen.getByText('Subscribe for 50% off')
    expect(div).toBeTruthy()
  })

  it('getButtonText returns acqusition sale messaging for news-only subs when the games sale is active', () => {
    render(<ComponentWithGamesSale />)
    const div = screen.getByText('Subscribe for 50% off')
    expect(div).toBeTruthy()
  })
})
