import React from 'react'
import { render, screen } from '@testing-library/react'

import useSale from './useSale'

jest.mock('../abra/useFeatureFlag', () => ({
  __esModule: true,
  default: jest.fn().mockReturnValue(true),
}))

Object.defineProperty(window, 'location', {
  value: {
    search: '',
  },
  writable: true,
})

const ComponentWithSaleHook = () => {
  const { acqMessage, upgradeMessage, getUrgencyMessage } = useSale()

  return (
    <>
      <p>{acqMessage}</p>
      <p>{upgradeMessage}</p>
      <p className="urgency">{getUrgencyMessage()}</p>
    </>
  )
}

const saleDateFirstWeek = new Date('12/16/2023 12:00:00 GMT-0500')
const saleDateLastWeek = new Date('12/27/2023 12:00:00 GMT-0500')

describe('HOOK: useSale', () => {
  it('provides acquisition messaging for marketing components during a sale', () => {
    render(<ComponentWithSaleHook />)

    const elm = screen.getByText('Subscribe for 50% off')
    expect(elm).toBeTruthy()
  })

  it('provides upgrade messaging for marketing components during a sale', () => {
    render(<ComponentWithSaleHook />)

    const elm = screen.getByText('Upgrade and save')
    expect(elm).toBeTruthy()
  })
  it('provides urgency messaging for marketing components during a sale ', () => {
    window.location.search = `?date-override=${saleDateFirstWeek.toLocaleDateString()}`
    render(<ComponentWithSaleHook />)

    const elm = screen.getByText('Limited Time Offer')
    expect(elm).toBeTruthy()
  })
  it('changes urgency messaging during a sale based on the date', () => {
    window.location.search = `?date-override=${saleDateLastWeek.toISOString()}`
    render(<ComponentWithSaleHook />)

    const elm = screen.getByText('Ends Tomorrow')
    expect(elm).toBeTruthy()
  })
})
