import useFeatureFlag from '../abra/useFeatureFlag'

/**
 * When a new sale comes around, create a new file in /sales and import the messaging and dates here.
 * This will allow us to update messaging across the entire site within one file
 */
import {
  saleEndDate,
  urgencyMessages,
  acqMessage,
  upgradeMessage,
} from './sales/games'

export default () => {
  const isGamesSaleActive = useFeatureFlag('gamesSaleCTA')

  const getDate = (date?: Date) => {
    const now = date || new Date(Date.now())

    if (typeof window === undefined) return now

    const searchParams = new URLSearchParams(window.location.search)
    const override = searchParams.get('date-override')

    if (override) return new Date(override)

    return now
  }

  const getUrgencyMessage = (date?: Date) => {
    const today = getDate(date)

    const message = urgencyMessages.find(
      ({ startDate }) => today >= startDate && today < saleEndDate,
    )

    return message?.copy || ''
  }

  return {
    isGamesSaleActive,
    getUrgencyMessage,
    acqMessage,
    upgradeMessage,
  }
}
