import {
  shouldFailOpen,
  setFailedState,
  retrieveMeterValue,
} from './index'

import { grantReasons, sourceApp } from './MeterTypes'

const failClosedResponse = {
  loggedIn: false,
  grantReason: grantReasons.METERING,
  granted: true,
  isOffline: true,
}

const failOpenResponse = {
  loggedIn: true,
  grantReason: grantReasons.IP,
  granted: true,
  isOffline: true,
}

jest.mock('foundation', () => ({
  env: { meter: 'https://meter-svc.nytimes.com' },
  xhr: {
    get: jest.fn(() =>
      Promise.resolve({
        loggedIn: true,
        grantReason: 'OPEN',
        granted: true,
        isOffline: true,
      }),
    ),
  },
}))

jest.mock('./request', () => ({
  ...jest.requireActual('./request'),
  getCache: jest.fn(() => ({
    loggedIn: true,
    grantReason: 'IP',
    granted: true,
  })),
}))

jest.mock('./abra', () => ({
  willMakeMeterRequest: jest.fn(() => true),
}))

describe('Meter Integration', () => {
  it('should fail open for users whos IP addresses are allowed to play', () => {
    expect(shouldFailOpen(failOpenResponse)).toBe(true)
  })

  it('should fail closed for users who are not logged in and are being metered', () => {
    expect(shouldFailOpen(failClosedResponse)).toBe(false)
  })

  it('should check the cache when the meter request has failed and use that to decide to fail open or closed', () => {
    expect(setFailedState()).toEqual(
      expect.objectContaining({
        loggedIn: true,
        grantReason: 'IP',
        granted: true,
        isOffline: true,
      }),
    )
  })

  it('will construct an xhr get request to the meter service with the right url', async () => {
    const puzzleUrl = 'https://www.nytimes.com/puzzles/spelling-bee'
    await retrieveMeterValue({ puzzleUrl })

    expect(
      jest.requireMock('foundation').xhr.get,
    ).toHaveBeenCalledWith(
      `https://meter-svc.nytimes.com/meter.js?sourceApp=${sourceApp.WEB}&url=${puzzleUrl}`,
      {},
    )
  })

  it('updates meter isOffline status to false', async () => {
    const puzzleUrl = 'https://www.nytimes.com/puzzles/spelling-bee'
    const result = await retrieveMeterValue({ puzzleUrl })

    expect(result).toEqual({
      loggedIn: true,
      grantReason: 'OPEN',
      granted: true,
      isOffline: false,
    })
  })
})
