import { grantReasons, sourceApp } from './MeterTypes'
import {
  getCache,
  setCache,
  determineSourceApp,
  generateMeterUrl,
} from './request'

jest.mock('foundation', () => ({
  env: { meter: 'https://meter-svc.nytimes.com' },
}))

const openMeter = {
  loggedIn: true,
  granted: true,
  grantReason: grantReasons.OPEN,
  isOffline: false,
}

const puzzleUrl = 'https://www.nytimes.com/puzzles/spelling-bee'

describe('Meter: Request cache and url generation', () => {
  beforeEach(() => {
    window.gamesAppPlatform = ''
    window.newsreaderAppPlatform = ''
  })

  it('sets the cache for a successful meter response', () => {
    setCache(openMeter)
    expect(getCache()).toEqual(expect.objectContaining(openMeter))
  })

  it('determines the right sourceApp for web', () => {
    expect(determineSourceApp()).toEqual(sourceApp.WEB)
  })

  it('determines the right sourceApp for hybrid xwd', () => {
    window.gamesAppPlatform = 'ios'
    expect(determineSourceApp()).toEqual(sourceApp.IOS_XWD)
  })

  it('determines the right sourceApp for hybrid xwd', () => {
    window.gamesAppPlatform = 'android'
    expect(determineSourceApp()).toEqual(sourceApp.ANDROID_XWD)
  })

  it('determines the right sourceApp for hybrid newsreader', () => {
    window.newsreaderAppPlatform = 'ios'
    expect(determineSourceApp()).toEqual(sourceApp.IOS_NEWS)
  })

  it('determines the right sourceApp for hybrid newsreader', () => {
    window.newsreaderAppPlatform = 'android'
    expect(determineSourceApp()).toEqual(sourceApp.ANDROID_NEWS)
  })

  it('generates the right request url to hit meter', () => {
    expect(generateMeterUrl(puzzleUrl)).toEqual(
      `https://meter-svc.nytimes.com/meter.js?sourceApp=${sourceApp.WEB}&url=${puzzleUrl}`,
    )
  })
})
