import type { CoreState, Player } from '@nyt/games-schema'

import { env, xhr } from 'foundation'

import type {
  MoogleData,
  MultiStateResponse,
  PostResponse,
} from './moogleState'

export const fetchMultiStates = async (
  game: CoreState['game'],
  puzzleIds: Array<string | number>,
  onSuccess: (
    data: MoogleData[],
    regiId?: number,
    player?: Player | null,
  ) => void,
  onFailure?: (errorMessage: string) => void,
) => {
  const puzzleIdsQuery = puzzleIds.join(',')

  try {
    const response = await xhr.get<MultiStateResponse>(
      `${env.moogle}/svc/games/state/${game}/latests?puzzle_ids=${puzzleIdsQuery}`,
    )

    if (response.error === 'forbidden') {
      throw new Error('not authenticated')
    }

    if (response.states) {
      onSuccess(response.states, response.user_id, response.player)
      return
    }

    throw new Error(
      `fetchMultiStates: ${response.error || 'Invalid response'}`,
    )
  } catch (err: any) {
    onFailure?.(err.message)
  }
}

// Calls to this function must always be in either a promise chain or a try/catch,
// as it does not handle errors on its own
export const postToMoogle = (moogleData: MoogleData) => {
  return xhr.post<PostResponse>(
    `${env.moogle}/svc/games/state`,
    moogleData,
  )
}
