import type { CoreState } from '@nyt/games-schema'
import type { AnyAction } from 'redux'
import type { ThunkAction } from 'redux-thunk'

import type { MoogleAction } from './moogleActions'
import type { MoogleState } from './moogleState'

export type Versioned<IGameData extends CoreState['game_data']> =
  IGameData & {
    timestamp: number
    schemaVersion: string
  }

export type MoogleOptions<
  IStoreState, // Shape of Redux Store State for this game
  IAction extends AnyAction, // Shape of general Redux Action for this game
  IGameData extends CoreState['game_data'], // Shape of state object that is persisted in games-state
> = {
  /**
   * GENERAL CONFIG
   */
  // The name of the game, as recognized by games-state
  game: CoreState['game']
  // Returns key to use for local storage
  getLocalStorageKey: (
    state: IStoreState,
    regiId?: string | number | null,
  ) => string
  // Returns puzzleId to use for saving to backend
  selectPuzzleId: (state: IStoreState) => string
  // Optionally fetch additional puzzle states from API
  selectAdditionalPuzzleIdsToFetch?: (state: IStoreState) => string[]
  // Moogle reducer must be plugged into overall store, this selector indicates how
  selectMoogleState: (state: IStoreState) => MoogleState
  /**
   * SAVING CONFIG
   */
  // Returns true for actions that should trigger saves
  shouldSave: (
    state: IStoreState,
    action: IAction | MoogleAction,
  ) => boolean
  // Returns object that should be saved to backend and local storage
  selectPersistedState: (state: IStoreState) => IGameData
  /**
   * LOADING CONFIG
   */
  // After loading from remote and local, resolve into a single initial state
  reconcileRemoteAndLocalState: (
    remoteState: Versioned<IGameData> | null,
    localState: Versioned<IGameData> | null,
  ) => IGameData | null
  // Optionally handle the situation where a user logs in after making progress as an anon
  handleMidGameLogin?: (
    regiState: IGameData | null,
    anonState: IGameData | null,
  ) => IGameData | null
  // Action thunk creator that inserts initial progress into redux store
  insertProgress: (
    gameData: IGameData | null,
  ) => ThunkAction<void, IStoreState, unknown, IAction>
}
