import { captureSentryError } from 'foundation'

import type { MoogleOptions } from './types'

export const getFromLocalStorage = <T>(
  key: string,
  defaultValue: T | null = null,
): T | null => {
  try {
    const storedString = window.localStorage.getItem(key)
    if (!storedString) return defaultValue

    // TODO: safety around this parse?
    return JSON.parse(storedString) as T
  } catch (e) {
    console.error(e)
    captureSentryError(e as Error)
    return defaultValue
  }
}

export const writeToLocalStorage = <T>(key: string, value: T) => {
  try {
    window.localStorage.setItem(key, JSON.stringify(value))
    return true
  } catch (e) {
    console.error(e)
    captureSentryError(e as Error)
    return false
  }
}

export const getMoogleData = <IStoreState>(
  options: MoogleOptions<IStoreState, any, any>,
  state: IStoreState,
) => {
  const puzzleId = options.selectPuzzleId(state)
  const moogleState = options.selectMoogleState(state)
  return moogleState.getRequest.statesByPuzzleId[puzzleId] || null
}

export const getMoogleRegiId = <IStoreState>(
  options: MoogleOptions<IStoreState, any, any>,
  state: IStoreState,
) => options.selectMoogleState(state).getRequest.regiId

export const getIsPostLoading = <IStoreState>(
  options: MoogleOptions<IStoreState, any, any>,
  state: IStoreState,
) => {
  const { postRequest } = options.selectMoogleState(state)
  return Object.keys(postRequest).some(
    (puzzId) => postRequest[puzzId].isLoading,
  )
}

export const getPendingSaves = <IStoreState>(
  options: MoogleOptions<IStoreState, any, any>,
  state: IStoreState,
) => options.selectMoogleState(state).pendingSaves

export const getIsSavePending = <IStoreState>(
  options: MoogleOptions<IStoreState, any, any>,
  state: IStoreState,
) => {
  return getPendingSaves(options, state).length > 0
}

export const getIsErrorRetry = <IStoreState>(
  options: MoogleOptions<IStoreState, any, any>,
  state: IStoreState,
) => {
  const { postRequest } = options.selectMoogleState(state)
  const puzzleId = options.selectPuzzleId(state)
  return postRequest[puzzleId]?.isErrorRetry
}
