# responsive

Responsive provides a hook for us to observe when the screen changes across `$grid-breakpoints` defined by `scss-helpers/variables.scss`.

It can only be used in the browser.

_We do not have a great deal of clarity about what these breakpoints should be, but they do exist and this JS is available to all games._

This was inspired by [Paul Hayes](https://paulrhayes.com/use-css-transitions-to-link-media-queries-and-javascript/)

### why

If a game is rendered entirely on the client, and if it has massive layout changes in various orientations and sizes, it is possible that managing those changes using these JS hooks could be more clear than attempting to do so with pure media queries.

### usage

If you want to read the current value of the breakpoint

```javascript
console.log('breakpoint', responsive.width.value)
```

_Please note: this value will be correct before any of your code runs, so there is no need to wait_

If you want to subscribe to changes in breakpoint

```javascript
import responsive from 'responsive'

responsive.width.subscribe((newBreakpoint) => {
  console.log('breakpoint', newBreakpoint)
})
```

The value of the breakpoint will be a number that corresponds to the breakpoint like so:

- `0` means `<= xs`
- `1` means `> xs && <= sm`
- `2` means `> sm && <= md`
- `3` means `> md && <= lg`
- `4` means `> lg && <= xl`

You can do the same with the ratio of the screen:

```javascript
console.log('ratio', responsive.ratio.value)

responsive.width.subscribe((newRatio) => {
  console.log('ratio', newRatio)
})
```

And here the value of ratio means:

- `0` means `portrait`
- `1` means `landscape`
