import {
  determineGamesAppPlatform,
  determineNewsreaderAppPlatform,
  getAppVersion,
  isAndroidCrosswordWebView,
  isAndroidDevice,
  isAndroidNewsreaderWebView,
  isIOSCrosswordWebView,
  isIOSDevice,
  isIOSNewsreaderWebView,
  isMobileBrowser,
  isHybridOptIn,
  setHybridWindowProperties,
  getNewsreaderVersion,
} from '../hybrid'

const mobileUAs = [
  'Mozilla/5.0 (iPhone; CPU iPhone OS 16_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) CriOS/107.0.5304.101 Mobile/15E148 Safari/604.1',
  'Mozilla/5.0 (Linux; Android 10; LM-X420) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.5304.105 Mobile Safari/537.36',
  'Mozilla/5.0 (iPod; CPU iPhone OS 16_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) CriOS/107.0.5304.101 Mobile/15E148 Safari/604.1',
]

const desktopUAs = [
  'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36',
  'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36',
  'Mozilla/5.0 (Macintosh; Intel Mac OS X 13_0_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36',
]

const iosUAs = [
  'Mozilla/5.0 (iPhone; CPU iPhone OS 16_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) CriOS/107.0.5304.101 Mobile/15E148 Safari/604.1',
  'Mozilla/5.0 (iPad; CPU OS 16_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) CriOS/107.0.5304.101 Mobile/15E148 Safari/604.1',
  'Mozilla/5.0 (iPod; CPU iPhone OS 16_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) CriOS/107.0.5304.101 Mobile/15E148 Safari/604.1',
]

const androidUAs = [
  'Mozilla/5.0 (Linux; Android 13) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/109.0.5414.117 Mobile Safari/537.36',
  'Mozilla/5.0 (Android 13; Mobile; rv:68.0) Gecko/68.0 Firefox/109.0',
  'Mozilla/5.0 (Linux; Android 13; SM-G960U) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/109.0.5414.117 Mobile Safari/537.36',
]

const droidNewsUA =
  'Mozilla/5.0 (Linux; Android 12; sdk_gphone64_arm64 Build/S2B2.211203.006; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/91.0.4472.114 Mobile Safari/537.36 nyt_android/9.75.0'

const iosNewsUA =
  'Mozilla/5.0 (iPhone; CPU iPhone OS 13_6 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) nytios/9.33.0'

const droidXwdUA =
  'Crosswords/4.39.0 (Android; 10; Hybrid Build: unknown; Build Type: release)'

const iosXwdUA =
  'Mozilla/5.0 (iPhone; CPU iPhone OS 15_5 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) nyt_xwords_ios/AppVersion(string: "4.37")'

const androidHybridNewsUA =
  'Reader/10.36.0 (Android; 13; Hybrid Build: unknown; Build Type: release)'

describe('RESPONSIVE: HYBRID DETECTION', () => {
  // @ts-ignore
  let userAgent

  beforeEach(() => {
    userAgent = jest.spyOn(navigator, 'userAgent', 'get')

    // unset any query params set by individual tests
    Object.defineProperty(global.window, 'location', {
      writable: true,
      value: {
        search: '',
      },
    })
  })

  it(`can identify a mobile browser's user agent`, () => {
    mobileUAs.forEach((ua) => {
      expect(isMobileBrowser(ua)).toBe(true)
    })
  })

  it(`can identify a desktop browser's user agent`, () => {
    desktopUAs.forEach((ua) => {
      expect(isMobileBrowser(ua)).toBe(false)
    })
  })

  it(`can identify the Android newsreader app's webview`, () => {
    expect(isAndroidNewsreaderWebView(droidNewsUA)).toBe(true)
    expect(isAndroidNewsreaderWebView(iosNewsUA)).toBe(false)
  })

  it(`can identify the iOS newsreader app's webview`, () => {
    expect(isIOSNewsreaderWebView(iosNewsUA)).toBe(true)
    expect(isIOSNewsreaderWebView(droidNewsUA)).toBe(false)
  })

  it(`can identify the Android Crossword app's webview`, () => {
    expect(isAndroidCrosswordWebView(droidXwdUA)).toBe(true)
    expect(isAndroidCrosswordWebView(iosXwdUA)).toBe(false)
  })

  it(`can identify the iOS Crossword app's webview`, () => {
    expect(isIOSCrosswordWebView(iosXwdUA)).toBe(true)
    expect(isIOSCrosswordWebView(droidXwdUA)).toBe(false)
  })

  it('can identify an iOS device', () => {
    iosUAs.forEach((ua) => {
      expect(isIOSDevice(ua)).toBe(true)
    })

    desktopUAs.forEach((ua) => {
      expect(isIOSDevice(ua)).toBe(false)
    })

    androidUAs.forEach((ua) => {
      expect(isIOSDevice(ua)).toBe(false)
    })
  })

  it('can identify an android device', () => {
    androidUAs.forEach((ua) => {
      expect(isAndroidDevice(ua)).toBe(true)
    })

    desktopUAs.forEach((ua) => {
      expect(isAndroidDevice(ua)).toBe(false)
    })

    iosUAs.forEach((ua) => {
      expect(isAndroidDevice(ua)).toBe(false)
    })
  })

  it('can identify the platform of the crossword webview', () => {
    // @ts-ignore
    userAgent.mockReturnValue(iosXwdUA)

    expect(determineGamesAppPlatform()).toBe('ios')
  })

  it('can identify the platform of the newsreader webview', () => {
    // @ts-ignore
    userAgent.mockReturnValue(droidNewsUA)

    expect(determineNewsreaderAppPlatform()).toBe('android')
  })

  it('can capture the semantic version of the ios games app', () => {
    expect(getAppVersion(iosXwdUA, 'ios')).toBe('4.37')
  })

  it('can capture the semantic version of the android games app', () => {
    expect(getAppVersion(droidXwdUA, 'android')).toBe('4.39.0')
  })

  it('can capture the semantic version of the ios newsreader app', () => {
    expect(getNewsreaderVersion(iosNewsUA)).toBe('9.33.0')
  })

  it('can capture the semantic version of the android newsreader app', () => {
    expect(getNewsreaderVersion(droidNewsUA)).toBe('9.75.0')
  })

  it('can detect hybrid opt in for android', () => {
    // @ts-ignore
    userAgent.mockReturnValue(androidHybridNewsUA)
    expect(isHybridOptIn(androidHybridNewsUA)).toBe(true)
  })

  it('can detect hybrid opt in for ios', () => {
    // @ts-ignore
    userAgent.mockReturnValue(iosXwdUA)

    Object.defineProperty(global.window, 'location', {
      writable: true,
      value: {
        search: '?hybrid=news',
      },
    })

    expect(isHybridOptIn(iosXwdUA)).toBe(true)
  })

  it('sets the correct device properties on the window object', () => {
    // @ts-ignore
    userAgent.mockReturnValue(iosXwdUA)

    const w = {}
    // @ts-ignore
    setHybridWindowProperties(w, iosXwdUA)

    expect(w).toStrictEqual({
      gamesAppPlatform: 'ios',
      gamesAppVersion: '4.37',
      isAndroidDevice: false,
      isHybridWebView: false,
      isIOSDevice: true,
      isMobileDevice: true,
      isPlayTab: false,
      newsreaderAppPlatform: '',
      newsreaderAppVersion: '',
    })
  })

  it('sets the hybrid context appropriately for android newsreader', () => {
    // @ts-ignore
    userAgent.mockReturnValue(androidHybridNewsUA)

    const w = {}
    // @ts-ignore
    setHybridWindowProperties(w, androidHybridNewsUA)

    expect(w).toStrictEqual({
      newsreaderAppPlatform: 'android',
      newsreaderAppVersion: '10.36.0',
      gamesAppPlatform: '',
      isPlayTab: false,
      isIOSDevice: false,
      isAndroidDevice: true,
      isMobileDevice: true,
      gamesAppVersion: '',
      isHybridWebView: true,
    })
  })

  it('sets the non-hybrid context appropriately for android newsreader', () => {
    // @ts-ignore
    userAgent.mockReturnValue(droidNewsUA)

    const w = {}
    // @ts-ignore
    setHybridWindowProperties(w, droidNewsUA)

    expect(w).toStrictEqual({
      newsreaderAppPlatform: 'android',
      newsreaderAppVersion: '9.75.0',
      gamesAppPlatform: '',
      isPlayTab: false,
      isIOSDevice: false,
      isAndroidDevice: true,
      isMobileDevice: true,
      gamesAppVersion: '',
      isHybridWebView: false,
    })
  })

  it('sets the hybrid context appropriately for ios newsreader', () => {
    // @ts-ignore
    userAgent.mockReturnValue(iosNewsUA)
    Object.defineProperty(global.window, 'location', {
      writable: true,
      value: {
        search: '?hybrid=news',
      },
    })

    const w = {}
    // @ts-ignore
    setHybridWindowProperties(w, iosNewsUA)

    expect(w).toStrictEqual({
      gamesAppPlatform: '',
      gamesAppVersion: '',
      isAndroidDevice: false,
      isHybridWebView: true,
      isIOSDevice: true,
      isMobileDevice: true,
      isPlayTab: false,
      newsreaderAppPlatform: 'ios',
      newsreaderAppVersion: '9.33.0',
    })
  })

  it('sets the non-hybrid context appropriately for ios newsreader', () => {
    // @ts-ignore
    userAgent.mockReturnValue(iosNewsUA)

    const w = {}
    // @ts-ignore
    setHybridWindowProperties(w, iosNewsUA)

    expect(w).toStrictEqual({
      gamesAppPlatform: '',
      gamesAppVersion: '',
      isAndroidDevice: false,
      isHybridWebView: false,
      isIOSDevice: true,
      isMobileDevice: true,
      isPlayTab: false,
      newsreaderAppPlatform: 'ios',
      newsreaderAppVersion: '9.33.0',
    })
  })
})
