/**
 * Taken from http://detectmobilebrowsers.com/
 *
 * PROCEED WITH CAUTION -- EXPECTED RESULTS:
 * Returns true for iOS phones (hybrid & browser) and Android mobile browsers
 * Returns false for all Android hybrid webviews (regardless of device), all tablets, and desktop
 */
export const isMobileBrowser = (userAgent = '') => {
  const ua =
    userAgent ||
    navigator.userAgent ||
    navigator.vendor ||
    (window.opera ? 'opera' : '')

  return (
    /(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows ce|xda|xiino/i.test(
      ua,
    ) ||
    // eslint-disable-next-line no-useless-escape
    /1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i.test(
      ua.substr(0, 4),
    )
  )
}

export const isMultiTouchAppleDevice = (
  globalNavigator = window.navigator,
) => {
  return (
    /iPad/.test(globalNavigator.platform) ||
    (globalNavigator.platform === 'MacIntel' &&
      globalNavigator.maxTouchPoints > 1)
  )
}

/**
 * Returns URLSearchParams for for window.location.search
 */
export const getParams = () =>
  new URLSearchParams(window.location.search)

/**
 * Determine if the user agent indicates we're in the Android Newsreader WebView.
 * Special case: for hybrid spelling-bee, the user agent will include 'Reader/'
 *
 * Example UAs:
 * "nyt_android/9.13"
 * "Reader/9.13"
 */
export const isAndroidNewsreaderWebView = (userAgent = '') => {
  const androidRegex = /nyt[-_]?android/i
  const sbUserAgent = 'Reader/'
  return (
    userAgent.includes(sbUserAgent) || androidRegex.test(userAgent)
  )
}

/**
 * Determine if the user agent indicates we're in the iOS Newsreader WebView.
 *
 * Example UAs:
 * "Mozilla/5.0 (iPhone; CPU iPhone OS 13_6 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) nytios/9.33.0"
 * "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/605.1.15 (KHTML, like Gecko) nytios/9.33.0"
 */
export const isIOSNewsreaderWebView = (userAgent = '') => {
  const iOSRegex = /nyt[-_]?ios/i
  return iOSRegex.test(userAgent)
}

/**
 * Determine if we are in a WebView. We'll look at a few different things here
 * and short-circuit evaluate to avoid doing more progressively expensive or
 * sketchy things.
 *
 * We look at rid query param cause iOS app appends that to any Games WebView.
 * And then we can look at user agent, cause that'll never go wrong.
 *
 * Some helpful reading from hybrid folks:
 * https://docs.google.com/document/d/10PNzQxXIHImtuh2c-VLRuH7yUGDgCh7zxqMrYMxg1eQ
 */
export const determineNewsreaderAppPlatform = (userAgent = '') => {
  const params = getParams()
  const iosQueryParams = ['ios', 'ipad', 'iphone']
  const androidQueryParams = ['android', 'androidtab', 'androidphone']

  const embed = params.get('embed') || ''
  const rid = params.get('rid') || ''
  const ua = userAgent || navigator.userAgent

  if (
    iosQueryParams.includes(embed) ||
    rid ||
    isIOSNewsreaderWebView(ua)
  ) {
    return 'ios'
  }

  if (
    androidQueryParams.includes(embed) ||
    isAndroidNewsreaderWebView(ua)
  ) {
    return 'android'
  }

  return ''
}

/**
 * Determine if the user agent indicates we're in the Android Crossword WebView.
 * Example UA: "Crosswords/4.12.0 (Android; Android 8.1.0; Build 0/debug)"
 */
export const isAndroidCrosswordWebView = (userAgent = '') => {
  return userAgent.includes('Crosswords/')
}

/**
 * Determine if the user agent indicates we're in the iOS Crossword WebView.
 * Example UA: "nyt_xwords_ios/4.10"
 */
export const isIOSCrosswordWebView = (userAgent = '') => {
  return userAgent.includes('nyt_xwords_ios/')
}

/**
 * Determine if we are in a Crossword WebView based on the user agent.
 */
export const determineGamesAppPlatform = (userAgent = '') => {
  const params = getParams()
  const ua = userAgent || navigator.userAgent

  if (
    isIOSCrosswordWebView(ua) ||
    params.get('hybrid') === 'games' ||
    params.get('embed') === 'games-ios'
  ) {
    return 'ios'
  }

  if (
    isAndroidCrosswordWebView(ua) ||
    params.get('embed') === 'games-android'
  ) {
    return 'android'
  }

  return ''
}

/**
 * Determine if the user agent indicates the device is an iPhone or iPad or iPod
 */
export const isIOSDevice = (userAgent = '') => {
  const iOSRegex = /i(Phone|Pad|Pod)/i
  return (
    iOSRegex.test(userAgent) ||
    isIOSCrosswordWebView(userAgent) ||
    isIOSNewsreaderWebView(userAgent) ||
    isMultiTouchAppleDevice()
  )
}

/**
 * Parses the semantic version from the user agent string.
 */
export const getAppVersion = (
  userAgent = '',
  platform: 'ios' | 'android' | '',
) => {
  const androidRegex = /Crosswords\/([0-9]+\.[0-9]+(\.[0-9]+)?)/i
  const iOSRegex =
    /nyt[-_]?xwords[-_]?ios\/(?:AppVersion\(string: "|.{0})([0-9]+\.[0-9]+(\.[0-9]+)?).*/i

  let matches // matches will be ['Crosswords/4.12.0', '4.12.0']

  if (platform === 'ios') {
    matches = userAgent.match(iOSRegex)
  } else if (platform === 'android') {
    matches = userAgent.match(androidRegex)
  }

  if (matches && matches.length >= 2) {
    return matches[1]
  }

  return ''
}

/**
 * Determine if the user agent indicates the device is an android
 */
export const isAndroidDevice = (userAgent = '') => {
  const androidRegex = /android/i

  return (
    androidRegex.test(userAgent) ||
    isAndroidCrosswordWebView(userAgent) ||
    isAndroidNewsreaderWebView(userAgent)
  )
}

const isMobileDevice = (userAgent = '') =>
  isMobileBrowser(userAgent) ||
  isIOSDevice(userAgent) ||
  isAndroidDevice(userAgent)

/**
 * Determines if a request originated from the iOS Newsreader Play tab.
 */
export const determinePlayTab = (userAgent = '') => {
  const params = getParams()
  const playTabParam = 'playTab'
  const ua = userAgent || navigator.userAgent

  if (
    params.get('entry') === playTabParam &&
    determineNewsreaderAppPlatform(ua) === 'ios'
  ) {
    return true
  }

  return false
}

/**
 * Determines if platforms are requesting hybrid explicitly.
 * Applicable to newsreader contexts.
 */
export const isHybridOptIn = (userAgent = '') => {
  const params = getParams()

  return (
    // android newsreader
    userAgent.includes('Reader/') ||
    // ios newsreader
    Boolean(params.get('hybrid'))
  )
}

function getAndroidNewsreaderVersion(userAgent = '') {
  const sbRegex = /Reader\/([0-9]+\.[0-9]+(\.[0-9]+)?)/i
  const sbMatches = userAgent.match(sbRegex) // matches will be ['Reader/9.70.0', '9.70.0']

  if (sbMatches && sbMatches.length >= 2) {
    return sbMatches[1]
  }

  const androidRegex = /nyt[-_]?android\/([0-9]+\.[0-9]+(\.[0-9]+)?)/i
  const matches = userAgent.match(androidRegex) // matches will be ['nyt_android/9.13', '9.13']

  if (matches && matches.length >= 2) {
    return matches[1]
  }

  return ''
}

function getIOSNewsreaderVersion(userAgent = '') {
  const iOSRegex = /nyt[-_]?ios\/([0-9]+\.[0-9]+(\.[0-9]+)?)/i
  const matches = userAgent.match(iOSRegex) // matches will be ['nytios/9.33.0', '9.33.0']

  if (matches && matches.length >= 2) {
    return matches[1]
  }

  return ''
}

export const getNewsreaderVersion = (userAgent = '') =>
  getIOSNewsreaderVersion(userAgent) ||
  getAndroidNewsreaderVersion(userAgent) ||
  ''

/**
 * Write properties to the window necessary before rendering. This is injected before most scripts.
 */
export const setHybridWindowProperties = (
  w = window,
  userAgent = '',
) => {
  const ua = userAgent || navigator.userAgent

  /**
   * Determine if the user is in a webview from the Newsreader app
   */
  if (typeof w.newsreaderAppPlatform === 'undefined') {
    w.newsreaderAppPlatform = determineNewsreaderAppPlatform()
  }

  /**
   * Determine if the user is in a webview from the Crossword app
   */
  if (typeof w.gamesAppPlatform === 'undefined') {
    w.gamesAppPlatform = determineGamesAppPlatform()
  }

  /**
   * Determine if the user is in a webview from the Crossword app
   */
  if (typeof w.isPlayTab === 'undefined') {
    w.isPlayTab = determinePlayTab()
  }

  /**
   * Determine if the user is on an ios device
   */
  if (typeof w.isIOSDevice === 'undefined') {
    w.isIOSDevice = isIOSDevice(ua)
  }

  /**
   * Determine if the user is on an android device
   */
  if (typeof w.isAndroidDevice === 'undefined') {
    w.isAndroidDevice = isAndroidDevice(ua)
  }

  /**
   * Determine if the user is on a mobile device.
   * Returns true for tablets, which are missed by
   * isMobileBrowser but caught by the device checks.
   */
  if (typeof w.isMobileDevice === 'undefined') {
    w.isMobileDevice = isMobileDevice(ua)
  }

  /**
   * Parse the version of the games app the user might be on
   */
  if (typeof w.gamesAppVersion === 'undefined') {
    w.gamesAppVersion = getAppVersion(ua, w.gamesAppPlatform)
  }

  /**
   * Parse the version of the newsreader app the user might be on
   */
  if (typeof w.newsreaderAppVersion === 'undefined') {
    w.newsreaderAppVersion = getNewsreaderVersion(ua)
  }

  /**
   * For Games that are cached in Fastly, determine here whether or not to enable
   * them to use Hybrid Webviews.
   *
   * For Games, not cached in Fastly yet, see server/util/createPageProps.js
   */
  const isHybridEnabledPage = (pageName: string) => {
    const HYBRID_ENABLED_PAGES = [
      'wordle',
      'sudoku',
      'tiles',
      'letter-boxed',
      'spelling-bee',
    ] as const

    return !!HYBRID_ENABLED_PAGES.find((enabledPage) =>
      pageName.includes(enabledPage),
    )
  }

  const params = getParams()

  /**
   * Rather than determine we're in a hybrid webview by sniffing the user agent, we
   * will check for the existence of the NYTG property, which is present when a
   * browser is a webview that has hybrid capabilities. Additionally, let's allow
   * this to be mocked when running in a unit test or local browser environment.
   *
   * Before setting this value we check to see if the server wrote it out. This ensures
   * backwards compatibility for games still server rendering this value.
   */
  if (typeof w.isHybridWebView === 'undefined') {
    const pageName = w.pageName || ''

    /**
     * Rules for determining whether or not to enable
     * a hybrid game in Phoenix
     */
    w.isHybridWebView =
      isHybridOptIn(ua) ||
      // There needs to be an NYTG property
      (typeof w.NYTG !== 'undefined' &&
        // This must be a page we enabled
        isHybridEnabledPage(pageName) &&
        !!determineGamesAppPlatform())
  }

  // If we are mocking for local dev or testing, force to true
  if (params.get('bridge') === 'mock') {
    w.isHybridWebView = true
  }
}
