import { useEffect } from 'react'

import type { UserType } from 'foundation'

import { parsePurrCookieValue } from '../foundation/js/parsePurrCookieValue'

const update = (
  classesToAdd: string[],
  classesToRemove: string[] = [],
) => {
  const body = document.querySelector('body')

  if (body) {
    body.classList.remove(...classesToRemove)
    body.classList.add(...classesToAdd)
  }
}

function useBody() {
  function setUserType(user: UserType) {
    const classNamesToAdd = []
    const classNamesToRemove = []

    if (user.hasXwd) {
      classNamesToAdd.push('pz-sub')
      if (user.hasDigi) {
        classNamesToAdd.push('pz-ada')
      }
      classNamesToRemove.push('pz-anon')
    } else if (user.hasDigi) {
      classNamesToAdd.push('pz-digi')
      classNamesToRemove.push('pz-anon')
    } else if (user.isLoggedIn) {
      classNamesToAdd.push('pz-regi')
      classNamesToRemove.push('pz-anon')
    } else {
      classNamesToAdd.push('pz-anon')
    }

    update(classNamesToAdd, classNamesToRemove)
  }

  /**
   * Set the PURR directive classes, and remove the loading state
   */
  useEffect(() => {
    const directives = parsePurrCookieValue()
    const add = []
    const remove = ['pz-loading']

    if (directives.PURR_AdConfiguration_v3) {
      add.push(
        `pz-purr-adconfiguration-${directives.PURR_AdConfiguration_v3}`,
      )
    }

    if (directives.PURR_CaliforniaNoticesUI) {
      add.push(
        `pz-purr-californianotices-${directives.PURR_CaliforniaNoticesUI}`,
      )
    }

    if (directives.PURR_DataSaleOptOutUI_v2) {
      add.push(
        `pz-purr-datasaleoptout-${
          directives.PURR_DataSaleOptOutUI_v2 === 'hide'
            ? 'hide'
            : 'show'
        }`,
      )
    }

    if (directives.PURR_LimitSensitivePI) {
      add.push(
        `pz-purr-limitsensitivepi-${directives.PURR_LimitSensitivePI}`,
      )
    }

    if (directives.PURR_FidesTCF) {
      add.push(
        `pz-purr-fidestcf-${
          directives.PURR_FidesTCF === 'hide' ? 'hide' : 'show'
        }`,
      )
    }

    update(add, remove)
  }, [])

  return {
    setUserType,
    update,
  }
}

export default useBody
export { update as setBodyClasses }
