import React, { Component, useEffect, useState } from 'react'
import pt from 'prop-types'
import cn from 'classnames'

import { useUser } from 'user'

import { trackImpression } from '../../../games/helpers/tracking'
import Error from '../../components/Error/Error'
import '../../error-page/index.scss'

import { Stats, fetchStats } from './api'
import StatsOverview from './StatsOverview'
import WeeklyStats from './WeeklyStats'
import Upsell from './Upsell'
import Loader from './Loader'

const StatsContainer = () => {
  const [stats, setStats] = useState<any>(undefined)
  const [loading, setLoading] = useState<boolean>(true)
  const [error, setError] = useState<boolean>(false)
  const { userType, hasLoaded } = useUser()
  const { regiId, hasXwd, isLoggedIn } = userType
  const subscribe = window?.navigationLinks?.subscribe?.default
  const login = window?.navigationLinks?.login

  useEffect(() => {
    if (hasLoaded) {
      const getStats = async () => {
        try {
          const data = await fetchStats(regiId)
          if (data) {
            setStats(data)
          }
        } catch (error) {
          setError(true)
        } finally {
          setLoading(false)
        }
      }
      getStats()
    }
  }, [hasLoaded, regiId])

  useEffect(() => {
    if (hasLoaded && !loading && !hasXwd) {
      trackImpression('hardpaywall', 'stats')
    }
  }, [hasLoaded, hasXwd])

  return (
    <div>
      {loading && <Loader />}
      {!loading && error && (
        <Error
          error={{ status: 500 }}
          navigationLinks={window.navigationLinks}
        />
      )}
      <div className="stats-content">
        {stats && <StatsOverview {...stats} />}
        {stats && <WeeklyStats {...stats} />}
        {hasLoaded && !loading && !hasXwd && (
          <Upsell
            subscribe={subscribe}
            login={login}
            userType={userType}
          />
        )}
      </div>
    </div>
  )
}

export default StatsContainer
