import React from 'react'

import { getButtonText } from '../../../server/views/components/Marketing/Sale/functions'

type UpsellProps = {
  subscribe: string
  login: string
  userType: {
    entitlement: string
    isLoggedIn: boolean
  }
}

const Upsell = (props: UpsellProps) => {
  const { subscribe, login, userType } = props
  const { entitlement, isLoggedIn } = userType

  const saleButtonText = getButtonText(
    entitlement || '',
  ).toUpperCase()

  return (
    <section id="subscribe">
      <div className="overlay-container">
        <div className="overlay-body">
          <div className="image-container" />
          <div className="info-container">
            <h1 className="upsell-title">
              Looking for your longest streak?
            </h1>
            <p>
              Track your progress and access more than 9000 New York
              Times daily puzzles with a crossword subscription.
            </p>
            <a className="subscribe-button default" href={subscribe}>
              <span>SUBSCRIBE</span>
            </a>
            <a className="subscribe-button sale" href={subscribe}>
              <span>{saleButtonText}</span>
            </a>
            {isLoggedIn ? null : (
              <p className="tiny-text">
                Already a subscriber?{' '}
                <a className="log-in" href={`${login}&asset=stats`}>
                  LOG IN
                </a>
              </p>
            )}
          </div>
        </div>
      </div>
    </section>
  )
}

export default Upsell
