import React, { useEffect } from 'react'

import SingleDayStats from './SingleDayStats'
import { dayClickHandler } from './helper'

export type Day = {
  label: string
  isToday: boolean
  averageTime: number
  latestTime: number
  bestTime: number
  bestDate: string
  fastestTime: number
  slowestTime: number
}

type WeeklyStatsProps = {
  byDay: Array<Day>
  fastestTime: number
  slowestTime: number
}
const WeeklyStats = (props: WeeklyStatsProps) => {
  useEffect(() => {
    const days = document.querySelectorAll('.single-day')
    days.forEach((day) => {
      day.addEventListener('click', () => {
        dayClickHandler(day)
      })
    })
  }, [])
  const { byDay, fastestTime, slowestTime } = props
  return (
    <section id="weekly-stats">
      <div className="header">
        <h1 className="stats-subheader">Daily Solve Times</h1>
      </div>
      <div className="container clearfix">
        {byDay.map((day: Day) => (
          <SingleDayStats
            key={day.label}
            label={day.label}
            fastestTime={fastestTime}
            slowestTime={slowestTime}
            bestDate={day.bestDate}
            bestTime={day.bestTime}
            latestTime={day.latestTime}
            averageTime={day.averageTime}
            isToday={day.isToday}
          />
        ))}
      </div>
    </section>
  )
}

export default WeeklyStats
