import React from 'react'

import { camelizeKeysDeep } from '../../hub/utils/miscellany'
import { PuzzleIconAndRibbon } from '../../hub/SponsoredCard/SponsoredCard'

import { Puzzle, TipPuzzle } from './helper'

const PuzzleIcon = ({ puzzle }: { puzzle: Puzzle }) => {
  const isMini = puzzle.publish_type === 'Mini'
  const adaptedPuzzle = {
    action: 'PLAY',
    iconType: isMini ? 'mini' : 'puzzle',
    ...camelizeKeysDeep(puzzle),
    isSolved: puzzle.solved || false,
  }

  return (
    <div className="puzzleContainer">
      <a href={puzzle.link} className="puzzleAction">
        <PuzzleIconAndRibbon puzzle={adaptedPuzzle} />
        <div className="puzzleType">
          {isMini ? 'MINI' : 'FULL-SIZE'}
        </div>
      </a>
    </div>
  )
}

export const TipOrTrick = ({
  puzzle,
  itemNo,
}: {
  puzzle: TipPuzzle
  itemNo: number
}) => {
  const { title, description, mini, full } = puzzle
  return (
    <div className="tipOrTrick">
      <div className="details">
        <h2>{`${itemNo}. ${title}`}</h2>
        <p>{description}</p>
      </div>
      <div className="puzzles">
        <PuzzleIcon puzzle={mini} />
        <PuzzleIcon puzzle={full} />
      </div>
    </div>
  )
}
