import React, { Component, useEffect, useState } from 'react'

import { useUser } from 'user'

import { fetchPuzzleProgress } from '../../hub/api/api'
import logger from '../../../games/shared/utils/clientLogger'

import { tipPuzzles, puzzleIds, Puzzle, TipPuzzles } from './helper'
import { TipOrTrick } from './TipAndTrick'

const TipsAndTricksContainer = () => {
  const { userType, hasLoaded } = useUser()
  const { hasXwd, regiId } = userType

  const [puzzles, setPuzzles] = useState([...tipPuzzles])
  useEffect(() => {
    if (hasLoaded && hasXwd && regiId) {
      fetchPuzzleProgress(regiId, puzzleIds)
        .then((data) => {
          const newPuzzles = puzzles.reduce<TipPuzzles>(
            (filledIn, tip) =>
              filledIn.concat([
                {
                  ...tip,
                  ...{
                    mini: { ...tip.mini, ...data[tip.mini.id] },
                    full: { ...tip.full, ...data[tip.full.id] },
                  },
                },
              ]),
            [],
          )
          setPuzzles(newPuzzles)
        })
        .catch((error) => {
          logger.error(
            `fetch tips and tricks puzzle progress failed: ${error.stack}`,
          )
        })
    }
  }, [userType])
  return (
    <div className="tipsAndTricks">
      <h1>Tips & Tricks Tutorial</h1>
      <div className="tipsAndTricks--divider" />
      <p>
        Make some sense of The New York Times Crossword. Here are some
        common clue patterns and how to solve them.
      </p>
      {puzzles.map((puzzle, idx) => {
        return (
          <TipOrTrick
            puzzle={puzzle}
            itemNo={idx + 1}
            key={puzzle.title}
          />
        )
      })}
    </div>
  )
}

export default TipsAndTricksContainer
