export type Puzzle = {
  id: number
  link: string
  publish_type: 'Mini' | 'Daily'
  format_type: 'Normal'
  solved?: boolean
}

export type TipPuzzle = {
  title: string
  description: string
  mini: Puzzle
  full: Puzzle
}

export type TipPuzzles = TipPuzzle[]

export const tipPuzzles: TipPuzzles = [
  {
    title: 'Clue/Answer Agreement',
    description:
      'The clue and answer must agree in tense, part of speech, and even language. In addition, abbreviated clues indicate an abbreviated answer.',
    mini: {
      id: 9501,
      link: '/crosswords/game/mini/tips-and-tricks/clue-answer-agreement',
      publish_type: 'Mini',
      format_type: 'Normal',
    },
    full: {
      id: 7680,
      link: '/crosswords/game/daily/2014/01/13',
      publish_type: 'Daily',
      format_type: 'Normal',
    },
  },
  {
    title: 'Question Mark Clues',
    description:
      'Clues that end in question marks indicate a play on words in the clue or answer.',
    mini: {
      id: 9505,
      link: '/crosswords/game/mini/tips-and-tricks/question-mark-clues',
      publish_type: 'Mini',
      format_type: 'Normal',
    },
    full: {
      id: 3786,
      link: '/crosswords/game/daily/2012/03/05',
      publish_type: 'Daily',
      format_type: 'Normal',
    },
  },
  {
    title: 'Crosswordese',
    description:
      'There are a lot of short words that appear in crosswords much more often than in real life. Mastering these 3- and 4-letter “repeater” answers will give you a leg up in solving.',
    mini: {
      id: 9503,
      link: '/crosswords/game/mini/tips-and-tricks/crosswordese',
      publish_type: 'Mini',
      format_type: 'Normal',
    },
    full: {
      id: 2955,
      link: '/crosswords/game/daily/2012/12/03',
      publish_type: 'Daily',
      format_type: 'Normal',
    },
  },
  {
    title: 'Themes',
    description:
      'Every Sunday-Thursday NYT crossword has a theme, something that unites the puzzle’s longest answers. Theme answers are always found in symmetrical places in the grid.',
    mini: {
      id: 9506,
      link: '/crosswords/game/mini/tips-and-tricks/themes',
      publish_type: 'Mini',
      format_type: 'Normal',
    },
    full: {
      id: 7826,
      link: '/crosswords/game/daily/2014/03/10',
      publish_type: 'Daily',
      format_type: 'Normal',
    },
  },
  {
    title: 'Rebus Answers',
    description:
      'The occasional puzzle (usually on Thursday or Sunday) will require you to enter multiple letters into a single square, which is called a rebus.',
    mini: {
      id: 9504,
      link: '/crosswords/game/mini/tips-and-tricks/rebus-answers',
      publish_type: 'Mini',
      format_type: 'Normal',
    },
    full: {
      id: 77,
      link: '/crosswords/game/daily/2004/03/15',
      publish_type: 'Daily',
      format_type: 'Normal',
    },
  },
]

export const puzzleIds = tipPuzzles.reduce<number[]>(
  (ids, tip) => ids.concat([tip.mini.id, tip.full.id]),
  [],
)
