import {
  getUserEntitlement,
  createUserInfoObject,
} from '../userHelpers'

jest.mock('foundation', () => ({}))

describe('USER: HELPERS', () => {
  describe('getUserEntitlement()', () => {
    it('detects anon uses', () => {
      const isLoggedIn = false
      const hasDigi = false
      const hasXwd = false
      expect(getUserEntitlement(isLoggedIn, hasDigi, hasXwd)).toBe(
        'anon',
      )
    })

    it('detects digital subscribers w/o a games subscription', () => {
      const isLoggedIn = true
      const hasDigi = true
      const hasXwd = false
      expect(getUserEntitlement(isLoggedIn, hasDigi, hasXwd)).toBe(
        'sub',
      )
    })

    it('detects digital subscribers w/ a games subscription', () => {
      const isLoggedIn = true
      const hasDigi = true
      const hasXwd = true
      expect(getUserEntitlement(isLoggedIn, hasDigi, hasXwd)).toBe(
        'sub,cr',
      )
    })

    it('detects games subscribers', () => {
      const isLoggedIn = true
      const hasDigi = false
      const hasXwd = true
      expect(getUserEntitlement(isLoggedIn, hasDigi, hasXwd)).toBe(
        'cr',
      )
    })

    it('detects registered users', () => {
      const isLoggedIn = true
      const hasDigi = false
      const hasXwd = false
      expect(getUserEntitlement(isLoggedIn, hasDigi, hasXwd)).toBe(
        'reg',
      )
    })
  })

  describe('createUserInfoObject()', () => {
    it('returns a default UserInfo if provided no query response', () => {
      expect(createUserInfoObject()).toEqual({
        regiId: undefined,
        isLoggedIn: false,
        hasXwd: false,
        hasDigi: false,
        hasHd: false,
        entitlement: 'anon',
        inShortzMode: false,
      })
    })

    it('returns regi information', () => {
      const mockUserQueryResponseData = {
        user: {
          userInfo: {
            regiId: '123456',
            subscriptions: [],
          },
        },
      }

      expect(createUserInfoObject(mockUserQueryResponseData)).toEqual(
        {
          regiId: '123456',
          isLoggedIn: true,
          hasXwd: false,
          hasDigi: false,
          hasHd: false,
          entitlement: 'reg',
          inShortzMode: false,
        },
      )
    })

    it('returns home delivery subscription status', () => {
      const mockUserQueryResponseData = {
        user: {
          userInfo: {
            regiId: '123456',
            subscriptions: ['FOO', 'BAR', 'HD'],
          },
        },
      }

      expect(createUserInfoObject(mockUserQueryResponseData)).toEqual(
        {
          regiId: '123456',
          isLoggedIn: true,
          hasXwd: false,
          hasDigi: false,
          hasHd: true,
          entitlement: 'reg',
          inShortzMode: false,
        },
      )
    })

    it('returns digital subscription status', () => {
      const mockUserQueryResponseData = {
        user: {
          userInfo: {
            regiId: '123456',
            subscriptions: ['MM'],
          },
        },
      }

      expect(createUserInfoObject(mockUserQueryResponseData)).toEqual(
        {
          regiId: '123456',
          isLoggedIn: true,
          hasXwd: false,
          hasDigi: true,
          hasHd: false,
          entitlement: 'sub',
          inShortzMode: false,
        },
      )
    })

    it('returns games subscription status', () => {
      const mockUserQueryResponseData = {
        user: {
          userInfo: {
            regiId: '123456',
            subscriptions: ['XWD'],
          },
        },
      }

      expect(createUserInfoObject(mockUserQueryResponseData)).toEqual(
        {
          regiId: '123456',
          isLoggedIn: true,
          hasXwd: true,
          hasDigi: false,
          hasHd: false,
          entitlement: 'cr',
          inShortzMode: false,
        },
      )
    })
  })
})
