import React from 'react'
import { shallow } from 'enzyme'

import * as userHooks from '../../useUser'
import Login from '../Login'

jest.mock('foundation', () => ({
  appendSupportedParams: () => 'foo',
}))

describe('USER: LOGIN BUTTON', () => {
  beforeAll(() => {
    window.navigationLinks = {}
  })

  it('does not render if user information has not loaded', () => {
    jest.spyOn(userHooks, 'default').mockImplementation(() => ({
      userType: {
        isLoggedIn: false,
      },
      hasLoaded: false,
    }))
    const login = shallow(<Login />)
    const button = login.find('.pz-nav__button')
    expect(button).toHaveLength(0)
  })

  it('does not render if user is logged in', () => {
    jest.spyOn(userHooks, 'default').mockImplementation(() => ({
      userType: {
        isLoggedIn: true,
      },
      hasLoaded: true,
    }))
    const login = shallow(<Login />)
    const button = login.find('.pz-nav__button')
    expect(button).toHaveLength(0)
  })

  it('renders if user is not logged in', () => {
    jest.spyOn(userHooks, 'default').mockImplementation(() => ({
      userType: {
        isLoggedIn: false,
      },
      hasLoaded: true,
    }))
    const login = shallow(<Login />)
    const button = login.find('.pz-nav__button')
    expect(button).toHaveLength(1)
  })
})
