import React from 'react'
import { shallow } from 'enzyme'

import * as userHooks from '../../useUser'
import Logout from '../Logout'

jest.mock('foundation', () => ({}))

describe('USER: LOGOUT BUTTON', () => {
  beforeAll(() => {
    window.navigationLinks = {}
  })

  it('does not render if user information has not loaded', () => {
    jest.spyOn(userHooks, 'default').mockImplementation(() => ({
      userType: {
        isLoggedIn: false,
      },
      hasLoaded: false,
    }))
    const logout = shallow(<Logout />)
    const button = logout.find('.pz-nav__button')
    expect(button).toHaveLength(0)
  })

  it('does not render if user is not logged in', () => {
    jest.spyOn(userHooks, 'default').mockImplementation(() => ({
      userType: {
        isLoggedIn: false,
      },
      hasLoaded: true,
    }))
    const logout = shallow(<Logout />)
    const button = logout.find('.pz-nav__button')
    expect(button).toHaveLength(0)
  })

  it('renders if user is logged in', () => {
    jest.spyOn(userHooks, 'default').mockImplementation(() => ({
      userType: {
        isLoggedIn: true,
      },
      hasLoaded: true,
    }))
    const logout = shallow(<Logout />)
    const button = logout.find('.pz-nav__button')
    expect(button).toHaveLength(1)
  })
})
