import React from 'react'
import { shallow } from 'enzyme'

import * as userHooks from '../../useUser'
import Profile from '../Profile'

jest.mock('foundation', () => ({}))

describe('USER: PROFILE SECTION', () => {
  beforeAll(() => {
    window.navigationLinks = {}
  })

  it('does not render if user information has not loaded', () => {
    jest.spyOn(userHooks, 'default').mockImplementation(() => ({
      userType: {
        isLoggedIn: false,
      },
      hasLoaded: false,
    }))
    const profile = shallow(<Profile />)
    const heading = profile.find('.pz-nav-drawer__heading')
    expect(heading).toHaveLength(0)
  })

  it('does not render if user is not logged in', () => {
    jest.spyOn(userHooks, 'default').mockImplementation(() => ({
      userType: {
        isLoggedIn: false,
      },
      hasLoaded: true,
    }))
    const profile = shallow(<Profile />)
    const heading = profile.find('.pz-nav-drawer__heading')
    expect(heading).toHaveLength(0)
  })

  it('renders if user is logged in', () => {
    jest.spyOn(userHooks, 'default').mockImplementation(() => ({
      userType: {
        isLoggedIn: true,
      },
      hasLoaded: true,
    }))
    const profile = shallow(<Profile />)
    const heading = profile.find('.pz-nav-drawer__heading')
    expect(heading).toHaveLength(1)
    const link = profile.find('.pz-nav-drawer__link')
    expect(link).toHaveLength(1)
  })
})
