import React from 'react'
import { shallow } from 'enzyme'

import * as userHooks from '../../useUser'
import Subscribe from '../Subscribe'

jest.mock('foundation', () => ({}))

describe('USER: SUBSCRIBE BUTTON', () => {
  beforeAll(() => {
    window.navigationLinks = {
      subscribe: {},
    }
  })

  it('does not render if user information has not loaded', () => {
    jest.spyOn(userHooks, 'default').mockImplementation(() => ({
      userType: {
        hasXwd: false,
      },
      hasLoaded: false,
    }))
    const subscribe = shallow(<Subscribe />)
    const button = subscribe.find('.pz-nav__button')
    expect(button).toHaveLength(0)
  })

  it('does not render if user has a subscription', () => {
    jest.spyOn(userHooks, 'default').mockImplementation(() => ({
      userType: {
        hasXwd: true,
      },
      hasLoaded: true,
    }))
    const subscribe = shallow(<Subscribe />)
    const button = subscribe.find('.pz-nav__button')
    expect(button).toHaveLength(0)
  })

  it('renders if user does not have a subscription', () => {
    jest.spyOn(userHooks, 'default').mockImplementation(() => ({
      userType: {
        hasXwd: false,
      },
      hasLoaded: true,
    }))
    const subscribe = shallow(<Subscribe />)
    const button = subscribe.find('.pz-nav__button')
    expect(button).toHaveLength(1)
  })
})
