// TODO: This package has been deprecated! https://www.npmjs.com/package/clipboard-polyfill
import * as clipboard from 'clipboard-polyfill/text'

import { isMobileBrowser } from 'shared/responsive'
import { isFirefox } from 'shared/utils/deviceIdentifiers'

import { isAndroidHybridWebview } from '../foundation/js/hybrid/detection'

/**
 * This looks incorrect, but apparently on Android, sharing the Wordle text score needs to
 * go in the url field of the actual share command otherwise it wont work. This is a hack and needs
 * to be resolved on the native side to make every command and every webview have consistent
 * command implementations.
 */
export function bridgeCommandShare(text: string) {
  window.NativeBridge?.share(text, '', '')
}

export function browserShare(
  message: { text: string },
  onCopy: () => void,
  onFail: () => void,
) {
  if (
    isMobileBrowser() &&
    !isFirefox() &&
    navigator.share !== undefined &&
    !!navigator.canShare &&
    navigator.canShare(message)
  ) {
    navigator.share(message).catch(() => {
      // most of these failures will be because the user intentionally aborted the operation
      // we might want to capture in analytics at some point
      // we don't want to call onFail because likely this was intentional
    })
  } else {
    clipboard
      .writeText(message.text)
      .then(onCopy, onFail)
      .catch((e) => {
        onFail()
        console.warn('Share failed', e)
      })
  }
}

/**
 * Hacky solve for android newsreader, which does not support
 * navigator.share or clipboard.writeText, and does not have the native bridge.
 * document.execCommand is deprecated, so hopefully we don't have to keep this around too long.
 * Once wordle is hybridized in newsreader we can delete this.
 */
const androidNewsShare = (
  message: { text: string },
  onCopy: () => void,
  onFail: () => void,
  event: React.MouseEvent<HTMLButtonElement>,
) => {
  try {
    const target = event.target as HTMLElement
    // use textarea instead of input so \n works
    const tempInput = document.createElement('textarea')
    tempInput.style.position = 'absolute'
    tempInput.style.left = '-1000px'
    tempInput.style.top = '-1000px'
    tempInput.value = message.text
    // append faux input to parent element so that it is not triggered as outside current modal for a11y
    target.parentElement!.appendChild(tempInput)
    tempInput.select()
    document.execCommand('copy')
    target.parentElement!.removeChild(tempInput)
    onCopy()
  } catch (e) {
    onFail()
    console.warn('Share failed', e)
  }
}

export function share(
  message: { text: string },
  onCopy: () => void,
  onFail: () => void,
  event: React.MouseEvent<HTMLButtonElement>,
) {
  // Android webviews do not support navigator.share so we must
  // use a bridge command for hybrid webviews on Android
  if (isAndroidHybridWebview()) {
    bridgeCommandShare(message?.text)
  } else if (window.newsreaderAppPlatform === 'android') {
    androidNewsShare(message, onCopy, onFail, event)
  } else {
    browserShare(message, onCopy, onFail)
  }
}
