const webpack = require('webpack')

const logger = require('../src/serverLogger')
const {
  RUNTIME_ENV,
  IS_DRONE_BUILD,
  USE_DIST,
  ROUTE_ASSETS,
  ROUTE_DIST,
} = require('../src/constants')
const webpackConfig = require('../webpack.config')

const cleanDistFolder = require('./clean')
const checkFileSize = require('./checkFileSize')
const copyPublic = require('./copyPublic')
const fetchShortz = require('./fetchShortz')

logger.headingInfo('building files')
logger.labeledInfo('IS_DRONE_BUILD', IS_DRONE_BUILD)
logger.labeledInfo('RUNTIME_ENV', RUNTIME_ENV || 'dev')
logger.labeledInfo('USE_DIST', USE_DIST || 'false')
logger.labeledInfo('ROUTE_ASSETS', ROUTE_ASSETS)
logger.labeledInfo('ROUTE_DIST', ROUTE_DIST)

const logBuildTime = logger.checkTime('total build time')

cleanDistFolder()

const webpackPromise = new Promise((resolve, reject) => {
  webpack(webpackConfig, (err, stats) => {
    if (err) {
      reject(err)
    }

    if (stats.hasErrors()) {
      const info = stats.toJson()
      reject(info.errors)
    }

    resolve()
  })
})

webpackPromise
  .then(copyPublic)
  .then(fetchShortz)
  .then(checkFileSize)
  .then(logBuildTime)
  .catch((err) => {
    console.error(err)
    process.exitCode = 1
  })
