const path = require('path')

const fs = require('fs-extra')
const uglify = require('uglify-js')
const coreJSBuilder = require('core-js-builder')

const logger = require('../src/serverLogger')
const { VENDOR_ROOT } = require('../src/constants')

module.exports = () => {
  logger.headingInfo('Creating core polyfills')

  coreJSBuilder({
    modules: [
      'es6',
      'es7.array.includes',
      'es7.object.entries',
      'es7.object.values',
      'es.promise.finally',
      'web.immediate',
      'web.dom.iterable',
    ],
    blacklist: ['es6.reflect', 'es6.math', 'es6.symbol', 'es6.typed'],
    library: false, // flag for build without global namespace pollution, by default - false
    umd: false, // use UMD wrapper for export `core` object, by default - true
  })
    .then((code) => {
      const howLong = logger.checkTime('total time')
      const output = path.resolve(VENDOR_ROOT, 'polyfills.js')
      const compressed = uglify.minify(code).code
      return fs.ensureFile(output).then(() => {
        return fs.writeFile(output, compressed).then(howLong)
      })
    })
    .catch((err) => {
      logger.error(err)
    })
}

module.exports(logger)
