require('dotenv').config()

const webpack = require('webpack')

const webpackConfig = require('../webpack.config')
const logger = require('../src/serverLogger')
const { RUNTIME_ENV } = require('../src/constants')

const fetchShortz = require('./fetchShortz')
const devServer = require('./devServer')
const cleanDistFolder = require('./clean')

let hasStarted = false
const startOrRestartServer = (err) => {
  if (!hasStarted) {
    devServer.create()
    hasStarted = true
  } else {
    devServer.restart(err)
  }
}

const dev = async () => {
  logger.headingInfo('watch')
  logger.labeledInfo('RUNTIME_ENV', RUNTIME_ENV || 'dev')

  cleanDistFolder()
  await fetchShortz()

  webpack(webpackConfig).watch({}, (err, stats) => {
    if (err) {
      console.error(err.stack || err)
      if (err.details) {
        console.error(err.details)
      }

      startOrRestartServer(err)
      return
    }

    const info = stats.toJson()

    if (stats.hasErrors()) {
      console.error(info.errors)
    }

    if (stats.hasWarnings()) {
      console.warn(info.warnings)
    }

    console.log(
      stats.toString({
        chunks: false, // Makes the build much quieter
        colors: true, // Shows colors in the console
      }),
    )

    startOrRestartServer()
  })
}

dev()
