#!/usr/bin/env bash
set -e

git prune && git fetch --prune --quiet
sandbox_branches=$(git branch -r | tr -d ' ' | sed -e 's,origin/,,' | sed -e 's/\..*//' | sed -e 's,deploy/,,' | sort)
sandbox_namespaces=$(kubectl get ns --output=name | grep 'phoenix\-deploy\-' | sed -e 's,namespace/,,' | sed -e 's,phoenix\-deploy\-,,' | sort)
sandbox_namespaces_active=()
sandbox_namespaces_inactive=()

echo "git deploy branches ======"
echo $sandbox_branches
echo "kube namespaces ======"
echo $sandbox_namespaces

for ns in $sandbox_namespaces; do
  if echo ${sandbox_branches[@]} | grep -q -w "$ns"; then
    # namespace has corresponding git branch
    sandbox_namespaces_active+=("$ns")
  else
    # namespace does not have a corresponding git branch
    sandbox_namespaces_inactive+=("$ns")
  fi
done

# delete any inactive sandbox versions
if [ -n "$sandbox_namespaces_inactive" ]; then
  echo "Deleting sandboxes without a corresponding git branch:"
  printf "* deploy-%s \n" "${sandbox_namespaces_inactive[@]}"
  echo ""
  sandbox_namespaces_with_prefix=$(printf "phoenix-deploy-%s " "${sandbox_namespaces_inactive[@]}")
  kubectl delete ns ${sandbox_namespaces_with_prefix[@]}
  # TODO Change permissions to be able to do this. 
  # This would be a straightforward IAM switch, but creds are for nyt-games-dev, and this needs nyt-games-prd storage access.
  # Error:
  # AccessDeniedException: 403 games-drone@nyt-games-dev.iam.gserviceaccount.com does not have storage.objects.list access to games-assets.

  # gsutil rm -r gs://games-assets/deployments/${sandbox_namespaces_inactive[@]}
  echo "Done."
else
  echo "No sandbox namespaces to delete. Done."
fi