#!/usr/bin/env bash

source ./tools/tiles/shared-tiles-utils.sh

echo "
 _____ _____ ___  ___ _  _   _  ___  _  _  ___
| __\ V / o \ __|| o \ || \_/ || __|| \| ||_ _|
| _| ) (|  _/ _| |   / || \_/ || _| | \\ | | |
|___/_n_\_| |___||_|\\_||_| |_||___||_|\_| |_|
"

echo "Type the name of the new experimental palette in kebab-case."
echo "  For instance, New Haven would be new-haven in kebab case."
echo "  When you are finished typing, hit the enter or return key:"
echo ""
echo ""
read -r name
echo ""
echo ""

echo "You typed: "
echo $name
echo ""

if [[ ! $name ]]; then
    echo "Name '${name}' is too short. Please try again."
    exit 1
fi

echo "Display Name: "
echo $name | tr '-' ' ' | awk '{for(i=1;i<=NF;i++){ $i=toupper(substr($i,1,1)) substr($i,2) }}1'
echo ""echo "Display Name: "
echo $name | tr '-' ' ' | awk '{for(i=1;i<=NF;i++){ $i=toupper(substr($i,1,1)) substr($i,2) }}1'
echo ""

if [ -f ./src/public/assets/tiles-game/palettes/${name}.svg ]; then
    echo "Ugh oh! Palette '${name}' already exists, please rename your palette and try again."
    exit 1
fi

echo "Searching in your Documents folder for a file called ${name}.svg..."
fileName="${name}.svg"
svgFileLocation="~/Documents/${fileName}"

if [ ! -f ~/Documents/${name}.svg ]; then
    echo "File ${fileName} not found in Documents."
    echo "Please check your Documents folder, make sure the svg file is at top-level, double-check casing, and try again."
    exit 1
fi

echo "File ${name}.svg found"

branchName=chore-tiles-palette-experiment-${name}
echo "Checking out a new branch called ${branchName}"
git checkout .
git checkout main
git pull origin main

# remove potential branch duplicates
git branch -D ${branchName}
git push -d origin ${branchName}

git checkout -b ${branchName}

echo "Moving ${fileName} into src/public/assets/tiles-game/palettes"
cp ~/Documents/${name}.svg ./src/public/assets/tiles-game/palettes/

echo "Adding ${name} to the experiments array..."

jq ".experiments |= . + [\"$name\"]" ./src/server/util/tilesConfig.json > tmp.json && mv tmp.json ./src/server/util/tilesConfig.json

echo "Adding the ${name} icon to the icons file..."

sed -e '$ d' ./src/public/assets/tiles-game/palettes/icons.svg > tmp.svg # everything except last line
awk '/id="icon"/{icon=1} icon {print} /<\/symbol>/{icon=0}' ./src/public/assets/tiles-game/palettes/${name}.svg >> tmp.svg
tail -1 ./src/public/assets/tiles-game/palettes/icons.svg >> tmp.svg # last line
mv tmp.svg ./src/public/assets/tiles-game/palettes/icons.svg

echo "  - Added the ${name} icon to the icons file!"

echo ""
echo "Adding all files and pushing them up to GitHub"
git add .
git commit -m "add new experimental palette ${name}" --no-verify
git push origin $branchName
echo ""
echo "Follow instructions below for creating a PR."

source ./tools/tiles/create-pr.sh "${branchName}" "feat: add new experimental palette ${name}"

echo ""
echo "If you have Shortz mode, you should be able to preview your new palette"
echo "at the link below in about 30 minutes on the VPN (be sure to log in):"
echo "  - https://games-${branchName}.dev.nytimes.com/puzzles/tiles"

echo ""
echo "Or, if you're in a hurry, you can log into drone here:"
echo "  - https://drone.dv.nyt.net/"
echo "Click 'Sync', wait for that process, then go here and find your branch ${branchName}:"
echo "  - https://drone.dv.nyt.net/nytimes/games-phoenix"
echo "Once it's green the preview environment should be live!"
echo ""
echo ""
echo ""
echo "That's it! Thanks for adding to our palettes, bye for now!"
