#!/usr/bin/env bash

source ./tools/tiles/shared-tiles-utils.sh

echo "
      __       __  ____    ____  _______
     |  |     |  | \   \  /   / |   ____|
     |  |     |  |  \   \/   /  |  |__
     |  |     |  |   \      /   |   __|
     |  |----.|  |    \    /    |  |____
     |_______||__|     \__/     |_______|
"
echo ""
echo ""

experimentCount=$(jq -r '.experiments | length' ./src/server/util/tilesConfig.json)
if [ "$experimentCount" -eq "0" ]; then
   echo "No Tiles experiments found. Please add a Tiles experiment before making it live."
   echo "  Do to this, run the following command:"
   echo "  - ./tools/tiles/add-experimental-palette.sh"
   echo ""
   echo ""
   exit;
fi

echo "Type the name of the live palette in kebab-case. It must match one of the following experiments: "
jq '.experiments' ./src/server/util/tilesConfig.json

echo "  When you are finished typing, hit the enter or return key:"
echo ""
echo ""
read -r name
echo ""
echo ""

echo "You typed: "
echo $name
echo ""

if [[ ! $name ]]; then
    echo "Name '${name}' is too short. Please try again."
    exit 1
fi

isValidPaletteName=$(jq "any(.experiments[] == \"${name}\"; .)" ./src/server/util/tilesConfig.json)
if [[ "$isValidPaletteName" = false ]] ; then
  echo "Name '${name}' not an experiment. Please add a Tiles experiment before making it live."
  echo "  Do to this, run the following command:"
  echo "  - ./tools/tiles/add-experimental-palette.sh"
  echo ""
  echo ""
  exit 1
fi

statusCode=$(curl -LI "https://www.nytimes.com/puzzles/tiles/palette/${name}" -o /dev/null -w '%{http_code}\n' -s)
if [[ ${statusCode} != *"200"* ]] ; then
  echo "Palette not found at https://www.nytimes.com/puzzles/tiles/palette/${name}"
  echo "  Did you remember to upload the palette to the Google bucket? You should see it in the list here:"
  echo "    - https://console.cloud.google.com/storage/browser/games-assets/v2/assets/tiles-game/palettes;tab=objects?project=nyt-games-prd"
  echo "If you do not, upload the svg file"

  exit 1
fi

branchName=feat-tiles-palette-live-${name}
echo "Checking out a new branch called ${branchName}"
git checkout .
git checkout main
git pull origin main

# remove potential branch duplicates
git branch -D ${branchName}
git push -d origin ${branchName}
git co -b ${branchName}

echo ""
echo "Removing ${name} from the experiments array..."
jq ".experiments |= . - [\"$name\"]" ./src/server/util/tilesConfig.json > tmp.json && mv tmp.json ./src/server/util/tilesConfig.json

echo ""
echo "Adding ${name} to the allPalettes array..."
jq ".allPalettes |= . + [\"$name\"]" ./src/server/util/tilesConfig.json > tmp.json && mv tmp.json ./src/server/util/tilesConfig.json

echo ""
echo "Adding ${name} to the most recent rotating array..."
jq ".configs[].palettes |= . + [\"$name\"]" ./src/server/util/tilesConfig.json > tmp.json && mv tmp.json ./src/server/util/tilesConfig.json

echo ""
echo "Adding all files and pushing them up to GitHub"
git add .
git commit -m "add new experimental palette ${name}" --no-verify
git push origin $branchName
echo ""

source ./tools/tiles/create-pr.sh "${branchName}" "feat: make palette ${name} live"

echo ""
echo ""
echo "That's it! Thanks for adding a new live palette, bye for now!"
echo ""
