#!/usr/bin/env bash

source ./tools/tiles/shared-tiles-utils.sh

echo "
 _____ _____ ___  ___ _  _   _  ___  _  _  ___
| __\ V / o \ __|| o \ || \_/ || __|| \| ||_ _|
| _| ) (|  _/ _| |   / || \_/ || _| | \\ | | |
|___/_n_\_| |___||_|\\_||_| |_||___||_|\_| |_|
  ____  _____ _   _    _    __  __ _____
 |  _ \| ____| \ | |  / \  |  \/  | ____|
 | |_) |  _| |  \| | / _ \ | |\/| |  _|
 |  _ <| |___| |\  |/ ___ \| |  | | |___
 |_| \_\_____|_| \_/_/   \_\_|  |_|_____|
"
echo ""
echo ""

experimentCount=$(jq -r '.experiments | length' ./src/server/util/tilesConfig.json)
if [ "$experimentCount" -eq "0" ]; then
   echo "No Tiles experiments found. Please add a Tiles experiment before making it live."
   echo "  Do to this, run the following command:"
   echo "  - ./tools/tiles/add-experimental-palette.sh"
   echo ""
   echo ""
   exit;
fi

echo "Type the name of the experimental palette you would like to rename in kebab-case."
echo "It must match one of the following experiments: "
jq '.experiments' ./src/server/util/tilesConfig.json

echo "  When you are finished typing, hit the enter or return key:"
echo ""
echo ""
read -r name
echo ""
echo ""

echo "You typed: "
echo $name
echo ""

if [[ ! $name ]]; then
    echo "Name '${name}' is too short. Please try again."
    exit 1
fi

isValidPaletteName=$(jq "any(.experiments[] == \"${name}\"; .)" ./src/server/util/tilesConfig.json)
if [[ "$isValidPaletteName" = false ]] ; then
  echo "Name '${name}' not an experiment. Please add a Tiles experiment before renaming."
  echo "  Do to this, run the following command:"
  echo "  - ./tools/tiles/add-experimental-palette.sh"
  echo ""
  echo ""
  exit 1
fi

echo "Type the name of the new name you would like to use for ${name}. Be sure to use kebab casing (ex. 'taos-light'):"
echo "  When you are finished typing, hit the enter or return key:"
echo ""
echo ""
read -r rename
echo ""
echo ""
echo "You typed: "
echo $rename
echo ""
echo "New Display Name: "
echo $rename | tr '-' ' ' | awk '{for(i=1;i<=NF;i++){ $i=toupper(substr($i,1,1)) substr($i,2) }}1'
echo ""

branchName=chore-rename-palette-${name}-to-${rename}
echo "Checking out a new branch called ${branchName}"
git checkout .
git checkout main
git pull origin main

 remove potential branch duplicates
git branch -D ${branchName}
git push -d origin ${branchName}
git co -b ${branchName}

echo ""
echo ""
echo "Starting the 4 rename steps:"

echo ""
echo "1. Removing ${name} from the experiments array..."
jq ".experiments |= . - [\"$name\"]" ./src/server/util/tilesConfig.json > tmp.json && mv tmp.json ./src/server/util/tilesConfig.json

echo ""
echo "2. Adding ${rename} to the experiments array..."
jq ".experiments |= . + [\"$rename\"]" ./src/server/util/tilesConfig.json > tmp.json && mv tmp.json ./src/server/util/tilesConfig.json

echo ""
echo "3. Renaming svg file..."
mv ./src/public/assets/tiles-game/palettes/${name}.svg ./src/public/assets/tiles-game/palettes/${rename}.svg

echo ""
echo "4. Updating sprite sheet..."
sed -i '' "s/id=\"${name}\"/id=\"${rename}\"/g" src/public/assets/tiles-game/palettes/icons.svg

echo ""
echo "Adding all changes to git and pushing them up to GitHub"
git add .
git commit -m "change name of tiles palette ${name} to ${rename}" --no-verify
git push origin $branchName
echo ""

source ./tools/tiles/create-pr.sh "${branchName}" "chore: rename experimental palette ${name} to ${rename}"

echo ""
echo ""
echo "That's it! Thanks for renaming an experimental palette, bye for now!"
echo ""
