const yargs = require('yargs/yargs')
const { hideBin } = require('yargs/helpers')

const { IS_DRONE_BUILD } = require('../src/constants')

/**
 * New entry points must be added here.
 *
 * The key should match the 'entry' passed to createPageProps.
 * The value is the path to the file, relative to webpack.config,
 * that serves as the root of the filetree for that entry point.
 * File extensions can be .js, .ts, or .tsx.
 */
const entries = {
  // games
  connections: './src/games/connections/index.tsx',
  crossword: './src/games/crossword/index.tsx',
  'letter-boxed': './src/games/letter-boxed/index.js',
  'spelling-bee': './src/games/spelling-bee/index.ts',
  sudoku: './src/games/sudoku/index.js',
  tiles: './src/games/tiles/index.js',
  vertex: './src/games/vertex/index.js',
  wordle: './src/games/wordle/index.tsx',

  // other
  apps: './src/shared/apps/index.js',
  'crossword-archive': './src/games/crossword-archive/index.js',
  'error-page': './src/shared/error-page/index.js',
  hub: './src/shared/hub/index.js',
  leaderboard: './src/shared/leaderboard/index.js',
  maintenance: './src/shared/maintenance-page/index.tsx',
  'spelling-bee-hub': './src/games/spelling-bee-hub/index.ts',
  stats: './src/shared/stats/index.js',
  testing: './src/shared/editorial-links/index.tsx',
  tipsandtricks: './src/shared/tips-and-tricks/index.js',

  // shortz
  connectionsshortz: './src/games/connections-v2/index.tsx',
  letterboxedshortz: './src/games/letter-boxed-shortz/index.tsx',
  spellingbeeshortz: './src/games/spelling-bee-shortz/index.tsx',
  tilesshortz: './src/games/tiles-shortz/index.tsx',
  vertexshortz: './src/games/vertex-shortz/index.js',
  wordleshortz: './src/games/wordle-shortz/index.tsx',
}

// handy dev tool for running one entry point to save a little build time
// e.g. npm run dev -- --entry=tiles
const {
  argv: { entry },
} = yargs(hideBin(process.argv))
const isSingleEntry = !IS_DRONE_BUILD && entry && entries[entry]

module.exports = isSingleEntry ? { [entry]: entries[entry] } : entries
